@@ -292,14 +292,14 @@ class addressbook_groupdav extends Api\CalDAV\Handler
 				if ($sync_collection_report)
 				{
 					list(,$sync_token) = explode('>', $filter[0]);
-					$where[] = 'list_modified>FROM_UNIXTIME('.(int)$sync_token.')';
+					if ((int)$sync_token) $where[] = 'list_modified>'.$GLOBALS['egw']->db->from_unixtime((int)$sync_token);
 				}
 				if (isset($filter[self::$path_attr]))	// multiget report?
 				{
 					$where['list_'.self::$path_attr] = $filter[self::$path_attr];
 				}
 				//error_log(__METHOD__."() filter=".array2string($filter).", do_groups=".in_array('D',$this->home_set_pref).", where=".array2string($where));
-				if (($lists = $this->bo->read_lists($where,'contact_uid',$where['list_owner'])))	// limit to contacts in same AB!
+				if ($where['id'] && ($lists = $this->bo->read_lists($where,'contact_uid',$where['list_owner'])))	// limit to contacts in same AB!
 				{
 					foreach($lists as $list)
 					{
