@@ -10,6 +10,7 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
 
 /**
  * Plugin to import vCard files
@@ -17,7 +18,7 @@
 class addressbook_import_vcard implements importexport_iface_import_plugin  {
 
 	private static $plugin_options = array(
-		
+
 		'contact_owner'
 	);
 
@@ -124,7 +125,7 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 		// Fix for Apple Addressbook
         $vCard = preg_replace('/item\d\.(ADR|TEL|EMAIL|URL)/', '\1', stream_get_contents($_stream));
 
-		$contacts = new egw_ical_iterator($vCard, '', $charset, array($this, '_vcard'),array(
+		$contacts = new Api\CalDAV\IcalIterator($vCard, '', $charset, array($this, '_vcard'),array(
 			// Owner (addressbook)
 			$contact_owner
 		));
@@ -147,7 +148,7 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 			$count++;
 			$contacts->next();
 		}
-		
+
 		return $count;
 	}
 
@@ -156,7 +157,7 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 	 */
 	public function _vcard($_vcard, $owner)
 	{
-		$charset = $_definition->plugin_options['charset'];
+		$charset = $this->definition->plugin_options['charset'];
 		if($charset == 'user') $charset = $GLOBALS['egw_info']['user']['preferences']['addressbook']['vcard_charset'];
 		$record = $this->bocontacts->vcardtoegw($_vcard,$charset);
 
@@ -166,8 +167,8 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 		if(!array_key_exists($record['owner'], $this->bocontacts->get_addressbooks()))
 		{
 			$this->errors[$this->current] = lang("Unable to import into %1, using %2",
-				common::grab_owner_name($record['owner']),
-				common::grab_owner_name($this->user)
+				Api\Accounts::username($record['owner']),
+				Api\Accounts::username($this->user)
 			);
 			$record['owner'] = $this->user;
 		}
@@ -201,8 +202,12 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 				// Only update if there are changes
 				$old = $this->bocontacts->read($_data['id']);
 				// if we get countrycodes as countryname, try to translate them -> the rest should be handled by bo classes.
-				foreach(array('adr_one_', 'adr_two_') as $c_prefix) {
-					if (strlen(trim($_data[$c_prefix.'countryname']))==2) $_data[$c_prefix.'countryname'] = $GLOBALS['egw']->country->get_full_name(trim($_data[$c_prefix.'countryname']),$translated=true);
+				foreach(array('adr_one_', 'adr_two_') as $c_prefix)
+				{
+					if (strlen(trim($_data[$c_prefix.'countryname']))==2)
+					{
+						$_data[$c_prefix.'countryname'] = Api\Country::get_full_name(trim($_data[$c_prefix.'countryname']), true);
+					}
 				}
 				// Don't change a user account into a contact
 				if($old['owner'] == 0) {
@@ -220,7 +225,7 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 				} else {
 					//error_log(__METHOD__.__LINE__.array2string($changed).' Old:'.$old['adr_one_countryname'].' ('.$old['adr_one_countrycode'].') New:'.$_data['adr_one_countryname'].' ('.$_data['adr_one_countryname'].')');
 				}
-				
+
 				// Make sure n_fn gets updated
 				unset($_data['n_fn']);
 
@@ -249,8 +254,8 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 					return $result;
 				}
 			default:
-				throw new egw_exception('Unsupported action: '. $_action);
-			
+				throw new Api\Exception('Unsupported action: '. $_action);
+
 		}
 	}
 
@@ -269,13 +274,13 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 
 		$record_class = get_class($this->preview_records[0]);
 
-		foreach($this->preview_records as $i => $record)
+		foreach($this->preview_records as $record)
 		{
 			// Convert to human-friendly
             importexport_export_csv::convert($record,$record_class::$types,$_definition->application);
 			$record = $record->get_record_array();
 			$row = array();
-			foreach($labels as $field => $label)
+			foreach(array_keys($labels) as $field)
 			{
 				$row[$field] = $record[$field];
 
@@ -289,7 +294,7 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
 			$row += $record;
 			$rows[] = $row;
 		}
-		return html::table($rows);
+		return Api\Html::table($rows);
 	}
 
 	/**
@@ -379,5 +384,4 @@ class addressbook_import_vcard implements importexport_iface_import_plugin  {
         public function get_results() {
                 return $this->results;
         }
-} // end of iface_export_plugin
-?>
+}
