@@ -90,7 +90,7 @@ app.classes.addressbook = AppJS.extend(
 		});
 	},
 
-/**
+	/**
 	 * Observer method receives update notifications from all applications
 	 *
 	 * App is responsible for only reacting to "messages" it is interested in!
@@ -253,7 +253,17 @@ app.classes.addressbook = AppJS.extend(
 			}
 			else
 			{
-				extras.owner.push('c'+ids);
+				// Check to see if this is a user account, we prefer to use
+				// account ID in calendar
+				var data = this.egw.dataGetUIDdata(_senders[i].id);
+				if(data && data.data && data.data.account_id)
+				{
+					extras.owner.push(data.data.account_id);
+				}
+				else
+				{
+					extras.owner.push('c'+ids);
+				}
 			}
 		}
 
@@ -488,7 +498,7 @@ app.classes.addressbook = AppJS.extend(
 			{
 				content.push({"confirm":id,"name":_data.doublicates[id]});
 			}
-			confirmdialog('Duplicate warning',content,et2_dialog.BUTTONs_OK_CANCEL);
+			confirmdialog(this.egw.lang('Duplicate warning'),content,et2_dialog.BUTTONs_OK_CANCEL);
 		}
 		if (typeof _data.fileas_options == 'object' && this.et2)
 		{
@@ -556,19 +566,58 @@ app.classes.addressbook = AppJS.extend(
 		}
 	},
 
-	add_new_list: function(owner)
+	/**
+	 * Add a new mailing list.  If any contacts are selected, they will be added.
+	 *
+	 * @param {egwAction} owner
+	 * @param {egwActionObject[]} selected
+	 */
+	add_new_list: function(owner, selected)
 	{
 		if(!owner || typeof owner == 'object')
 		{
 			var filter = this.et2.getWidgetById('filter');
 			owner = filter.getValue()||egw.preference('add_default','addressbook');
 		}
+		var contacts = [];
+		if(selected && selected[0] && selected[0].getAllSelected())
+		{
+			// Action says all contacts selected, better ask the server for _all_ the IDs
+			var fetching = fetchAll(selected, this.et2.getWidgetById('nm'), jQuery.proxy(
+				function(contacts) {
+					this._add_new_list_prompt(owner, contacts);
+				}, this));
+			if (fetching) return;
+		}
+		if(selected && selected.length)
+		{
+			for(var i = 0; i < selected.length; i++)
+			{
+				// Remove UID prefix for just contact_id
+				var ids = selected[i].id.split('::');
+				ids.shift();
+				ids = ids.join('::');
+				contacts.push(ids);
+			}
+		}
+		this._add_new_list_prompt(owner, contacts);
+	},
+
+	/**
+	 * Ask the user for a name, then create a new list with the provided contacts
+	 * in it.
+	 *
+	 * @param {int} owner
+	 * @param {String[]} contacts
+	 */
+	_add_new_list_prompt: function(owner, contacts)
+	{
 		var lists = this.et2.getWidgetById('filter2');
 		et2_dialog.show_prompt(
 			function(button, name) {
 				if(button == et2_dialog.OK_BUTTON)
 				{
-					egw.json('addressbook.addressbook_ui.ajax_set_list',[0, name, owner],
+					egw.json('addressbook.addressbook_ui.ajax_set_list',[0, name, owner, contacts],
 						function(result)
 						{
 							if(typeof result == 'object') return; // This response not for us
@@ -589,7 +638,7 @@ app.classes.addressbook = AppJS.extend(
 				}
 			},
 			this.egw.lang('Name for the distribution list'),
-			this.egw.lang('Add a new list...')
+			this.egw.lang('Add a new list')
 		);
 	},
 
@@ -638,16 +687,34 @@ app.classes.addressbook = AppJS.extend(
 		);
 	},
 
+	/**
+	 * OnChange for distribution list selectbox
+	 */
 	filter2_onchange: function()
 	{
+		var filter = this.et2.getWidgetById('filter');
 		var filter2 = this.et2.getWidgetById('filter2');
 		var widget = this.et2.getWidgetById('nm');
+		var filter2_val = filter2.get_value();
 
-		if(filter2.get_value()=='add')
+		if(filter2_val == 'add')
 		{
 			this.add_new_list(typeof widget == 'undefined' ? this.et2.getWidgetById('filter').value : widget.header.filter.get_value());
 			this.value='';
 		}
+		// automatic switch to accounts addressbook or all addressbooks depending on distribution list is a group
+		else if (filter2_val && (filter2_val < 0) !== (filter.get_value() === '0'))
+		{
+			// Change filter & filter2 at the same time
+			widget.applyFilters({
+				filter: filter2_val < 0 ? '0' : '',
+				filter2: filter2_val
+			});
+			// Don't get rows here, let applyFilters() do it
+			return false;
+		}
+		
+		return true;
 	},
 
 	/**
@@ -884,6 +951,40 @@ app.classes.addressbook = AppJS.extend(
 			},this).sendRequest(true);
 			return false;
 		}
+		else if (state.state.grouped_view)
+		{
+			// Deal with grouped views that are not valid (not in list of options)
+			// by faking viewing that organisation
+			var index = etemplate2.getById('addressbook-index');
+			if(index && index.widgetContainer)
+			{
+				var grouped = index.widgetContainer.getWidgetById('grouped_view');
+				var options = false;
+				if(grouped && grouped.options && grouped.options.select_options)
+				{
+					options = grouped.options.select_options;
+				}
+
+				// Check to see if it's not there
+				if(options && (options.find && 
+					!grouped.options.select_options.find(function(e) {console.log(e); return e.value === state.state.grouped_view;}) ||
+					!options[state.state.grouped_view]
+				))
+				{
+					var nm = index.widgetContainer.getWidgetById('nm');
+					var action = nm.controller._actionManager.getActionById('view_org');
+					var senders = [{_context: {_widget: nm}}];
+					return nm_action(action, senders, {}, {ids:[state.state.grouped_view]});
+				}
+			}
+		}
+
+		// Make sure advanced search is false if not set, this clears any
+		// currently set advanced search
+		if(typeof state.state.advanced_search === 'undefined')
+		{
+			state.state.advanced_search = false;
+		}
 		return this._super.apply(this, arguments);
 	},
 
@@ -900,6 +1001,7 @@ app.classes.addressbook = AppJS.extend(
 			case 'account_lid':
 			case 'n_family':
 			case 'n_given':
+			case 'account_passwd':
 			case 'account_passwd_2':
 				var values = this.et2._inst.getValues(this.et2);
 				var data = {
@@ -964,7 +1066,6 @@ app.classes.addressbook = AppJS.extend(
 		var addrs = [
 			content.data['adr_'+type+'_street'],
 			content.data['adr_'+type+'_locality'],
-			content.data['adr_'+type+'_countrycode'],
 			content.data['adr_'+type+'_postalcode']
 		];
 
