@@ -1,15 +1,17 @@
 <?php
 /**
- * eGgroupWare admin - admin command: edit/add a user
+ * EGgroupware admin - admin command: edit/add a user
  *
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package admin
- * @copyright (c) 2007-13 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2007-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * admin command: edit/add a user
  */
@@ -18,10 +20,10 @@ class admin_cmd_edit_user extends admin_cmd_change_pw
 	/**
 	 * Constructor
 	 *
-	 * @param string/int/array $account account name or id (!$account to add a new account), or array with all parameters
+	 * @param string|int|array $account account name or id (!$account to add a new account), or array with all parameters
 	 * @param array $set =null array with all data to change
 	 * @param string $password =null password
-	 * @param boolean $run_addaccount_hook =null default run addaccount for new accounts and editaccount for existing ones
+	 * @param boolean $run_addaccount_hook =null default run addaccount for new Api\Accounts and editaccount for existing ones
 	 */
 	function __construct($account,$set=null,$password=null,$run_addaccount_hook=null)
 	{
@@ -43,9 +45,9 @@ class admin_cmd_edit_user extends admin_cmd_change_pw
 	 *
 	 * @param boolean $check_only =false only run the checks (and throw the exceptions), but not the command itself
 	 * @return string success message
-	 * @throws egw_exception_no_admin
-	 * @throws egw_exception_wrong_userinput(lang("Unknown account: %1 !!!",$this->account),15);
-	 * @throws egw_exception_wrong_userinput(lang('Error changing the password for %1 !!!',$this->account),99);
+	 * @throws Api\Exception\NoPermission\Admin
+	 * @throws Api\Exception\WrongUserinput(lang("Unknown account: %1 !!!",$this->account),15);
+	 * @throws Api\Exception\WrongUserinput(lang('Error changing the password for %1 !!!',$this->account),99);
 	 */
 	protected function exec($check_only=false)
 	{
@@ -66,27 +68,27 @@ class admin_cmd_edit_user extends admin_cmd_change_pw
 		}
 		if (!$data['account_lid'] && (!$this->account || !is_null($data['account_lid'])))
 		{
-			throw new egw_exception_wrong_userinput(lang('You must enter a loginid'),9);
+			throw new Api\Exception\WrongUserinput(lang('You must enter a loginid'),9);
 		}
 		// Check if an account already exists as system user, and if it does deny creation
 		if ($GLOBALS['egw_info']['server']['account_repository'] == 'ldap' &&
 			!$GLOBALS['egw_info']['server']['ldap_allow_systemusernames'] && !$data['account_id'] &&
 			function_exists('posix_getpwnam') && posix_getpwnam($data['account_lid']))
 		{
-			throw new egw_exception_wrong_userinput(lang('There already is a system-user with this name. User\'s should not have the same name as a systemuser'),99);
+			throw new Api\Exception\WrongUserinput(lang('There already is a system-user with this name. User\'s should not have the same name as a systemuser'),99);
 		}
 		if (!$data['account_lastname'] && (!$this->account || !is_null($data['account_lastname'])))
 		{
-			throw new egw_exception_wrong_userinput(lang('You must enter a lastname'),9);
+			throw new Api\Exception\WrongUserinput(lang('You must enter a lastname'),9);
 		}
 		if (!is_null($data['account_lid']) && ($id = admin_cmd::$accounts->name2id($data['account_lid'],'account_lid','u')) &&
 			(string)$id !== (string)$data['account_id'])
 		{
-			throw new egw_exception_wrong_userinput(lang('That loginid has already been taken'),999);
+			throw new Api\Exception\WrongUserinput(lang('That loginid has already been taken'),999);
 		}
 		if (isset($data['account_passwd_2']) && $data['account_passwd'] != $data['account_passwd_2'])
 		{
-			throw new egw_exception_wrong_userinput(lang('The two passwords are not the same'),0);
+			throw new Api\Exception\WrongUserinput(lang('The two passwords are not the same'),0);
 		}
 		$expires = self::_parse_expired($data['account_expires'],(boolean)$this->account);
 		if ($expires === 0)	// deactivated
@@ -136,10 +138,10 @@ class admin_cmd_edit_user extends admin_cmd_change_pw
 		if ($this->account)
 		{
 			// invalidate account, before reading it, to code with changed to DB or LDAP outside EGw
-			accounts::cache_invalidate($data['account_id']);
+			Api\Accounts::cache_invalidate($data['account_id']);
 			if (!($old = admin_cmd::$accounts->read($data['account_id'])))
 			{
-				throw new egw_exception_wrong_userinput(lang("Unknown account: %1 !!!",$this->account),15);
+				throw new Api\Exception\WrongUserinput(lang("Unknown account: %1 !!!",$this->account),15);
 			}
 			// as the current account class always sets all values, we have to add the not specified ones
 			foreach($data as $name => &$value)
@@ -151,15 +153,15 @@ class admin_cmd_edit_user extends admin_cmd_change_pw
 		{
 			unset($data['account_id']);	// otherwise add will fail under postgres
 		}
-		// hook allowing apps to intercept adding/editing accounts before saving them
-		$GLOBALS['egw']->hooks->process($data+array(
+		// hook allowing apps to intercept adding/editing Api\Accounts before saving them
+		Api\Hooks::process($data+array(
 			'location' => $this->account ? 'pre_editaccount' : 'pre_addaccount',
 		),False,True);	// called for every app now, not only enabled ones)
 
 		if (!($data['account_id'] = admin_cmd::$accounts->save($data)))
 		{
 			//_debug_array($data);
-			throw new egw_exception_db(lang("Error saving account!"),11);
+			throw new Api\Db\Exception(lang("Error saving account!"),11);
 		}
 		// make new account_id available to caller
 		$update = (boolean)$this->account;
@@ -202,11 +204,11 @@ class admin_cmd_edit_user extends admin_cmd_change_pw
 		}
 		$data['account_passwd'] = $this->password;
 		$GLOBALS['hook_values'] =& $data;
-		$GLOBALS['egw']->hooks->process($GLOBALS['hook_values']+array(
+		Api\Hooks::process($GLOBALS['hook_values']+array(
 			'location' => $update && $this->run_addaccount_hook !== true ? 'editaccount' : 'addaccount'
 		),False,True);	// called for every app now, not only enabled ones)
 
-		return lang("Account %1 %2", $data['account_lid'] ? $data['account_lid'] : accounts::id2name($this->account),
+		return lang("Account %1 %2", $data['account_lid'] ? $data['account_lid'] : Api\Accounts::id2name($this->account),
 			$update ? lang('updated') : lang("created with id #%1", $this->account));
 	}
 
@@ -224,10 +226,10 @@ class admin_cmd_edit_user extends admin_cmd_change_pw
 	/**
 	 * parse the expired string and return the expired date as timestamp
 	 *
-	 * @param string $str date, 'never', 'already' or '' (=dont change, or default of never of new accounts)
+	 * @param string $str date, 'never', 'already' or '' (=dont change, or default of never of new Api\Accounts)
 	 * @param boolean $existing
 	 * @return int timestamp, 0 for already, -1 for never or null for dont change
-	 * @throws egw_exception_wrong_userinput(lang('Invalid formated date "%1"!',$datein),6);
+	 * @throws Api\Exception\WrongUserinput(lang('Invalid formated date "%1"!',$datein),6);
 	 */
 	private function _parse_expired($str,$existing)
 	{
@@ -235,7 +237,7 @@ class admin_cmd_edit_user extends admin_cmd_change_pw
 		{
 			case '':
 				if ($existing) return null;
-				// fall through --> default for new accounts is never
+				// fall through --> default for new Api\Accounts is never
 			case 'never':
 				return -1;
 			case 'already':
