@@ -5,11 +5,15 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package admin
- * @copyright (c) 2011 by Ralf Becker <rb@stylite.de>
+ * @copyright (c) 2011-16 by Ralf Becker <rb@stylite.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Etemplate;
+
 /**
  * Custom - instance specific - translations
  */
@@ -27,34 +31,34 @@ class admin_customtranslation
 	/**
 	 * Add, modify, delete custom translations
 	 *
-	 * @param array $content=null
-	 * @param string $msg=''
+	 * @param array $_content =null
+	 * @param string $msg =''
 	 */
-	function index(array $content=null, $msg='')
+	function index(array $_content=null, $msg='')
 	{
-		if (is_array($content))
+		if (is_array($_content))
 		{
-			//_debug_array($content);
-			if (isset($content['button']))
+			//_debug_array($_content);
+			if (isset($_content['button']))
 			{
-				list($action) = each($content['button']);
-				unset($content['button']);
+				list($action) = each($_content['button']);
+				unset($_content['button']);
 			}
-			elseif($content['rows']['delete'])
+			elseif($_content['rows']['delete'])
 			{
-				list($action) = each($content['rows']['delete']);
-				unset($content['rows']['delete']);
+				list($action) = each($_content['rows']['delete']);
+				unset($_content['rows']['delete']);
 			}
 			switch($action)
 			{
 				case 'save':
 				case 'apply':
 					$saved = 0;
-					foreach($content['rows'] as $n => $data)
+					foreach($_content['rows'] as $data)
 					{
 						if (!empty($data['phrase']))
 						{
-							translation::write('en', 'custom', strtolower(trim($data['phrase'])), $data['translation']);
+							Api\Translation::write('en', 'custom', strtolower(trim($data['phrase'])), $data['translation']);
 							++$saved;
 						}
 					}
@@ -62,20 +66,20 @@ class admin_customtranslation
 					if ($action == 'apply') break;
 					// fall through
 				case 'cancel':
-					egw::redirect_link('/admin/index.php');
+					Egw::redirect_link('/admin/index.php');
 					break;
 
 				default:	// line to delete;
-					if (!empty($content['rows'][$action]['phrase']))
+					if (!empty($_content['rows'][$action]['phrase']))
 					{
-						translation::write('en', 'custom', strtolower(trim($content['rows'][$action]['phrase'])), null);
+						Api\Translation::write('en', 'custom', strtolower(trim($_content['rows'][$action]['phrase'])), null);
 						$msg = lang('Phrase deleted');
 					}
 					break;
 			}
 		}
 		$content = array('rows' => array());
-		foreach(translation::load_app('custom', 'en') as $phrase => $translation)
+		foreach(Api\Translation::load_app('custom', 'en') as $phrase => $translation)
 		{
 			$content['rows'][++$row] = array(
 				'phrase' => $phrase,
@@ -91,7 +95,7 @@ class admin_customtranslation
 		$content['msg'] = $msg;
 
 		$GLOBALS['egw_info']['flags']['app_header'] = lang('Custom translation');
-		$tpl = new etemplate('admin.customtranslation');
-		$tpl->exec('admin.admin_customtranslation.index', $content, $sel_options, $readonlys, $preserv);
+		$tpl = new Etemplate('admin.customtranslation');
+		$tpl->exec('admin.admin_customtranslation.index', $content, array(), $readonlys);
 	}
 }
