@@ -9,6 +9,8 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 class admin_db_backup
 {
 	var $public_functions = array(
@@ -21,7 +23,7 @@ class admin_db_backup
 	 */
 	function do_backup()
 	{
-		$this->db_backup = new db_backup();
+		$this->db_backup = new Api\Db\Backup();
 
  		if (($f = $this->db_backup->fopen_backup()))
  		{
@@ -40,12 +42,12 @@ class admin_db_backup
 	{
 		$tpl_root = EGW_SERVER_ROOT.'/setup/templates/default';
 		$self = $GLOBALS['egw']->link('/index.php',array('menuaction'=>'admin.admin_db_backup.index'));
-		translation::add_app('setup');
-		egw_framework::csp_script_src_attrs('unsafe-inline');
+		Api\Translation::add_app('setup');
+		Api\Header\ContentSecurityPolicy::add('script-src', 'unsafe-inline');
 
 		include EGW_SERVER_ROOT.'/setup/db_backup.php';
 
 		unset($tpl_root, $self);
-		common::egw_footer();
+		echo $GLOBALS['egw']->framework->footer();
 	}
 }
