@@ -130,6 +130,17 @@ class admin_mail
 		'email'	    => 'EMail-address from account',
 	);
 
+	/**
+	 * Options for further identities
+	 *
+	 * @var array
+	 */
+	public static $further_identities = array(
+		0 => 'Forbid users to create identities',
+		1 => 'Allow users to create further identities',
+		2 => 'Allow users to create identities for aliases',
+	);
+
 	/**
 	 * List of domains know to not support Sieve
 	 *
@@ -374,7 +385,8 @@ class admin_mail
 			//_debug_array($content);
 			$sel_options['acc_folder_sent'] = $sel_options['acc_folder_trash'] =
 				$sel_options['acc_folder_draft'] = $sel_options['acc_folder_template'] =
-					$sel_options['acc_folder_junk'] = $sel_options['acc_folder_archive'] = self::mailboxes($imap, $content);
+					$sel_options['acc_folder_junk'] = $sel_options['acc_folder_archive'] =
+						$sel_options['acc_folder_ham'] = self::mailboxes($imap, $content);
 		}
 		catch(Exception $e) {
 			$content['msg'] = $e->getMessage();
@@ -419,6 +431,7 @@ class admin_mail
 			'acc_folder_draft' => array('\\drafts', 'drafts'),
 			'acc_folder_template' => array('', 'templates'),
 			'acc_folder_junk'  => array('\\junk', 'junk', 'spam'),
+			'acc_folder_ham'   => array('', 'ham'),
 			'acc_folder_archive' => array('', 'archive'),
 		) as $name => $common_names)
 		{
@@ -929,6 +942,11 @@ class admin_mail
 			unset($content['acc_smtp_auth_session']);
 			unset($content['notify_use_default']);
 		}
+		// copy ident_email_alias selectbox back to regular name
+		elseif (isset($content['ident_email_alias']) && !empty ($content['ident_email_alias']))
+		{
+			$content['ident_email'] = $content['ident_email_alias'];
+		}
 		$edit_access = Mail\Account::check_access(Acl::EDIT, $content);
 
 		// disable notification save-default and use-default, if only one account or no edit-rights
@@ -1053,7 +1071,7 @@ class admin_mail
 								// load default ones
 								$content = array_merge($content, Mail\Notifications::read($content['acc_id'], 0));
 							}
-							if (!$content['notify_use_default'])
+							if (!$content['notify_use_default'] && is_array($content['notify_folders']))
 							{
 								$content['notify_account_id'] = $content['called_for'] ?
 									$content['called_for'] : $GLOBALS['egw_info']['user']['account_id'];
@@ -1158,7 +1176,8 @@ class admin_mail
 			try {
 				$sel_options['acc_folder_sent'] = $sel_options['acc_folder_trash'] =
 					$sel_options['acc_folder_draft'] = $sel_options['acc_folder_template'] =
-					$sel_options['acc_folder_junk'] = $sel_options['acc_folder_archive'] = $sel_options['notify_folders'] =
+					$sel_options['acc_folder_junk'] = $sel_options['acc_folder_archive'] =
+					$sel_options['notify_folders'] = $sel_options['acc_folder_ham'] =
 						self::mailboxes(self::imap_client ($content));
 			}
 			catch(Exception $e) {
@@ -1179,6 +1198,17 @@ class admin_mail
 		$sel_options['acc_imap_logintype'] = self::$login_types;
 		$sel_options['ident_id'] = $content['identities'];
 		$sel_options['acc_id'] = $content['accounts'];
+		$sel_options['acc_further_identities'] = self::$further_identities;
+
+		// if only aliases are allowed for futher identities, add them as options
+		if ($content['acc_further_identities'] == 2)
+		{
+			$sel_options['ident_email_alias'] = array_merge(
+				array('' => $content['mailLocalAddress'].' ('.lang('Default').')'),
+				array_combine($content['mailAlternateAddress'], $content['mailAlternateAddress']));
+			// copy ident_email to select-box ident_email_alias, as et2 requires unique ids
+			$content['ident_email_alias'] = $content['ident_email'];
+		}
 
 		// user is allowed to create or edit further identities
 		if ($edit_access || $content['acc_further_identities'])
@@ -1193,7 +1223,7 @@ class admin_mail
 					'button[save]' => false, 'button[apply]' => false,
 					'button[placeholders]' => false,
 					'ident_name' => false,
-					'ident_realname' => false, 'ident_email' => false,
+					'ident_realname' => false, 'ident_email' => false, 'ident_email_alias' => false,
 					'ident_org' => false, 'ident_signature' => false,
 				);
 			}
@@ -1204,12 +1234,12 @@ class admin_mail
 				{
 					$identity = Mail\Account::read_identity($content['ident_id'], false, $content['called_for']);
 					unset($identity['account_id']);
-					$content = array_merge($content, $identity);
+					$content = array_merge($content, $identity, array('ident_email_alias' => $identity['ident_email']));
 				}
 				else
 				{
 					$content['ident_name'] = $content['ident_realname'] = $content['ident_email'] =
-						$content['ident_org'] = $content['ident_signature'] = '';
+						$content['ident_email_alias'] = $content['ident_org'] = $content['ident_signature'] = '';
 				}
 				if (empty($msg) && $edit_access && $content['ident_id'] && $content['ident_id'] != $content['std_ident_id'])
 				{
@@ -1227,6 +1257,10 @@ class admin_mail
 		// disable aliases tab for default smtp class EGroupware\Api\Mail\Smtp
 		$readonlys['tabs']['admin.mailaccount.aliases'] = !$content['acc_smtp_type'] ||
 			$content['acc_smtp_type'] == 'EGroupware\\Api\\Mail\\Smtp';
+		if ($readonlys['tabs']['admin.mailaccount.aliases'])
+		{
+			unset($sel_options['acc_further_identities'][2]);	// can limit identities to aliases without aliases ;-)
+		}
 
 		// allow smtp class to disable certain features in alias tab
 		if ($content['acc_smtp_type'] && class_exists($content['acc_smtp_type']) &&
@@ -1276,6 +1310,12 @@ class admin_mail
 		}
 		$content['admin_actions'] = (bool)$admin_actions;
 
+		//try to fix identities with no domain part set e.g. alias as identity
+		if (!strpos($content['ident_email'], '@'))
+		{
+			$content['ident_email'] = Mail::fixInvalidAliasAddress (Api\Accounts::id2name($content['acc_imap_account_id'], 'account_email'), $content['ident_email']);
+		}
+
 		$tpl->exec(static::APP_CLASS.'edit', $content, $sel_options, $readonlys, $content, 2);
 	}
 
