@@ -308,7 +308,7 @@ app.classes.admin = AppJS.extend(
 		if(!_data || _data.type != undefined) return;
 
 		// Insert the content, etemplate will load into it
-		jQuery(this.ajax_target.node).append(_data[0]);
+		jQuery(this.ajax_target.node).append(typeof _data === 'string' ? _data : _data[0]);
 	},
 
 	/**
@@ -560,9 +560,10 @@ app.classes.admin = AppJS.extend(
 				// Only send the request if they entered everything (or selected no apps)
 				if(_value.acl_account && (_value.acl_appname && _value.acl_location || typeof _value.apps != 'undefined'))
 				{
+					var id = [];
 					if(_value.acl_appname && _value.acl_account && _value.acl_location)
 					{
-						var id = _value.acl_appname+':'+_value.acl_account+':'+_value.acl_location;
+						id = _value.acl_appname+':'+_value.acl_account+':'+_value.acl_location;
 						if(content && content.id && id != content.id)
 						{
 							// Changed the account or location, remove previous or we
@@ -570,6 +571,7 @@ app.classes.admin = AppJS.extend(
 							this.egw.json(className+'::ajax_change_acl', [content.id, 0], null,this,false,this)
 								.sendRequest();
 						}
+						id = [id];
 					}
 					var rights = 0;
 					for(var i in _value.acl)
@@ -609,7 +611,7 @@ app.classes.admin = AppJS.extend(
 						.sendRequest();
 				}
 			},this),
-			title: egw.lang('Access control'),
+			title: this.egw.lang('Access control'),
 			buttons: et2_dialog.BUTTONS_OK_CANCEL,
 			value: {
 				content: content,
@@ -826,7 +828,7 @@ app.classes.admin = AppJS.extend(
 		var _buttons = [
 				{"button_id": "delete[cancel]","text": this.egw.lang('Cancel'), id: 'delete[cancel]', image: 'cancel', "default":true},
 				{"button_id": "delete[delete]","text": this.egw.lang('Delete'), id: 'delete[delete]', image: 'delete'},
-				{"button_id": "delete[subs]","text": this.egw.lang('Delete including sub-enteries'), id: 'delete[subs]', image: 'delete'}
+				{"button_id": "delete[subs]","text": this.egw.lang('Delete including sub-entries'), id: 'delete[subs]', image: 'delete'}
 		];
 		var action = _action;
 		var self = this;
@@ -1142,5 +1144,21 @@ app.classes.admin = AppJS.extend(
 		{
 			this.egw.open_link(_action.data.url, _action.data.target || '_blank', _action.data.popup);
 		}
+	},
+
+	/**
+	 * Clear instance cache
+	 *
+	 * If there is an error on server-side, resend request with an parameter allowing
+	 * cache to use different method not requiring eg. so much memory
+	 */
+	clear_cache: function()
+	{
+		this.egw.message(this.egw.lang('Clear cache and register hooks')+"\n"+this.egw.lang('Please wait...'),'info');
+
+		this.egw.json('admin.admin_hooks.ajax_clear_cache').sendRequest(true, undefined, jQuery.proxy(function(_xmlhttp, _err)
+		{
+			this.egw.json('admin.admin_hooks.ajax_clear_cache&errored=1').sendRequest(true);
+		}, this));
 	}
 });
