@@ -10,7 +10,7 @@
  */
 
 $setup_info['admin']['name']      = 'admin';
-$setup_info['admin']['version']   = '14.3.001';
+$setup_info['admin']['version']   = '16.1';
 $setup_info['admin']['app_order'] = 1;
 $setup_info['admin']['tables']    = array('egw_admin_queue','egw_admin_remote');
 $setup_info['admin']['enable']    = 1;
@@ -34,24 +34,17 @@ $setup_info['admin']['description'] = 'EGroupware administration application';
 $setup_info['admin']['hooks'] = array(
 	'acl_manager',
 	'config_validate',
-	'deleteaccount',
-	'topmenu_info'
 );
 $setup_info['admin']['hooks']['admin'] = 'admin_hooks::all_hooks';
 $setup_info['admin']['hooks']['sidebox_menu'] = 'admin_hooks::all_hooks';
 $setup_info['admin']['hooks']['edit_user'] = 'admin_hooks::edit_user';
+$setup_info['admin']['hooks']['config'] = 'admin_hooks::config';
 
 // add account tab to addressbook.edit
 $setup_info['admin']['hooks']['addressbook_edit'] = 'admin.admin_account.addressbook_edit';
 
-/* Dependencies for this app to work */
+// Dependencies for this app to work
 $setup_info['admin']['depends'][] = array(
-	'appname' => 'phpgwapi',
-	'versions' => Array('14.1')
+	'appname' => 'api',
+	'versions' => Array('16.1')
 );
-$setup_info['admin']['depends'][] = array(
-	'appname' => 'etemplate',
-	'versions' => Array('14.1')
-);
-
-
