@@ -173,3 +173,8 @@ function admin_upgrade14_3()
 	}
 	return $GLOBALS['setup_info']['admin']['currentver'] = '14.3.001';
 }
+
+function admin_upgrade14_3_001()
+{
+	return $GLOBALS['setup_info']['admin']['currentver'] = '16.1';
+}
\ No newline at end of file
