@@ -150,6 +150,7 @@ String: A string in the user\'s date format, or a relative date. Relative dates
 			}
 
 			// Avoid collision of datepicker dialog with input field
+			var widget = this;
 			this.input_date.datepicker('option', 'beforeShow', function(input, inst){
 				var cal = inst.dpDiv;
 				setTimeout(function () {
@@ -166,6 +167,10 @@ String: A string in the user\'s date format, or a relative date. Relative dates
 							of: input
 						});
 					}
+					// Add tooltip to Today/Now button
+					jQuery('[data-handler="today"]',cal).attr('title',
+						widget._type == 'date' ? egw.lang('Today') : egw.lang('Now')
+					);
 
 				},0);
 			})
@@ -467,7 +472,7 @@ String: A string in the user\'s date format, or a relative date. Relative dates
 			_value = date('Y-m-d\\TH:i:s\\Z', _value);
 		}
 		// Check for full timestamp
-		if(typeof _value == 'string' && _value.match(/(\d{4})-(\d{2})-(\d{2})T(\d{2})\:(\d{2})\:(\d{2})(?:\.\d{3})?(?:Z|[+-](\d{2})\:(\d{2}))/))
+		if(typeof _value == 'string' && _value.match(/^(\d{4})-(\d{2})-(\d{2})T(\d{2})\:(\d{2})\:(\d{2})(?:\.\d{3})?(?:Z|[+-](\d{2})\:(\d{2})|)$/))
 		{
 			_value = new Date(_value);
 		}
@@ -665,6 +670,12 @@ var et2_date_duration = (function(){ "use strict"; return et2_date.extend(
 			"default": false,
 			"type": "boolean",
 			"description": "use d/h/m instead of day/hour/minute"
+		},
+		"step" : {
+			"name": "Step limit",
+			"default": 'any',
+			"type": "string",
+			"description": "Works with the min and max attributes to limit the increments at which a numeric or date-time value can be set."
 		}
 	},
 
@@ -711,7 +722,7 @@ var et2_date_duration = (function(){ "use strict"; return et2_date.extend(
 						.addClass('et2_date_duration');
 		this.duration = jQuery(document.createElement("input"))
 						.addClass('et2_date_duration')
-						.attr({type: 'number', size: 3});
+						.attr({type: 'number', size: 3, step:this.options.step});
 		this.node.append(this.duration);
 
 		if(this.options.display_format.length > 1)
@@ -732,7 +743,30 @@ var et2_date_duration = (function(){ "use strict"; return et2_date.extend(
 		{
 			this.format = jQuery("<span>"+this.time_formats["m"]+"</span>").appendTo(this.node);
 		}
+		var self = this;
+		// seems the 'invalid' event doesn't work in all browsers, eg. FF therefore
+		// we use focusout event to check the valifdity of input right after user
+		// enters the value.
+		this.duration.on('focusout', function(){if(!self.duration[0].checkValidity()) return self.duration.change();});
 	},
+
+	/**
+	 * Clientside validation
+	 *
+	 * @param {array} _messages
+	 */
+	isValid: function(_messages)
+	{
+		var ok = true;
+		// if we have a html5 validation error, show it, as this.input.val() will be empty!
+		if (this.duration && this.duration[0] && this.duration[0].validationMessage && !this.duration[0].validity.stepMismatch)
+		{
+			_messages.push(this.duration[0].validationMessage);
+			ok = false;
+		}
+		return this._super.apply(this, arguments) && ok;
+	},
+
 	attachToDOM: function() {
 		var node = this.getInputNode();
 		if (node)
