@@ -387,7 +387,7 @@ var et2_dialog = (function(){ "use strict"; return et2_widget.extend(
 				}
 				if (button.image)
 				{
-					button.style = 'background-image: url('+this.egw().image(button.image)+')';
+					button.style = 'background-image: url('+this.egw().image(button.image,'etemplate')+')';
 					delete button.image;
 				}
 			}
@@ -724,6 +724,12 @@ jQuery.extend(et2_dialog, //(function(){ "use strict"; return
 		var log = null;
 		var progressbar = null;
 		var cancel = false;
+		var totals = {
+			success: 0,
+			skipped: 0,
+			failed: 0,
+			widget: null
+		};
 
 		// Updates progressbar & log, calls next step
 		var update = function(response) {
@@ -731,16 +737,52 @@ jQuery.extend(et2_dialog, //(function(){ "use strict"; return
 			var index = this || 0;
 
 			progressbar.set_value(100*(index/_list.length));
+			progressbar.set_label(index +' / ' + _list.length);
 
 			// Display response information
 			switch(response.type)
 			{
 				case 'error':
-					log.append("<div class='message error'>"+response.data+"</div>");
-					break;
+					jQuery("<div class='message error'></div>")
+						.text(response.data)
+						.appendTo(log);
+
+					totals.failed++
+
+					// Ask to retry / ignore / abort
+					et2_createWidget("dialog", {
+						callback:function(button) {
+							switch(button)
+							{
+								case 'dialog[cancel]':
+									cancel = true;
+									return update.call(index,'');
+								case 'dialog[skip]':
+									// Continue with next index
+									totals.skipped++;
+									return update.call(index,'');
+								default:
+									// Try again with previous index
+									return update.call(index-1,'');
+							}
+
+						},
+						message: response.data,
+						title: '',
+						buttons: [
+							// These ones will use the callback, just like normal
+							{text: egw.lang("Abort"),id:'dialog[cancel]',},
+							{text: egw.lang("Retry"),id:'dialog[retry]'},
+							{text: egw.lang("Skip"),id:'dialog[skip]', class:"ui-priority-primary", default: true}
+						],
+						dialog_type: et2_dialog.ERROR_MESSAGE
+					}, parent);
+					// Early exit
+					return;
 				default:
 					if(response)
 					{
+						totals.success++;
 						log.append("<div class='message'>"+response+"</div>");
 					}
 			}
@@ -748,6 +790,12 @@ jQuery.extend(et2_dialog, //(function(){ "use strict"; return
 			var height = log[0].scrollHeight;
 			log.scrollTop(height);
 
+			// Update totals
+			totals.widget.set_value(egw.lang(
+				"Total: %1 Successful: %2 Failed: %3 Skipped: %4",
+				_list.length, totals.success, totals.failed, totals.skipped
+			));
+
 			// Fire next step
 			if(!cancel && index < _list.length)
 			{
@@ -755,6 +803,7 @@ jQuery.extend(et2_dialog, //(function(){ "use strict"; return
 				if(typeof parameters != 'object') parameters = [parameters];
 
 				// Async request, we'll take the next step in the callback
+				// We can't pass index = 0, it looks like false and causes issues
 				egw.json(_menuaction, parameters, update, index+1,true,index+1).sendRequest();
 			}
 			else
@@ -774,6 +823,8 @@ jQuery.extend(et2_dialog, //(function(){ "use strict"; return
 			// Get access to template widgets
 			log = jQuery(dialog.template.widgetContainer.getWidgetById('log').getDOMNode());
 			progressbar = dialog.template.widgetContainer.getWidgetById('progressbar');
+			progressbar.set_label('0 / ' + _list.length);
+			totals.widget = dialog.template.widgetContainer.getWidgetById('totals');
 
 			// Start
 			window.setTimeout(function() {update.call(0,'');},0);
