@@ -88,6 +88,12 @@ var et2_file = (function(){ "use strict"; return et2_inputWidget.extend(
 			"type": "any",
 			"default": et2_no_init,
 			"description": "A (js) function called when a file to be uploaded is finished."
+		},
+		accept: {
+			"name": "Acceptable extensions",
+			"type": "string",
+			"default": '',
+			"description": "Define types of files that the server accepts. Multiple types can be seperated by comma and the default is to accept everything."
 		}
 	},
 
@@ -180,6 +186,7 @@ var et2_file = (function(){ "use strict"; return et2_inputWidget.extend(
 					jQuery(span).removeClass('et2_file_spanActive');
 				}
 			});
+		if (this.options.accept) this.input.attr('accept', this.options.accept);
 		var self = this;
 		// trigger native input upload file
 		if (!this.options.readonly) this.span.click(function(){self.input.click()});
@@ -499,7 +506,7 @@ var et2_file = (function(){ "use strict"; return et2_inputWidget.extend(
 		//Add uploading indicator and bind hover handler on it
 		jQuery(this.node).find('span').addClass('totalProgress_loader');
 
-		jQuery(this.node).find('input').hover(function(){
+		jQuery(this.node).find('span.et2_file_span').hover(function(){
 					jQuery('.progress_dropDown_fileList').show();
 		});
 		//Bind click handler to dismiss the dropdown while uploading
@@ -537,7 +544,7 @@ var et2_file = (function(){ "use strict"; return et2_inputWidget.extend(
 		if(this.progress)
 		{
 			var fileName = file.fileName || 'file';
-			var status = jQuery("<li data-file='"+fileName+"'>"+fileName
+			var status = jQuery("<li data-file='"+fileName.replace(/'/g, '&quot')+"'>"+fileName
 					+"<div class='remove'/><span class='progressBar'><p/></span></li>")
 				.appendTo(this.progress);
 			jQuery("div.remove",status).on('click', file, jQuery.proxy(this.cancel,this));
@@ -554,7 +561,7 @@ var et2_file = (function(){ "use strict"; return et2_inputWidget.extend(
 	_fileProgress: function(file) {
 		if(this.progress)
 		{
-			jQuery("li[data-file='"+file.fileName+"'] > span.progressBar > p").css("width", Math.ceil(file.progress()*100)+"%");
+			jQuery("li[data-file='"+file.fileName.replace(/'/g, '&quot')+"'] > span.progressBar > p").css("width", Math.ceil(file.progress()*100)+"%");
 
 		}
 		return true;
@@ -577,7 +584,7 @@ var et2_file = (function(){ "use strict"; return et2_inputWidget.extend(
 				if(typeof response.response[0].data[key] == "string")
 				{
 					// Message from server - probably error
-					jQuery("[data-file='"+name+"']",this.progress)
+					jQuery("[data-file='"+name.replace(/'/g, '&quot')+"']",this.progress)
 						.addClass("error")
 						.css("display", "block")
 						.text(response.response[0].data[key]);
@@ -585,16 +592,21 @@ var et2_file = (function(){ "use strict"; return et2_inputWidget.extend(
 				else
 				{
 					this.options.value[key] = response.response[0].data[key];
+					// If not multiple, we already destroyed the status, so re-create it
+					if(!this.options.multiple)
+					{
+						this.createStatus({}, file);
+					}
 					if(this.progress)
 					{
-						jQuery("[data-file='"+name+"']",this.progress).addClass("message success");
+						jQuery("[data-file='"+name.replace(/'/g, '&quot')+"']",this.progress).addClass("message success");
 					}
 				}
 			}
 		}
 		else if (this.progress)
 		{
-			jQuery("[data-file='"+name+"']",this.progress)
+			jQuery("[data-file='"+name.replace(/'/g, '&quot')+"']",this.progress)
 				.addClass("ui-state-error")
 				.css("display", "block")
 				.text(this.egw().lang("Server error"));
@@ -628,7 +640,7 @@ var et2_file = (function(){ "use strict"; return et2_inputWidget.extend(
 			if(this.options.value[key].name == file.fileName)
 			{
 				delete this.options.value[key];
-				jQuery('[data-file="'+file.fileName+'"]',this.node).remove();
+				jQuery('[data-file="'+file.fileName.replace(/'/g, '&quot')+'"]',this.node).remove();
 				return;
 			}
 		}
