@@ -172,18 +172,25 @@ var et2_link_to = (function(){ "use strict"; return et2_inputWidget.extend(
 			application_list: this.options.application_list,
 			blur: this.options.search_label ? this.options.search_label : this.egw().lang('Search...'),
 			query: function() { self.link_button.hide(); return true;},
-			select: function() {self.link_button.show(); return true;}
+			select: function() {self.link_button.show(); return true;},
+			readonly: this.options.readonly
 		};
 		this.link_entry = et2_createWidget("link-entry", link_entry_attrs,this);
 
 		// Filemanager select
 		var select_attrs = {
-			method: 'EGroupware\\Api\\Etemplate\\Widget\\Link::link_existing',
-			method_id: function() { return self.options.value.to_app + ':' + self.options.value.to_id;},
 			button_label: egw.lang('Link'),
-			button_caption: ''
+			button_caption: '',
+			readonly: this.options.readonly
 		};
+		// only set server-side callback, if we have a real application-id (not null or array)
+		// otherwise it only gives an error on server-side
+		if (self.options.value && self.options.value.to_id && typeof self.options.value.to_id != 'object') {
+			select_attrs.method = 'EGroupware\\Api\\Etemplate\\Widget\\Link::link_existing';
+			select_attrs.method_id = self.options.value.to_app + ':' + self.options.value.to_id;
+		}
 		this.vfs_select = et2_createWidget("vfs-select", select_attrs,this);
+		this.vfs_select.set_readonly(this.options.readonly);
 		jQuery(this.vfs_select.getDOMNode()).change( function() {
 			var values = true;
 			// If entry not yet saved, store for linking on server
@@ -191,16 +198,19 @@ var et2_link_to = (function(){ "use strict"; return et2_inputWidget.extend(
 			{
 				values = self.options.value.to_id || {};
 				var files = self.vfs_select.getValue();
-				for(var i = 0; i < files.length; i++)
+				if(typeof files !== 'undefined')
 				{
-					values['link:'+files[i]] = {
-						app: 'link',
-						id: files[i],
-						type: 'unknown',
-						icon: 'link',
-						remark: '',
-						title: files[i]
-					};
+					for(var i = 0; i < files.length; i++)
+					{
+						values['link:'+files[i]] = {
+							app: 'link',
+							id: files[i],
+							type: 'unknown',
+							icon: 'link',
+							remark: '',
+							title: files[i]
+						};
+					}
 				}
 			}
 			self._link_result(values);
@@ -213,6 +223,7 @@ var et2_link_to = (function(){ "use strict"; return et2_inputWidget.extend(
 			label: '',
 			// Make the whole template a drop target
 			drop_target: this.getInstanceManager().DOMContainer.getAttribute("id"),
+			readonly: this.options.readonly,
 
 			// Change to this tab when they drop
 			onStart: function(event, file_count) {
@@ -246,6 +257,7 @@ var et2_link_to = (function(){ "use strict"; return et2_inputWidget.extend(
 		};
 
 		this.file_upload = et2_createWidget("file", file_attrs,this);
+		this.file_upload.set_readonly(this.options.readonly);
 		return true;
 	},
 
@@ -287,7 +299,7 @@ var et2_link_to = (function(){ "use strict"; return et2_inputWidget.extend(
 					id: file,
 					name: self.file_upload.options.value[file].name,
 					type: self.file_upload.options.value[file].type,
-					remark: jQuery("li[file='"+self.file_upload.options.value[file].name+"'] > input", self.file_upload.progress)
+					remark: jQuery("li[file='"+self.file_upload.options.value[file].name.replace(/'/g, '&quot')+"'] > input", self.file_upload.progress)
 						.filter(function() { return jQuery(this).attr("placeholder") != jQuery(this).val();}).val()
 				});
 			}
@@ -682,7 +694,7 @@ var et2_link_entry = (function(){ "use strict"; return et2_inputWidget.extend(
 			// Normal stuff
 			li.append(jQuery( "<a></a>" ).text( item.label ))
 				.appendTo(ul);
-			window.setTimeout(function(){ul.toggleClass('ui-menu-rtl',(ul.offset().left + ul.width() > window.outerWidth))}, 300);
+			window.setTimeout(function(){ul.css('max-width', jQuery('.et2_container').width()-ul.offset().left)}, 300);
 			return li;
 		};
 
@@ -1627,7 +1639,7 @@ var et2_link_list = (function(){ "use strict"; return et2_link_string.extend(
 
 			// Download ZIP
 			window.location = self.egw().link('/index.php',{
-				menuaction: 'EGroupware\\Api\\Etemplate\\Widget\\Link::download_zip',
+				menuaction: 'api.etemplate_widget_link.download_zip',
 				app: self.value.to_app,
 				id: self.value.to_id
 			});
