@@ -248,7 +248,10 @@ var et2_selectbox = (function(){ "use strict"; return et2_inputWidget.extend(
 		var option = jQuery(document.createElement("option"))
 			.attr("value", _value)
 			.text(_label+"");
-
+		if (this.options.tags && this._type == 'select-cat')
+		{
+			option.addClass('cat_'+_value);
+		}
 		if (typeof _title != "undefined" && _title)
 		{
 			option.attr("title", _title);
@@ -381,10 +384,13 @@ var et2_selectbox = (function(){ "use strict"; return et2_inputWidget.extend(
 			var header_controls = {
 				check: {
 					icon_class: 'ui-icon-check',
-					label:	'Check all',
+					label:	this.egw().lang('Check all'),
 					click: function(e) {
-						var all_set = jQuery("input[type='checkbox']",e.data).prop("checked");
-						jQuery("input[type='checkbox']",e.data).prop("checked", !all_set);
+						var all_off = false;
+						jQuery("input[type='checkbox']",e.data).each(function() {
+							if(!jQuery(this).prop("checked")) all_off = true;
+						});
+						jQuery("input[type='checkbox']",e.data).prop("checked", all_off);
 					}
 				}
 			};
@@ -492,6 +498,16 @@ var et2_selectbox = (function(){ "use strict"; return et2_inputWidget.extend(
 			// No options set yet
 			this.set_select_options(this.options.select_options);
 		}
+		// select-cat set/unset right cat_ color for selected value
+		if (this._type == 'select-cat' && this.options.tags) {
+			var chosen = this.input.siblings();
+			this.input.removeClass('cat_'+this._oldValue);
+			this.input.addClass('cat_'+this.value);
+			if (chosen.length > 0) {
+				chosen.removeClass('cat_'+this._oldValue);
+				chosen.addClass('cat_'+this.value);
+			}
+		}
 		this._oldValue = this.value;
 		if(this.input !== null && (this.options.tags || this.options.search))
 		{
@@ -692,9 +708,61 @@ var et2_selectbox = (function(){ "use strict"; return et2_inputWidget.extend(
 			this.input.chosen({
 				inherit_select_classes: true,
 				search_contains: true,
-				width: _width || size.w + "px"
-			})
-			.change(this.onchange);
+				width: _width || size.w + "px",
+				no_results_text: this.egw().lang('No results match')
+			});
+
+			if(this.options.onchange)
+			{
+				// Unbind change handler of widget's ancestor to stop it from bubbling
+				// chosen has its own onchange
+				jQuery(this.input).unbind('change.et2_inputWidget');
+
+				var self = this;
+				this.input.chosen().change(function(_ev, _change)
+				{
+					// enhance signature of regular et2_selectbox.onchange with 3. parameter from chosen
+					self.change.call(self, self.input, self, _change);
+				});
+			}
+
+			// multi selection with limited show line of single row
+			if (this.options.multiple && this.options.rows == 1 && this.options.height)
+			{
+				var $chosen_div = jQuery(this.input.siblings());
+				var self = this;
+
+				/**
+				 * A function to set counter for multi tags limited for single row
+				 * @returns {undefined}
+				 */
+				var _update_item_counter = function ()
+				{
+					$chosen_div.find('ul.chzn-choices').attr('data-after',self.getValue().length);
+				};
+
+				// Update the item counter
+				_update_item_counter();
+				// Initialize the single row class
+				$chosen_div.toggleClass('et2_selectbox_single_row', true);
+
+				// bind hover actions
+				$chosen_div
+					.off()
+					.hover(
+						//mouseIn
+						function(e){
+							jQuery(this).toggleClass('et2_selectbox_multi_row', true);
+							jQuery(this).toggleClass('et2_selectbox_single_row', false);
+						},
+						//mouseOut
+						function(e){
+							jQuery(this).toggleClass('et2_selectbox_multi_row', false);
+							jQuery(this).toggleClass('et2_selectbox_single_row', true);
+							_update_item_counter();
+						}
+				);
+			}
 		}
 	},
 
@@ -1296,6 +1364,19 @@ jQuery.extend(et2_selectbox, //(function(){ "use strict"; return
 					delete cache_owner[cache_id];
 					return this.cached_server_side_options(widget, options_string, attrs);
 				}
+				else
+				{
+					if(attrs.value && widget && widget.get_value() !== attrs.value)
+					{
+						egw.window.setTimeout(jQuery.proxy(function() {
+							// Avoid errors if widget is destroyed before the timeout
+							if(this.widget && typeof this.widget.id !== 'undefined')
+							{
+								this.widget.set_value(this.widget.options.value);
+							}
+						},{widget: widget}),1);
+					}
+				}
 			}
 			return cache;
 		}
