@@ -236,6 +236,9 @@ var et2_taglist = (function(){ "use strict"; return et2_selectbox.extend([et2_IR
 			renderer: jQuery.proxy(this.options.listRenderer || this.selectionRenderer,this),
 			maxSelection: this.options.multiple ? this.options.maxSelection : 1,
 			maxSelectionRenderer: jQuery.proxy(function(v) { this.egw().lang('You can not choose more then %1 item(s)!', v); }, this),
+			minCharsRenderer: jQuery.proxy(function(v){ 
+				this.egw().lang(v == 1 ? 'Please type 1 more character' : 'Please type %1 more characters',v);
+			}, this),
 			width: this.options.width,	// propagate width
 			highlight: false,	// otherwise renderer have to return strings
 			selectFirst: true,
@@ -401,6 +404,11 @@ var et2_taglist = (function(){ "use strict"; return et2_selectbox.extend([et2_IR
 		// Do size limit checks
 		this.resize();
 
+		// Make sure magicsuggest loses focus class to prevent issues with
+		// multiple on the page
+		this.div.on('blur', 'input', function() {
+			jQuery('.ms-ctn-focus', widget.div).removeClass('ms-ctn-focus');
+		})
 		return true;
 	},
 
@@ -1030,7 +1038,18 @@ var et2_taglist_account = (function(){ "use strict"; return et2_taglist.extend(
 					this.deferred_loading++;
 					this.egw().link_title('api-accounts', v, function(label) {
 						this.deferred_loading--;
-						if (label) this.set_value(values);
+						if (label)
+						{
+							// Seems the magic suggest can not deal with broken taglist value
+							// like selected value with no label set and maxSelection set. This
+							// trys to first unset maxSelection and set value to magix suggest taglist
+							// object then calls set_value of the widget taglist, and at the end
+							// re-set the maxSelection option again.
+							if (this.options.maxSelection) this.taglist.setMaxSelection(null);
+							this.taglist.setValue([{id:v,label:label}]);
+							this.set_value(values);
+							this.taglist.setMaxSelection(this.options.maxSelection);
+						}
 					}, this);
 				}
 			}
@@ -1075,6 +1094,12 @@ var et2_taglist_email = (function(){ "use strict"; return et2_taglist.extend(
 			type: "boolean",
 			"default": false,
 			description: "Set to false to allow comma in entered content"
+		},
+		domainOptional: {
+			name: "Domain optional",
+			description:"Allows domain part of an email address to be optional",
+			default: false,
+			type: "boolean"
 		}
 	},
 	lib_options: {
@@ -1089,11 +1114,19 @@ var et2_taglist_email = (function(){ "use strict"; return et2_taglist.extend(
 		{
 			this.options.autocomplete_params.include_lists = true;
 		}
+
+		// Make domain name optional for EMAIL_PREG if it's requested
+		if (this.options.domainOptional)
+		{
+			et2_url.prototype.EMAIL_PREG = new RegExp(/^(([^\042',<][^,<]+|\042[^\042]+\042|\'[^\']+\'|)\s?<)?[^\x00-\x20()<>@,;:\042\[\]\x80-\xff]+(@([a-z0-9ÄÖÜäöüß](|[a-z0-9ÄÖÜäöüß_-]*[a-z0-9ÄÖÜäöüß])\.)+[a-z]{2,})?>?$/i);
+		}
 	},
 
 	// PREG for validation comes from et2_url
-	//EMAIL_PREG: new RegExp(/^[^\x00-\x20()<>@,;:\".\[\]]+@([a-z0-9ÄÖÜäöüß](|[a-z0-9ÄÖÜäöüß_-]*[a-z0-9ÄÖÜäöüß])\.)+[a-z]{2,6}/),
-
+	//EMAIL_PREG: new RegExp(/^(([^\042',<][^,<]+|\042[^\042]+\042|\'[^\']+\'|)\s?<)?[^\x00-\x20()<>@,;:\042\[\]\x80-\xff]+@([a-z0-9ÄÖÜäöüß](|[a-z0-9ÄÖÜäöüß_-]*[a-z0-9ÄÖÜäöüß])\.)+[a-z]{2,}>?$/i),
+	//
+	// REGEXP with domain part to be optional
+	// new RegExp(/^(([^\042',<][^,<]+|\042[^\042]+\042|\'[^\']+\'|)\s?<)?[^\x00-\x20()<>@,;:\042\[\]\x80-\xff]+(@([a-z0-9ÄÖÜäöüß](|[a-z0-9ÄÖÜäöüß_-]*[a-z0-9ÄÖÜäöüß])\.)+[a-z]{2,})?>?$/i)
 	selectionRenderer: function(item)
 	{
 		// Trim
@@ -1121,33 +1154,41 @@ var et2_taglist_email = (function(){ "use strict"; return et2_taglist.extend(
 			if (!valid)
 			{
 				var parts = item.id.split(/, */);
+				var items = [], errors = [];
 				if (parts.length > 1)
 				{
-					valid = true;
 					for(var i=0; i < parts.length; ++i)
 					{
 						parts[i] = parts[i].trim();
 						if (!et2_url.prototype.EMAIL_PREG.test(parts[i]))
 						{
-							valid = false;
-							break;
+							errors.push(parts[i]);
+						}
+						else
+						{
+							items.push({id: parts[i], label: parts[i]});
 						}
 					}
-					if (valid)
+					item.id = item.label = errors.length ? errors.join(', ') : items.shift().id;
+					valid = !errors.length;
+					// insert further parts into taglist, after validation first one
+					if (items.length)
 					{
-						item.id = item.label = parts.shift();
-						// insert further parts into taglist, after validation first one
-						var taglist = this.taglist;
-						window.setTimeout(function()
+						// a bit ugly but unavoidable
+						if (valid)
 						{
-							var items = [];
-							for(var i=0; i < parts.length; ++i)
+							// if no error, we need to delay insert, as taglist gets into wired state and shows first item twice
+							var taglist = this.taglist;
+							window.setTimeout(function()
 							{
-								items.push({id: parts[i], label: parts[i]});
-
-							}
-							taglist.addToSelection(items);
-						}, 10);
+								taglist.addToSelection(items);
+							}, 10);
+						}
+						else
+						{
+							// if we have an error, we need to insert items now, to not overwrite the error
+							this.taglist.addToSelection(items);
+						}
 					}
 				}
 			}
