@@ -74,9 +74,10 @@ var et2_vfs = (function(){ "use strict"; return et2_valueWidget.extend([et2_IDet
 		// calculate path as parent of name, which can contain slashes
 		// eg. _value.path=/home/ralf/sub/file, _value.name=sub/file --> path=/home/ralf
 		// --> generate clickable fields for sub/ + file
-		if(_value.path.indexOf(_value.name) >= 0)
+		var sub_path = path.substr(0, _value.path.length-_value.name.length-1);
+		if(_value.path.indexOf(_value.name) >= 0 && sub_path[sub_path.length-1] === '/')
 		{
-			path = path.substr(0, _value.path.length-_value.name.length-1);
+			path = sub_path;
 			var path_offset = path.split('/').length;
 			var path_parts = _value.path.split('/');
 		}
@@ -720,7 +721,7 @@ var et2_vfsUpload = (function(){ "use strict"; return et2_file.extend(
 		if(sender !== this && sender._type.indexOf('vfs') >= 0 )
 		{
 			var value = sender.getValue && sender.getValue() || sender.options.value || {};
-			var row =  jQuery('[data-path="'+(value.path)+'"]',this.list);
+			var row =  jQuery("[data-path='"+(value.path.replace(/'/g, '&quot'))+"']",this.list);
 			if(sender._type === 'vfs-mime')
 			{
 				return jQuery('.icon',row).get(0) || null;
@@ -750,9 +751,41 @@ var et2_vfsUpload = (function(){ "use strict"; return et2_file.extend(
 		return extra;
 	},
 
+	/**
+	 * A file upload is finished, update the UI
+	 */
+	finishUpload: function(file, response) {
+		var result = this._super.apply(this, arguments);
+
+		if(typeof response == 'string') response = jQuery.parseJSON(response);
+		if(response.response[0] && typeof response.response[0].data.length == 'undefined') {
+			for(var key in response.response[0].data) {
+				var value = response.response[0].data[key];
+				if(value && value.path)
+				{
+					this._addFile(value);
+					jQuery("[data-file='"+file.fileName.replace(/'/g, '&quot')+"']",this.progress).hide();
+				}
+			}
+		}
+		return result;
+	},
+
 	_addFile: function(file_data) {
+		if(jQuery("[data-path='"+file_data.path.replace(/'/g, '&quot')+"']").remove().length)
+		{
+			for(var child_index = this._children.length-1; child_index >= 0; child_index--)
+			{
+				var child = this._children[child_index];
+				if(child.options.value.path === file_data.path)
+				{
+					this.removeChild(child);
+					child.free();
+				}
+			}
+		}
 		var row = jQuery(document.createElement("tr"))
-			.attr("data-path", file_data.path)
+			.attr("data-path", file_data.path.replace(/'/g, '&quot'))
 			.attr("draggable", "true")
 			.appendTo(this.list);
 		var mime = jQuery(document.createElement("td"))
@@ -782,7 +815,7 @@ var et2_vfsUpload = (function(){ "use strict"; return et2_file.extend(
 							{
 								egw.json("filemanager_ui::ajax_action", [
 										'delete',
-										[row.attr('data-path')],
+										[row.attr('data-path').replace(/&quot/g, "'")],
 										''
 									],
 									function(data) {
@@ -873,6 +906,11 @@ var et2_vfsSelect = (function(){ "use strict"; return et2_inputWidget.extend(
 			.addClass("et2_button et2_vfs_btn")
 			.css("background-image","url("+this.egw().image("filemanager/navbar")+")");
 
+		if(this.options.readonly)
+		{
+			this.button.hide();
+		}
+		
 		if (this.options.button_caption != "")
 		{
 			this.button.text(this.options.button_caption);
@@ -982,6 +1020,19 @@ var et2_vfsSelect = (function(){ "use strict"; return et2_inputWidget.extend(
 		this.options.method_id = id;
 	},
 
+	set_readonly: function(readonly) {
+		this.options.readonly = Boolean(readonly);
+		debugger;
+		if(this.options.readonly)
+		{
+			this.button.hide();
+		}
+		else
+		{
+			this.button.show();
+		}
+	},
+
 	getValue: function() {
 		return this.value;
 	}
