@@ -170,6 +170,14 @@ var fw_base = (function(){ "use strict"; return Class.extend(
 		{
 			_url = _app.indexUrl;
 		}
+		// If there are query parameters and URL is the same, don't just refresh
+		// because the app's state may have changed since last time
+		else if (_app.browser != null && _url == _app.browser.currentLocation
+			&& !_url.match(/menuaction=[^&]+&ajax=true/))
+		{
+			// Reset current so new url loads fully
+			_app.browser.currentLocation = _app.indexUrl;
+		}
 		else if (_app.browser != null &&
 			// check if app has its own linkHandler
 			!(this.applications[_app.appName].app_refresh) &&
@@ -884,7 +892,8 @@ var fw_base = (function(){ "use strict"; return Class.extend(
 			}
 
 			this.tabsUi.setAppHeader(this.activeApp.app_header);
-			document.title = this.activeApp.website_title;
+			var default_title = egw.config('site_title', 'phpgwapi') + ' ['+this.activeApp.displayName+']';
+			document.title = this.activeApp.website_title || default_title;
 		}
 
 		this.resizeHandler();
