@@ -473,7 +473,16 @@ var AppJS = (function(){ "use strict"; return Class.extend(
 		var templateName = mobileViewTemplate[0];
 		var templateTimestamp = mobileViewTemplate[1];
 		var templateURL = egw.webserverUrl+ '/' + this.appname + '/templates/mobile/'+templateName+'.xet'+'?'+templateTimestamp;
-		var data = {content:content, readonlys:{'__ALL__':true,'link_to':false}, currentapp:this.appname};
+
+		var data = {
+			'content': content,
+			'readonlys': {'__ALL__':true,'link_to':false},
+			'currentapp': this.appname,
+			'langRequire': this.et2.getArrayMgr('langRequire').data,
+			'sel_options': this.et2.getArrayMgr('sel_options').data,
+			'modifications': this.et2.getArrayMgr('modifications').data,
+			'validation_errors': this.et2.getArrayMgr('validation_errors').data
+		};
 
 		// etemplate2 object for view
 		this.et2_view = new etemplate2 (this.viewTemplate[0], false);
@@ -730,6 +739,7 @@ var AppJS = (function(){ "use strict"; return Class.extend(
 		buttons['save'] = {
 			text: this.egw.lang('save'),
 			default: true,
+			style: 'background-image: url('+this.egw.image('save')+')',
 			click: function() {
 				// Add a new favorite
 				var name = jQuery("#name",this);
@@ -798,14 +808,18 @@ var AppJS = (function(){ "use strict"; return Class.extend(
 				jQuery(this).dialog("close");
 			}
 		};
-		buttons[this.egw.lang("cancel")] = function() {
-			if(typeof self.favorite_popup.group !== 'undefined' && self.favorite_popup.group.set_value)
-			{
-				self.favorite_popup.group.set_value(null);
+		buttons['cancel'] = {
+			text: this.egw.lang("cancel"),
+			style: 'background-image: url('+this.egw.image('cancel')+')',
+			click: function() {
+				if(typeof self.favorite_popup.group !== 'undefined' && self.favorite_popup.group.set_value)
+				{
+					self.favorite_popup.group.set_value(null);
+				}
+				jQuery(this).dialog("close");
 			}
-			jQuery(this).dialog("close");
 		};
-
+		
 		this.favorite_popup.dialog({
 			autoOpen: false,
 			modal: true,
@@ -888,7 +902,7 @@ var AppJS = (function(){ "use strict"; return Class.extend(
 			request.sendRequest(true);
 		};
 		et2_dialog.show_dialog(do_delete, (egw.lang("Delete") + " " +name +"?"),
-			"Delete", et2_dialog.YES_NO, et2_dialog.QUESTION_MESSAGE);
+			egw.lang("Delete"), et2_dialog.YES_NO, et2_dialog.QUESTION_MESSAGE);
 
 		return false;
 	},
