@@ -197,6 +197,24 @@ class Accounts
 		//error_log(__METHOD__.'('.array2string($param).') '.function_backtrace());
 		if (!isset($param['active'])) $param['active'] = true;	// default is true = only return active accounts
 
+		// Check for lang(Group) in search - if there, we search all groups
+		$group_index = array_search(strtolower(lang('Group')), array_map('strtolower', $query = explode(' ',$param['query'])));
+		if($group_index !== FALSE)
+		{
+			// do not return any groups for account-selection == "none"
+			if ($GLOBALS['egw_info']['user']['preferences']['common']['account_selection'] === 'none' &&
+				!isset($GLOBALS['egw_info']['user']['apps']['admin']))
+			{
+				$this->total = 0;
+				return array();
+			}
+			// only return own memberships for account-selection == "groupmembers"
+			$param['type'] = $GLOBALS['egw_info']['user']['preferences']['common']['account_selection'] === 'groupmembers' &&
+				!isset($GLOBALS['egw_info']['user']['apps']['admin']) ? 'owngroups' : 'groups';
+			// Remove the 'group' from the query, but only one (eg: Group NoGroup -> NoGroup)
+			unset($query[$group_index]);
+			$param['query'] = implode(' ', $query);
+		}
 		self::setup_cache();
 		$account_search = &self::$cache['account_search'];
 		$serial = serialize($param);
@@ -356,20 +374,15 @@ class Accounts
 	/**
 	 * Reads the data of one account
 	 *
-	 * It's depricated to use read with out parameter to read the internal data of this class!!!
 	 * All key of the returned array use the 'account_' prefix.
 	 * For backward compatibility some values are additionaly availible without the prefix, using them is depricated!
 	 *
-	 * @param int|string $id numeric account_id or string with account_lid (use of default value of 0 is depricated!!!)
+	 * @param int|string $id numeric account_id or string with account_lid
 	 * @param boolean $set_depricated_names =false set _additionaly_ the depricated keys without 'account_' prefix
 	 * @return array/boolean array with account data (keys: account_id, account_lid, ...) or false if account not found
 	 */
-	function read($id=0,$set_depricated_names=false)
+	function read($id, $set_depricated_names=false)
 	{
-		if (!$id)	// deprecated use!!!
-		{
-			return $this->data ? $this->data : $this->read_repository();
-		}
 		if (!is_int($id) && !is_numeric($id))
 		{
 			$id = $this->name2id($id);
@@ -675,16 +688,18 @@ class Accounts
 	}
 
 	/**
-	 * test if an account is expired
+	 * Test if given an account is expired
 	 *
-	 * Can be used static if array with user-data is supplied
-	 *
-	 * @param array $data =null array with account data, not specifying the account is depricated!!!
+	 * @param int|string|array $data account_(l)id or array with account-data
 	 * @return boolean true=expired (no more login possible), false otherwise
 	 */
-	function is_expired($data=null)
+	static function is_expired($data)
 	{
-		if (is_null($data)) $data = $this->data;	// depricated use
+		if (is_null($data))
+		{
+			throw new Exception\WrongParameter('Missing parameter to Accounts::is_active()');
+		}
+		if (!is_array($data)) $data = self::getInstance()->read($data);
 
 		$expires = isset($data['account_expires']) ? $data['account_expires'] : $data['expires'];
 
@@ -694,14 +709,12 @@ class Accounts
 	/**
 	 * Test if an account is active - NOT deactivated or expired
 	 *
-	 * Can be used static if array with user-data is supplied
-	 *
-	 * @param int|array $data account_id or array with account-data
+	 * @param int|string|array $data account_(l)id or array with account-data
 	 * @return boolean false if account does not exist, is expired or decativated, true otherwise
 	 */
-	function is_active($data)
+	static function is_active($data)
 	{
-		if (!is_array($data)) $data = $this->read($data);
+		if (!is_array($data)) $data = self::getInstance()->read($data);
 
 		return $data && !(self::is_expired($data) || $data['account_status'] != 'A');
 	}
@@ -791,7 +804,7 @@ class Accounts
 	 */
 	function exists($account_id)
 	{
-		if (!($data = $this->read($account_id)))
+		if (!$account_id || !($data = $this->read($account_id)))
 		{
 			return 0;
 		}
