@@ -559,6 +559,19 @@ class Cache
 		return $providers[$level];
 	}
 
+	/**
+	 * Get class-name of caching provider
+	 *
+	 * @param string $level
+	 * @return string class-name of provider
+	 */
+	public static function getProvider($level=self::INSTANCE)
+	{
+		$provider = self::get_provider($level);
+
+		return get_class($provider);
+	}
+
 	/**
 	 * Get a system configuration, even if in setup and it's not read
 	 *
@@ -604,7 +617,7 @@ class Cache
 	 * Flush (delete) whole (instance) cache or application/class specific part of it
 	 *
 	 * @param string $level =self::INSTANCE
-	 * @param string $app =null
+	 * @param string $app =null app-name or "all" to empty complete cache
 	 */
 	static public function flush($level=self::INSTANCE, $app=null)
 	{
@@ -615,7 +628,7 @@ class Cache
 		}
 		else
 		{
-			if (!$provider->flush(self::keys($level, $app)))
+			if (!$provider->flush($app !== "all" ? self::keys($level, $app) : array()))
 			{
 				if ($level == self::INSTANCE)
 				{
@@ -730,11 +743,13 @@ class Cache
 	}
 }
 
-// setting apc as default provider, if apc_fetch function exists AND further checks in Api\Cache\Apc recommed it
+// setting apc(u) as default provider, if apc(u)_fetch function exists AND further checks in Api\Cache\Apc(u) recommed it
 if (is_null(Cache::$default_provider))
 {
-	Cache::$default_provider = function_exists('apc_fetch') && Cache\Apc::available() ?
-		'EGroupware\Api\Cache\Apc' : 'EGroupware\Api\Cache\Files';
+	Cache::$default_provider =
+		function_exists('apcu_fetch') && Cache\Apcu::available() ? 'EGroupware\Api\Cache\Apcu' :
+			(function_exists('apc_fetch') && Cache\Apc::available() ? 'EGroupware\Api\Cache\Apc' :
+				'EGroupware\Api\Cache\Files');
 }
 
 //error_log('Cache::$default_provider='.array2string(Cache::$default_provider));
