@@ -1309,7 +1309,7 @@ class CalDAV extends HTTP_WebDAV_Server
 
 			case 'attachment-remove':
 			case 'attachment-update':
-				if (empty($_GET['managed-id']) || !($path = self::managed_id2path($_GET['managed-id'], $handler->app, $id)))
+				if (empty($_GET['managed-id']) || !($path = self::managed_id2path($_GET['managed-id'], $handler->app, $entry['id'])))
 				{
 					self::xml_error(self::mkprop(self::CALDAV, 'valid-managed-id-parameter', ''));
 					return '403 Forbidden';
@@ -2216,9 +2216,9 @@ class CalDAV extends HTTP_WebDAV_Server
 	 *
 	 * Does NOT return and get installed in constructor.
 	 *
-	 * @param \Exception $e
+	 * @param \Exception|\Error $e
 	 */
-	public static function exception_handler(\Exception $e)
+	public static function exception_handler($e)
 	{
 		// logging exception as regular egw_execption_hander does
 		$headline = null;
