@@ -23,6 +23,13 @@ use calendar_bo;	// to_do: do NOT require it, just use if there
  */
 class Contacts extends Contacts\Storage
 {
+
+	/**
+	 * Birthdays are read into the cache, cache is expired when a
+	 * birthday changes, or after 10 days.
+	 */
+	const BIRTHDAY_CACHE_TIME = 864000; /* 10 days*/
+
 	/**
 	 * @var int $now_su actual user (!) time
 	 */
@@ -848,9 +855,10 @@ class Contacts extends Contacts\Storage
 	*
 	* @param array &$contact contact array from etemplate::exec
 	* @param boolean $ignore_acl =false should the acl be checked or not
+	* @param boolean $touch_modified =true should modified/r be updated
 	* @return int/string/boolean id on success, false on failure, the error-message is in $this->error
 	*/
-	function save(&$contact,$ignore_acl=false)
+	function save(&$contact, $ignore_acl=false, $touch_modified=true)
 	{
 		// remember if we add or update a entry
 		if (($isUpdate = $contact['id']))
@@ -885,8 +893,8 @@ class Contacts extends Contacts\Storage
 				$contact['owner'] = $this->default_addressbook ? $this->default_addressbook : $this->user;
 			}
 			// allow admins to import contacts with creator / created date set
-			if (!$contact['creator'] || !$this->is_admin($contact)) $contact['creator'] = $this->user;
-			if (!$contact['created'] || !$this->is_admin($contact)) $contact['created'] = $this->now_su;
+			if (!$contact['creator'] || !$ignore_acl && !$this->is_admin($contact)) $contact['creator'] = $this->user;
+			if (!$contact['created'] || !$ignore_acl && !$this->is_admin($contact)) $contact['created'] = $this->now_su;
 
 			if (!$contact['tid']) $contact['tid'] = 'n';
 		}
@@ -932,8 +940,11 @@ class Contacts extends Contacts\Storage
 		}
 
 		// last modified
-		$contact['modifier'] = $this->user;
-		$contact['modified'] = $this->now_su;
+		if ($touch_modified)
+		{
+			$contact['modifier'] = $this->user;
+			$contact['modified'] = $this->now_su;
+		}
 		// set full name and fileas from the content
 		if (!isset($contact['n_fn']))
 		{
@@ -1018,6 +1029,15 @@ class Contacts extends Contacts\Storage
 				if (!isset($this->tracking)) $this->tracking = new Contacts\Tracking($this);
 				$this->tracking->track($to_write, $old ? $old : null, null, $deleted);
 			}
+
+			// Expire birthday cache for this year and next if birthday changed
+			if($isUpdate && $old['bday'] !== $to_write['bday'] || !$isUpdate && $to_write['bday'])
+			{
+				$year = (int) date('Y',time());
+				Cache::unsetInstance(__CLASS__,"birthday-$year-{$to_write['owner']}");
+				$year++;
+				Cache::unsetInstance(__CLASS__,"birthday-$year-{$to_write['owner']}");
+			}
 		}
 
 		return $this->error ? false : $contact['id'];
@@ -1597,23 +1617,18 @@ class Contacts extends Contacts\Storage
 	/**
 	 * Read the next and last event of given contacts
 	 *
-	 * @param array $ids contact_id's
+	 * @param array $uids participant IDs.  Contacts should be c<contact_id>, user accounts <account_id>
 	 * @param boolean $extra_title =true if true, use a short date only title and put the full title as extra_title (tooltip)
 	 * @return array
 	 */
-	function read_calendar($ids,$extra_title=true)
+	function read_calendar($uids,$extra_title=true)
 	{
 		if (!$GLOBALS['egw_info']['user']['apps']['calendar']) return array();
 
-		$uids = array();
-		foreach($ids as $id)
-		{
-			if (is_numeric($id)) $uids[] = 'c'.$id;
-		}
-		if (!$uids) return array();
-
 		$bocal = new calendar_bo();
 		$events = $bocal->search(array(
+			'start' => strtotime('2 years ago'),
+			'end'	=> strtotime('2 years from now'),
 			'users' => $uids,
 			'enum_recuring' => true,
 		));
@@ -1625,17 +1640,16 @@ class Contacts extends Contacts\Storage
 		{
 			foreach($event['participants'] as $uid => $status)
 			{
-				if ($uid[0] != 'c' || ($status == 'R' && !$GLOBALS['egw_info']['user']['preferences']['calendar']['show_rejected']))
+				if ($status == 'R' && !$GLOBALS['egw_info']['user']['preferences']['calendar']['show_rejected'])
 				{
 					continue;
 				}
-				$id = (int)substr($uid,1);
 
 				if ($event['start'] < $this->now_su)	// past event --> check for last event
 				{
-					if (!isset($calendars[$id]['last_event']) || $event['start'] > $calendars[$id]['last_event'])
+					if (!isset($calendars[$uid]['last_event']) || $event['start'] > $calendars[$uid]['last_event'])
 					{
-						$calendars[$id]['last_event'] = $event['start'];
+						$calendars[$uid]['last_event'] = $event['start'];
 						$link = array(
 							'id' => $event['id'],
 							'app' => 'calendar',
@@ -1649,14 +1663,14 @@ class Contacts extends Contacts\Storage
 							$link['extra_title'] = $link['title'];
 							$link['title'] = date($GLOBALS['egw_info']['user']['preferences']['common']['dateformat'],$event['start']);
 						}
-						$calendars[$id]['last_link'] = $link;
+						$calendars[$uid]['last_link'] = $link;
 					}
 				}
 				else	// future event --> check for next event
 				{
-					if (!isset($calendars[$id]['next_event']) || $event['start'] < $calendars[$id]['next_event'])
+					if (!isset($calendars[$uid]['next_event']) || $event['start'] < $calendars[$uid]['next_event'])
 					{
-						$calendars[$id]['next_event'] = $event['start'];
+						$calendars[$uid]['next_event'] = $event['start'];
 						$link = array(
 							'id' => $event['id'],
 							'app' => 'calendar',
@@ -1670,7 +1684,7 @@ class Contacts extends Contacts\Storage
 							$link['extra_title'] = $link['title'];
 							$link['title'] = date($GLOBALS['egw_info']['user']['preferences']['common']['dateformat'],$event['start']);
 						}
-						$calendars[$id]['next_link'] = $link;
+						$calendars[$uid]['next_link'] = $link;
 					}
 				}
 			}
@@ -1678,6 +1692,68 @@ class Contacts extends Contacts\Storage
 		return $calendars;
 	}
 
+	/**
+	 * Read the holidays (birthdays) from the given addressbook, either from the
+	 * instance cache, or read them & cache for next time.  Cached for HOLIDAY_CACHE_TIME.
+	 *
+	 * @param int $addressbook - Addressbook to search.  We cache them separately in the instance.
+	 * @param int $year
+	 */
+	public function read_birthdays($addressbook, $year)
+	{
+		$birthdays = Cache::getInstance(__CLASS__,"birthday-$year-$addressbook");
+		if($birthdays !== null)
+		{
+			return $birthdays;
+		}
+
+		$birthdays = array();
+		$filter = array(
+			'owner' => (int)$addressbook,
+			'n_family' => "!''",
+			'bday' => "!''",
+		);
+		$bdays =& $this->search('',array('id','n_family','n_given','n_prefix','n_middle','bday'),
+			'contact_bday ASC',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter);
+
+		if ($bdays)
+		{
+			// sort by month and day only
+			usort($bdays, function($a, $b)
+			{
+				return (int) $a['bday'] == (int) $b['bday'] ?
+					strcmp($a['bday'], $b['bday']) :
+					(int) $a['bday'] - (int) $b['bday'];
+			});
+			foreach($bdays as $pers)
+			{
+				if (empty($pers['bday']) || $pers['bday']=='0000-00-00 0' || $pers['bday']=='0000-00-00' || $pers['bday']=='0.0.00')
+				{
+					//error_log(__METHOD__.__LINE__.' Skipping entry for invalid birthday:'.array2string($pers));
+					continue;
+				}
+				list($y,$m,$d) = explode('-',$pers['bday']);
+				if ($y > $year)
+				{
+					// not yet born
+					continue;
+				}
+				$birthdays[sprintf('%04d%02d%02d',$year,$m,$d)][] = array(
+					'day'       => $d,
+					'month'     => $m,
+					'occurence' => 0,
+					'name'      => lang('Birthday').' '.($pers['n_given'] ? $pers['n_given'] : $pers['n_prefix']).' '.$pers['n_middle'].' '.
+						$pers['n_family'].
+						($GLOBALS['egw_info']['server']['hide_birthdays'] == 'age' ? ' '.($year - $y): '').
+						($y && in_array($GLOBALS['egw_info']['server']['hide_birthdays'], array('','age')) ? ' ('.$y.')' : ''),
+					'birthyear' => $y,	// this can be used to identify birthdays from holidays
+				);
+			}
+		}
+		Cache::setInstance(__CLASS__,"birthday-$year-$addressbook", $birthdays, self::BIRTHDAY_CACHE_TIME);
+		return $birthdays;
+	}
+
 	/**
 	 * Called by delete-account hook, when an account get deleted --> deletes/moves the personal addressbook
 	 *
