@@ -114,7 +114,7 @@ class Ldap
 	 */
 	var $search_attributes = array(
 		'n_family','n_middle','n_given','org_name','org_unit',
-		'adr_one_location','adr_two_location','note',
+		'adr_one_locality','adr_two_locality','note',
 		'email','mozillasecondemail','uidnumber',
 	);
 
@@ -872,7 +872,22 @@ class Ldap
 					$order[] = $o;
 				}
 			}
-			$rows = ExecMethod2('phpgwapi.arrayfunctions.arfsort',$rows,$order,$sort);
+			usort($rows, function($a, $b) use ($order, $sort)
+			{
+				foreach($order as $f)
+				{
+					if($sort == 'ASC')
+					{
+						$strc = strcmp($a[$f], $b[$f]);
+					}
+					else
+					{
+						$strc = strcmp($b[$f], $a[$f]);
+					}
+					if ($strc) return $strc;
+				}
+				return 0;
+			});
 		}
 		// if requested ($start !== false) return only limited resultset
 		if (is_array($start))
@@ -918,8 +933,12 @@ class Ldap
 					}
 					elseif ($value)
 					{
-						$filters .= '(uidNumber='.Api\Ldap::quote($value).')';
-
+						if (is_array($value)) $filters .= '(|';
+						foreach((array)$value as $value)
+						{
+							$filters .= '(uidNumber='.(int)$value.')';
+						}
+						if (is_array($value)) $filters .= ')';
 					}
 					break;
 
@@ -958,6 +977,10 @@ class Ldap
 					$filters .= $this->ids_filter($value);
 					break;
 
+				case 'list':
+					$filters .= $this->membershipFilter($value);
+					break;
+
 				default:
 					$matches = null;
 					if (!is_int($key))
@@ -994,6 +1017,28 @@ class Ldap
 		return $filters;
 	}
 
+	/**
+	 * Return a LDAP filter by group membership
+	 *
+	 * @param int $gid gidNumber (< 0 as used in EGroupware!)
+	 * @return string filter or '' if $gid not < 0
+	 */
+	function membershipFilter($gid)
+	{
+		$filter = '';
+		if ($gid < 0)
+		{
+			$filter .= '(|';
+			// unfortunately we have no group-membership attribute in LDAP, like in AD
+			foreach($GLOBALS['egw']->accounts->members($gid, true) as $account_id)
+			{
+				$filter .= '(uidNumber='.(int)$account_id.')';
+			}
+			$filter .= ')';
+		}
+		return $filter;
+	}
+
 	/**
 	 * Perform the actual ldap-search, retrieve and convert all entries
 	 *
@@ -1335,7 +1380,7 @@ class Ldap
 	{
 		if ($data['c'])
 		{
-			$contact['adr_one_countryname'] = ExecMethod('phpgwapi.country.get_full_name',$data['c'][0]);
+			$contact['adr_one_countryname'] = Api\Country::get_full_name($data['c'][0]);
 		}
 	}
 
@@ -1357,7 +1402,7 @@ class Ldap
 		}
 		elseif ($data['adr_one_countryname'])
 		{
-			$ldapContact['c'] = ExecMethod('phpgwapi.country.country_code',$data['adr_one_countryname']);
+			$ldapContact['c'] = Api\Country::country_code($data['adr_one_countryname']);
 			if ($ldapContact['c'] && strlen($ldapContact['c']) > 2)	// Bad countryname when "custom" selected!
 			{
 				$ldapContact['c'] = array(); // should return error...
@@ -1403,7 +1448,7 @@ class Ldap
 		}
 		elseif ($data['adr_one_countryname'])
 		{
-			$ldapContact['c'] = ExecMethod('phpgwapi.country.country_code',$data['adr_one_countryname']);
+			$ldapContact['c'] = Api\Country::country_code($data['adr_one_countryname']);
 			if ($ldapContact['c'] && strlen($ldapContact['c']) > 2)	// Bad countryname when "custom" selected!
 			{
 				$ldapContact['c'] = array(); // should return error...
