@@ -118,7 +118,7 @@ class Sql extends Api\Storage
 		if ($advanced_search || (isset($param['wildcard']) && !empty($param['wildcard']))) $wildcard = ($param['wildcard']?$param['wildcard']:'');
 
 		// fix cat_id filter to search in comma-separated multiple cats and return subcats
-		if ((int)$filter['cat_id'])
+		if ($filter['cat_id'])
 		{
 			$filter[] = $this->_cat_filter($filter['cat_id']);
 			unset($filter['cat_id']);
@@ -262,9 +262,10 @@ class Sql extends Api\Storage
 	 * @param string $join ='' sql to do a join, added as is after the table-name, eg. ", table2 WHERE x=y" or
 	 *	"LEFT JOIN table2 ON (x=y)", Note: there's no quoting done on $join!
 	 * @param boolean $need_full_no_count =false If true an unlimited query is run to determine the total number of rows, default false
+	 * @param boolean $ignore_acl =false true: no acl check
 	 * @return boolean/array of matching rows (the row is an array of the cols) or False
 	 */
-	function &search($criteria,$only_keys=True,$order_by='',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter=null,$join='',$need_full_no_count=false)
+	function &search($criteria,$only_keys=True,$order_by='',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter=null,$join='',$need_full_no_count=false, $ignore_acl=false)
 	{
 		if ((int) $this->debug >= 4) echo '<p>'.__METHOD__.'('.array2string($criteria).','.array2string($only_keys).",'$order_by','$extra_cols','$wildcard','$empty','$op',$start,".array2string($filter).",'$join')</p>\n";
 		//error_log(__METHOD__.'('.array2string($criteria,true).','.array2string($only_keys).",'$order_by', ".array2string($extra_cols).",'$wildcard','$empty','$op',$start,".array2string($filter).",'$join')");
@@ -285,12 +286,13 @@ class Sql extends Api\Storage
 				$filter['cat_id'] = substr($filter['cat_id'],1);
 				$not = 'NOT';
 			}
-			$filter[] = $this->_cat_filter((int)$filter['cat_id'],$not);
+			$filter[] = $this->_cat_filter($filter['cat_id'],$not);
 			unset($filter['cat_id']);
 		}
 
 		// add filter for read ACL in sql, if user is NOT the owner of the addressbook
-		if (isset($this->grants) && !(isset($filter['owner']) && $filter['owner'] == $GLOBALS['egw_info']['user']['account_id']))
+		if (isset($this->grants) && !$ignore_acl &&
+			!(isset($filter['owner']) && $filter['owner'] == $GLOBALS['egw_info']['user']['account_id']))
 		{
 			// add read ACL for groupmembers (they have no
 			if ($GLOBALS['egw_info']['user']['preferences']['common']['account_selection'] == 'groupmembers' &&
@@ -344,7 +346,16 @@ class Sql extends Api\Storage
 		}
 		if (isset($filter['list']))
 		{
-			$join .= " JOIN $this->ab2list_table ON $this->table_name.contact_id=$this->ab2list_table.contact_id AND list_id=".(int)$filter['list'];
+			if ($filter['list'] < 0)
+			{
+				$join .= " JOIN egw_acl ON $this->table_name.account_id=acl_account AND acl_appname='phpgw_group' AND ".
+					$this->db->expression('egw_acl', array('acl_location' => $filter['list']));
+			}
+			else
+			{
+				$join .= " JOIN $this->ab2list_table ON $this->table_name.contact_id=$this->ab2list_table.contact_id AND ".
+					$this->db->expression($this->ab2list_table, array('list_id' => $filter['list']));
+			}
 			unset($filter['list']);
 		}
 		// add join to show only active accounts (only if accounts are shown and in sql and we not already join the accounts table, eg. used by admin)
@@ -429,7 +440,7 @@ class Sql extends Api\Storage
 	 * fix cat_id filter to search in comma-separated multiple cats and return subcats
 	 *
 	 * @internal
-	 * @param int $cat_id
+	 * @param int|array $cat_id
 	 * @return string sql to filter by given cat
 	 */
 	function _cat_filter($cat_id, $not='')
@@ -438,7 +449,7 @@ class Sql extends Api\Storage
 		{
 			$GLOBALS['egw']->categories = new Api\Categories;
 		}
-		foreach($GLOBALS['egw']->categories->return_all_children((int)$cat_id) as $cat)
+		foreach($GLOBALS['egw']->categories->return_all_children($cat_id) as $cat)
 		{
 			$cat_filter[] = $this->db->concat("','",cat_id,"','")." $not LIKE '%,$cat,%'";
 		}
@@ -548,6 +559,28 @@ class Sql extends Api\Storage
 				$lists[$row['list_id']]['members'][] = $row[$member_attr];
 			}
 		}
+		/* groups as list are implemented currently in Contacts\Storage::get_lists() for all backends
+		if ($uid_column == 'list_owner' && in_array(0, (array)$uids) && (!$limit_in_ab || in_array(0, (array)$limit_in_ab)))
+		{
+			foreach($GLOBALS['egw']->accounts->search(array(
+				'type' => 'groups'
+			)) as $account_id => $group)
+			{
+				$list = array(
+					'list_id' => $account_id,
+					'list_name' => Api\Accounts::format_username($group['account_lid'], '', '', $account_id),
+					'list_owner' => 0,
+					'list_uid' => 'group'.$account_id,
+					'list_carddav_name' => 'group'.$account_id.'.vcf',
+					'list_etag' => md5(json_encode($GLOBALS['egw']->accounts->members($account_id, true)))
+				);
+				if ($member_attr)
+				{
+					$list['members'] = array();	// ToDo
+				}
+				$lists[(string)$account_id] = $list;
+			}
+		}*/
 		//error_log(__METHOD__.'('.array2string($uids).", '$uid_column', '$member_attr') returning ".array2string($lists));
 		return $lists;
 	}
