@@ -600,9 +600,10 @@ class Storage
 	 * @param array $filter =null if set (!=null) col-data pairs, to be and-ed (!) into the query without wildcards
 	 *  $filter['cols_to_search'] limit search columns to given columns, otherwise $this->columns_to_search is used
 	 * @param string $join ='' sql to do a join (only used by sql backend!), eg. " RIGHT JOIN egw_accounts USING(account_id)"
+	 * @param boolean $ignore_acl =false true: no acl check
 	 * @return array of matching rows (the row is an array of the cols) or False
 	 */
-	function &search($criteria,$only_keys=True,$order_by='',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter=null,$join='')
+	function &search($criteria,$only_keys=True,$order_by='',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter=null,$join='', $ignore_acl=false)
 	{
 		//error_log(__METHOD__.'('.array2string($criteria,true).','.array2string($only_keys).",'$order_by','$extra_cols','$wildcard','$empty','$op',".array2string($start).','.array2string($filter,true).",'$join')");
 
@@ -703,7 +704,7 @@ class Storage
 		}
 		// get the used backend for the search and call it's search method
 		$rows = $backend->search($criteria, $only_keys, $order_by, $extra_cols,
-			$wildcard, $empty, $op, $start, $filter, $join);
+			$wildcard, $empty, $op, $start, $filter, $join, false, $ignore_acl);
 
 		$this->total = $backend->total;
 
@@ -959,6 +960,7 @@ class Storage
 				{
 					$contact = $ldap_contacts->read($contact['id']);
 				}
+				$old_contact_id = $contact['id'];
 				unset($contact['id']);	// ldap uid/account_lid
 				if ($contact['account_id'] && ($old = $sql_contacts->read(array('account_id' => $contact['account_id']))))
 				{
@@ -971,7 +973,25 @@ class Storage
 				{
 					echo '<p style="margin: 0px;">'.$n.': '.$contact['n_fn'].
 						($contact['org_name'] ? ' ('.$contact['org_name'].')' : '')." --> SQL (".
-						($contact['owner']?lang('User'):lang('Contact')).")</p>\n";
+						($contact['owner']?lang('User'):lang('Contact')).")<br>\n";
+
+					$new_contact_id = $sql_contacts->data['id'];
+					echo "&nbsp;&nbsp;&nbsp;&nbsp;" . $old_contact_id . " --> " . $new_contact_id . " / ";
+
+					$tq = $this->db->update('egw_links',array(
+						'link_id1' => $new_contact_id,
+					),array(
+						'link_app1' => 'addressbook',
+						'link_id1' => $old_contact_id
+					),__LINE__,__FILE__);
+
+					$tq = $this->db->update('egw_links',array(
+						'link_id2' => $new_contact_id,
+					),array(
+						'link_app2' => 'addressbook',
+						'link_id2' => $old_contact_id
+					),__LINE__,__FILE__);
+					echo "</p>\n";
 				}
 				else
 				{
@@ -992,26 +1012,43 @@ class Storage
 	 */
 	function get_lists($required=Api\Acl::READ,$extra_labels=null)
 	{
-		if (!method_exists($this->somain,'get_lists')) return false;
-
-		$uids = array();
-		foreach($this->grants as $uid => $rights)
-		{
-			if (($rights & $required) == $required)
-			{
-				$uids[] = $uid;
-			}
-		}
 		$lists = is_array($extra_labels) ? $extra_labels : array();
 
-		foreach($this->somain->get_lists($uids) as $list_id => $data)
+		if (method_exists($this->somain,'get_lists'))
 		{
-			$lists[$list_id] = $data['list_name'];
-			if ($data['list_owner'] != $this->user)
+			$uids = array();
+			foreach($this->grants as $uid => $rights)
 			{
-				$lists[$list_id] .= ' ('.Api\Accounts::username($data['list_owner']).')';
+				// only requests groups / list in accounts addressbook for read
+				if (!$uid && $required != Api\Acl::READ) continue;
+
+				if (($rights & $required) == $required)
+				{
+					$uids[] = $uid;
+				}
+			}
+
+			foreach($this->somain->get_lists($uids) as $list_id => $data)
+			{
+				$lists[$list_id] = $data['list_name'];
+				if ($data['list_owner'] != $this->user)
+				{
+					$lists[$list_id] .= ' ('.Api\Accounts::username($data['list_owner']).')';
+				}
 			}
 		}
+
+		// add groups for all backends, if accounts addressbook is not hidden
+		if (empty($GLOBALS['egw_info']['user']['preferences']['addressbook']['hide_accounts']))
+		{
+			foreach($GLOBALS['egw']->accounts->search(array(
+				'type' => 'groups'
+			)) as $account_id => $group)
+			{
+				$lists[(string)$account_id] = Api\Accounts::format_username($group['account_lid'], '', '', $account_id);
+			}
+		}
+
 		return $lists;
 	}
 
