@@ -7,7 +7,7 @@
  * @package api
  * @subpackage db
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2003-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2003-17 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @version $Id$
  */
 
@@ -101,13 +101,18 @@ class Db
 	*/
 	var $Password = '';
 
+	/**
+	 * @var boolean $readonly only allow readonly access to database
+	 */
+	var $readonly = false;
+
 	/**
 	* @var int $Debug enable debuging - 0 no, 1 yes
 	*/
 	var $Debug         = 0;
 
 	/**
-	 * Log update querys to error_log, do not run them
+	 * Log update querys to error_log
 	 *
 	 * @var boolean
 	 */
@@ -248,7 +253,7 @@ class Db
 	/**
 	 * Constructor
 	 *
-	 * @param array $db_data =null values for keys 'db_name', 'db_host', 'db_port', 'db_user', 'db_pass', 'db_type'
+	 * @param array $db_data =null values for keys 'db_name', 'db_host', 'db_port', 'db_user', 'db_pass', 'db_type', 'db_readonly'
 	 */
 	function __construct(array $db_data=null)
 	{
@@ -261,6 +266,7 @@ class Db
 				'User'     => 'db_user',
 				'Password' => 'db_pass',
 				'Type'     => 'db_type',
+				'readonly' => 'db_readonly',
 			) as $var => $key)
 			{
 				$this->$var = $db_data[$key];
@@ -609,8 +615,7 @@ class Db
 		if (!empty($this->setupType)) $this->Type = $this->setupType;	// restore Type eg. to mysqli
 
 		$vars = get_object_vars($this);
-		unset($vars['Link_ID']);
-		unset($vars['privat_Link_ID']);
+		unset($vars['Link_ID'], $vars['Query_ID'], $vars['privat_Link_ID']);
 		return array_keys($vars);
 	}
 
@@ -749,10 +754,10 @@ class Db
 		{
 			$num_rows = $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
 		}
-		if ($this->log_updates && stripos($Query_String, 'SELECT') !== 0)
+		if (($this->readonly || $this->log_updates) && !preg_match('/^\(?(SELECT|SET|SHOW)/i', $Query_String))
 		{
-			error_log($Query_String);
-			return 0;
+			if ($this->log_updates) error_log($Query_String.': '.function_backtrace());
+			if ($this->readonly) return 0;
 		}
 		if ($num_rows > 0)
 		{
@@ -852,6 +857,70 @@ class Db
 		return $this->Link_ID->FailTrans();
 	}
 
+	/**
+	 * Lock a rows in table
+	 *
+	 * Will escalate and lock the table if row locking not supported.
+	 * Will normally free the lock at the end of the transaction.
+	 *
+	 * @param string $table name of table to lock
+	 * @param string $where ='true' where clause to use, eg: "WHERE row=12". Defaults to lock whole table.
+	 * @param string $col ='1 as adodbignore'
+	 */
+	function row_lock($table, $where='true', $col='1 as adodbignore')
+	{
+		if (!$this->Link_ID && !$this->connect())
+		{
+			return False;
+		}
+		if (self::$tablealiases && isset(self::$tablealiases[$table]))
+		{
+			$table = self::$tablealiases[$table];
+		}
+
+		return $this->Link_ID->RowLock($table, $where, $col);
+	}
+
+	/**
+	 * Commit changed rows in table
+	 *
+	 * @param string $table
+	 * @return boolean
+	 */
+	function commit_lock($table)
+	{
+		if (!$this->Link_ID && !$this->connect())
+		{
+			return False;
+		}
+		if (self::$tablealiases && isset(self::$tablealiases[$table]))
+		{
+			$table = self::$tablealiases[$table];
+		}
+
+		return $this->Link_ID->CommitLock($table);
+	}
+
+	/**
+	 * Unlock rows in table
+	 *
+	 * @param string $table
+	 * @return boolean
+	 */
+	function rollback_lock($table)
+	{
+		if (!$this->Link_ID && !$this->connect())
+		{
+			return False;
+		}
+		if (self::$tablealiases && isset(self::$tablealiases[$table]))
+		{
+			$table = self::$tablealiases[$table];
+		}
+
+		return $this->Link_ID->RollbackLock($table);
+	}
+
 	/**
 	* Find the primary key of the last insertion on the current db connection
 	*
@@ -1063,9 +1132,9 @@ class Db
 				$sqls[] = "GRANT ALL ON `$currentDatabase`.* TO $currentUser@'$grant_host' IDENTIFIED BY ".$this->quote($currentPassword);
 				break;
 			default:
-				echo "<p>db::create_database(user='$adminname',\$pw) not yet implemented for DB-type '$this->Type'</p>\n";
-				break;
+				throw new Exception\WrongParameter(__METHOD__."(user=$adminname, \$pw) not yet implemented for DB-type '$this->Type'");
 		}
+		//error_log(__METHOD__."() this->Type=$this->Type: sqls=".array2string($sqls));
 		foreach($sqls as $sql)
 		{
 			$this->query($sql,__LINE__,__FILE__);
