@@ -354,7 +354,19 @@ class Backup
 				$system_config[] = $row;
 			}
 		}
-		if (substr($this->db->Type,0,5) != 'mysql') $this->db->transaction_begin();
+
+		// as MySQL 5.7+ has sql_mode STRICT_(ALL|TRANS)_TABLES enabled by default,
+		// it will no longer restore '0000-00-00 00:00:00' in timestamps it created before,
+		// so switching strict-mode off temporary for the restore (we dont create these!)
+		if (substr($this->db->Type,0,5) == 'mysql')
+		{
+			$this->db->query("SET SESSION sql_mode=(SELECT REPLACE(REPLACE(@@sql_mode,'STRICT_ALL_TABLES',''),'STRICT_TRANS_TABLES',''))", __LINE__, __FILE__);
+		}
+		else
+		{
+			$this->db->transaction_begin();
+		}
+
 
 		// drop all existing tables
 		foreach($this->adodb->MetaTables('TABLES') as $table)
@@ -584,7 +596,6 @@ class Backup
 				{
 					if ($def['type'] === 'bool') $bools[] = $col;
 				}
-				if ($table == 'egw_cal_dates') error_log(__METHOD__."() $table: bools=".array2string($bools).", schema[fd]=".array2string($this->schemas[$table]['fd']));
 
 				if (feof($f)) break;
 				continue;
@@ -867,7 +878,7 @@ class Backup
 	/**
 	 * Number of rows to select per chunk, to not run into memory limit on huge tables
 	 */
-	const ROW_CHUNK = 10000;
+	const ROW_CHUNK = 5000;
 
 	/**
 	 * Backup all data in the form of a (compressed) csv file
@@ -919,6 +930,9 @@ class Backup
 
 		fwrite($f,"\nschema: ".json_encode($this->schemas)."\n");
 
+		// let apps know that backup is about to start
+		Api\Hooks::process('backup_starts', array(), true);
+
 		foreach($this->schemas as $table => $schema)
 		{
 			if (in_array($table,$this->exclude_tables)) continue;	// dont backup
@@ -931,7 +945,7 @@ class Backup
 
 			if ($lock_table || empty($pk) && is_null($lock_table))
 			{
-				$this->db->Link_ID->RowLock($table);
+				$this->db->row_lock($table);
 			}
 			$total = $max = 0;
 			do {
@@ -958,8 +972,12 @@ class Backup
 			}
 			while((!empty($pk) || $lock_table !== false) && !($total % self::ROW_CHUNK) && $num_rows);
 
-			if (!$pk) $this->db->Link_ID->RollbackLock($table);
+			if (!$pk) $this->db->rollback_lock($table);
 		}
+
+		// let apps know that backup is finished
+		Api\Hooks::process('backup_finished', array(), true);
+
 		if(!$zippresent)  // save without files
 		{
 			if ($this->backup_files)
