@@ -231,12 +231,6 @@ class Etemplate extends Etemplate\Widget\Template
 			{
 				$content = '<form target="egw_iframe_autocomplete_helper" action="'.$form_action.'" id="'.$dom_id.'" class="et2_container"></form>'."\n".
 					'<iframe name="egw_iframe_autocomplete_helper" style="width:0;height:0;position: absolute;visibility:hidden;"></iframe>';
-				// add server-side page-generation times
-				if($GLOBALS['egw_info']['user']['preferences']['common']['show_generation_time'])
-				{
-					$vars = $GLOBALS['egw']->framework->_get_footer();
-					$content .= "\n".$vars['page_generation_time'];
-				}
 				$GLOBALS['egw']->framework->response->generic("data", array($content));
 				$GLOBALS['egw']->framework->response->generic('et2_load',$load_array+Framework::get_extra());
 				Framework::clear_extra();	// to not send/set it twice for multiple etemplates (eg. CRM view)
@@ -263,9 +257,10 @@ class Etemplate extends Etemplate\Widget\Template
 				$load_array['response'] = Json\Response::get()->returnResult();
 			}
 			// <iframe> and <form> tags added only to get browser autocomplete handling working again
-			echo '<form target="egw_iframe_autocomplete_helper" action="'.$form_action.'" id="'.$dom_id.'" class="et2_container" data-etemplate="'.
+			$form = '<form target="egw_iframe_autocomplete_helper" action="'.$form_action.'" id="'.$dom_id.'" class="et2_container" data-etemplate="'.
 				htmlspecialchars(Json\Response::json_encode($load_array), ENT_COMPAT, Translation::charset(), true).'"></form>'."\n".
 				'<iframe name="egw_iframe_autocomplete_helper" style="width:0;height:0;position: absolute;visibility:hidden;"></iframe>';
+			echo $form;
 
 			if ($output_mode == 2)
 			{
@@ -273,6 +268,7 @@ class Etemplate extends Etemplate\Widget\Template
 				echo $GLOBALS['egw']->framework->footer();
 			}
 			ob_flush();
+			if ($output_mode == 1)	return $form;
 		}
 		self::$request = null;
 	}
@@ -323,6 +319,9 @@ class Etemplate extends Etemplate\Widget\Template
 			throw new Exception\WrongParameter('Can NOT read template '.array2string(self::$request->template));
 		}
 
+		// let session class know, which is the app & method of this request
+		$GLOBALS['egw']->session->set_action('Etemplate: '.self::$request->method);
+
 		// Set current app for validation
 		list($app) = explode('.',self::$request->method);
 		if(!$app) list($app) = explode('::',self::$request->method);
