@@ -33,4 +33,4 @@ class Accountfilter extends Widget\Taglist
 		$this->attrs['type'] = 'select-account';
 	}
 }
-Customfilter::registerWidget(__NAMESPACE__.'\\Accountfilter', array('nextmatch-accountfilter'));
\ No newline at end of file
+Widget::registerWidget(__NAMESPACE__.'\\Accountfilter', array('nextmatch-accountfilter'));
\ No newline at end of file
