@@ -104,7 +104,9 @@ abstract class Framework extends Framework\Extra
 		if (file_exists(EGW_SERVER_ROOT.'/pixelegg') &&
 			(empty($GLOBALS['egw_info']['flags']['deny_mobile']) && Header\UserAgent::mobile() ||
 			$GLOBALS['egw_info']['user']['preferences']['common']['theme'] == 'mobile' ||
-			empty($GLOBALS['egw_info']['server']['template_set'])))
+			empty($GLOBALS['egw_info']['server']['template_set'])) ||
+			// change old idots and jerryr to our standard template (pixelegg)
+			in_array($GLOBALS['egw_info']['server']['template_set'], array('idots', 'jerryr')))
 		{
 			$GLOBALS['egw_info']['server']['template_set'] = 'pixelegg';
 		}
@@ -113,29 +115,8 @@ abstract class Framework extends Framework\Extra
 		{
 			$GLOBALS['egw_info']['server']['template_set'] = 'jdots';
 		}
-		// and last, if installed old phpgwapi idots etc.
-		if (file_exists(EGW_SERVER_ROOT.'/phpgwapi'))
-		{
-			// default to idots, if no template_set set, to eg. not stall installations if settings use self::link
-			if (empty($GLOBALS['egw_info']['server']['template_set'])) $GLOBALS['egw_info']['server']['template_set'] = 'idots';
-			// setup the new eGW framework (template sets)
-			$class = $GLOBALS['egw_info']['server']['template_set'].'_framework';
-			if (!class_exists($class) &&	// first try to autoload the class
-				file_exists($file=EGW_INCLUDE_ROOT.'/phpgwapi/templates/'.$GLOBALS['egw_info']['server']['template_set'].'/class.'.$class.'.inc.php'))
-			{
-				require_once($file);
-				if (!in_array($file,(array)$_SESSION['egw_required_files']))
-				{
-					$_SESSION['egw_required_files'][] = $file;	// automatic load the used framework class, when the object get's restored
-				}
-			}
-		}
-		else
-		{
-			$class = $GLOBALS['egw_info']['server']['template_set'].'_framework';
-		}
 		// eg. "default" is only used for login at the moment
-		if (!class_exists($class))
+		if (!class_exists($class=$GLOBALS['egw_info']['server']['template_set'].'_framework'))
 		{
 			$class = __CLASS__.'\\Minimal';
 		}
@@ -348,6 +329,23 @@ abstract class Framework extends Framework\Extra
 		(new Framework\Login($this))->deny_screen();
 	}
 
+	/**
+	 * Calculate page-generation- and session-restore times
+	 *
+	 * @return array values for keys 'page_generation_time' and 'session_restore_time', if display is an
+	 */
+	public static function get_page_generation_time()
+	{
+		$times = array(
+			'page_generation_time' => sprintf('%4.2lf', microtime(true) - $GLOBALS['egw_info']['flags']['page_start_time']),
+		);
+		if ($GLOBALS['egw_info']['flags']['session_restore_time'])
+		{
+			$times['session_restore_time'] = sprintf('%4.2lf', $GLOBALS['egw_info']['flags']['session_restore_time']);
+		}
+		return $times;
+	}
+
 	/**
 	 * Get footer as array to eg. set as vars for a template (from idots' head.inc.php)
 	 *
@@ -362,19 +360,21 @@ abstract class Framework extends Framework\Extra
 		$var['page_generation_time'] = '';
 		if($GLOBALS['egw_info']['user']['preferences']['common']['show_generation_time'])
 		{
-			$totaltime = sprintf('%4.2lf',microtime(true) - $GLOBALS['egw_info']['flags']['page_start_time']);
+			$times = self::get_page_generation_time();
 
-			$var['page_generation_time'] = '<div class="pageGenTime" id="divGenTime_'.$GLOBALS['egw_info']['flags']['currentapp'].'"><span>'.lang('Page was generated in %1 seconds',$totaltime);
-			if ($GLOBALS['egw_info']['flags']['session_restore_time'])
+			$var['page_generation_time'] = '<div class="pageGenTime" id="divGenTime_'.$GLOBALS['egw_info']['flags']['currentapp'].'"><span>'.
+				lang('Page was generated in %1 seconds', $times['page_generation_time']);
+
+			if (isset($times['session_restore_time']))
 			{
 				$var['page_generation_time'] .= ' '.lang('(session restored in %1 seconds)',
-					sprintf('%4.2lf',$GLOBALS['egw_info']['flags']['session_restore_time']));
+					$times['session_restore_time']);
 			}
 			$var['page_generation_time'] .= '</span></div>';
 		}
 		$var['powered_by'] = '<a href="http://www.egroupware.org/" target="_blank">'.
-			lang('Powered by').' Stylite\'s EGroupware '.
-			$GLOBALS['egw_info']['server']['versions']['phpgwapi'].'</a>';
+			lang('Powered by').' EGroupware '.
+			$GLOBALS['egw_info']['server']['versions']['api'].'</a>';
 
 		return $var;
 	}
@@ -603,11 +603,12 @@ abstract class Framework extends Framework\Extra
 	 *
 	 * @param string $username =null username for regular basic Auth
 	 * @param string $password =null password --------- " ----------
+	 * @param array $opts =array() further params for http(s) context, eg. array('timeout' => 123)
 	 * @return resource|null context to use with file_get_context/fopen or null if no proxy configured
 	 */
-	public static function proxy_context($username=null, $password=null)
+	public static function proxy_context($username=null, $password=null, array $opts = array())
 	{
-		$opts = array(
+		$opts += array(
 			'method' => 'GET',
 		);
 		if (!empty($GLOBALS['egw_info']['server']['httpproxy_server']))
@@ -979,6 +980,11 @@ abstract class Framework extends Framework\Extra
 	function list_themes()
 	{
 		$list = array();
+		if (file_exists($file=EGW_SERVER_ROOT.$this->template_dir.'/setup/setup.inc.php') &&
+			(include $file) && isset($GLOBALS['egw_info']['template'][$this->template]['themes']))
+		{
+			$list = $GLOBALS['egw_info']['template'][$this->template]['themes'];
+		}
 		if (($dh = @opendir(EGW_SERVER_ROOT.$this->template_dir.'/css')))
 		{
 			while (($file = readdir($dh)))
@@ -986,7 +992,7 @@ abstract class Framework extends Framework\Extra
 				if (preg_match('/'."\.css$".'/i', $file))
 				{
 					list($name) = explode('.',$file);
-					$list[$name] = $name;
+					if (!isset($list[$name])) $list[$name] = ucfirst ($name);
 				}
 			}
 			closedir($dh);
@@ -1002,31 +1008,7 @@ abstract class Framework extends Framework\Extra
 	 */
 	static function list_templates($full_data=false)
 	{
-		$list = array('pixelegg'=>null,'jdots'=>null,'idots'=>null);
-		// templates packaged in old phpgwapi
-		if (file_exists(EGW_SERVER_ROOT . '/phpgwapi') && ($d = dir(EGW_SERVER_ROOT . '/phpgwapi/templates')))
-		{
-			while (($entry=$d->read()))
-			{
-				if ($entry != '..' && file_exists(EGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry .'/class.'.$entry.'_framework.inc.php'))
-				{
-					if (file_exists ($f = EGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry . '/setup/setup.inc.php'))
-					{
-						include($f);
-						$list[$entry] = $full_data ? $GLOBALS['egw_info']['template'][$entry] :
-							$GLOBALS['egw_info']['template'][$entry]['title'];
-					}
-					else
-					{
-						$list[$entry] = $full_data ? array(
-							'name'  => $entry,
-							'title' => $entry,
-						) : $entry;
-					}
-				}
-			}
-			$d->close();
-		}
+		$list = array('pixelegg'=>null);
 		// templates packaged like apps in own directories (containing as setup/setup.inc.php file!)
 		$dr = dir(EGW_SERVER_ROOT);
 		while (($entry=$dr->read()))
@@ -1390,6 +1372,9 @@ abstract class Framework extends Framework\Extra
 	 */
 	public static function ajax_get_preference($app)
 	{
+		// dont block session, while we read preferences, they are not supposed to change something in the session
+		$GLOBALS['egw']->session->commit_session();
+
 		if (preg_match('/^[a-z0-9_]+$/i', $app))
 		{
 			// send etag header, if we are directly called (not via jsonq!)
