@@ -546,8 +546,13 @@ abstract class Ajax extends Api\Framework
 		// fix app admin menus to use admin.admin_ui.index loader
 		if (($type == 'admin' || $menu_title == lang('Admin')) && $appname != 'admin')
 		{
-			$file = preg_replace("/^(javascript:egw_link_handler\(')(.*)menuaction=([^&]+)(.*)(','[^']+'\))$/",
-				'$1$2menuaction=admin.admin_ui.index&load=$3$4&ajax=true\',\'admin\')', $file_was=$file);
+			foreach($file as &$link)
+			{
+				preg_match('/ajax=(true|false)/', $link, $ajax);
+				$link = preg_replace("/^(javascript:egw_link_handler\(')(.*)menuaction=([^&]+)(.*)(','[^']+'\))$/",
+					'$1$2menuaction=admin.admin_ui.index&load=$3$4&ajax=' . ($ajax[1] ? $ajax[1] : 'true') .'\',\'admin\')', $file_was=$link);
+			}
+			 
 		}
 
 		$this->sideboxes[$appname][$menu_title] = $file;
@@ -599,6 +604,7 @@ abstract class Ajax extends Api\Framework
 		}
 
 		$data = array();
+		$sendToBottom = array();
 		foreach($this->sideboxes[$appname] as $menu_name => &$file)
 		{
 			$current_menu = array(
@@ -609,7 +615,7 @@ abstract class Ajax extends Api\Framework
 			);
 			foreach($file as $item_text => $item_link)
 			{
-				if ($item_text === 'menuOpened' ||	// flag, not menu entry
+				if ($item_text === 'menuOpened' || $item_text === 'sendToBottom' ||// flag, not menu entry
 					$item_text === '_NewLine_' || $item_link === '_NewLine_')
 				{
 					continue;
@@ -648,9 +654,17 @@ abstract class Ajax extends Api\Framework
 				}
 				$current_menu['entries'][] = $var;
 			}
-			$data[] = $current_menu;
+
+			if ($file['sendToBottom'])
+			{
+				$sendToBottom[] = $current_menu;
+			}
+			else
+			{
+				$data[] = $current_menu;
+			}
 		}
-		return $data;
+		return array_merge($data, $sendToBottom);
 	}
 
 	/**
@@ -704,6 +718,9 @@ abstract class Ajax extends Api\Framework
 	 */
 	public function ajax_sidebox($appname, $md5)
 	{
+		// dont block session, while we read sidebox, they are not supposed to change something in the session
+		$GLOBALS['egw']->session->commit_session();
+
 		$response = Api\Json\Response::get();
 		$sidebox = $this->get_sidebox($appname);
 		$encoded = json_encode($sidebox);
@@ -973,6 +990,9 @@ abstract class Ajax extends Api\Framework
 		{
 			throw new Api\Exception\WrongParameter(__METHOD__."('$link') no menuaction set!");
 		}
+		// set session action
+		$GLOBALS['egw']->session->set_action('Ajax: '.$_GET['menuaction']);
+
 		list($app,$class,$method) = explode('.',$_GET['menuaction']);
 
 		if (!isset($GLOBALS['egw_info']['user']['apps'][$app]))
