@@ -214,7 +214,7 @@ class Html
 		if($enhanced) {
 			Framework::includeJS('/api/js/jquery/chosen/chosen.jquery.js');
 			Framework::includeCSS('/api/js/jquery/chosen/chosen.css',null,false);
-			$out .= "<script>var lab = egw_LAB || \$LAB; lab.wait(function() {\jQuery(function() {if(\jQuery().chosen) \jQuery('select[name=\"$name\"]').chosen({width: '100%'});});})</script>\n";
+			$out .= "<script>var lab = egw_LAB || \$LAB; lab.wait(function() {jQuery(function() {if(jQuery().chosen) jQuery('select[name=\"$name\"]').chosen({width: '100%'});});})</script>\n";
 		}
 		return $out;
 	}
@@ -448,7 +448,7 @@ class Html
 		}
 
 		//include the ckeditor js file
-		Framework::includeJS('ckeditor','ckeditor','phpgwapi');
+		Framework::includeJS('/vendor/egroupware/ckeditor/ckeditor.js');
 
 		// run content through htmlpurifier
 		if ($_purify && !empty($_content))
@@ -474,7 +474,7 @@ class Html
 		return self::textarea($_name,$_content,'id="'.htmlspecialchars($_name).'"',true).	// true = double encoding
 '
 <script type="text/javascript">
-window.CKEDITOR_BASEPATH="'.$GLOBALS['egw_info']['server']['webserver_url'].'/api/js/ckeditor/";
+window.CKEDITOR_BASEPATH="'.$GLOBALS['egw_info']['server']['webserver_url'].'/vendor/egroupware/ckeditor/";
 egw_LAB.wait(function() {
 	CKEDITOR.replace("'.$_name.'", '.Html\CkEditorConfig::get_ckeditor_config($_mode,
 		$pxheight, $expanded, $_start_path).');
@@ -873,10 +873,6 @@ egw_LAB.wait(function() {
 		if (!$color) $color = '#D00000';
 		$title = $_title ? self::htmlspecialchars($_title) : $percent.'%';
 
-		if (self::$netscape4)
-		{
-			return $title;
-		}
 		return '<div class="onlyPrint">'.$title.'</div><div class="noPrint" title="'.$title.'" '.$options.
 			' style="height: '.$height.'; width: '.$width.'; border: 1px solid black; padding: 1px; text-align: left;'.
 			(@stristr($options,'onclick="') ? ' cursor: pointer;' : '').'">'."\n\t".
