@@ -25,7 +25,7 @@ class CkEditorConfig
 	private static $enterMode = null;
 	private static $skin = null;
 
-	// Defaults, defined in phpgwapi/js/ckeditor/plugins/font/plugin.js
+	// Defaults, defined in /vendor/egroupware/ckeditor/plugins/font/plugin.js
 	public static $font_options = array(
 		'arial, helvetica, sans-serif' => 'Arial',
 		'Comic Sans MS, cursive' => 'Comic Sans MS',
@@ -75,7 +75,7 @@ class CkEditorConfig
 		);
 		$skins = array();
 
-		foreach(scandir(EGW_SERVER_ROOT.'/api/js/ckeditor/skins') as $skin)
+		foreach(scandir(EGW_SERVER_ROOT.'/vendor/egroupware/ckeditor/skins') as $skin)
 		{
 			if ($skin[0] == '.') continue;
 
@@ -89,7 +89,7 @@ class CkEditorConfig
 			}
 		}
 		uasort($skins, 'strcasecmp');
-		
+
 		// flat skin is reserved for mobile template, although we are not
 		// supporting it on desktop (becuase FF has problem with action icons)
 		if (!\EGroupware\Api\Header\UserAgent::mobile()) unset($skins['flat']);
@@ -127,9 +127,7 @@ class CkEditorConfig
 	private static function read_lang_country()
 	{
 		//use the lang and country information to construct a possible lang info for CKEditor UI and scayt_slang
-		self::$lang = ($GLOBALS['egw_info']['user']['preferences']['common']['spellchecker_lang'] ?
-			$GLOBALS['egw_info']['user']['preferences']['common']['spellchecker_lang']:
-			$GLOBALS['egw_info']['user']['preferences']['common']['lang']);
+		self::$lang = $GLOBALS['egw_info']['user']['preferences']['common']['lang'];
 
 		self::$country = $GLOBALS['egw_info']['user']['preferences']['common']['country'];
 
@@ -165,7 +163,7 @@ class CkEditorConfig
 	private static function get_base_path()
 	{
 		//Get the ckeditor base url
-		return $GLOBALS['egw_info']['server']['webserver_url'].'/api/js/ckeditor/';
+		return $GLOBALS['egw_info']['server']['webserver_url'].'/vendor/egroupware/ckeditor/';
 	}
 
 	/**
@@ -233,7 +231,7 @@ class CkEditorConfig
 			}
 
 			//Check whether the skin actually exists, if not, switch to a default
-			if (!file_exists(EGW_SERVER_ROOT.'/api/js/ckeditor/skins/'.$skin))
+			if (!file_exists(EGW_SERVER_ROOT.'/vendor/egroupware/ckeditor/skins/'.$skin))
 			{
 				$skin = "moono"; //this is the basic skin for ckeditor
 			}
