@@ -167,6 +167,11 @@ class Link extends Link\Storage
 			),
 		),
 	);
+
+	/**
+	 * Max. number of titles stored in session (older once get removed)
+	 */
+	const TITLE_CACHE_SIZE = 500;
 	/**
 	 * Caches link titles for a better performance
 	 *
@@ -174,6 +179,10 @@ class Link extends Link\Storage
 	 */
 	private static $title_cache = array();
 
+	/**
+	 * Max. number of titles stored in session (older once get removed)
+	 */
+	const FILE_ACCESS_CACHE_SIZE = 1000;
 	/**
 	 * Cache file access permissions
 	 *
@@ -200,7 +209,7 @@ class Link extends Link\Storage
 		if (Header\UserAgent::type() == 'firefox' && $GLOBALS['egw_info']['user']['preferences']['common']['theme'] == 'mobile' ||
 			Header\UserAgent::mobile())
 		{
-			unset(self::$app_register['home']['mime']['application/pdf']);
+			unset(self::$app_register['api']['mime']['application/pdf']);
 		}
 		// other apps can participate in the linking by implementing a search_link hook, which
 		// has to return an array in the format of an app_register entry
@@ -301,7 +310,17 @@ class Link extends Link\Storage
 		if (isset($GLOBALS['egw']->session))	// eg. cron-jobs use it too, without any session
 		{
 			//error_log(__METHOD__.'() items in title-cache: '.count(self::$title_cache).' file-access-cache: '.count(self::$file_access_cache));
+
+			if (count(self::$title_cache > self::TITLE_CACHE_SIZE))
+			{
+				self::$title_cache = array_slice(self::$title_cache, -self::TITLE_CACHE_SIZE);
+			}
 			Cache::setSession(__CLASS__, 'link_title_cache', self::$title_cache);
+
+			if (count(self::$file_access_cache > self::FILE_ACCESS_CACHE_SIZE))
+			{
+				self::$file_access_cache = array_slice(self::$file_access_cache, -self::FILE_ACCESS_CACHE_SIZE);
+			}
 			Cache::setSession(__CLASS__, 'link_file_access_cache', self::$file_access_cache);
 		}
 	}
@@ -685,7 +704,7 @@ class Link extends Link\Storage
 				Storage\History::static_add($app,$id,$GLOBALS['egw_info']['user']['account_id'],'~link~','',$app2.':'.$id2);
 				Storage\History::static_add($app2,$id2,$GLOBALS['egw_info']['user']['account_id'],'~link~','',$app.':'.$id);
 			}
-			$deleted =& Link\Storage::unlink($link_id,$app,$id,$owner,$app2 != '!'.self::VFS_APPNAME ? $app2 : '',$id2,$hold_for_purge);
+			$deleted = Link\Storage::unlink($link_id,$app,$id,$owner,$app2 != '!'.self::VFS_APPNAME ? $app2 : '',$id2,$hold_for_purge);
 
 			// only notify on real links, not the one cached for writing or fileattachments
 			self::notify_unlink($deleted);
@@ -734,10 +753,10 @@ class Link extends Link\Storage
 	 *
 	 * @param string $app app to search
 	 * @param string $pattern pattern to search
-	 * @param string $type Search only a certain sub-type of records (optional)
+	 * @param array& $options passed to callback: type, start, num_rows, filter; on return value for "total"
 	 * @return array with $id => $title pairs of matching entries of app
 	 */
-	static function query($app,$pattern, &$options = array())
+	static function query($app, $pattern, &$options = array())
 	{
 		if ($app == '' || !is_array($reg = self::$app_register[$app]) || !isset($reg['query']))
 		{
@@ -751,45 +770,7 @@ class Link extends Link\Storage
 			echo "Options: "; _debug_array($options);
 		}
 
-		// See etemplate's nextmatch widget, following was copied from there
-		// allow static callbacks
-		if(strpos($method,'::') !== false)
-		{
-			//  workaround for php < 5.3: do NOT call it static, but allow application code to specify static callbacks
-			if (version_compare(PHP_VERSION,'5.3','<')) list($class,$method) = explode('::',$method);
-		}
-		else
-		{
-			list($app,$class,$method) = explode('.',$method);
-		}
-		if ($class)
-		{
-			if (!$app && !is_object($GLOBALS[$class]))
-			{
-				$GLOBALS[$class] = new $class();
-			}
-			if (is_object($GLOBALS[$class]))        // use existing instance (put there by a previous CreateObject)
-			{
-				$obj = $GLOBALS[$class];
-			}
-			else
-			{
-				$obj = CreateObject($app.'.'.$class);
-			}
-		}
-		if(is_callable($method))        // php5.3+ call
-		{
-			$result = call_user_func($method,$pattern,$options);
-		}
-		elseif(is_object($obj) && method_exists($obj,$method))
-		{
-			$result = $obj->$method($pattern,$options);
-		}
-		else
-		{
-			// if there is no object or no method, give a more explaining error message
-			throw new Exception\AssertionFailed("Object has no method '$reg[query]'!");
-		}
+		$result = self::exec($method, array($pattern, &$options));
 
 		if (!isset($options['total']))
 		{
@@ -848,7 +829,7 @@ class Link extends Link\Storage
 		}
 		$method = $reg['title'];
 
-		if (true) $title = ExecMethod($method,$id);
+		if (true) $title = self::exec($method, array($id));
 
 		if ($id && is_null($title))	// $app,$id has been deleted ==> unlink all links to it
 		{
@@ -909,7 +890,7 @@ class Link extends Link\Storage
 		{
 			for ($n = 0; ($ids = array_slice($ids_to_query,$n*self::MAX_TITLES_QUERY,self::MAX_TITLES_QUERY)); ++$n)
 			{
-				foreach(ExecMethod(self::$app_register[$app]['titles'],$ids) as $id => $t)
+				foreach(self::exec(self::$app_register[$app]['titles'], array($ids)) as $id => $t)
 				{
 					$title =& self::get_cache($app,$id);
 					$titles[$id] = $title = $t;
@@ -1204,7 +1185,7 @@ class Link extends Link\Storage
 	 * @param string $app appname to linke the file to
 	 * @param string $id id in $app
 	 * @param array $file informations about the file in format of the etemplate file-type
-	 * 	$file['name'] name of the file (no directory)
+	 * 	$file['name'] name of the file (optional incl. a directory)
 	 * 	$file['type'] mine-type of the file
 	 * 	$file['tmp_name'] name of the uploaded file (incl. directory) or resource of opened file
 	 * @param string $comment ='' comment to add to the link
@@ -1212,14 +1193,23 @@ class Link extends Link\Storage
 	 */
 	static function attach_file($app,$id,$file,$comment='')
 	{
-		$entry_dir = self::vfs_path($app,$id);
+		// check if $file['name'] specifies a subdirectory, in which case use and, if necessary, create it
+		if (is_array($file) && strpos($file['name'], '/') && strpos($file['name'], '..') === false)
+		{
+			$entry_dir = self::vfs_path($app, $id, Vfs::dirname($file['name']));
+			$file['name'] = Vfs::basename($file['name']);
+		}
+		else
+		{
+			$entry_dir = self::vfs_path($app,$id);
+		}
 		if (self::DEBUG)
 		{
 			echo "<p>attach_file: app='$app', id='$id', tmp_name='$file[tmp_name]', name='$file[name]', size='$file[size]', type='$file[type]', path='$file[path]', ip='$file[ip]', comment='$comment', entry_dir='$entry_dir'</p>\n";
 		}
 		if (file_exists($entry_dir) || ($Ok = mkdir($entry_dir,0,true)))
 		{
-			$Ok = Vfs::copy_uploaded($file, $p=self::vfs_path($app,$id,'',true), $comment, false);	// no is_uploaded_file() check!
+			$Ok = Vfs::copy_uploaded($file, $p=Vfs::parse_url($entry_dir, PHP_URL_PATH), $comment, false);	// no is_uploaded_file() check!
 			if (!$Ok) error_log(__METHOD__."('$app', '$id', ".array2string($file).", '$comment') called Vfs::copy_uploaded('$file[tmp_name]', '$p', '$comment', false)=".array2string($Ok));
 		}
 		else
@@ -1235,26 +1225,27 @@ class Link extends Link\Storage
 	 * @param string $app appname to link the file to
 	 * @param string $id id in $app
 	 * @param string $file VFS path to link to
-	 * @param string $comment ='' comment to add to the link
+	 * @return boolean true on success, false on failure
 	 */
-	static function link_file($app,$id,$file)//,$comment='')
+	static function link_file($app,$id,$file)
 	{
 		// Don't try to link into app dir if there is no id
 		if(!$id) return;
 
-		$app_path = self::vfs_path($app,$id);
-		$ok = true;
-		if (Vfs::file_exists($app_path) || ($ok = Vfs::mkdir($app_path,0,true)))
+		if (!Vfs::stat($file))
 		{
-			if (!Vfs::stat($file))
-			{
-				error_log(__METHOD__. ' (Link target ' . Vfs::decodePath($file) . ' not found!');
-				return false;
-			}
+			error_log(__METHOD__. ' (Link target ' . Vfs::decodePath($file) . ' not found!');
+			return false;
 		}
 
-		$link = Vfs::concat($app_path,Vfs::basename($file));
-		return Vfs::symlink($file,$link);
+		$entry_dir = self::vfs_path($app, $id);
+		if (!file_exists($entry_dir) && !mkdir($entry_dir, 0, true))
+		{
+			error_log(__METHOD__."($app,$id,".array2string($file).") Can't mkdir $entry_dir!");
+			return false;
+		}
+
+		return Vfs::symlink($file, Vfs::concat($entry_dir, Vfs::basename($file)));
 	}
 	/**
 	 * deletes a single or all attached files of an entry (for all there's no acl check, as the entry probably not exists any more!)
@@ -1338,7 +1329,7 @@ class Link extends Link\Storage
 		if (!is_array($fileinfo))
 		{
 			$url = Vfs\Sqlfs\StreamWrapper::id2path($fileinfo);
-			if (!($fileinfo = Vfs::url_stat($url,STREAM_URL_STAT_QUIET)))
+			if (!($fileinfo = Vfs::stat($url,STREAM_URL_STAT_QUIET)))
 			{
 				return false;
 			}
@@ -1533,7 +1524,7 @@ class Link extends Link\Storage
 			$method = $args['method'];
 			unset($args['method']);
 			//error_log(__METHOD__."() calling $method(".array2string($args).')');
-			ExecMethod($method, $args);
+			self::exec($method, array($args));
 		}
 	}
 
@@ -1566,6 +1557,10 @@ class Link extends Link\Storage
 		switch($type)
 		{
 			case 'title':
+				if ($app == self::VFS_APPNAME)
+				{
+					return null;	// do not cache file titles, they are just the names
+				}
 				return self::$title_cache[$app.':'.$id];
 			case 'file_access':
 				return self::$file_access_cache[$app.':'.$id];
@@ -1589,7 +1584,8 @@ class Link extends Link\Storage
 	public static function set_cache($app,$id,$title,$file_access=null)
 	{
 		//error_log(__METHOD__."($app,$id,$title,$file_access)");
-		if (!is_null($title))
+		// do not cache file titles, they are just the names
+		if (!is_null($title) && $app != self::VFS_APPNAME)
 		{
 			self::$title_cache[$app.':'.$id] = $title;
 		}
@@ -1649,7 +1645,8 @@ class Link extends Link\Storage
 		{
 			throw new Exception\WrongParameter(__METHOD__."('$id')");
 		}
-		$ret = call_user_func_array('ExecMethod2', $data);
+		$method = array_shift($data);
+		$ret = self::exec($method, $data);
 
 		if (is_resource($ret)) fseek($ret, 0);
 
@@ -1703,7 +1700,7 @@ class Link extends Link\Storage
 			}
 			else
 			{
-				$ret = ExecMethod2($method,$id,$required,$rel_path,$user);
+				$ret = self::exec($method, array($id, $required, $rel_path, $user));
 				$err = "(from $method)";
 			}
 			//error_log(__METHOD__."('$app',$id,$required,'$rel_path',$user) returning $err ".array2string($ret));
@@ -1716,7 +1713,7 @@ class Link extends Link\Storage
 		{
 			if(($method = self::get_registry($app,'file_access')))
 			{
-				$cache |= ExecMethod2($method,$id,$required,$rel_path) ? $required|Acl::READ : 0;
+				$cache |= self::exec($method, array($id, $required, $rel_path)) ? $required|Acl::READ : 0;
 			}
 			else
 			{
@@ -1727,5 +1724,40 @@ class Link extends Link\Storage
 		//else error_log(__METHOD__."($app,$id,$required,$rel_path) using cached value $cache --> ".($cache & $required ? 'true' : 'false'));
 		return !!($cache & $required);
 	}
+
+	/**
+	 * Execute a static method or $app.$class.$method string with given arguments
+	 *
+	 * In case of a non-static method as shared instance of the class is used.
+	 * This is a replacement for global ExecMethod(2) functions.
+	 *
+	 * @param callable|string $method "$app.$class.$method" or static method
+	 * @param array $params array with arguments incl. references
+	 * @return mixed
+	 */
+	protected static function exec($method, array $params=array())
+	{
+		static $objs = array();
+
+		// static methods or callables can be called directly
+		if (is_callable($method))
+		{
+			return call_user_func_array($method, $params);
+		}
+
+		list($app, $class, $m) = $parts = explode('.', $method);
+		if (count($parts) != 3) throw Api\Exception\WrongParameter("Wrong dot-delimited method string '$method'!");
+
+		if (!isset($objs[$class]))
+		{
+			if (!class_exists($class))
+			{
+				require_once EGW_INCLUDE_ROOT.'/'.$app.'/inc/class.'.$class.'.inc.php';
+			}
+			$objs[$class] = new $class;
+		}
+		// php5.6+: return $objs[$class]->$m(...$params);
+		return call_user_func_array(array($objs[$class], $m), $params);
+	}
 }
 Link::init_static();
