@@ -309,6 +309,11 @@ class Account implements \ArrayAccess
 				$this->imapServer($this->user) && is_a($this->imapServer, __NAMESPACE__.'\\Imap') &&
 				($data = $this->imapServer->getUserData($GLOBALS['egw']->accounts->id2name($this->user))))
 			{
+				// give quota-limit from SMTP/SQL precedence over (cached) quota from Dovecot
+				if (isset($this->params['quotaLimit']) && is_a($this->imapServer, __NAMESPACE__.'\\Imap\\Dovecot'))
+				{
+					unset($data['quotaLimit']);
+				}
 				$this->params = array_merge($this->params, $data);
 			}
 		}
@@ -332,6 +337,8 @@ class Account implements \ArrayAccess
 	 */
 	public function saveUserData($user, array $data)
 	{
+		$data += $this->params;	// in case only user-data has been specified
+
 		// store account-information of managed mail server
 		if ($user > 0 && $data['acc_smtp_type'] && $data['acc_smtp_type'] != __NAMESPACE__.'\\Smtp')
 		{
@@ -1030,7 +1037,7 @@ class Account implements \ArrayAccess
 	 */
 	protected static function db2data(array $data)
 	{
-		foreach(array('acc_sieve_enabled','acc_further_identities','acc_user_editable','acc_smtp_auth_session','acc_user_forward') as $name)
+		foreach(array('acc_sieve_enabled','acc_user_editable','acc_smtp_auth_session','acc_user_forward') as $name)
 		{
 			if (isset($data[$name]))
 			{
@@ -1487,7 +1494,7 @@ class Account implements \ArrayAccess
 						{
 							$account = new Account($params);
 						}
-						catch (Exception $x)
+						catch (\Exception $x)
 						{
 							unset($x);
 							continue;
@@ -1581,7 +1588,6 @@ class Account implements \ArrayAccess
 			catch(\Exception $e) {
 				_egw_log_exception($e);
 			}
-
 		}
 		if (strlen(trim($account['ident_realname'].$account['ident_org'])))
 		{
@@ -1591,11 +1597,11 @@ class Account implements \ArrayAccess
 		{
 			$name = $account['acc_name'];
 		}
-		if (strpos($account['ident_email'], '@') !== false)
+		if (strpos($account['ident_email'], '@') !== false || trim($account['ident_email']) !='')
 		{
 			$name .= ' <'.$account['ident_email'].'>';
 		}
-		elseif(strpos($account['acc_imap_username'], '@') !== false)
+		elseif(strpos($account['acc_imap_username'], '@') !== false || trim($account['acc_imap_username']) !='')
 		{
 			$name .= ' <'.$account['acc_imap_username'].'>';
 		}
