@@ -320,10 +320,10 @@ class Html
 			12 => '/<blockquote>/',
 			13 => '~</blockquote>~si',
 			14 => '~<blockquote[^>]*>~si',
-			15 => '/<=([1234567890])/',
-			16 => '/>=([1234567890])/',
-			17 => '/<([1234567890])/',
-			18 => '/>([1234567890])/',
+			15 => '/<=\s*([1234567890])/',
+			16 => '/>=\s*([1234567890])/',
+			17 => '/<\s*([1234567890])/',
+			18 => '/>\s*([1234567890])/',
 		);
 		$Replace = array (
 			0 => "\r\n",
