@@ -159,6 +159,8 @@ class Imap extends Horde_Imap_Client_Socket implements Imap\Iface
 		if (is_null($_timeout)) $_timeout = $this->params['acc_imap_timeout']?$this->params['acc_imap_timeout']:self::getTimeOut ();
 
 		// Horde use locale for translation of error messages
+		// need to set LC_CTYPE for charachter classification (eg. Umlauts)
+		Api\Preferences::setlocale(LC_CTYPE);
 		Api\Preferences::setlocale(LC_MESSAGES);
 
 		// some plugins need extra measures to switch to an admin connection (eg. Dovecot constructs a special admin user name)
@@ -1050,7 +1052,7 @@ class Imap extends Horde_Imap_Client_Socket implements Imap\Iface
 	{
 		if (is_numeric($_username))
 		{
-			$_username = $GLOBALS['egw']->accounts->id2name($_username);
+			$_username = $GLOBALS['egw']->accounts->id2name($accountID=$_username);
 		}
 		else
 		{
@@ -1059,16 +1061,7 @@ class Imap extends Horde_Imap_Client_Socket implements Imap\Iface
 		switch ($this->loginType)
 		{
 			case 'email':
-				$accountemail = $GLOBALS['egw']->accounts->id2name($accountID,'account_email');
-				//$accountemail = $GLOBALS['egw']->accounts->read($GLOBALS['egw']->accounts->name2id($_username,'account_email'));
-				if (!empty($accountemail))
-				{
-					list($lusername,$domain) = explode('@',$accountemail,2);
-					if (strtolower($domain) == strtolower($this->domainName) && !empty($lusername))
-					{
-						$_username = $lusername;
-					}
-				}
+				$_username = $GLOBALS['egw']->accounts->id2name($accountID,'account_email');
 				break;
 
 			case 'vmailmgr':
@@ -1078,6 +1071,7 @@ class Imap extends Horde_Imap_Client_Socket implements Imap\Iface
 			case 'uidNumber':
 				$_username = 'u'.$accountID;
 				break;
+
 			default:
 				if (empty($this->loginType))
 				{
@@ -1104,11 +1098,6 @@ class Imap extends Horde_Imap_Client_Socket implements Imap\Iface
 		{
 			case 'email':
 				$account_id = $GLOBALS['egw']->accounts->name2id($_username, 'account_email');
-				if (!$account_id)
-				{
-					list($uid) = explode('@', $_username);
-					$account_id = $GLOBALS['egw']->accounts->name2id($uid, 'account_lid');
-				}
 				break;
 
 			case 'uidNumber':
@@ -1136,7 +1125,7 @@ class Imap extends Horde_Imap_Client_Socket implements Imap\Iface
 		}
 
 		$username = $this->getMailBoxUserName($_username);
-		if($this->loginType == 'vmailmgr' || $this->loginType == 'email' || $this->loginType == 'uidNumber') {
+		if($this->loginType == 'vmailmgr' || $this->loginType == 'uidNumber') {
 			$username .= '@'. $this->domainName;
 		}
 
