@@ -178,8 +178,10 @@ abstract class Merge
 				return true;	// open office write xml files
 			case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':	// ms word 2007 xml format
 			case 'application/vnd.openxmlformats-officedocument.wordprocessingml.d':	// mimetypes in vfs are limited to 64 chars
+			case 'application/vnd.ms-word.document.macroenabled.12':
 			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':	// ms excel 2007 xml format
 			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.shee':
+			case 'application/vnd.ms-excel.sheet.macroenabled.12':
 				if (!$zip_available) break;
 				return true;	// ms word xml format
 			case 'application/xml':
@@ -578,6 +580,7 @@ abstract class Merge
 		try {
 			$content = $this->merge_string($content,$ids,$err,$mimetype,$fix);
 		} catch (\Exception $e) {
+			_egw_log_exception($e);
 			$err = $e->getMessage();
 			return false;
 		}
@@ -616,7 +619,9 @@ abstract class Merge
 				break;
 			case 'application/xmlWord.Document':	// Word 2003*/
 			case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':	// ms office 2007
+			case 'application/vnd.ms-word.document.macroenabled.12':
 			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+			case 'application/vnd.ms-excel.sheet.macroenabled.12':
 				// It seems easier to split the parent tags here
 				$replace_tags = array(
 					// Tables, lists don't go inside <w:p>
@@ -755,7 +760,7 @@ abstract class Merge
 				list($contentstart,$contentrepeat,$contentend) = preg_split('/\$\$pagerepeat\$\$/',$content,-1, PREG_SPLIT_NO_EMPTY);  //get different parts of document, seperated by pagerepeat
 			}
 		}
-		if ($mimetype == 'application/vnd.openxmlformats-officedocument.wordprocessingml.document' && count($ids) > 1)
+		if (in_array($mimetype, array('application/vnd.ms-word.document.macroenabled.12', 'application/vnd.openxmlformats-officedocument.wordprocessingml.document')) && count($ids) > 1)
 		{
 			//for Word 2007 XML files we have to split the content and add a style for page break to  the style area
 			list($contentstart,$contentrepeat,$contentend) = preg_split('/w:body>/',$content,-1, PREG_SPLIT_NO_EMPTY);  //get differt parts of document, seperatet by Pagerepeat
@@ -794,7 +799,9 @@ abstract class Merge
 					$joiner = '';
 					break;
 				case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':
+				case 'application/vnd.ms-word.document.macroenabled.12':
 				case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+				case 'application/vnd.ms-excel.sheet.macroenabled.12':
 					$joiner = '<w:br w:type="page" />';
 					break;
 				case 'text/plain':
@@ -901,7 +908,9 @@ abstract class Merge
 				case 'application/vnd.oasis.opendocument.spreadsheet':
 					return $contentstart.implode('</text:p><text:p>',$contentrepeatpages).$contentend;
 				case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':
+				case 'application/vnd.ms-word.document.macroenabled.12':
 				case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+				case 'application/vnd.ms-excel.sheet.macroenabled.12':
 					return $contentstart.implode('<w:br w:type="page" />',$contentrepeatpages).$contentend;
 				case 'text/plain':
 					return $contentstart.implode("\r\n",$contentrep).$contentend;
@@ -938,7 +947,9 @@ abstract class Merge
 			case 'application/vnd.oasis.opendocument.text':		// open office
 			case 'application/vnd.oasis.opendocument.spreadsheet':
 			case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':	// ms office 2007
+			case 'application/vnd.ms-word.document.macroenabled.12':
 			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+			case 'application/vnd.ms-excel.sheet.macroenabled.12':
 			case 'application/xml':
 			case 'text/xml':
 				$is_xml = true;
@@ -1009,7 +1020,9 @@ abstract class Merge
 						break;
 					case 'application/xmlWord.Document':	// Word 2003*/
 					case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':	// ms office 2007
+					case 'application/vnd.ms-word.document.macroenabled.12':
 					case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+					case 'application/vnd.ms-excel.sheet.macroenabled.12':
 						$replace_tags = array(
 							'<b>','<strong>','<i>','<em>','<u>','<span>','<ol>','<ul>','<li>',
 							'<table>','<tr>','<td>',
@@ -1038,8 +1051,9 @@ abstract class Merge
 						$value = preg_replace('/&[^; ]+;/','',$value);
 					}
 				}
-
-				if(!$this->parse_html_styles)
+				if(!$this->parse_html_styles || (
+					strpos($value, "\n") !== FALSE && strpos($value,'<br') === FALSE && strpos($value, '<span') === FALSE && strpos($value, '<p') === FALSE
+				))
 				{
 					// Encode special chars so they don't break the file
 					$value = htmlspecialchars($value,ENT_NOQUOTES);
@@ -1116,6 +1130,7 @@ abstract class Merge
 					$break = '</text:p><text:p>';
 					break;
 				case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':	// ms word 2007
+				case 'application/vnd.ms-word.document.macroenabled.12':
 					$break = '</w:t><w:br/><w:t>';
 					break;
 				case 'application/xmlExcel.Sheet':	// Excel 2003
@@ -1128,6 +1143,7 @@ abstract class Merge
 					$break = '<br/>';
 					break;
 				case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':	// ms excel 2007
+				case 'application/vnd.ms-excel.sheet.macroenabled.12':
 				default:
 					$break = "\r\n";
 					break;
@@ -1259,6 +1275,7 @@ abstract class Merge
 			'!'.Api\DateTime::$user_dateformat . '* ' .Api\DateTime::$user_timeformat,
 			'!'.Api\DateTime::$user_dateformat . '*',
 			'!'.Api\DateTime::$user_dateformat,
+			'!Y-m-d\TH:i:s'
 		);
 
 		// Properly format values for spreadsheet
@@ -1296,7 +1313,8 @@ abstract class Merge
 				{
 					$date = new Api\DateTime($values[$key]);
 				}
-				if($mimetype == 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet')//Excel WTF
+				if($mimetype == 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' ||
+					$mimetype == 'application/vnd.ms-excel.sheet.macroenabled.12')//Excel WTF
 				{
 					$interval = $date->diff(new Api\DateTime('1900-01-00 0:00'));
 					$values[$key] = $interval->format('%a')+1;// 1900-02-29 did not exist
@@ -1329,6 +1347,7 @@ abstract class Merge
 
 				break;
 			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+			case 'application/vnd.ms-excel.sheet.macroenabled.12':
 				break;
 		}
 		if($format && $names)
@@ -1365,6 +1384,18 @@ abstract class Merge
 		preg_match_all('/\${2}(([^\/#]*?\/)?)#([^$\/]+)\/(.*?)[$}]{2}/', $content, $matches);
 		list($placeholders, , , $cf, $sub) = $matches;
 
+		// Collect any used custom fields from entries so you can do
+		// {{#other_app/#other_app_cf/n_fn}}
+		$expand_sub_cfs = [];
+		foreach($sub as $index => $cf_sub)
+		{
+			if(strpos($cf_sub, '#') === 0)
+			{
+				$expand_sub_cfs[$cf[$index]] .= '$$'.$cf_sub . '$$ ';
+			}
+		}
+		$expand_sub_cfs = array_unique($expand_sub_cfs);
+
 		foreach($cf as $index => $field)
 		{
 			if($cfs[$field])
@@ -1395,9 +1426,10 @@ abstract class Merge
 				{
 					$classname = "{$field_app}_merge";
 					$class = new $classname();
-					// If we send the real content, it can result in infinite loop of lookups
-					// This means you can't do {{#other_app/#other_app_cf/n_fn}}
-					$content = '';
+					// If we send the real content it can result in infinite loop of lookups
+					// so we send only the used fields
+					$content = $expand_sub_cfs[$field] ? $expand_sub_cfs[$field] : '';
+
 					$app_replacements[$field] = $class->get_replacements($values['#'.$field], $content);
 				}
 				$replacements[$placeholders[$index]] = $app_replacements[$field]['$$'.$sub[$index].'$$'];
@@ -1473,7 +1505,9 @@ abstract class Merge
 			case 'application/vnd.oasis.opendocument.text':		// open office
 			case 'application/vnd.oasis.opendocument.spreadsheet':
 			case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':	// ms office 2007
+			case 'application/vnd.ms-word.document.macroenabled.12':
 			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+			case 'application/vnd.ms-excel.sheet.macroenabled.12':
 			case 'application/xml':
 			case 'text/xml':
 			case 'text/html':
@@ -1497,12 +1531,17 @@ abstract class Merge
 					$LF = '&#10;';
 					break;
 				case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':
+				case 'application/vnd.ms-word.document.macroenabled.12':
 				case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+				case 'application/vnd.ms-excel.sheet.macroenabled.12':
 					$LF ='</w:t></w:r></w:p><w:p><w:r><w:t>';
 					break;
 				case 'application/xml';
 					$LF ='</w:t></w:r><w:r><w:br w:type="text-wrapping" w:clear="all"/></w:r><w:r><w:t>';
 					break;
+				case 'text/html':
+					$LF = "<br/>";
+					break;
 				default:
 					$LF = "\n";
 			}
@@ -1584,6 +1623,7 @@ abstract class Merge
 			case 'application/vnd.openxmlformats-officedocument.wordprocessingml.d':	// mimetypes in vfs are limited to 64 chars
 				$mimetype = 'application/vnd.openxmlformats-officedocument.wordprocessingml.document';
 			case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':
+			case 'application/vnd.ms-word.document.macroenabled.12':
 				$archive = tempnam($GLOBALS['egw_info']['server']['temp_dir'], basename($document,'.docx').'-').'.docx';
 				copy($content_url,$archive);
 				$content_url = 'zip://'.$archive.'#'.($content_file = 'word/document.xml');
@@ -1608,6 +1648,7 @@ abstract class Merge
 			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.shee':
 				$mimetype = 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet';
 			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+			case 'application/vnd.ms-excel.sheet.macroenabled.12':
 				$fix = array(	// hack to get Excel 2007 to display additional rows in tables
 					'/ss:ExpandedRowCount="\d+"/' => 'ss:ExpandedRowCount="9999"',
 				);
