@@ -201,11 +201,11 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 
 		parse_str(parse_url($url, PHP_URL_QUERY), $this->dir_url_params);
 
-		if (!is_null($overwrite_new) || !($stat = static::url_stat($path,STREAM_URL_STAT_QUIET)) || $mode[0] == 'x')	// file not found or file should NOT exist
+		if (!is_null($overwrite_new) || !($stat = $this->url_stat($path,STREAM_URL_STAT_QUIET)) || $mode[0] == 'x')	// file not found or file should NOT exist
 		{
-			if ($mode[0] == 'r' ||	// does $mode require the file to exist (r,r+)
+			if (!$dir || $mode[0] == 'r' ||	// does $mode require the file to exist (r,r+)
 				$mode[0] == 'x' && $stat ||	// or file should not exist, but does
-				!($dir_stat=static::url_stat($dir,STREAM_URL_STAT_QUIET)) ||	// or parent dir does not exist																																			create it
+				!($dir_stat=$this->url_stat($dir,STREAM_URL_STAT_QUIET)) ||	// or parent dir does not exist																																			create it
 				!Vfs::check_access($dir,Vfs::WRITABLE,$dir_stat))	// or we are not allowed to 																																			create it
 			{
 				self::_remove_password($url);
@@ -385,7 +385,7 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 		$ret = fclose($this->opened_stream) && $ret;
 
 		unset(self::$stat_cache[$this->opened_path]);
-		$this->opened_stream = $this->opened_path = $this->opened_mode = $this->opend_fs_id = null;
+		$this->opened_stream = $this->opened_path = $this->opened_mode = $this->opened_fs_id = null;
 		$this->operation = self::DEFAULT_OPERATION;
 
 		return $ret;
@@ -543,17 +543,21 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param string $url
 	 * @return boolean TRUE on success or FALSE on failure
 	 */
-	static function unlink ( $url, $parent_stat=null )
+	function unlink ( $url, $parent_stat=null )
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($url)");
 
 		$path = Vfs::parse_url($url,PHP_URL_PATH);
 
 		// need to get parent stat from Sqlfs, not Vfs
-		if (!isset($parent_stat)) $parent_stat = static::url_stat(Vfs::dirname($path), STREAM_URL_STAT_LINK);
+		if (!isset($parent_stat))
+		{
+			$parent_stat = !($dir = Vfs::dirname($path)) ? false :
+				$this->url_stat($dir, STREAM_URL_STAT_LINK);
+		}
 
-		if (!$parent_stat || !($stat = self::url_stat($path,STREAM_URL_STAT_LINK)) ||
-			!Vfs::check_access(Vfs::dirname($path),Vfs::WRITABLE, $parent_stat))
+		if (!$parent_stat || !($stat = $this->url_stat($path,STREAM_URL_STAT_LINK)) ||
+			!$dir || !Vfs::check_access($dir, Vfs::WRITABLE, $parent_stat))
 		{
 			self::_remove_password($url);
 			if (self::LOG_LEVEL) error_log(__METHOD__."($url) permission denied!");
@@ -595,7 +599,7 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param string $url_to
 	 * @return boolean TRUE on success or FALSE on failure
 	 */
-	static function rename ( $url_from, $url_to)
+	function rename ( $url_from, $url_to)
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($url_from,$url_to)");
 
@@ -605,16 +609,15 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 		$to_dir = Vfs::dirname($path_to);
 		$operation = self::url2operation($url_from);
 
-		// we have to use array($class,'url_stat'), as $class.'::url_stat' requires PHP 5.2.3 and we currently only require 5.2+
-		if (!($from_stat = static::url_stat($path_from, 0)) ||
-			!Vfs::check_access($from_dir, Vfs::WRITABLE, $from_dir_stat = static::url_stat($from_dir, 0)))
+		if (!($from_stat = $this->url_stat($path_from, 0)) || !$from_dir ||
+			!Vfs::check_access($from_dir, Vfs::WRITABLE, $from_dir_stat = $this->url_stat($from_dir, 0)))
 		{
 			self::_remove_password($url_from);
 			self::_remove_password($url_to);
 			if (self::LOG_LEVEL) error_log(__METHOD__."($url_from,$url_to): $path_from permission denied!");
 			return false;	// no permission or file does not exist
 		}
-		if (!Vfs::check_access($to_dir, Vfs::WRITABLE, $to_dir_stat = static::url_stat($to_dir, 0)))
+		if (!$to_dir || !Vfs::check_access($to_dir, Vfs::WRITABLE, $to_dir_stat = $this->url_stat($to_dir, 0)))
 		{
 			self::_remove_password($url_from);
 			self::_remove_password($url_to);
@@ -623,7 +626,7 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 		}
 		// the filesystem stream-wrapper does NOT allow to rename files to directories, as this makes problems
 		// for our vfs too, we abort here with an error, like the filesystem one does
-		if (($to_stat = static::url_stat($path_to, 0)) &&
+		if (($to_stat = $this->url_stat($path_to, 0)) &&
 			($to_stat['mime'] === self::DIR_MIME_TYPE) !== ($from_stat['mime'] === self::DIR_MIME_TYPE))
 		{
 			self::_remove_password($url_from);
@@ -690,37 +693,45 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param int $options Posible values include STREAM_REPORT_ERRORS and STREAM_MKDIR_RECURSIVE
 	 * @return boolean TRUE on success or FALSE on failure
 	 */
-	static function mkdir ( $url, $mode, $options )
+	function mkdir ( $url, $mode, $options )
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($url,$mode,$options)");
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__." called from:".function_backtrace());
 		$path = Vfs::parse_url($url,PHP_URL_PATH);
 
-		if (self::url_stat($path,STREAM_URL_STAT_QUIET))
+		if ($this->url_stat($path,STREAM_URL_STAT_QUIET))
 		{
 			self::_remove_password($url);
 			if (self::LOG_LEVEL) error_log(__METHOD__."('$url',$mode,$options) already exist!");
 			if (!($options & STREAM_REPORT_ERRORS))
 			{
-				//throw new Exception(__METHOD__."('$url',$mode,$options) already exist!");
 				trigger_error(__METHOD__."('$url',$mode,$options) already exist!",E_USER_WARNING);
 			}
 			return false;
 		}
-		$parent_path = Vfs::dirname($path);
+		if (!($parent_path = Vfs::dirname($path)))
+		{
+			self::_remove_password($url);
+			if (self::LOG_LEVEL) error_log(__METHOD__."('$url',$mode,$options) dirname('$path')===false!");
+			if (!($options & STREAM_REPORT_ERRORS))
+			{
+				trigger_error(__METHOD__."('$url',$mode,$options) dirname('$path')===false!", E_USER_WARNING);
+			}
+			return false;
+		}
 		if (($query = Vfs::parse_url($url,PHP_URL_QUERY))) $parent_path .= '?'.$query;
-		$parent = self::url_stat($parent_path,STREAM_URL_STAT_QUIET);
+		$parent = $this->url_stat($parent_path,STREAM_URL_STAT_QUIET);
 
 		// check if we should also create all non-existing path components and our parent does not exist,
 		// if yes call ourself recursive with the parent directory
 		if (($options & STREAM_MKDIR_RECURSIVE) && $parent_path != '/' && !$parent)
 		{
 			if (self::LOG_LEVEL > 1) error_log(__METHOD__." creating parents: $parent_path, $mode");
-			if (!self::mkdir($parent_path,$mode,$options))
+			if (!$this->mkdir($parent_path,$mode,$options))
 			{
 				return false;
 			}
-			$parent = self::url_stat($parent_path,0);
+			$parent = $this->url_stat($parent_path,0);
 		}
 		if (!$parent || !Vfs::check_access($parent_path,Vfs::WRITABLE,$parent))
 		{
@@ -777,15 +788,15 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param int $options Possible values include STREAM_REPORT_ERRORS.
 	 * @return boolean TRUE on success or FALSE on failure.
 	 */
-	static function rmdir ( $url, $options )
+	function rmdir ( $url, $options )
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($url)");
 
 		$path = Vfs::parse_url($url,PHP_URL_PATH);
-		$parent = Vfs::dirname($path);
 
-		if (!($stat = self::url_stat($path,0)) || $stat['mime'] != self::DIR_MIME_TYPE ||
-			!Vfs::check_access($parent, Vfs::WRITABLE, static::url_stat($parent,0)))
+		if (!($parent = Vfs::dirname($path)) ||
+			!($stat = $this->url_stat($path, 0)) || $stat['mime'] != self::DIR_MIME_TYPE ||
+			!Vfs::check_access($parent, Vfs::WRITABLE, $this->url_stat($parent,0)))
 		{
 			self::_remove_password($url);
 			$err_msg = __METHOD__."($url,$options) ".(!$stat ? 'not found!' :
@@ -824,6 +835,49 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 		return $ret;
 	}
 
+	/**
+	 * StreamWrapper method (PHP 5.4+) for touch, chmod, chown and chgrp
+	 *
+	 * We use protected helper methods touch, chmod, chown and chgrp to implement the functionality.
+	 *
+	 * @param string $path
+	 * @param int $option STREAM_META_(TOUCH|ACCESS|((OWNER|GROUP)(_NAME)?))
+	 * @param array|int|string $value
+	 * - STREAM_META_TOUCH array($time, $atime)
+	 * - STREAM_META_ACCESS int
+	 * - STREAM_(OWNER|GROUP) int
+	 * - STREAM_(OWNER|GROUP)_NAME string
+	 * @return boolean true on success, false on failure
+	 */
+	function stream_metadata($path, $option, $value)
+	{
+		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($path, $option, ".array2string($value).")");
+
+		switch($option)
+		{
+			case STREAM_META_TOUCH:
+				return $this->touch($path, $value[0]);	// atime is not supported
+
+			case STREAM_META_ACCESS:
+				return $this->chmod($path, $value);
+
+			case STREAM_META_OWNER_NAME:
+				if (($value = $GLOBALS['egw']->accounts->name2id($value, 'account_lid', 'u')) === false)
+					return false;
+				// fall through
+			case STREAM_META_OWNER:
+				return $this->chown($path, $value);
+
+			case STREAM_META_GROUP_NAME:
+				if (($value = $GLOBALS['egw']->accounts->name2id($value, 'account_lid', 'g')) === false)
+					return false;
+				// fall through
+			case STREAM_META_GROUP:
+				return $this->chgrp($path, $value);
+		}
+		return false;
+	}
+
 	/**
 	 * This is not (yet) a stream-wrapper function, but it's necessary and can be used static
 	 *
@@ -831,25 +885,26 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param int $time =null modification time (unix timestamp), default null = current time
 	 * @param int $atime =null access time (unix timestamp), default null = current time, not implemented in the vfs!
 	 */
-	static function touch($url,$time=null,$atime=null)
+	protected function touch($url,$time=null,$atime=null)
 	{
 		unset($atime);	// not used
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($url, $time)");
 
 		$path = Vfs::parse_url($url,PHP_URL_PATH);
 
-		if (!($stat = self::url_stat($path,STREAM_URL_STAT_QUIET)))
+		$vfs = new self();
+		if (!($stat = $vfs->url_stat($path,STREAM_URL_STAT_QUIET)))
 		{
 			// file does not exist --> create an empty one
 			if (!($f = fopen(self::SCHEME.'://default'.$path,'w')) || !fclose($f))
 			{
 				return false;
 			}
-			if (is_null($time))
+			if (!$time)
 			{
 				return true;	// new (empty) file created with current mod time
 			}
-			$stat = self::url_stat($path,0);
+			$stat = $vfs->url_stat($path,0);
 		}
 		unset(self::$stat_cache[$path]);
 		$stmt = self::$pdo->prepare('UPDATE '.self::TABLE.' SET fs_modified=:fs_modified,fs_modifier=:fs_modifier WHERE fs_id=:fs_id');
@@ -868,13 +923,14 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param int $owner
 	 * @return boolean
 	 */
-	static function chown($url,$owner)
+	protected function chown($url,$owner)
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($url,$owner)");
 
 		$path = Vfs::parse_url($url,PHP_URL_PATH);
 
-		if (!($stat = self::url_stat($path,0)))
+		$vfs = new self();
+		if (!($stat = $vfs->url_stat($path,0)))
 		{
 			if (self::LOG_LEVEL) error_log(__METHOD__."($url,$owner) no such file or directory!");
 			trigger_error("No such file or directory $url !",E_USER_WARNING);
@@ -912,13 +968,14 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param int $owner
 	 * @return boolean
 	 */
-	static function chgrp($url,$owner)
+	protected function chgrp($url,$owner)
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($url,$owner)");
 
 		$path = Vfs::parse_url($url,PHP_URL_PATH);
 
-		if (!($stat = self::url_stat($path,0)))
+		$vfs = new self();
+		if (!($stat = $vfs->url_stat($path,0)))
 		{
 			if (self::LOG_LEVEL) error_log(__METHOD__."($url,$owner) no such file or directory!");
 			trigger_error("No such file or directory $url !",E_USER_WARNING);
@@ -957,13 +1014,14 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param int $mode
 	 * @return boolean
 	 */
-	static function chmod($url,$mode)
+	protected function chmod($url,$mode)
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($url, $mode)");
 
 		$path = Vfs::parse_url($url,PHP_URL_PATH);
 
-		if (!($stat = self::url_stat($path,0)))
+		$vfs = new self();
+		if (!($stat = $vfs->url_stat($path,0)))
 		{
 			if (self::LOG_LEVEL) error_log(__METHOD__."($url, $mode) no such file or directory!");
 			trigger_error("No such file or directory $url !",E_USER_WARNING);
@@ -1007,12 +1065,13 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 
 		$path = Vfs::parse_url($url,PHP_URL_PATH);
 
-		if (!($stat = self::url_stat($url,0)) || 		// dir not found
-			$stat['mime'] != self::DIR_MIME_TYPE ||		// no dir
+		if (!($stat = $this->url_stat($url,0)) || 		// dir not found
+			!($stat['mode'] & self::MODE_DIR) && $stat['mime'] != self::DIR_MIME_TYPE ||		// no dir
 			!Vfs::check_access($url,Vfs::EXECUTABLE|Vfs::READABLE,$stat))	// no access
 		{
 			self::_remove_password($url);
-			$msg = $stat['mime'] != self::DIR_MIME_TYPE ? "$url is no directory" : 'permission denied';
+			$msg = !($stat['mode'] & self::MODE_DIR) && $stat['mime'] != self::DIR_MIME_TYPE ?
+				"$url is no directory" : 'permission denied';
 			if (self::LOG_LEVEL) error_log(__METHOD__."('$url',$options) $msg!");
 			$this->opened_dir = null;
 			return false;
@@ -1067,7 +1126,7 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * @param boolean $eacl_access =null allows extending classes to pass the value of their check_extended_acl() method (no lsb!)
 	 * @return array
 	 */
-	static function url_stat ( $url, $flags, $eacl_access=null )
+	function url_stat ( $url, $flags, $eacl_access=null )
 	{
 		static $max_subquery_depth=null;
 		if (is_null($max_subquery_depth))
@@ -1176,7 +1235,7 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 			error_log(__METHOD__."() decremented max_subquery_depth to $max_subquery_depth");
 			Api\Config::save_value('max_subquery_depth', $max_subquery_depth, 'phpgwapi');
 			if (method_exists($GLOBALS['egw'],'invalidate_session_cache')) $GLOBALS['egw']->invalidate_session_cache();
-			return self::url_stat($url, $flags, $eacl_access);
+			return $this->url_stat($url, $flags, $eacl_access);
 		}
 		self::$stat_cache[$path] = $info;
 
@@ -1273,7 +1332,8 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 */
 	static function readlink($path)
 	{
-		$link = !($lstat = self::url_stat($path,STREAM_URL_STAT_LINK)) || is_null($lstat['readlink']) ? false : $lstat['readlink'];
+		$vfs = new self();
+		$link = !($lstat = $vfs->url_stat($path,STREAM_URL_STAT_LINK)) || is_null($lstat['readlink']) ? false : $lstat['readlink'];
 
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."('$path') = $link");
 
@@ -1291,13 +1351,14 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."('$target','$link')");
 
-		if (self::url_stat($link,0))
+		$inst = new static();
+		if ($inst->url_stat($link,0))
 		{
 			if (self::LOG_LEVEL > 0) error_log(__METHOD__."('$target','$link') $link exists, returning false!");
 			return false;	// $link already exists
 		}
 		if (!($dir = Vfs::dirname($link)) ||
-			!Vfs::check_access($dir,Vfs::WRITABLE,$dir_stat=static::url_stat($dir,0)))
+			!Vfs::check_access($dir,Vfs::WRITABLE,$dir_stat=$inst->url_stat($dir,0)))
 		{
 			if (self::LOG_LEVEL > 0) error_log(__METHOD__."('$target','$link') returning false! (!is_writable('$dir'), dir_stat=".array2string($dir_stat).")");
 			return false;	// parent dir does not exist or is not writable
@@ -1411,7 +1472,8 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 		}
 		if (is_null($fs_id))
 		{
-			if (!($stat = self::url_stat($path,0)))
+			$vfs = new self();
+			if (!($stat = $vfs->url_stat($path,0)))
 			{
 				if (self::LOG_LEVEL) error_log(__METHOD__."($path,$rights,$owner,$fs_id) no such file or directory!");
 				return false;	// $path not found
@@ -1465,7 +1527,8 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 */
 	static function get_eacl($path)
 	{
-		if (!($stat = static::url_stat($path, STREAM_URL_STAT_QUIET)))
+		$inst = new static();
+		if (!($stat = $inst->url_stat($path, STREAM_URL_STAT_QUIET)))
 		{
 			error_log(__METHOD__.__LINE__.' '.array2string($path).' not found!');
 			return false;	// not found
@@ -1492,6 +1555,11 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 		return $eacls;
 	}
 
+	/**
+	 * Max allowed sub-directory depth, to be able to break infinit recursion by wrongly linked directories
+	 */
+	const MAX_ID2PATH_RECURSION = 100;
+
 	/**
 	 * Return the path of given fs_id(s)
 	 *
@@ -1499,11 +1567,17 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 * Calls itself recursive to to determine the path of the parent/directory
 	 *
 	 * @param int|array $fs_ids integer fs_id or array of them
-	 * @return string|array path or array or pathes indexed by fs_id
+	 * @param int $recursion_count =0 internally used to break infinit recursions
+	 * @return false|string|array path or array or pathes indexed by fs_id, or false on error
 	 */
-	static function id2path($fs_ids)
+	static function id2path($fs_ids, $recursion_count=0)
 	{
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__.'('.array2string($fs_ids).')');
+		if ($recursion_count > self::MAX_ID2PATH_RECURSION)
+		{
+			error_log(__METHOD__."(".array2string($fs_ids).", $recursion_count) max recursion depth reached, probably broken filesystem!");
+			return false;
+		}
 		$ids = (array)$fs_ids;
 		$pathes = array();
 		// first check our stat-cache for the ids
@@ -1547,7 +1621,7 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 		}
 		unset($stmt);
 
-		if ($parents && !($parents = self::id2path($parents)))
+		if ($parents && !($parents = self::id2path($parents, $recursion_count+1)))
 		{
 			return false;	// parent not found, should never happen ...
 		}
@@ -1726,10 +1800,12 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 */
 	static function proppatch($path,array $props)
 	{
+		static $inst = null;
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."(".array2string($path).','.array2string($props));
 		if (!is_numeric($path))
 		{
-			if (!($stat = self::url_stat($path,0)))
+			if (!isset($inst)) $inst = new self();
+			if (!($stat = $inst->url_stat($path,0)))
 			{
 				return false;
 			}
@@ -1791,12 +1867,15 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 	 */
 	static function propfind($path_ids,$ns=Vfs::DEFAULT_PROP_NAMESPACE)
 	{
+		static $inst = null;
+
 		$ids = is_array($path_ids) ? $path_ids : array($path_ids);
 		foreach($ids as &$id)
 		{
 			if (!is_numeric($id))
 			{
-				if (!($stat = self::url_stat($id,0)))
+				if (!isset($inst)) $inst = new self();
+				if (!($stat = $inst->url_stat($id,0)))
 				{
 					if (self::LOG_LEVEL) error_log(__METHOD__."(".array2string($path_ids).",$ns) path '$id' not found!");
 					return false;
@@ -1827,9 +1906,9 @@ class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 		{
 			$props = $props[$row['fs_id']] ? $props[$row['fs_id']] : array();	// return empty array for no props
 		}
-		elseif ($props && isset($stat))	// need to map fs_id's to pathes
+		elseif ($props && isset($stat) && is_array($id2path = self::id2path(array_keys($props))))	// need to map fs_id's to pathes
 		{
-			foreach(self::id2path(array_keys($props)) as $id => $path)
+			foreach($id2path as $id => $path)
 			{
 				$props[$path] =& $props[$id];
 				unset($props[$id]);
