@@ -7,8 +7,7 @@
  * @package api
  * @subpackage vfs
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2008-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @version $Id$
+ * @copyright (c) 2008-17 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  */
 
 namespace EGroupware\Api\Vfs\Sqlfs;
@@ -32,7 +31,6 @@ class Utils extends StreamWrapper
 		{
 			self::_pdo();
 		}
-		$query = 'SELECT fs_id,fs_name,fs_size,fs_content'.
 		$query = 'SELECT fs_id,fs_name,fs_size,fs_content'.
 			' FROM '.self::TABLE.' WHERE fs_content IS NOT NULL'.
 			' ORDER BY fs_id LIMIT 5 OFFSET :offset';
@@ -46,8 +44,9 @@ class Utils extends StreamWrapper
 		$stmt->bindColumn(4,$fs_content,\PDO::PARAM_LOB);
 		$stmt->bindValue(':offset', $n, \PDO::PARAM_INT);
 
-		while ($stmt->execute())
+		while ($stmt->execute())	// && $stmt->rowCount() does not work for all dbs :(
 		{
+			$start = $n;
 			foreach($stmt as $row)
 			{
 				// hack to work around a current php bug (http://bugs.php.net/bug.php?id=40913)
@@ -57,7 +56,7 @@ class Utils extends StreamWrapper
 					$content = fopen('php://temp', 'wb');
 					fwrite($content, $fs_content);
 					fseek($content, 0, SEEK_SET);
-					unset($fs_content);
+					$fs_content = '';	// can NOT unset it, at least in PHP 7 it looses bind to column!
 				}
 				else
 				{
@@ -86,7 +85,7 @@ class Utils extends StreamWrapper
 
 				++$n;
 			}
-			if (!$n) break;	// just in case nothing is found, statement will execute just fine
+			if (!$n || $n == $start) break;	// just in case nothing is found, statement will execute just fine
 
 			$stmt->bindValue(':offset', $n, \PDO::PARAM_INT);
 		}
@@ -150,9 +149,10 @@ class Utils extends StreamWrapper
 		);
 		$stmt = $delete_stmt = null;
 		$msgs = array();
+		$sqlfs = new StreamWrapper();
 		foreach($dirs as $path => $id)
 		{
-			if (!($stat = self::url_stat($path, STREAM_URL_STAT_LINK)))
+			if (!($stat = $sqlfs->url_stat($path, STREAM_URL_STAT_LINK)) || $stat['ino'] != $id)
 			{
 				if ($check_only)
 				{
@@ -308,6 +308,7 @@ class Utils extends StreamWrapper
 	{
 		$lostnfound = null;
 		$msgs = array();
+		$sqlfs = new StreamWrapper();
 		foreach(self::$pdo->query('SELECT fs.* FROM '.self::TABLE.' fs'.
 			' LEFT JOIN '.self::TABLE.' dir ON dir.fs_id=fs.fs_dir'.
 			' WHERE fs.fs_id > 1 AND dir.fs_id IS NULL') as $row)
@@ -322,13 +323,13 @@ class Utils extends StreamWrapper
 			if (!isset($lostnfound))
 			{
 				// check if we already have /lost+found, create it if not
-				if (!($lostnfound = self::url_stat(self::LOST_N_FOUND, STREAM_URL_STAT_QUIET)))
+				if (!($lostnfound = $sqlfs->url_stat(self::LOST_N_FOUND, STREAM_URL_STAT_QUIET)))
 				{
 					Vfs::$is_root = true;
-					if (!self::mkdir(self::LOST_N_FOUND, self::LOST_N_FOUND_MOD, 0) ||
+					if (!$sqlfs->mkdir(self::LOST_N_FOUND, self::LOST_N_FOUND_MOD, 0) ||
 						!(!($admins = $GLOBALS['egw']->accounts->name2id(self::LOST_N_FOUND_GRP)) ||
 						   self::chgrp(self::LOST_N_FOUND, $admins) && self::chmod(self::LOST_N_FOUND,self::LOST_N_FOUND_MOD)) ||
-						!($lostnfound = self::url_stat(self::LOST_N_FOUND, STREAM_URL_STAT_QUIET)))
+						!($lostnfound = $sqlfs->url_stat(self::LOST_N_FOUND, STREAM_URL_STAT_QUIET)))
 					{
 						$msgs[] = lang("Can't create directory %1 to connect found unconnected nodes to it!",self::LOST_N_FOUND);
 					}
