@@ -157,11 +157,11 @@ class StreamWrapper implements StreamWrapperIface
 	 * @param array|boolean &$stat=null on return: stat of existing file or false for non-existing files
 	 * @return string|boolean false if the url cant be resolved, should not happen if fstab has a root entry
 	 */
-	static function resolve_url_symlinks($_path,$file_exists=true,$resolve_last_symlink=true,&$stat=null)
+	function resolve_url_symlinks($_path,$file_exists=true,$resolve_last_symlink=true,&$stat=null)
 	{
 		$path = self::get_path($_path);
 
-		if (!($stat = self::url_stat($path,$resolve_last_symlink?0:STREAM_URL_STAT_LINK)) && !$file_exists)
+		if (!($stat = $this->url_stat($path,$resolve_last_symlink?0:STREAM_URL_STAT_LINK)) && !$file_exists)
 		{
 			$url = null;
 			$stat = self::check_symlink_components($path,0,$url);
@@ -172,9 +172,9 @@ class StreamWrapper implements StreamWrapperIface
 			$url = $stat['url'];
 		}
 		// if the url resolves to a symlink to the vfs, resolve this vfs:// url direct
-		if ($url && self::parse_url($url,PHP_URL_SCHEME) == self::SCHEME)
+		if ($url && Vfs::parse_url($url,PHP_URL_SCHEME) == self::SCHEME)
 		{
-			$url = self::resolve_url(self::parse_url($url,PHP_URL_PATH));
+			$url = self::resolve_url(Vfs::parse_url($url,PHP_URL_PATH));
 		}
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($path,file_exists=$file_exists,resolve_last_symlink=$resolve_last_symlink) = '$url'$log");
 		return $url;
@@ -223,7 +223,7 @@ class StreamWrapper implements StreamWrapperIface
 				'home' => str_replace(array('\\\\','\\'),array('','/'),$GLOBALS['egw_info']['user']['homedirectory']),
 			);
 		}
-		$parts = array_merge(self::parse_url($path),$defaults);
+		$parts = array_merge(Vfs::parse_url($path),$defaults);
 		if (!$parts['host']) $parts['host'] = 'default';	// otherwise we get an invalid url (scheme:///path/to/something)!
 
 		if (!empty($parts['scheme']) && $parts['scheme'] != self::SCHEME)
@@ -237,7 +237,7 @@ class StreamWrapper implements StreamWrapperIface
 		{
 			if ($mounted == '/' || $mounted == $parts['path'] || $mounted.'/' == substr($parts['path'],0,strlen($mounted)+1))
 			{
-				$scheme = self::parse_url($url,PHP_URL_SCHEME);
+				$scheme = Vfs::parse_url($url,PHP_URL_SCHEME);
 				if (is_null(self::$wrappers) || !in_array($scheme,self::$wrappers))
 				{
 					self::load_wrapper($scheme);
@@ -291,13 +291,6 @@ class StreamWrapper implements StreamWrapperIface
 		return null;
 	}
 
-	/**
-	 * Can be used from egw_vfs to tell vfs notifications to treat an opened file as a new file
-	 *
-	 * @var boolean
-	 */
-	static protected $treat_as_new;
-
 	/**
 	 * This method is called immediately after your stream object is created.
 	 *
@@ -316,7 +309,7 @@ class StreamWrapper implements StreamWrapperIface
 		$this->opened_stream = null;
 
 		$stat = null;
-		if (!($url = self::resolve_url_symlinks($path,$mode[0]=='r',true,$stat)))
+		if (!($url = $this->resolve_url_symlinks($path,$mode[0]=='r',true,$stat)))
 		{
 			return false;
 		}
@@ -330,16 +323,17 @@ class StreamWrapper implements StreamWrapperIface
 			return false;
 		}
 		$this->opened_stream_mode = $mode;
-		$this->opened_stream_path = $path[0] == '/' ? $path : self::parse_url($path, PHP_URL_PATH);
+		$this->opened_stream_path = $path[0] == '/' ? $path : Vfs::parse_url($path, PHP_URL_PATH);
 		$this->opened_stream_url = $url;
 		$this->opened_stream_is_new = !$stat;
 
 		// are we requested to treat the opened file as new file (only for files opened NOT for reading)
-		if ($mode[0] != 'r' && !$this->opened_stream_is_new && self::$treat_as_new)
+		if ($mode[0] != 'r' && !$this->opened_stream_is_new && $this->context &&
+			($opts = stream_context_get_params($this->context)) &&
+			$opts['options'][self::SCHEME]['treat_as_new'])
 		{
 			$this->opened_stream_is_new = true;
-			//error_log(__METHOD__."($path,$mode,...) stat=$stat, treat_as_new=".self::$treat_as_new." --> ".array2string($this->opened_stream_is_new));
-			self::$treat_as_new = null;
+			//error_log(__METHOD__."($path,$mode,...) stat=$stat, context=".array2string($opts)." --> ".array2string($this->opened_stream_is_new));
 		}
 		return true;
 	}
@@ -358,7 +352,7 @@ class StreamWrapper implements StreamWrapperIface
 		// causing eg. notifications to be ignored, because of previous size 0, when using WebDAV
 		clearstatcache(false);
 
-		if (isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
+		if (!class_exists('setup_process', false))
 		{
 			Api\Hooks::process(array(
 				'location' => str_replace('b','',$this->opened_stream_mode) == 'r' ? 'vfs_read' :
@@ -480,6 +474,55 @@ class StreamWrapper implements StreamWrapperIface
 		return fstat($this->opened_stream);
 	}
 
+	/**
+	 * StreamWrapper method (PHP 5.4+) for touch, chmod, chown and chgrp
+	 *
+	 * @param string $path
+	 * @param int $option STREAM_META_(TOUCH|ACCESS|((OWNER|GROUP)(_NAME)?))
+	 * @param array|int|string $value
+	 * - STREAM_META_TOUCH array($time, $atime)
+	 * - STREAM_META_ACCESS int
+	 * - STREAM_(OWNER|GROUP) int
+	 * - STREAM_(OWNER|GROUP)_NAME string
+	 * @return boolean true on success, false on failure
+	 */
+	function stream_metadata($path, $option, $value)
+	{
+		if (!($url = $this->resolve_url_symlinks($path, $option != STREAM_META_TOUCH, false)))	// true,false file need to exist, but do not resolve last component
+		{
+			return false;
+		}
+		if (self::url_is_readonly($url))
+		{
+			return false;
+		}
+		if (self::LOG_LEVEL > 1) error_log(__METHOD__."('$path', $option, ".array2string($value).") url=$url");
+
+		switch($option)
+		{
+			case STREAM_META_TOUCH:
+				return touch($url, $value[0]);	// atime is not supported
+
+			case STREAM_META_ACCESS:
+				return chmod($url, $value);
+
+			case STREAM_META_OWNER_NAME:
+				if (($value = $GLOBALS['egw']->accounts->name2id($value, 'account_lid', 'u')) === false)
+					return false;
+				// fall through
+			case STREAM_META_OWNER:
+				return chown($url, $value);
+
+			case STREAM_META_GROUP_NAME:
+				if (($value = $GLOBALS['egw']->accounts->name2id($value, 'account_lid', 'g')) === false)
+					return false;
+				// fall through
+			case STREAM_META_GROUP:
+				return chgrp($url, $value);
+		}
+		return false;
+	}
+
 	/**
 	 * This method is called in response to unlink() calls on URL paths associated with the wrapper.
 	 *
@@ -489,9 +532,9 @@ class StreamWrapper implements StreamWrapperIface
 	 * @param string $path
 	 * @return boolean TRUE on success or FALSE on failure
 	 */
-	static function unlink ( $path )
+	function unlink ( $path )
 	{
-		if (!($url = self::resolve_url_symlinks($path,true,false)))	// true,false file need to exist, but do not resolve last component
+		if (!($url = $this->resolve_url_symlinks($path,true,false)))	// true,false file need to exist, but do not resolve last component
 		{
 			return false;
 		}
@@ -499,17 +542,17 @@ class StreamWrapper implements StreamWrapperIface
 		{
 			return false;
 		}
-		$stat = self::url_stat($path, STREAM_URL_STAT_LINK);
+		$stat = $this->url_stat($path, STREAM_URL_STAT_LINK);
 
 		self::symlinkCache_remove($path);
 		$ok = unlink($url);
 
 		// call "vfs_unlink" hook only after successful unlink, with data from (not longer possible) stat call
-		if ($ok && isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
+		if ($ok && !class_exists('setup_process', false))
 		{
 			Api\Hooks::process(array(
 				'location' => 'vfs_unlink',
-				'path' => $path[0] == '/' ? $path : self::parse_url($path, PHP_URL_PATH),
+				'path' => $path[0] == '/' ? $path : Vfs::parse_url($path, PHP_URL_PATH),
 				'url'  => $url,
 				'stat' => $stat,
 			),'',true);
@@ -528,16 +571,21 @@ class StreamWrapper implements StreamWrapperIface
 	 * @param string $path_from
 	 * @param string $path_to
 	 * @return boolean TRUE on success or FALSE on failure
+	 * @throws Exception\ProtectedDirectory if trying to delete a protected directory, see Vfs::isProtected()
 	 */
-	static function rename ( $path_from, $path_to )
+	function rename ( $path_from, $path_to )
 	{
-		if (!($url_from = self::resolve_url_symlinks($path_from,true,false)) ||
-			!($url_to = self::resolve_url_symlinks($path_to,false)))
+		if (Vfs::isProtectedDir($path_from))
+		{
+			throw new Exception\ProtectedDirectory("Renaming protected directory '$path_from' rejected!");
+		}
+		if (!($url_from = $this->resolve_url_symlinks($path_from,true,false)) ||
+			!($url_to = $this->resolve_url_symlinks($path_to,false)))
 		{
 			return false;
 		}
 		// if file is moved from one filesystem / wrapper to an other --> copy it (rename fails cross wrappers)
-		if (self::parse_url($url_from,PHP_URL_SCHEME) == self::parse_url($url_to,PHP_URL_SCHEME))
+		if (Vfs::parse_url($url_from,PHP_URL_SCHEME) == Vfs::parse_url($url_to,PHP_URL_SCHEME))
 		{
 			self::symlinkCache_remove($path_from);
 			$ret = rename($url_from,$url_to);
@@ -547,7 +595,7 @@ class StreamWrapper implements StreamWrapperIface
 			$ret = stream_copy_to_stream($from,$to) !== false;
 			fclose($from);
 			fclose($to);
-			if ($ret) self::unlink($path_from);
+			if ($ret) $this->unlink($path_from);
 		}
 		else
 		{
@@ -558,12 +606,12 @@ class StreamWrapper implements StreamWrapperIface
 			error_log(__METHOD__."('$path_from','$path_to') url_from='$url_from', url_to='$url_to' returning ".array2string($ret));
 		}
 		// call "vfs_rename" hook
-		if ($ret && isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
+		if ($ret && !class_exists('setup_process', false))
 		{
 			Api\Hooks::process(array(
 				'location' => 'vfs_rename',
-				'from' => $path_from[0] == '/' ? $path_from : self::parse_url($path_from, PHP_URL_PATH),
-				'to' => $path_to[0] == '/' ? $path_to : self::parse_url($path_to, PHP_URL_PATH),
+				'from' => $path_from[0] == '/' ? $path_from : Vfs::parse_url($path_from, PHP_URL_PATH),
+				'to' => $path_to[0] == '/' ? $path_to : Vfs::parse_url($path_to, PHP_URL_PATH),
 				'url_from' => $url_from,
 				'url_to' => $url_to,
 			),'',true);
@@ -574,28 +622,39 @@ class StreamWrapper implements StreamWrapperIface
 	/**
 	 * This method is called in response to mkdir() calls on URL paths associated with the wrapper.
 	 *
-	 * It should attempt to create the directory specified by path.
-	 * In order for the appropriate error message to be returned, do not define this method if your wrapper does not support creating directories.
+	 * Not all wrappers, eg. smb(client) support recursive directory creation.
+	 * Therefore we handle that here instead of passing the options to underlaying wrapper.
 	 *
 	 * @param string $path
 	 * @param int $mode
 	 * @param int $options Posible values include STREAM_REPORT_ERRORS and STREAM_MKDIR_RECURSIVE
 	 * @return boolean TRUE on success or FALSE on failure
 	 */
-	static function mkdir ( $path, $mode, $options )
+	function mkdir ( $path, $mode, $options )
 	{
-		if (!($url = self::resolve_url_symlinks($path,false)))	// false = directory does not need to exists
+		if (!($url = $this->resolve_url_symlinks($path,false)))	// false = directory does not need to exists
 		{
 			return false;
 		}
+		// check if recursive option is set and needed
+		if (($options & STREAM_MKDIR_RECURSIVE) &&
+			($parent_url = Vfs::dirname($url)) &&
+			!($this->url_stat($parent_url, STREAM_URL_STAT_QUIET)) &&
+			Vfs::parse_url($parent_url, PHP_URL_PATH) !== '/')
+		{
+			if (!mkdir($parent_url, $mode, $options)) return false;
+		}
+		// unset it now, as it was handled above
+		$options &= ~STREAM_MKDIR_RECURSIVE;
+
 		$ret = mkdir($url,$mode,$options);
 
 		// call "vfs_mkdir" hook
-		if ($ret && isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
+		if ($ret && !class_exists('setup_process', false))
 		{
 			Api\Hooks::process(array(
 				'location' => 'vfs_mkdir',
-				'path' => $path[0] == '/' ? $path : self::parse_url($path, PHP_URL_PATH),
+				'path' => $path[0] == '/' ? $path : Vfs::parse_url($path, PHP_URL_PATH),
 				'url' => $url,
 			),'',true);
 		}
@@ -611,11 +670,16 @@ class StreamWrapper implements StreamWrapperIface
 	 * @param string $path
 	 * @param int $options Possible values include STREAM_REPORT_ERRORS.
 	 * @return boolean TRUE on success or FALSE on failure.
+	 * @throws Exception\ProtectedDirectory if trying to delete a protected directory, see Vfs::isProtected()
 	 */
-	static function rmdir ( $path, $options )
+	function rmdir ( $path, $options )
 	{
+		if (Vfs::isProtectedDir($path))
+		{
+			throw new Exception\ProtectedDirectory("Deleting protected directory '$path' rejected!");
+		}
 		unset($options);	// not uses but required by function signature
-		if (!($url = self::resolve_url_symlinks($path)))
+		if (!($url = $this->resolve_url_symlinks($path)))
 		{
 			return false;
 		}
@@ -623,17 +687,17 @@ class StreamWrapper implements StreamWrapperIface
 		{
 			return false;
 		}
-		$stat = self::url_stat($path, STREAM_URL_STAT_LINK);
+		$stat = $this->url_stat($path, STREAM_URL_STAT_LINK);
 
 		self::symlinkCache_remove($path);
 		$ok = rmdir($url);
 
 		// call "vfs_rmdir" hook, only after successful rmdir
-		if ($ok && isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
+		if ($ok && !class_exists('setup_process', false))
 		{
 			Api\Hooks::process(array(
 				'location' => 'vfs_rmdir',
-				'path' => $path[0] == '/' ? $path : self::parse_url($path, PHP_URL_PATH),
+				'path' => $path[0] == '/' ? $path : Vfs::parse_url($path, PHP_URL_PATH),
 				'url' => $url,
 				'stat' => $stat,
 			),'',true);
@@ -641,217 +705,6 @@ class StreamWrapper implements StreamWrapperIface
 		return $ok;
 	}
 
-	/**
-	 * Allow to call methods of the underlying stream wrapper: touch, chmod, chgrp, chown, ...
-	 *
-	 * We cant use a magic __call() method, as it does not work for static methods!
-	 *
-	 * @param string $name
-	 * @param array $params first param has to be the path, otherwise we can not determine the correct wrapper
-	 * @param boolean $fail_silent =false should only false be returned if function is not supported by the backend,
-	 * 	or should an E_USER_WARNING error be triggered (default)
-	 * @param int $path_param_key =0 key in params containing the path, default 0
-	 * @return mixed return value of backend or false if function does not exist on backend
-	 */
-	static protected function _call_on_backend($name,$params,$fail_silent=false,$path_param_key=0)
-	{
-		$pathes = $params[$path_param_key];
-
-		$scheme2urls = array();
-		foreach(is_array($pathes) ? $pathes : array($pathes) as $path)
-		{
-			if (!($url = self::resolve_url_symlinks($path,false,false)))
-			{
-				return false;
-			}
-			$k=(string)self::parse_url($url,PHP_URL_SCHEME);
-			if (!(is_array($scheme2urls[$k]))) $scheme2urls[$k] = array();
-			$scheme2urls[$k][$path] = $url;
-		}
-		$ret = array();
-		foreach($scheme2urls as $scheme => $urls)
-		{
-			if ($scheme)
-			{
-				if (!class_exists($class = self::scheme2class($scheme)) || !method_exists($class,$name))
-				{
-					if (!$fail_silent) trigger_error("Can't $name for scheme $scheme!\n",E_USER_WARNING);
-					return false;
-				}
-				if (!is_array($pathes))
-				{
-					$params[$path_param_key] = $url;
-
-					return call_user_func_array(array($class,$name),$params);
-				}
-				$params[$path_param_key] = $urls;
-				if (!is_array($r = call_user_func_array(array($class,$name),$params)))
-				{
-					return $r;
-				}
-				// we need to re-translate the urls to pathes, as they can eg. contain symlinks
-				foreach($urls as $path => $url)
-				{
-					if (isset($r[$url]) || isset($r[$url=self::parse_url($url,PHP_URL_PATH)]))
-					{
-						$ret[$path] = $r[$url];
-					}
-				}
-			}
-			// call the filesystem specific function (dont allow to use arrays!)
-			elseif(!function_exists($name) || is_array($pathes))
-			{
-				return false;
-			}
-			else
-			{
-				$time = null;
-				return $name($url,$time);
-			}
-		}
-		return $ret;
-	}
-
-	/**
-	 * This is not (yet) a stream-wrapper function, but it's necessary and can be used static
-	 *
-	 * @param string $path
-	 * @param int $time =null modification time (unix timestamp), default null = current time
-	 * @param int $atime =null access time (unix timestamp), default null = current time, not implemented in the vfs!
-	 * @return boolean true on success, false otherwise
-	 */
-	static function touch($path,$time=null,$atime=null)
-	{
-		return self::_call_on_backend('touch',array($path,$time,$atime));
-	}
-
-	/**
-	 * This is not (yet) a stream-wrapper function, but it's necessary and can be used static
-	 *
-	 * Requires owner or root rights!
-	 *
-	 * @param string $path
-	 * @param string $mode mode string see Vfs::mode2int
-	 * @return boolean true on success, false otherwise
-	 */
-	static function chmod($path,$mode)
-	{
-		return self::_call_on_backend('chmod',array($path,$mode));
-	}
-
-	/**
-	 * This is not (yet) a stream-wrapper function, but it's necessary and can be used static
-	 *
-	 * Requires root rights!
-	 *
-	 * @param string $path
-	 * @param int $owner numeric user id
-	 * @return boolean true on success, false otherwise
-	 */
-	static function chown($path,$owner)
-	{
-		return self::_call_on_backend('chown',array($path,$owner));
-	}
-
-	/**
-	 * This is not (yet) a stream-wrapper function, but it's necessary and can be used static
-	 *
-	 * Requires owner or root rights!
-	 *
-	 * @param string $path
-	 * @param int $group numeric group id
-	 * @return boolean true on success, false otherwise
-	 */
-	static function chgrp($path,$group)
-	{
-		return self::_call_on_backend('chgrp',array($path,$group));
-	}
-
-	/**
-	 * Returns the target of a symbolic link
-	 *
-	 * This is not (yet) a stream-wrapper function, but it's necessary and can be used static
-	 *
-	 * @param string $path
-	 * @return string|boolean link-data or false if no link
-	 */
-	static function readlink($path)
-	{
-		$ret = self::_call_on_backend('readlink',array($path),true);	// true = fail silent, if backend does not support readlink
-		//error_log(__METHOD__."('$path') returning ".array2string($ret).' '.function_backtrace());
-		return $ret;
-	}
-
-	/**
-	 * Creates a symbolic link
-	 *
-	 * This is not (yet) a stream-wrapper function, but it's necessary and can be used static
-	 *
-	 * @param string $target target of the link
-	 * @param string $link path of the link to create
-	 * @return boolean true on success, false on error
-	 */
-	static function symlink($target,$link)
-	{
-		if (($ret = self::_call_on_backend('symlink',array($target,$link),false,1)))	// 1=path is in $link!
-		{
-			self::symlinkCache_remove($link);
-		}
-		return $ret;
-	}
-
-	/**
-	 * This is not (yet) a stream-wrapper function, but it's necessary and can be used static
-	 *
-	 * The methods use the following ways to get the mime type (in that order)
-	 * - directories (is_dir()) --> self::DIR_MIME_TYPE
-	 * - stream implemented by class defining the STAT_RETURN_MIME_TYPE constant --> use mime-type returned by url_stat
-	 * - for regular filesystem use mime_content_type function if available
-	 * - use eGW's mime-magic class
-	 *
-	 * @param string $path
-	 * @param boolean $recheck =false true = do a new check, false = rely on stored mime type (if existing)
-	 * @return string mime-type (self::DIR_MIME_TYPE for directories)
-	 */
-	static function mime_content_type($path,$recheck=false)
-	{
-		if (!($url = self::resolve_url_symlinks($path)))
-		{
-			return false;
-		}
-		if (($scheme = self::parse_url($url,PHP_URL_SCHEME)) && !$recheck)
-		{
-			// check it it's an eGW stream wrapper returning mime-type via url_stat
-			// we need to first check if the constant is defined, as we get a fatal error in php5.3 otherwise
-			if (class_exists($class = self::scheme2class($scheme)) &&
-				defined($class.'::STAT_RETURN_MIME_TYPE') &&
-				($mime_attr = constant($class.'::STAT_RETURN_MIME_TYPE')))
-			{
-				$stat = call_user_func(array($class,'url_stat'),self::parse_url($url,PHP_URL_PATH),0);
-				if ($stat && $stat[$mime_attr])
-				{
-					$mime = $stat[$mime_attr];
-				}
-			}
-		}
-		if (!$mime && is_dir($url))
-		{
-			$mime = self::DIR_MIME_TYPE;
-		}
-		// if we operate on the regular filesystem and the mime_content_type function is available --> use it
-		if (!$mime && !$scheme && function_exists('mime_content_type'))
-		{
-			$mime = mime_content_type($path);
-		}
-		// using EGw's own mime magic (currently only checking the extension!)
-		if (!$mime)
-		{
-			$mime = Api\MimeMagic::filename2mime(self::parse_url($url,PHP_URL_PATH));
-		}
-		//error_log(__METHOD__."($path,$recheck) mime=$mime");
-		return $mime;
-	}
-
 	/**
 	 * This method is called immediately when your stream object is created for examining directory contents with opendir().
 	 *
@@ -864,7 +717,7 @@ class StreamWrapper implements StreamWrapperIface
 		$this->dir_url_params = array();
 		$this->extra_dir_ptr = 0;
 
-		if (!($this->opened_dir_url = self::resolve_url_symlinks($path)))
+		if (!($this->opened_dir_url = $this->resolve_url_symlinks($path)))
 		{
 			if (self::LOG_LEVEL > 0) error_log(__METHOD__."( $path,$options) resolve_url_symlinks() failed!");
 			return false;
@@ -877,7 +730,7 @@ class StreamWrapper implements StreamWrapperIface
 		}
 		$this->opened_dir_writable = Vfs::check_access($this->opened_dir_url,Vfs::WRITABLE);
 		// check our fstab if we need to add some of the mountpoints
-		$basepath = self::parse_url($path,PHP_URL_PATH);
+		$basepath = Vfs::parse_url($path,PHP_URL_PATH);
 		foreach(array_keys(self::$fstab) as $mounted)
 		{
 			if (((Vfs::dirname($mounted) == $basepath || Vfs::dirname($mounted).'/' == $basepath) && $mounted != '/') &&
@@ -922,7 +775,7 @@ class StreamWrapper implements StreamWrapperIface
 	 * @param boolean $check_symlink_components =true check if path contains symlinks in path components other then the last one
 	 * @return array
 	 */
-	static function url_stat ( $path, $flags, $try_create_home=false, $check_symlink_components=true, $check_symlink_depth=self::MAX_SYMLINK_DEPTH, $try_reconnect=true )
+	function url_stat ( $path, $flags, $try_create_home=false, $check_symlink_components=true, $check_symlink_depth=self::MAX_SYMLINK_DEPTH, $try_reconnect=true )
 	{
 		if (!($url = self::resolve_url($path,!($flags & STREAM_URL_STAT_LINK), $check_symlink_components)))
 		{
@@ -946,17 +799,17 @@ class StreamWrapper implements StreamWrapperIface
 						if (self::LOG_LEVEL > 0) error_log(__METHOD__."('$path',$flags) maximum symlink depth exceeded, might be a circular symlink!");
 						$stat = false;
 					}
-					elseif (($lpath = self::readlink($url)))
+					elseif (($lpath = Vfs::readlink($url)))
 					{
 						if ($lpath[0] != '/')	// concat relative path
 						{
-							$lpath = Vfs::concat(self::parse_url($path,PHP_URL_PATH),'../'.$lpath);
+							$lpath = Vfs::concat(Vfs::parse_url($path,PHP_URL_PATH),'../'.$lpath);
 						}
 						$u_query = parse_url($url,PHP_URL_QUERY);
 						$url = Vfs::PREFIX.$lpath;
 						if (self::LOG_LEVEL > 1) error_log(__METHOD__."($path,$flags) symlif (substr($path,-1) == '/' && $path != '/') $path = substr($path,0,-1);	// remove trailing slash eg. added by WebDAVink found and resolved to $url");
 						// try reading the stat of the link
-						if (($stat = self::url_stat($lpath, STREAM_URL_STAT_QUIET, false, true, $check_symlink_depth-1)))
+						if (($stat = $this->url_stat($lpath, STREAM_URL_STAT_QUIET, false, true, $check_symlink_depth-1)))
 						{
 							$stat_query = parse_url($stat['url'], PHP_URL_QUERY);
 							if($u_query || $stat_query)
@@ -982,13 +835,13 @@ class StreamWrapper implements StreamWrapperIface
 			{
 				// reconnect to db
 				Vfs\Sqlfs\StreamWrapper::reconnect();
-				return self::url_stat($path, $flags, $try_create_home, $check_symlink_components, $check_symlink_depth, false);
+				return $this->url_stat($path, $flags, $try_create_home, $check_symlink_components, $check_symlink_depth, false);
 			}
 			// if numer of tries is exceeded, re-throw exception
 			throw $e;
 		}
 		// check if a failed url_stat was for a home dir, in that case silently create it
-		if (!$stat && $try_create_home && Vfs::dirname(self::parse_url($path,PHP_URL_PATH)) == '/home' &&
+		if (!$stat && $try_create_home && Vfs::dirname(Vfs::parse_url($path,PHP_URL_PATH)) == '/home' &&
 			($id = $GLOBALS['egw']->accounts->name2id(basename($path))) &&
 			$GLOBALS['egw']->accounts->id2name($id) == basename($path))	// make sure path has the right case!
 		{
@@ -1000,7 +853,7 @@ class StreamWrapper implements StreamWrapperIface
 			);
 			call_user_func(array(__NAMESPACE__.'\\Hooks',$hook_data['location']),$hook_data);
 			unset($hook_data);
-			$stat = self::url_stat($path,$flags,false);
+			$stat = $this->url_stat($path,$flags,false);
 		}
 		$query = parse_url($url, PHP_URL_QUERY);
 		if (!$stat && $check_symlink_components)	// check if there's a symlink somewhere inbetween the path
@@ -1043,7 +896,7 @@ class StreamWrapper implements StreamWrapperIface
 	 * @param string &$url=null already resolved path
 	 * @return array|boolean stat array or false if not found
 	 */
-	static private function check_symlink_components($path,$flags=0,&$url=null)
+	private function check_symlink_components($path,$flags=0,&$url=null)
 	{
 		if (is_null($url) && !($url = self::resolve_url($path)))
 		{
@@ -1055,20 +908,20 @@ class StreamWrapper implements StreamWrapperIface
 		while (($rel_path = Vfs::basename($url).($rel_path ? '/'.$rel_path : '')) &&
 		       ($url = Vfs::dirname($url)))
 		{
-			if (($stat = self::url_stat($url,0,false,false)))
+			if (($stat = $this->url_stat($url,0,true,false)))
 			{
-				if (is_link($url) && ($lpath = self::readlink($url)))
+				if (is_link($url) && ($lpath = Vfs::readlink($url)))
 				{
 					if (self::LOG_LEVEL > 1) $log = "rel_path='$rel_path', url='$url': lpath='$lpath'";
 
 					if ($lpath[0] != '/')
 					{
-						$lpath = Vfs::concat(self::parse_url($url,PHP_URL_PATH),'../'.$lpath);
+						$lpath = Vfs::concat(Vfs::parse_url($url,PHP_URL_PATH),'../'.$lpath);
 					}
 					//self::symlinkCache_add($path,Vfs::PREFIX.$lpath);
 					$url = Vfs::PREFIX.Vfs::concat($lpath,$rel_path);
 					if (self::LOG_LEVEL > 1) error_log("$log --> lpath='$lpath', url='$url'");
-					return self::url_stat($url,$flags);
+					return $this->url_stat($url,$flags);
 				}
 				$url = Vfs::concat($url,$rel_path);
 				if (self::LOG_LEVEL > 1) error_log(__METHOD__."('$path',$flags,'$url') returning null");
@@ -1098,7 +951,7 @@ class StreamWrapper implements StreamWrapperIface
 
 		if (isset(self::$symlink_cache[$path])) return;	// nothing to do
 
-		if ($target[0] != '/') $target = self::parse_url($target,PHP_URL_PATH);
+		if ($target[0] != '/') $target = Vfs::parse_url($target,PHP_URL_PATH);
 
 		self::$symlink_cache[$path] = $target;
 
@@ -1115,7 +968,7 @@ class StreamWrapper implements StreamWrapperIface
 	 *
 	 * @param string $_path vfs path
 	 */
-	static protected function symlinkCache_remove($_path)
+	static public function symlinkCache_remove($_path)
 	{
 		$path = self::get_path($_path);
 
@@ -1162,17 +1015,9 @@ class StreamWrapper implements StreamWrapperIface
 	 * Clears our internal stat and symlink cache
 	 *
 	 * Normaly not necessary, as it is automatically cleared/updated, UNLESS Vfs::$user changes!
-	 *
-	 * We have to clear the symlink cache before AND after calling the backend,
-	 * because auf traversal rights may be different when Vfs::$user changes!
-	 *
-	 * @param string $path ='/' path of backend, whos cache to clear
 	 */
-	static function clearstatcache($path='/')
+	static function clearstatcache()
 	{
-		//error_log(__METHOD__."('$path')");
-		self::$symlink_cache = self::$resolve_url_cache = array();
-		self::_call_on_backend('clearstatcache', array($path), true, 0);
 		self::$symlink_cache = self::$resolve_url_cache = array();
 	}
 
@@ -1310,59 +1155,6 @@ class StreamWrapper implements StreamWrapperIface
 		}
 	}
 
-	/**
-	 * Utf-8 save version of parse_url
-	 *
-	 * Does caching withing request, to not have to parse urls over and over again.
-	 *
-	 * @param string $url
-	 * @param int $component =-1 PHP_URL_* constants
-	 * @return array|string|boolean on success array or string, if $component given, or false on failure
-	 */
-	static function parse_url($url, $component=-1)
-	{
-		static $component2str = array(
-			PHP_URL_SCHEME => 'scheme',
-			PHP_URL_HOST => 'host',
-			PHP_URL_PORT => 'port',
-			PHP_URL_USER => 'user',
-			PHP_URL_PASS => 'pass',
-			PHP_URL_PATH => 'path',
-			PHP_URL_QUERY => 'query',
-			PHP_URL_FRAGMENT => 'fragment',
-		);
-		static $cache = array();	// some caching
-
-		$result =& $cache[$url];
-
-		if (!isset($result))
-		{
-			// Build arrays of values we need to decode before parsing
-			static $entities = array('%21', '%2A', '%27', '%28', '%29', '%3B', '%3A', '%40', '%26', '%3D', '%24', '%2C', '%2F', '%3F', '%23', '%5B', '%5D');
-			static $replacements = array('!', '*', "'", "(", ")", ";", ":", "@", "&", "=", "$", ",", "/", "?", "#", "[", "]");
-			static $str_replace = null;
-			if (!isset($str_replace)) $str_replace = function_exists('mb_str_replace') ? 'mb_str_replace' : 'str_replace';
-
-			// Create encoded URL with special URL characters decoded so it can be parsed
-			// All other characters will be encoded
-			$encodedURL = $str_replace($entities, $replacements, urlencode($url));
-
-			// Parse the encoded URL
-			$result = $encodedParts = parse_url($encodedURL);
-
-			// Now, decode each value of the resulting array
-			if ($encodedParts)
-			{
-				$result = array();
-				foreach ($encodedParts as $key => $value)
-				{
-					$result[$key] = urldecode($str_replace($replacements, $entities, $value));
-				}
-			}
-		}
-		return $component >= 0 ? $result[$component2str[$component]] : $result;
-	}
-
 	/**
 	 * Getting the path from an url (or path) AND removing trailing slashes
 	 *
@@ -1372,14 +1164,14 @@ class StreamWrapper implements StreamWrapperIface
 	 */
 	static protected function get_path($path,$only_remove_scheme=self::SCHEME)
 	{
-		if ($path[0] != '/' && (!$only_remove_scheme || self::parse_url($path, PHP_URL_SCHEME) == $only_remove_scheme))
+		if ($path[0] != '/' && (!$only_remove_scheme || Vfs::parse_url($path, PHP_URL_SCHEME) == $only_remove_scheme))
 		{
-			$path = self::parse_url($path, PHP_URL_PATH);
+			$path = Vfs::parse_url($path, PHP_URL_PATH);
 		}
 		// remove trailing slashes eg. added by WebDAV, but do NOT remove / from "sqlfs://default/"!
 		if ($path != '/')
 		{
-			while (mb_substr($path, -1) == '/' && $path != '/' && ($path[0] == '/' || self::parse_url($path, PHP_URL_PATH) != '/'))
+			while (mb_substr($path, -1) == '/' && $path != '/' && ($path[0] == '/' || Vfs::parse_url($path, PHP_URL_PATH) != '/'))
 			{
 				$path = mb_substr($path,0,-1);
 			}
@@ -1405,6 +1197,116 @@ class StreamWrapper implements StreamWrapperIface
 		return $ret;
 	}
 
+	/**
+	 * Mounts $url under $path in the vfs, called without parameter it returns the fstab
+	 *
+	 * The fstab is stored in the eGW configuration and used for all eGW users.
+	 *
+	 * @param string $url =null url of the filesystem to mount, eg. oldvfs://default/
+	 * @param string $path =null path to mount the filesystem in the vfs, eg. /
+	 * @param boolean $check_url =null check if url is an existing directory, before mounting it
+	 * 	default null only checks if url does not contain a $ as used in $user or $pass
+	 * @param boolean $persitent_mount =true create a persitent mount, or only a temprary for current request
+	 * @param boolean $clear_fstab =false true clear current fstab, false (default) only add given mount
+	 * @return array|boolean array with fstab, if called without parameter or true on successful mount
+	 */
+	static function mount($url=null,$path=null,$check_url=null,$persitent_mount=true,$clear_fstab=false)
+	{
+		if (is_null($check_url)) $check_url = strpos($url,'$') === false;
+
+		if (!isset($GLOBALS['egw_info']['server']['vfs_fstab']))	// happens eg. in setup
+		{
+			$api_config = Api\Config::read('phpgwapi');
+			if (isset($api_config['vfs_fstab']) && is_array($api_config['vfs_fstab']))
+			{
+				self::$fstab = $api_config['vfs_fstab'];
+			}
+			else
+			{
+				self::$fstab = array(
+					'/' => 'sqlfs://$host/',
+					'/apps' => 'links://$host/apps',
+				);
+			}
+			unset($api_config);
+		}
+		if (is_null($url) || is_null($path))
+		{
+			if (self::LOG_LEVEL > 1) error_log(__METHOD__.'('.array2string($url).','.array2string($path).') returns '.array2string(self::$fstab));
+			return self::$fstab;
+		}
+		if (!Vfs::$is_root)
+		{
+			if (self::LOG_LEVEL > 0) error_log(__METHOD__.'('.array2string($url).','.array2string($path).') permission denied, you are NOT root!');
+			return false;	// only root can mount
+		}
+		if ($clear_fstab)
+		{
+			self::$fstab = array();
+		}
+		if (isset(self::$fstab[$path]) && self::$fstab[$path] === $url)
+		{
+			if (self::LOG_LEVEL > 0) error_log(__METHOD__.'('.array2string($url).','.array2string($path).') already mounted.');
+			return true;	// already mounted
+		}
+		self::load_wrapper(Vfs::parse_url($url,PHP_URL_SCHEME));
+
+		if ($check_url && (!file_exists($url) || opendir($url) === false))
+		{
+			if (self::LOG_LEVEL > 0) error_log(__METHOD__.'('.array2string($url).','.array2string($path).') url does NOT exist!');
+			return false;	// url does not exist
+		}
+		self::$fstab[$path] = $url;
+
+		uksort(self::$fstab, function($a, $b)
+		{
+			return strlen($a) - strlen($b);
+		});
+
+		if ($persitent_mount)
+		{
+			Api\Config::save_value('vfs_fstab',self::$fstab,'phpgwapi');
+			$GLOBALS['egw_info']['server']['vfs_fstab'] = self::$fstab;
+			// invalidate session cache
+			if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
+			{
+				$GLOBALS['egw']->invalidate_session_cache();
+			}
+		}
+		if (self::LOG_LEVEL > 1) error_log(__METHOD__.'('.array2string($url).','.array2string($path).') returns true (successful new mount).');
+		return true;
+	}
+
+	/**
+	 * Unmounts a filesystem part of the vfs
+	 *
+	 * @param string $path url or path of the filesystem to unmount
+	 */
+	static function umount($path)
+	{
+		if (!Vfs::$is_root)
+		{
+			if (self::LOG_LEVEL > 0) error_log(__METHOD__.'('.array2string($path).','.array2string($path).') permission denied, you are NOT root!');
+			return false;	// only root can mount
+		}
+		if (!isset(self::$fstab[$path]) && ($path = array_search($path,self::$fstab)) === false)
+		{
+			if (self::LOG_LEVEL > 0) error_log(__METHOD__.'('.array2string($path).') NOT mounted!');
+			return false;	// $path not mounted
+		}
+		unset(self::$fstab[$path]);
+
+		Api\Config::save_value('vfs_fstab',self::$fstab,'phpgwapi');
+		$GLOBALS['egw_info']['server']['vfs_fstab'] = self::$fstab;
+		// invalidate session cache
+		if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
+		{
+			$GLOBALS['egw']->invalidate_session_cache();
+		}
+		if (self::LOG_LEVEL > 1) error_log(__METHOD__.'('.array2string($path).') returns true (successful unmount).');
+		return true;
+	}
+
 	/**
 	 * Init our static properties and register this wrapper
 	 *
