@@ -23,6 +23,7 @@ use EGroupware\Api\Vfs;
 	/* $Id$ */
 
 	require_once('class.ico.inc.php');
+
 	class bookmarks_bo extends Api\Storage\Tracking
 	{
 		var $so;
@@ -61,7 +62,7 @@ use EGroupware\Api\Vfs;
 			'custom'	=>	'custom fields',
 		);
 
-		function bookmarks_bo()
+		function __construct()
 		{
 			$this->so = new bookmarks_so();
 			$this->grants      = $GLOBALS['egw']->acl->get_grants('bookmarks');
@@ -105,10 +106,10 @@ use EGroupware\Api\Vfs;
 			$count = $this->so->get_rows($query, $rows, $readonlys);
 
 			// Add in permissions
-			foreach($rows as $key => &$row) {
+			foreach($rows as &$row) {
 				$favicon = Link::vfs_path('bookmarks', $row['id'], 'favicon.png', true);
 
-				if(@egw_vfs::stat($favicon))
+				if(@Vfs::stat($favicon))
 				{
 					$row['favicon'] = Egw::link(Vfs::download_url($favicon));
 				}
