@@ -180,10 +180,7 @@ class calendar_bo
 	protected static $cached_event = array();
 	protected static $cached_event_date_format = false;
 	protected static $cached_event_date = 0;
-	/**
-	 * @var array $cached_holidays holidays plus birthdays (gets cached in the session for performance reasons)
-	 */
-	var $cached_holidays;
+	
 	/**
 	 * Instance of the socal class
 	 *
@@ -196,6 +193,12 @@ class calendar_bo
 	 * @var Api\Categories
 	 */
 	var $categories;
+	/**
+	 * Config values for "calendar", only used for horizont, regular calendar config is under phpgwapi
+	 *
+	 * @var array
+	 */
+	var $config;
 
 	/**
 	 * Does a user require an extra invite grant, to be able to invite an other user, default no
@@ -245,15 +248,25 @@ class calendar_bo
 				'info' => __CLASS__.'::email_info',
 				'app'  => 'email',
 			);
+			$this->resources['l'] = array(
+				'type' => 'l',// one char type-identifier for this resources
+				'info' => __CLASS__ .'::mailing_lists',// info method, returns array with id, type & name for a given id
+				'app' => 'Distribution list'
+			);
 			$this->resources[''] = array(
 				'type' => '',
 				'app' => 'api-accounts',
 			);
+			$this->resources['l'] = array(
+				'type' => 'l',// one char type-identifier for this resources
+				'info' => __CLASS__ .'::mailing_lists',// info method, returns array with id, type & name for a given id
+				'app' => 'Distribution list'
+			);
 			Api\Cache::setSession('calendar', 'resources', $this->resources);
 		}
 		//error_log(__METHOD__ . " registered resources=". array2string($this->resources));
 
-		$this->config = Api\Config::read('calendar');	// only used for horizont, regular calendar Api\Config is under phpgwapi
+		$this->config = Api\Config::read('calendar');	// only used for horizont, regular calendar config is under phpgwapi
 		$this->require_acl_invite = $GLOBALS['egw_info']['server']['require_acl_invite'];
 
 		$this->categories = new Api\Categories($this->user,'calendar');
@@ -321,6 +334,85 @@ class calendar_bo
 		return $data;
 	}
 
+	/**
+	 * returns info about mailing lists as participants
+	 *
+	 * @param int|array $ids single mailing list ID or array of id's
+	 * @return array
+	 */
+	static function mailing_lists($ids)
+	{
+		if(!is_array($ids))
+		{
+			$ids = array($ids);
+		}
+		$data = array();
+
+		// Email list
+		$contacts_obj = new Api\Contacts();
+		$bo = new calendar_bo();
+		foreach($ids as $id)
+		{
+			$list = $contacts_obj->read_list((int)$id);
+
+			$data[] = array(
+				'res_id' => $id,
+				'rights' => self::ACL_READ_FOR_PARTICIPANTS,
+				'name' => $list['list_name'],
+				'resources' => $bo->enum_mailing_list('l'.$id, false, false)
+			);
+		}
+
+		return $data;
+	}
+
+	/**
+	 * Enumerates the contacts in a contact list, and returns the list of contact IDs
+	 *
+	 * This is used to enable mailing lists as owner/participant
+	 *
+	 * @param string $id Mailing list participant ID, which is the mailing list
+	 *	ID prefixed with 'l'
+	 * @param boolean $ignore_acl = false Flag to skip ACL checks
+	 * @param boolean $use_freebusy =true should freebusy rights are taken into account, default true, can be set to false eg. for a search
+	 *
+	 * @return array
+	 */
+	public function enum_mailing_list($id, $ignore_acl= false, $use_freebusy = true)
+	{
+		$contact_list = array();
+		$contacts = new Api\Contacts();
+		if($contacts->check_list((int)substr($id,1), ACL::READ))
+		{
+			$options = array('list' => substr($id,1));
+			$lists = $contacts->search('',true,'','','',false,'AND',false,$options);
+			if(!$lists)
+			{
+				return $contact_list;
+			}
+			foreach($lists as &$contact)
+			{
+				// Check for user account
+				if (($account_id = $GLOBALS['egw']->accounts->name2id($contact['id'],'person_id')))
+				{
+					$contact = ''.$account_id;
+				}
+				else
+				{
+					$contact = 'c'.$contact['id'];
+				}
+				if ($ignore_acl || $this->check_perms(ACL::READ|self::ACL_READ_FOR_PARTICIPANTS|($use_freebusy?self::ACL_FREEBUSY:0),0,$contact))
+				{
+					if ($contact && !in_array($contact,$contact_list))	// already added?
+					{
+						$contact_list[] = $contact;
+					}
+				}
+			}
+		}
+		return $contact_list;
+	}
+
 	/**
 	 * Add group-members as participants with status 'G'
 	 *
@@ -368,10 +460,39 @@ class calendar_bo
 		foreach($_users as $user)
 		{
 			$user = trim($user);
+			
+			// Handle email lists
+			if(!is_numeric($user) && $user[0] == 'l')
+			{
+				foreach($this->enum_mailing_list($user, $ignore_acl, $use_freebusy) as $contact)
+				{
+					if ($contact && !in_array($contact,$users))	// already added?
+					{
+						$users[] = $contact;
+					}
+				}
+				continue;
+			}
 			if ($ignore_acl || $this->check_perms(ACL::READ|self::ACL_READ_FOR_PARTICIPANTS|($use_freebusy?self::ACL_FREEBUSY:0),0,$user))
 			{
 				if ($user && !in_array($user,$users))	// already added?
 				{
+					// General expansion check
+					if (!is_numeric($user) && $this->resources[$user[0]]['info'])
+					{
+						$info = $this->resource_info($user);
+						if($info && $info['resources'])
+						{
+							foreach($info['resources'] as $_user)
+							{
+								if($_user && !in_array($_user, $users))
+								{
+									$users[] = $_user;
+								}
+							}
+							continue;
+						}
+					}
 					$users[] = $user;
 				}
 			}
@@ -491,7 +612,7 @@ class calendar_bo
 		}
 		// if we have no grants from the given user(s), we directly return no events / an empty array,
 		// as calling the so-layer without users would give the events of all users (!)
-		if (!count($users))
+		if (!count($users) && !$params['ignore_acl'])
 		{
 			return false;
 		}
@@ -546,7 +667,7 @@ class calendar_bo
 			{
 				$is_private = !$this->check_perms(Acl::READ,$event);
 			}
-			if ($is_private || (!$event['public'] && $filter == 'hideprivate'))
+			if (!$params['ignore_acl'] && ($is_private || (!$event['public'] && $filter == 'hideprivate')))
 			{
 				$this->clear_private_infos($events[$id],$users);
 			}
@@ -794,6 +915,9 @@ class calendar_bo
 			$start = $this->date2ts($event['start'],true);
 			if ($event['whole_day'])
 			{
+				$start = new Api\DateTime($event['start'], Api\DateTime::$server_timezone);
+				$start->setTime(0,0,0);
+				$start = $start->format('ts');
 				$time = $this->so->startOfDay(new Api\DateTime($event['end'], Api\DateTime::$user_timezone));
 				$time->setTime(23, 59, 59);
 				$end = $this->date2ts($time,true);
@@ -851,11 +975,11 @@ class calendar_bo
 					$time->setTime(23, 59, 59);
 					$event['recur_enddate'] = Api\DateTime::to($time, $date_format);
 				}
-				$timestamps = array('modified','created');
+				$timestamps = array('modified','created','deleted');
 			}
 			else
 			{
-				$timestamps = array('start','end','modified','created','recur_enddate','recurrence','recur_date');
+				$timestamps = array('start','end','modified','created','recur_enddate','recurrence','recur_date','deleted');
 			}
 			// we convert here from the server-time timestamps to user-time and (optional) to a different date-format!
 			foreach ($timestamps as $ts)
@@ -1000,13 +1124,22 @@ class calendar_bo
 			// insert at least the event itself, if it's behind the horizont
 			$event['recur_enddate'] = $this->date2ts($end) < $this->date2ts($event['end']) ? $event['end'] : $end;
 		}
+		$event['recur_enddate'] = is_a($event['recur_enddate'],'DateTime') ?
+				$event['recur_enddate'] :
+				new Api\DateTime($event['recur_enddate'], calendar_timezones::DateTimeZone($event['tzid']));
 		// unset exceptions, as we need to add them as recurrence too, but marked as exception
 		unset($event['recur_exception']);
 		// loop over all recurrences and insert them, if they are after $start
-		$rrule = calendar_rrule::event2rrule($event, true);	// true = we operate in usertime, like the rest of calendar_bo
+ 		$rrule = calendar_rrule::event2rrule($event, !$event['whole_day'], Api\DateTime::$user_timezone->getName());	// true = we operate in usertime, like the rest of calendar_bo
 		foreach($rrule as $time)
 		{
 			$time->setUser();	// $time is in timezone of event, convert it to usertime used here
+			if($event['whole_day'])
+			{
+				// All day events are processed in server timezone
+				$time->setServer();
+				$time->setTime(0,0,0);
+			}
 			if (($ts = $this->date2ts($time)) < $start-$event_length)
 			{
 				//echo "<p>".$time." --> ignored as $ts < $start-$event_length</p>\n";
@@ -1343,6 +1476,7 @@ class calendar_bo
 							$param = "'$param'";
 						}
 						break;
+					case 'EGroupware\\Api\\DateTime':
 					case 'egw_time':
 					case 'datetime':
 						$p = $param;
@@ -1363,6 +1497,7 @@ class calendar_bo
 			}
 			$msg = str_replace('%'.($i-1),$param,$msg);
 		}
+		error_log($msg);
 		if ($backtrace) error_log(function_backtrace(1));
 	}
 
@@ -1750,67 +1885,26 @@ class calendar_bo
 	{
 		if (!$year) $year = (int) date('Y',$this->now_su);
 
-		if (!$this->cached_holidays)	// try reading the holidays from the session
-		{
-			$this->cached_holidays = Api\Cache::getSession('calendar', 'holidays');
-		}
-		if (!isset($this->cached_holidays[$year]))
-		{
-			$this->cached_holidays[$year] = calendar_holidays::read(
+		$holidays = calendar_holidays::read(
 				!empty($GLOBALS['egw_info']['server']['ical_holiday_url']) ?
 				$GLOBALS['egw_info']['server']['ical_holiday_url'] :
 				$GLOBALS['egw_info']['user']['preferences']['common']['country'], $year);
 
-			// search for birthdays
-			if ($GLOBALS['egw_info']['server']['hide_birthdays'] != 'yes')
+		// search for birthdays
+		if ($GLOBALS['egw_info']['server']['hide_birthdays'] != 'yes')
+		{
+			$contacts = new Api\Contacts();
+			foreach($contacts->get_addressbooks() as $owner => $name)
 			{
-				$contacts = new Api\Contacts();
-				$filter = array(
-					'n_family' => "!''",
-					'bday' => "!''",
-				);
-				$bdays =& $contacts->search('',array('id','n_family','n_given','n_prefix','n_middle','bday'),
-					'contact_bday ASC',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter);
-				// search accounts too, if not stored in contacts repository
-				$extra_accounts_search = $contacts->account_repository == 'ldap' && !is_null($contacts->so_accounts) &&
-					!$GLOBALS['egw_info']['user']['preferences']['addressbook']['hide_accounts'];
-				if ($extra_accounts_search && ($bdays2 =& $contacts->search('',array('id','n_family','n_given','n_prefix','n_middle','bday'),
-					'contact_bday ASC',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter+array('owner' => 0))))
-				{
-					$bdays = !$bdays ? $bdays2 : array_merge($bdays,$bdays2);
-				}
-				if ($bdays)
-				{
-					// sort by month and day only
-					usort($bdays,create_function('$a,$b','return (int) $a[\'bday\'] == (int) $b[\'bday\'] ? strcmp($a[\'bday\'],$b[\'bday\']) : (int) $a[\'bday\'] - (int) $b[\'bday\'];'));
-					foreach($bdays as $pers)
-					{
-						if (empty($pers['bday']) || $pers['bday']=='0000-00-00 0' || $pers['bday']=='0000-00-00' || $pers['bday']=='0.0.00')
-						{
-							//error_log(__METHOD__.__LINE__.' Skipping entry for invalid birthday:'.array2string($pers));
-							continue;
-						}
-						list($y,$m,$d) = explode('-',$pers['bday']);
-						if ($y > $year) continue; 	// not yet born
-						$this->cached_holidays[$year][sprintf('%04d%02d%02d',$year,$m,$d)][] = array(
-							'day'       => $d,
-							'month'     => $m,
-							'occurence' => 0,
-							'name'      => lang('Birthday').' '.($pers['n_given'] ? $pers['n_given'] : $pers['n_prefix']).' '.$pers['n_middle'].' '.
-								$pers['n_family'].($y && !$GLOBALS['egw_info']['server']['hide_birthdays'] ? ' ('.$y.')' : ''),
-							'birthyear' => $y,	// this can be used to identify birthdays from holidays
-						);
-					}
-				}
+				$holidays += $contacts->read_birthdays($owner, $year);
 			}
-			// store holidays and birthdays in the session
-			Api\Cache::setSession('calendar', 'holidays', $this->cached_holidays);
 		}
+
 		if ((int) $this->debug >= 2 || $this->debug == 'read_holidays')
 		{
-			$this->debug_message('calendar_bo::read_holidays(%1)=%2',true,$year,$this->cached_holidays[$year]);
+			$this->debug_message('calendar_bo::read_holidays(%1)=%2',true,$year,$holidays);
 		}
-		return $this->cached_holidays[$year];
+		return $holidays;
 	}
 
 	/**
