@@ -230,35 +230,143 @@ class calendar_boupdate extends calendar_bo
 			}
 		}
 		// check for conflicts only happens !$ignore_conflicts AND if start + end date are given
-		if (!$ignore_conflicts && !$event['non_blocking'] && isset($event['start']) && isset($event['end']))
+		$checked_excluding = null;
+		if (!$ignore_conflicts && !$event['non_blocking'] && isset($event['start']) && isset($event['end']) &&
+			(($conflicts = $this->conflicts($event, $checked_excluding)) || $checked_excluding))
 		{
-			$types_with_quantity = array();
-			foreach($this->resources as $type => $data)
+			if ($checked_excluding)	// warn user if not all recurrences have been checked
 			{
-				if ($data['max_quantity']) $types_with_quantity[] = $type;
+				$conflicts['warning'] = array(
+					'start' => $checked_excluding,
+					'title' => lang('Only recurrences until %1 (excluding) have been checked!', $checked_excluding->format(true)),
+				);
 			}
-			// get all NOT rejected participants and evtl. their quantity
-			$quantity = $users = array();
-			foreach($event['participants'] as $uid => $status)
-			{
-				calendar_so::split_status($status,$q,$r);
-				if ($status[0] == 'R') continue;	// ignore rejected participants
+			return $conflicts;
+		}
 
-				if ($uid < 0)	// group, check it's members too
+		//echo "saving $event[id]="; _debug_array($event);
+		$event2save = $event;
+
+		if (!($cal_id = $this->save($event, $ignore_acl)))
+		{
+			return $cal_id;
+		}
+
+		// we re-read the event, in case only partial information was update and we need the full info for the notifies
+		// The check for new private events is to at least show the private version,
+		// otherwise we get FALSE
+		$event = $this->read($cal_id, null, $ignore_acl, 'ts', $new_event && !$event['public'] ? $this->user : null);
+		//error_log("new $cal_id=". array2string($event));
+
+		if($old_event['deleted'] && $event['deleted'] == null)
+		{
+			// Restored, bring back links
+			Link::restore('calendar', $cal_id);
+		}
+		if ($this->log_file)
+		{
+			$this->log2file($event2save,$event,$old_event);
+		}
+		// send notifications
+		if(!$skip_notification)
+		{
+			if ($new_event)
+			{
+				$this->send_update(MSG_ADDED,$event['participants'],'',$event);
+			}
+			else // update existing event
+			{
+				$this->check4update($event,$old_event);
+			}
+		}
+
+		// notify the link-class about the update, as other apps may be subscribt to it
+		Link::notify_update('calendar',$cal_id,$event);
+
+		return $cal_id;
+	}
+
+	/**
+	 * Check given event for conflicts and return them
+	 *
+	 * For recurring events we check a configurable fixed number of recurrences
+	 * and for a fixed maximum time (default 3s).
+	 *
+	 * Conflict check skips past events/recurrences and is always limited by recurrence horizont,
+	 * as it would only report non-recurring events after.
+	 *
+	 * @param array $event
+	 * @param Api\DateTime& $checked_excluding =null time until which (excluding) recurrences have been checked
+	 * @return array or events
+	 */
+	function conflicts(array $event, &$checked_excluding=null)
+	{
+		$types_with_quantity = array();
+		foreach($this->resources as $type => $data)
+		{
+			if ($data['max_quantity']) $types_with_quantity[] = $type;
+		}
+		// get all NOT rejected participants and evtl. their quantity
+		$quantity = $users = array();
+		foreach($event['participants'] as $uid => $status)
+		{
+			$q = $r = null;
+			calendar_so::split_status($status,$q,$r);
+			if ($status[0] == 'R') continue;	// ignore rejected participants
+
+			if ($uid < 0)	// group, check it's members too
+			{
+				$users = array_unique(array_merge($users, (array)$GLOBALS['egw']->accounts->members($uid,true)));
+			}
+			$users[] = $uid;
+			if (in_array($uid[0],$types_with_quantity))
+			{
+				$quantity[$uid] = $q;
+			}
+		}
+		$max_quantity = $possible_quantity_conflicts = $conflicts = array();
+
+		if ($event['recur_type'])
+		{
+			$recurences = calendar_rrule::event2rrule($event);
+		}
+		else
+		{
+			$recurences = array(new Api\DateTime((int)$event['start']));
+		}
+		$checked_excluding = null;
+		$max_checked = $GLOBALS['egw_info']['server']['conflict_max_checked'];
+		if (($max_check_time = (float)$GLOBALS['egw_info']['server']['conflict_max_check_time']) < 1.0)
+		{
+			$max_check_time = 3.0;
+		}
+		$checked = 0;
+		$start = microtime(true);
+		$duration = $event['end']-$event['start'];
+		foreach($recurences as $date)
+		{
+			$startts = $date->format('ts');
+
+			// skip past events or recurrences
+			if ($startts+$duration < $this->now_su) continue;
+
+			// abort check if configured limits are exceeded
+			if ($event['recur_type'] &&
+				(++$checked > $max_checked && $max_checked > 0 || // maximum number of checked recurrences exceeded
+				microtime(true) > $start+$max_check_time ||	// max check time exceeded
+				$startts > $this->config['horizont']))	// we are behind horizon for which recurrences are rendered
+			{
+				if ($this->debug > 2 || $this->debug == 'conflicts')
 				{
-					$users += (array)$GLOBALS['egw']->accounts->members($uid,true);
-					$users = array_unique($users);
+					$this->debug_message(__METHOD__.'() conflict check limited to %1 recurrences, %2 seconds, until (excluding) %3',
+						$checked, microtime(true)-$start, $date);
 				}
-				$users[] = $uid;
-				if (in_array($uid[0],$types_with_quantity))
-				{
-					$quantity[$uid] = $q;
-				}
+				$checked_excluding = $date;
+				break;
 			}
-			//$start = microtime(true);
 			$overlapping_events =& $this->search(array(
-				'start' => $event['start'],
-				'end'   => $event['end'],
+				'start' => $startts,
+				'end'   => $startts+$duration,
 				'users' => $users,
 				'ignore_acl' => true,	// otherwise we get only events readable by the user
 				'enum_groups' => true,	// otherwise group-events would not block time
@@ -267,12 +375,10 @@ class calendar_boupdate extends calendar_bo
 				),
 				'no_integration' => true,	// do NOT use integration of other apps
 			));
-			//error_log(__METHOD__."() conflict check took ".number_format(microtime(true)-$start, 3).'s');
-			if ($this->debug > 2 || $this->debug == 'update')
+			if ($this->debug > 2 || $this->debug == 'conflicts')
 			{
-				$this->debug_message('calendar_boupdate::update() checking for potential overlapping events for users %1 from %2 to %3',false,$users,$event['start'],$event['end']);
+				$this->debug_message(__METHOD__.'() checking for potential overlapping events for users %1 from %2 to %3',false,$users,$startts,$startts+$duration);
 			}
-			$max_quantity = $possible_quantity_conflicts = $conflicts = array();
 			foreach((array) $overlapping_events as $k => $overlap)
 			{
 				if ($overlap['id'] == $event['id'] ||	// that's the event itself
@@ -281,9 +387,9 @@ class calendar_boupdate extends calendar_bo
 				{
 					continue;
 				}
-				if ($this->debug > 3 || $this->debug == 'update')
+				if ($this->debug > 3 || $this->debug == 'conflicts')
 				{
-					$this->debug_message('calendar_boupdate::update() checking overlapping event %1',false,$overlap);
+					$this->debug_message(__METHOD__.'() checking overlapping event %1',false,$overlap);
 				}
 				// check if the overlap is with a rejected participant or within the allowed quantity
 				$common_parts = array_intersect($users,array_keys($overlap['participants']));
@@ -316,90 +422,52 @@ class calendar_boupdate extends calendar_bo
 				}
 				if (count($common_parts))
 				{
-					if ($this->debug > 3 || $this->debug == 'update')
+					if ($this->debug > 3 || $this->debug == 'conflicts')
 					{
-						$this->debug_message('calendar_boupdate::update() conflicts with the following participants found %1',false,$common_parts);
+						$this->debug_message(__METHOD__.'() conflicts with the following participants found %1',false,$common_parts);
 					}
 					$conflicts[$overlap['id'].'-'.$this->date2ts($overlap['start'])] =& $overlapping_events[$k];
 				}
 			}
-			// check if we are withing the allowed quantity and if not add all events using that resource
-			// seems this function is doing very strange things, it gives empty conflicts
-			foreach($max_quantity as $uid => $max)
+		}
+		//error_log(__METHOD__."() conflict check took ".number_format(microtime(true)-$start, 3).'s');
+		// check if we are withing the allowed quantity and if not add all events using that resource
+		// seems this function is doing very strange things, it gives empty conflicts
+		foreach($max_quantity as $uid => $max)
+		{
+			if ($quantity[$uid] > $max)
 			{
-				if ($quantity[$uid] > $max)
+				foreach((array)$possible_quantity_conflicts[$uid] as $conflict)
 				{
-					foreach((array)$possible_quantity_conflicts[$uid] as $conflict)
-					{
-						$conflicts[$conflict['id'].'-'.$this->date2ts($conflict['start'])] =& $possible_quantity_conflicts[$k];
-					}
+					$conflicts[$conflict['id'].'-'.$this->date2ts($conflict['start'])] =& $possible_quantity_conflicts[$k];
 				}
 			}
-			unset($possible_quantity_conflicts);
+		}
+		unset($possible_quantity_conflicts);
 
-			if (count($conflicts))
+		if (count($conflicts))
+		{
+			foreach($conflicts as $key => $conflict)
 			{
-				foreach($conflicts as $key => $conflict)
+					$conflict['participants'] = array_intersect_key((array)$conflict['participants'],$event['participants']);
+				if (!$this->check_perms(Acl::READ,$conflict))
 				{
-						$conflict['participants'] = array_intersect_key((array)$conflict['participants'],$event['participants']);
-					if (!$this->check_perms(Acl::READ,$conflict))
-					{
-						$conflicts[$key] = array(
-							'id'    => $conflict['id'],
-							'title' => lang('busy'),
-							'participants' => $conflict['participants'],
-							'start' => $conflict['start'],
-							'end'   => $conflict['end'],
-						);
-					}
+					$conflicts[$key] = array(
+						'id'    => $conflict['id'],
+						'title' => lang('busy'),
+						'participants' => $conflict['participants'],
+						'start' => $conflict['start'],
+						'end'   => $conflict['end'],
+					);
 				}
-				if ($this->debug > 2 || $this->debug == 'update')
-				{
-					$this->debug_message('calendar_boupdate::update() %1 conflicts found %2',false,count($conflicts),$conflicts);
-				}
-				return $conflicts;
 			}
-		}
-
-		//echo "saving $event[id]="; _debug_array($event);
-		$event2save = $event;
-
-		if (!($cal_id = $this->save($event, $ignore_acl, $updateTS)))
-		{
-			return $cal_id;
-		}
-
-		$event = $this->read($cal_id);	// we re-read the event, in case only partial information was update and we need the full info for the notifies
-		//echo "new $cal_id="; _debug_array($event);
-
-		if($old_event['deleted'] && $event['deleted'] == null)
-		{
-			// Restored, bring back links
-			Link::restore('calendar', $cal_id);
-		}
-		if ($this->log_file)
-		{
-			$this->log2file($event2save,$event,$old_event);
-		}
-		// send notifications
-		if(!$skip_notification)
-		{
-			if ($new_event)
+			if ($this->debug > 2 || $this->debug == 'conflicts')
 			{
-				$this->send_update(MSG_ADDED,$event['participants'],'',$event);
-			}
-			else // update existing event
-			{
-				$this->check4update($event,$old_event);
+				$this->debug_message(__METHOD__.'() %1 conflicts found %2',false,count($conflicts),$conflicts);
 			}
 		}
-
-		// notify the link-class about the update, as other apps may be subscribt to it
-		Link::notify_update('calendar',$cal_id,$event);
-
-		return $cal_id;
+		return $conflicts;
 	}
-
 	/**
 	 * Remove participants current user has no right to invite
 	 *
@@ -837,6 +905,8 @@ class calendar_boupdate extends calendar_bo
 					$preferences = new Api\Preferences($userid);
 					$GLOBALS['egw_info']['user']['preferences'] = $part_prefs = $preferences->read_repository();
 					$fullname = Api\Accounts::username($userid);
+					$tfn = Api\Accounts::id2name($userid,'account_firstname');
+					$tln = Api\Accounts::id2name($userid,'account_lastname');
 				}
 				else	// external email address: use Api\Preferences of event-owner, plus some hardcoded settings (eg. ical notification)
 				{
@@ -864,12 +934,16 @@ class calendar_boupdate extends calendar_bo
 					Api\Translation::init();
 					$lang = $part_prefs['common']['lang'];
 				}
+
+				// Since we're running from cron, make sure notifications uses user's theme (for images)
+				$GLOBALS['egw_info']['server']['template_set'] = $GLOBALS['egw_info']['user']['preferences']['common']['template_set'];
+
 				$event_arr = null;
 				$details = $this->_get_event_details(isset($cleared_event) ? $cleared_event : $event,
 					$action, $event_arr, $disinvited);
 				$details['to-fullname'] = $fullname;
-				if (isset($tfn)) $details['to-firstname'] = $tfn;
-				if (isset($tln)) $details['to-lastname'] = $tln;
+				$details['to-firstname'] = isset($tfn)? $tfn: '';
+				$details['to-lastname'] = isset($tln)? $tln: '';
 
 				// event is in user-time of current user, now we need to calculate the tz-difference to the notified user and take it into account
 				if (!isset($part_prefs['common']['tz'])) $part_prefs['common']['tz'] = $GLOBALS['egw_info']['server']['server_timezone'];
@@ -976,6 +1050,10 @@ class calendar_boupdate extends calendar_bo
 
 						if(is_array($attachment)) { $notification->set_attachments(array($attachment)); }
 						$notification->send();
+						foreach(notifications::errors(true) as $error)
+						{
+							error_log(__METHOD__."() Error notifying $userid from $senderid: $subject: $error");
+						}
 					}
 					catch (Exception $exception) {
 						error_log(__METHOD__.' error while notifying user '.$userid.':'.$exception->getMessage());
@@ -1075,12 +1153,11 @@ class calendar_boupdate extends calendar_bo
 	 * @param array $event
 	 * @param boolean $ignore_acl =false should we ignore the acl
 	 * @param boolean $updateTS =true update the content history of the event
-	 * DEPRECATED: we allways (have to) update timestamp, as they are required for sync!
+	 * Please note: you should ALLWAYS update timestamps, as they are required for sync!
 	 * @return int|boolean $cal_id > 0 or false on error (eg. permission denied)
 	 */
 	function save($event,$ignore_acl=false,$updateTS=true)
 	{
-		unset($updateTS);
 		//error_log(__METHOD__.'('.array2string($event).", $ignore_acl, $updateTS)");
 
 		// check if user has the permission to update / create the event
@@ -1101,8 +1178,27 @@ class calendar_boupdate extends calendar_bo
 		{
 			$old_event = null;
 		}
-
 		if (!isset($event['whole_day'])) $event['whole_day'] = $this->isWholeDay($event);
+
+		// set recur-enddate/range-end to real end-date of last recurrence
+		if ($event['recur_type'] != MCAL_RECUR_NONE && $event['recur_enddate'])
+		{
+			$event['recur_enddate'] = new Api\DateTime($event['recur_enddate'], calendar_timezones::DateTimeZone($event['tzid']));
+			$event['recur_enddate']->setTime(23,59,59);
+			$rrule = calendar_rrule::event2rrule($event, true, Api\DateTime::$user_timezone->getName());
+			$rrule->rewind();
+			$enddate = $rrule->current();
+			do
+			{
+				$rrule->next_no_exception();
+				$occurrence = $rrule->current();
+			}
+			while ($rrule->valid($event['whole_day']) && ($enddate = $occurrence));
+			$enddate->modify(($event['end'] - $event['start']).' second');
+			$event['recur_enddate'] = $save_event['recur_enddate'] = $enddate->format('ts');
+			//error_log(__METHOD__."($event[title]) start=".Api\DateTime::to($event['start'],'string').', end='.Api\DateTime::to($event['end'],'string').', range_end='.Api\DateTime::to($event['recur_enddate'],'string'));
+		}
+
 		$save_event = $event;
 		if ($event['whole_day'])
 		{
@@ -1115,6 +1211,13 @@ class calendar_boupdate extends calendar_bo
 			if (!empty($event['end']))
 			{
 				$time = new Api\DateTime($event['end'], Api\DateTime::$user_timezone);
+
+				// Check to see if switching timezones changes the date, we'll need to adjust for that
+				$end_event_timezone = clone $time;
+				$time->setServer();
+				$delta = (int)$end_event_timezone->format('z') - (int)$time->format('z');
+				$time->add("$delta days");
+
 				$time->setTime(23, 59, 59);
 				$event['end'] = Api\DateTime::to($time, 'ts');
 				$save_event['end'] = $time;
@@ -1126,14 +1229,23 @@ class calendar_boupdate extends calendar_bo
 			}
 			if (!empty($event['recur_enddate']))
 			{
-				$time = $this->so->startOfDay(new Api\DateTime($event['recur_enddate'], Api\DateTime::$user_timezone));
-				$event['recur_enddate'] = Api\DateTime::to($time, 'ts');
-				$time->setUser();
-				$save_event['recur_enddate'] = Api\DateTime::to($time, 'ts');
+				// all-day events are handled in server time, but here (BO) it's in user time
+				$time = new Api\DateTime($event['recur_enddate'], Api\DateTime::$user_timezone);
+				$time->setTime(23, 59, 59);
+				// Check to see if switching timezones changes the date, we'll need to adjust for that
+				$enddate_event_timezone = clone $time;
+				$time->setServer();
+				$delta = (int)$enddate_event_timezone->format('z') - (int)$time->format('z');
+				$time->add("$delta days");
+
+				//$time->setServer();
+				$time->setTime(23, 59, 59);
+				
+				$event['recur_enddate'] = $save_event['recur_enddate'] = $time;
 			}
 			$timestamps = array('modified','created');
 			// all-day events are handled in server time
-			$event['tzid'] = $save_event['tzid'] = Api\DateTime::$server_timezone->getName();
+		//	$event['tzid'] = $save_event['tzid'] = Api\DateTime::$server_timezone->getName();
 		}
 		else
 		{
@@ -1211,16 +1323,19 @@ class calendar_boupdate extends calendar_bo
 			}
 		}
 
-		// always update modification time (ctag depends on it!)
-		$event['modified'] = $this->now;
-		$event['modifier'] = $this->user;
+		// you should always update modification time (ctag depends on it!)
+		if ($updateTS)
+		{
+			$event['modified'] = $this->now;
+			$event['modifier'] = $this->user;
+		}
 
 		if (empty($event['id']) && (!isset($event['created']) || $event['created'] > $this->now))
 		{
 			$event['created'] = $this->now;
 			$event['creator'] = $this->user;
 		}
-		$set_recurrences = $old_event ? $event['recur_enddate'] != $old_event['recur_enddate'] : false;
+		$set_recurrences = $old_event ? $event['recur_enddate'] != $old_event['recur_enddate']+1 : false;
 		$set_recurrences_start = 0;
 		if (($cal_id = $this->so->save($event,$set_recurrences,$set_recurrences_start,0,$event['etag'])) && $set_recurrences && $event['recur_type'] != MCAL_RECUR_NONE)
 		{
@@ -1450,14 +1565,14 @@ class calendar_boupdate extends calendar_bo
 			error_log(__FILE__.'['.__LINE__.'] '.__METHOD__.
 				"($cal_id, $uid, $status, $recur_date)\n",3,$this->logfile);
 		}
-		$old_event = $this->read($cal_id, $recur_date, false, 'server');
+		$old_event = $this->read($cal_id, $recur_date, $ignore_acl, 'server');
 		if (($Ok = $this->so->set_status($cal_id,is_numeric($uid)?'u':$uid[0],
 				is_numeric($uid)?$uid:substr($uid,1),$status,
 				$recur_date?$this->date2ts($recur_date,true):0,$role)))
 		{
 			if ($status == 'R')	// remove alarms belonging to rejected participants
 			{
-				foreach(isset($event['alarm']) ? $event['alarm'] : $old_event['alarm'] as $id => $alarm)
+				foreach(is_array($event) && isset($event['alarm']) ? $event['alarm'] : $old_event['alarm'] as $id => $alarm)
 				{
 					if ((string)$alarm['owner'] === (string)$uid)
 					{
@@ -1481,7 +1596,7 @@ class calendar_boupdate extends calendar_bo
 			}
 
 			// Update history
-			$event = $this->read($cal_id, $recur_date, false, 'server');
+			$event = $this->read($cal_id, $recur_date, $ignore_acl, 'server');
 			$tracking = new calendar_tracking($this);
 			$tracking->track($event, $old_event);
 
