@@ -347,7 +347,7 @@ class calendar_groupdav extends Api\CalDAV\Handler
 					unset($requested_multiget_ids[$k]);
 				}
 				// sync-collection report: deleted entries need to be reported without properties, same for rejected or deleted invitations
-				if ($sync_collection && ($event['deleted'] || in_array($event['participants'][$filter['users']][0], array('R','X'))))
+				if ($sync_collection && ($event['deleted'] && !$event['cal_reference'] || in_array($event['participants'][$filter['users']][0], array('R','X'))))
 				{
 					$files[] = array('path' => $path.urldecode($this->get_path($event)));
 					continue;
@@ -758,14 +758,10 @@ class calendar_groupdav extends Api\CalDAV\Handler
 				}
 				continue;	// nothing to change
 			}
-			// alarms are reported on recurrences --> move them to master
-			if ($master)
+			// add alarms from master to recurrences, as clients otherwise have no alarms on virtual exceptions
+			if ($master && $master['alarm'])
 			{
-				foreach($recurrence['alarm'] as $alarm)
-				{
-					$master['alarm'][] = $alarm;
-				}
-				$recurrence['alarm'] = array();
+				$recurrence['alarm'] = $master['alarm'];
 			}
 			// now we need to check if this recurrence is an exception
 			if (!$expand && $master && $master['participants'] == $recurrence['participants'])
@@ -1638,7 +1634,7 @@ class calendar_groupdav extends Api\CalDAV\Handler
 			'admin'  => False,
 		);
 		$settings['calendar-past-limit'] = array(
-			'type'   => 'input',
+			'type'   => 'integer',
 			'label'  => lang('How many days to sync in the past (default %1)', self::PAST_LIMIT),
 			'name'   => 'calendar-past-limit',
 			'help'   => 'Clients not explicitly stating a limit get limited to these many days. A too high limit may cause problems with some clients.',
@@ -1646,7 +1642,7 @@ class calendar_groupdav extends Api\CalDAV\Handler
 			'admin'  => False,
 		);
 		$settings['calendar-future-limit'] = array(
-			'type'   => 'input',
+			'type'   => 'integer',
 			'label'  => lang('How many days to sync in the future (default %1)', self::FUTURE_LIMIT),
 			'name'   => 'calendar-future-limit',
 			'help'   => 'Clients not explicitly stating a limit get limited to these many days. A too high limit may cause problems with some clients.',
