@@ -577,7 +577,7 @@ class calendar_merge extends Api\Storage\Merge
 				$replacements = $this->contact_replacements(substr($participant,1),'');
 				break;
 			case 'r':
-				if (is_null(self::$resources)) self::$resources = CreateObject('resources.resources_bo');
+				if (is_null(self::$resources)) self::$resources = new resources_bo();
 				if (($resource = self::$resources->read(substr($participant,1))))
 				{
 					foreach($resource as $name => $value)
@@ -719,7 +719,7 @@ class calendar_merge extends Api\Storage\Merge
 			'labelplacement' => lang('Tag to mark positions for address labels'),
 			'IF fieldname' => lang('Example {{IF n_prefix~Mr~Hello Mr.~Hello Ms.}} - search the field "n_prefix", for "Mr", if found, write Hello Mr., else write Hello Ms.'),
 			'NELF' => lang('Example {{NELF role}} - if field role is not empty, you will get a new line with the value of field role'),
-			'NENVLF' => lang('Example {{NELFNV role}} - if field role is not empty, set a LF without any value of the field'),
+			'NENVLF' => lang('Example {{NENVLF role}} - if field role is not empty, set a LF without any value of the field'),
 			'LETTERPREFIX' => lang('Example {{LETTERPREFIX}} - Gives a letter prefix without double spaces, if the title is emty for  example'),
 			'LETTERPREFIXCUSTOM' => lang('Example {{LETTERPREFIXCUSTOM n_prefix title n_family}} - Example: Mr Dr. James Miller'),
 			) as $name => $label)
