@@ -130,13 +130,25 @@ class calendar_rrule implements Iterator
 	 * @var DateTime
 	 */
 	public $enddate;
+
 	/**
 	 * Enddate of recurring event, as Ymd integer (eg. 20091111)
 	 *
+	 * Or 5 years in future, if no enddate. So iterator is always limited.
+	 *
 	 * @var int
 	 */
 	public $enddate_ymd;
 
+	/**
+	 * Enddate of recurring event, as timestamp
+	 *
+	 * Or 5 years in future, if no enddate. So iterator is always limited.
+	 *
+	 * @var int
+	 */
+	public $enddate_ts;
+
 	const SUNDAY    = 1;
 	const MONDAY    = 2;
 	const TUESDAY   = 4;
@@ -296,6 +308,7 @@ class calendar_rrule implements Iterator
 			$enddate->setTimezone($this->time->getTimezone());
 		}
 		$this->enddate_ymd = (int)$enddate->format('Ymd');
+		$this->enddate_ts = $enddate->format('ts');
 
 		// if no valid weekdays are given for weekly repeating, we use just the current weekday
 		if (!($this->weekdays = (int)$weekdays) && ($type == self::WEEKLY || $type == self::MONTHLY_WDAY))
@@ -537,11 +550,16 @@ class calendar_rrule implements Iterator
 	/**
 	 * Checks if current position is valid
 	 *
+	 * @param boolean $use_just_date =false default use also time
 	 * @return boolean
 	 */
-	public function valid ()
+	public function valid($use_just_date=false)
 	{
-		return $this->current->format('Ymd') <= $this->enddate_ymd;
+		if ($use_just_date)
+		{
+			return $this->current->format('Ymd') <= $this->enddate_ymd;
+		}
+		return $this->current->format('ts') < $this->enddate_ts;
 	}
 
 	/**
@@ -555,8 +573,8 @@ class calendar_rrule implements Iterator
 		// Repeated Events
 		if($this->type != self::NONE)
 		{
-			list($str) = explode(' (',lang(self::$types[$this->type]));	// remove (by day/date) from Monthly
-
+			$str = lang(self::$types[$this->type]);
+			
 			$str_extra = array();
 			switch ($this->type)
 			{
@@ -738,10 +756,24 @@ class calendar_rrule implements Iterator
 		self::rrule2tz($event, $time, $to_tz);
 
 		$time->setTimezone(self::$tz_cache[$to_tz]);
-
+		
 		if ($event['recur_enddate'])
 		{
-			$enddate = is_a($event['recur_enddate'],'DateTime') ? $event['recur_enddate'] : new Api\DateTime($event['recur_enddate'],$timestamp_tz);
+			$enddate = is_a($event['recur_enddate'],'DateTime') ? clone $event['recur_enddate'] : new Api\DateTime($event['recur_enddate'],$timestamp_tz);
+
+			// Check to see if switching timezones changes the date, we'll need to adjust for that
+			$enddate_event_timezone = clone $enddate;
+			$enddate->setTimezone($timestamp_tz);
+			$delta = (int)$enddate_event_timezone->format('z') - (int)$enddate->format('z');
+			$enddate->add("$delta days");
+
+			$end = is_a($event['end'],'DateTime') ? clone $event['end'] : new Api\DateTime($event['end'],$timestamp_tz);
+			$end->setTimezone($enddate->getTimezone());
+			$enddate->setTime($end->format('H'),$end->format('i'),0);
+			if($event['whole_day'])
+			{
+				$enddate->setTime(23,59,59);
+			}
 		}
 		if (is_array($event['recur_exception']))
 		{
@@ -753,6 +785,87 @@ class calendar_rrule implements Iterator
 		return new calendar_rrule($time,$event['recur_type'],$event['recur_interval'],$enddate,$event['recur_data'],$exceptions);
 	}
 
+	/**
+	 * Generate a rrule from a string generated by __toString().
+	 * @param String $rrule Recurrence rule in string format, as generated by __toString()
+	 * @param DateTime date Optional date to work from, defaults to today
+	 */
+	public static function from_string(String $rrule, DateTime $date)
+	{
+		$time = $date ? $date : new Api\DateTime();
+		$type_id = self::NONE;
+		$interval = 1;
+		$enddate = null;
+		$weekdays = 0;
+		$exceptions = array();
+
+		list($type, $sub, $conditions) = explode(' (', $rrule);
+		if(!$conditions)
+		{
+			$conditions = $sub;
+		}
+		else
+		{
+			$type .= " ($sub";
+		}
+		$conditions = explode(', ', substr($conditions, 0, -1));
+
+		foreach(static::$types as $id => $type_name)
+		{
+			$str = lang($type_name);
+			if($str == $type)
+			{
+				$type_id = $id;
+				break;
+			}
+		}
+
+		// Rejoin some extra splits for conditions with multiple values
+		foreach($conditions as $condition_index => $condition)
+		{
+			if(((int)$condition || strpos($condition, lang('last')) === 0) &&
+					substr_compare( $condition, lang('day'), -strlen( lang('day') ) ) === 0)
+			{
+				$time->setDate($time->format('Y'), $time->format('m'), (int)($condition) ? (int)$condition : $time->format('t'));
+				unset($conditions[$condition_index]);
+				continue;
+			}
+			if(!strpos($condition, ':') && strpos($conditions[$condition_index-1], ':'))
+			{
+				$conditions[$condition_index-1] .= ', ' . $condition;
+				unset($conditions[$condition_index]);
+			}
+		}
+		foreach($conditions as $condition_index => $condition)
+		{
+			list($condition_name, $value) = explode(': ', $condition);
+			if($condition_name == lang('days repeated'))
+			{
+				foreach (self::$days as $mask => $label)
+				{
+					if (strpos($value, $label) !== FALSE || strpos($value, lang($label)) !== FALSE)
+					{
+						$weekdays += $mask;
+					}
+				}
+				if(stripos($condition, lang('all')) !== false)
+				{
+					$weekdays = self::ALLDAYS;
+				}
+			}
+			else if ($condition_name == lang('interval'))
+			{
+				$interval = (int)$value;
+			}
+			else if ($condition_name == lang('ends'))
+			{
+				list($dow, $date) = explode(', ', $value);
+				$enddate = new DateTime($date);
+			}
+		}
+		
+		return new calendar_rrule($time,$type_id,$interval,$enddate,$weekdays,$exceptions);
+	}
 	/**
 	 * Get recurrence data (keys 'recur_*') to merge into an event
 	 *
