@@ -518,12 +518,15 @@ class calendar_ui
 		if ($GLOBALS['egw_info']['user']['apps']['admin'])
 		{
 			$file = Array(
-				'Configuration'=>Egw::link('/index.php','menuaction=admin.admin_config.index&appname=calendar&ajax=true'),
-				'Custom Fields'=>Egw::link('/index.php','menuaction=admin.customfields.index&appname=calendar'),
-				'Global Categories' =>Egw::link('/index.php','menuaction=admin.admin_categories.index&appname=calendar'),
+				'Site configuration'=>Egw::link('/index.php','menuaction=admin.admin_config.index&appname=calendar&ajax=true'),
+				'Custom Fields'=>Egw::link('/index.php','menuaction=admin.admin_customfields.index&appname=calendar&ajax=true'),
+				'Global Categories' =>Egw::link('/index.php','menuaction=admin.admin_categories.index&appname=calendar&ajax=true'),
 			);
 			$GLOBALS['egw']->framework->sidebox($appname,lang('Admin'),$file,'admin');
 		}
+		display_sidebox('calendar', lang('Utilities'), array('Category report' => "javascript:egw_openWindowCentered2('".
+					Egw::link('/index.php',array('menuaction'=>'calendar.calendar_category_report.index','ajax'=>true),false).
+					"','_blank',870,500,'yes')" ));
 	}
 
 	/**
@@ -555,7 +558,8 @@ class calendar_ui
 		$cont = $this->cal_prefs['saved_states'];
 		if (!is_array($cont)) $cont = array();
 		$cont['view'] = $this->view ? $this->view : 'week';
-		$cont['date'] = $this->date ? $this->date : Api\DateTime();
+		$cont['date'] = $this->date ? $this->date : new Api\DateTime();
+		$cont['owner'] = $this->owner ? (is_array($this->owner) ? $this->owner : explode(',',$this->owner) ) : $cont['owner'];
 
 		$cont['year'] = (int)Api\DateTime::to($cont['date'],'Y');
 		$cont['holidays'] = $this->bo->read_holidays($cont['year']);
@@ -613,18 +617,23 @@ class calendar_ui
 	public function update_client($event_id, Api\DateTime $recurrence_date = null)
 	{
 		if(!$event_id) return false;
+		if(is_string($event_id) && strpos($event_id,':') !== FALSE)
+		{
+			list($event_id, $date) = explode(':',$event_id);
+			$recurrence_date = new Api\DateTime($date);
+		}
 
 		// Directly update stored data.
 		// Make sure we have the whole event
-		$event = $this->bo->read($event_id, $recurrence_date);
+		$event = $this->bo->read($event_id, $recurrence_date, false, 'ts', $this->cal_prefs['saved_states']['owner']);
 		$response = Api\Json\Response::get();
 
 
 		// Check filters to see if they still match, may have to remove
 		// the event because it should no longer be displayed
 		$filter_match = true;
-		if($this->cal_prefs['saved_states']['status_filter'] != 'all' ||
-			$this->cal_prefs['saved_states']['cat_id'])
+		if($event && ($this->cal_prefs['saved_states']['status_filter'] != 'all' ||
+			$this->cal_prefs['saved_states']['cat_id']))
 		{
 			$filter_check = array(
 				'start' => $event['start'],
@@ -748,7 +757,17 @@ class calendar_ui
 		// set id for grid
 		$event['row_id'] = $event['id'].($event['recur_type'] ? ':'.Api\DateTime::to($event['recur_date'] ? $event['recur_date'] : $event['start'],'ts') : '');
 
-		$event['parts'] = implode(",\n",$this->bo->participants($event,false));
+		// Set up participant section of tooltip
+		$participants = $this->bo->participants($event,false);
+		$event['parts'] = implode("\n",$participants);
+		$event['participant_types'] = array();
+		foreach($participants as $uid => $text)
+		{
+			$user_type = $user_id = null;
+			calendar_so::split_user($uid, $user_type, $user_id);
+			$type_name = lang($this->bo->resources[$user_type]['app']);
+			$event['participant_types'][$type_name ? $type_name : ''][] = $text;
+		}
 		$event['date'] = $this->bo->date2string($event['start']);
 
 		// Change dates
