@@ -159,6 +159,10 @@ class calendar_uilist extends calendar_ui
 		{
 			$content['nm']['search'] = $_GET['search'];
 		}
+		if($this->owner)
+		{
+			$content['nm']['col_filter']['participant'] = is_array($this->owner) ? $this->owner : explode(',',$this->owner);
+		}
 		// search via jdots ajax_exec uses $_REQUEST['json_data'] instead of regular GET parameters
 		if (isset($_REQUEST['json_data']) && ($json_data = json_decode($_REQUEST['json_data'], true)) &&
 			!empty($json_data['request']['parameters'][0]))
@@ -221,13 +225,11 @@ class calendar_uilist extends calendar_ui
 		$params['order'] = 'cal_start';
 		if ($keywords)
 		{
-			$params['filter'] = 'all';
 			$params['sort'] = 'DESC';
 			unset($params['col_filter']['participant']);
 		}
 		else
 		{
-			$params['filter'] = 'after';
 			$params['sort'] = 'ASC';
 		}
 	}
@@ -273,10 +275,15 @@ class calendar_uilist extends calendar_ui
 			if ($old_params['search'] != $params['search'])
 			{
 				$this->adjust_for_search($params['search'],$params);
+				$this->filter = $params['filter'];
 			}
 		}
-		if (!$params['csv_export']) Api\Cache::setSession('calendar', 'calendar_list', $params);
 
+		if (!$params['csv_export'])
+		{
+			Api\Cache::setSession('calendar', 'calendar_list',
+				array_diff_key ($params, array_flip(array('rows', 'actions', 'action_links', 'placeholder_actions'))));
+		}
 		// do we need to query custom fields and which
 		// Check stored preference if selectcols isn't available (ie: first call)
 		$select_cols = $params['selectcols'] ? $params['selectcols'] : $GLOBALS['egw_info']['user']['preferences']['calendar']['nextmatch-calendar.list.rows'];
@@ -890,6 +897,14 @@ class calendar_uilist extends calendar_ui
 				'popup' => Link::get_registry('calendar', 'view_popup'),
 				'allowOnMultiple' => false,
 			),
+			'print' => array(
+				'caption' => 'Print',
+				'group' => $group,
+				'disableClass' => 'rowNoView',
+				'url' => 'menuaction=calendar.calendar_uiforms.edit&cal_id=$id&print=1',
+				'popup' => Link::get_registry('calendar', 'view_popup'),
+				'allowOnMultiple' => false,
+			),
 			'select_all' => array(
 				'caption' => 'Whole query',
 				'checkbox' => true,
