@@ -144,6 +144,7 @@ class calendar_uiviews extends calendar_ui
 			'start'   => $this->date,
 			'cat_id'  => $this->cat_id ? (is_array($this->cat_id)?$this->cat_id:explode(',',$this->cat_id)) : 0,
 			'users'   => explode(',',$this->owner),
+			'owner'   => explode(',',$this->owner),
 			'filter'  => $this->filter,
 			'daywise' => True,
 			'use_so_events' => $this->test === 'true',
@@ -236,7 +237,7 @@ class calendar_uiviews extends calendar_ui
 		// Load the different views once, we'll switch between them on the client side
 		$todo = new Etemplate('calendar.todo');
 		$label = '';
-		$todo->exec('calendar_uiviews::index',array('todos'=>$this->get_todos($label), 'label' => $label));
+		$todo->exec('calendar_uiviews::index',array('todos'=>'', 'label' => $label));
 
 		// Actually, this takes care of most of it...
 		$this->week();
@@ -686,7 +687,7 @@ class calendar_uiviews extends calendar_ui
 			}
 			else
 			{
-				foreach(array_keys($this->_get_planner_users(false)) as $uid)
+				foreach($users as $uid)
 				{
 					$search_params['users'] = $uid;
 					$content['view'][] = $this->tagWholeDayOnTop($this->bo->search($search_params))
@@ -914,6 +915,8 @@ class calendar_uiviews extends calendar_ui
 		$actions['add']['onExecute'] =  'javaScript:app.calendar.action_open';
 		$actions['copy']['open'] = '{"app": "calendar", "type": "add", "extra": "cal_id=$id&action=copy"}';
 		$actions['copy']['onExecute'] = 'javaScript:app.calendar.action_open';
+		$actions['print']['open'] = '{"app": "calendar", "type": "add", "extra": "cal_id=$id&print=1"}';
+		$actions['print']['onExecute'] = 'javaScript:app.calendar.action_open';
 
 		foreach($actions['status']['children'] as $id => &$status)
 		{
