@@ -70,8 +70,12 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 			.css('left', this.options.left);
 		this.title = jQuery(document.createElement('div'))
 			.appendTo(this.header);
+		this.user_spacer = jQuery(document.createElement('div'))
+			.addClass("calendar_calDayColHeader_spacer")
+			.appendTo(this.header);
 		this.all_day = jQuery(document.createElement('div'))
 			.addClass("calendar_calDayColAllDay")
+			.css('max-height', (egw.preference('limit_all_day_lines', 'calendar') || 3 ) * 1.4 + 'em')
 			.appendTo(this.header);
 		this.event_wrapper = jQuery(document.createElement('div'))
 			.addClass("event_wrapper")
@@ -125,6 +129,7 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 		this.div = null;
 		this.header = null;
 		this.title = null;
+		this.user_spacer = null;
 
 		// date_helper has no parent, so we must explicitly remove it
 		this.date_helper.destroy();
@@ -299,6 +304,7 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 		this.title
 			.attr("data-owner", _owner);
 		this.header.attr('data-owner',_owner);
+		this.div.attr('data-owner',_owner);
 
 		// Simple comparison, both numbers
 		if(_owner === this.options.owner) return;
@@ -417,8 +423,8 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 			{
 				if (typeof holidays[i]['birthyear'] !== 'undefined')
 				{
-					// Show holidays as events on mobile
-					if(egwIsMobile())
+					// Show holidays as events on mobile or by preference
+					if(egwIsMobile() || egw.preference('birthdays_as_events','calendar'))
 					{
 						// Create event
 						this._parent.date_helper.set_value(this.options.date.substring(0,4)+'-'+
@@ -443,7 +449,7 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 						event.doLoadingFinished();
 						event._update();
 					}
-					else
+					if (!egwIsMobile())
 					{
 						//If the birthdays are already displayed as event, don't
 						//show them in the caption
@@ -471,7 +477,7 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 								owner: this.options.owner,
 								participants: this.options.owner,
 								app: 'calendar',
-								class: 'calendar_calBirthday'
+								class: 'calendar_calHoliday'
 							},
 							readonly: true,
 							class: 'calendar_calHoliday'
@@ -553,8 +559,8 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 		}
 
 
-		// Show holidays as events on mobile
-		if(egwIsMobile())
+		// Show holidays as events on mobile or by preference
+		if(egwIsMobile() || egw.preference('birthdays_as_events','calendar'))
 		{
 			this.day_class_holiday();
 		}
@@ -860,7 +866,7 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 			if(!event) continue;
 			if(event.date && event.date != this.options.date &&
 				// Multi-day events date may be different
-				(new Date(event.start) >= this.date || new Date(event.end) <= this.date )
+				(new Date(event.start) >= this.date || new Date(event.end) < this.date )
 			)
 			{
 				// Still have a child event that has changed date (DnD)
@@ -879,13 +885,13 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 			{
 				event.end = new Date(event.end);
 			}
-			event['start_m'] = parseInt((event.start.valueOf()/1000 - day_start) / 60);
+			event['start_m'] = (event.start.valueOf()/1000 - day_start) / 60
 			if (event['start_m'] < 0)
 			{
 				event['start_m'] = 0;
 				event['multiday'] = true;
 			}
-			event['end_m'] = parseInt((event.end.valueOf()/1000 - day_start) / 60);
+			event['end_m'] = (event.end.valueOf()/1000 - day_start) / 60;
 			if (event['end_m'] >= 24*60)
 			{
 				event['end_m'] = 24*60-1;
@@ -1057,6 +1063,11 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 	 */
 	click: function(_ev)
 	{
+		if(this._parent.options.readonly ) return;
+
+		// Drag to create in progress
+		if(this._parent.drag_create.start !== null) return;
+
 		// Click on the title
 		if (jQuery(_ev.target).hasClass('calendar_calAddEvent'))
 		{
@@ -1066,32 +1077,31 @@ var et2_calendar_daycol = (function(){ "use strict"; return et2_valueWidget.exte
 				var options = {
 					date: _ev.target.dataset.date || this.options.date,
 					hour: _ev.target.dataset.hour || this._parent.options.day_start,
-					minute: _ev.target.dataset.minute || 0
+					minute: _ev.target.dataset.minute || 0,
+					owner: this.options.owner
 				};
-				if (this.options.owner != app.calendar.state.owner)
-				{
-					options.owner = this.options.owner;
-				}
 				this.egw().open(null, 'calendar', 'add', options, '_blank');
 				return false;
 			}
 			// Header, all day non-blocking
 			else if (this.header.has(_ev.target).length && !jQuery('.hiddenEventBefore',this.header).has(_ev.target).length ||
-			this.header.is(_ev.target)
+				this.header.is(_ev.target)
 			)
 			{
 				// Click on the header, but not the title.  That's an all-day non-blocking
 				var end = this.date.getFullYear() + '-' + (this.date.getUTCMonth()+1) + '-' + this.date.getUTCDate() + 'T23:59';
-				this.egw().open(null, 'calendar', 'add', {
+				var options = {
 					start: this.date.toJSON(),
 					end: end,
-					non_blocking: true
-				} , '_blank');
+					non_blocking: true,
+					owner: this.options.owner
+				}
+				this.egw().open(null, 'calendar', 'add', options, '_blank');
 				return false;
 			}
 		}
 		// Day label
-		else if(this.title.is(_ev.target) || this.title.has(_ev.target))
+		else if(this.title.is(_ev.target) || this.title.has(_ev.target).length)
 		{
 			app.calendar.update_state({view: 'day',date: this.date.toJSON()});
 			return false;
