@@ -71,6 +71,11 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 			.addClass(this.options.class)
 			.css('width',this.options.width)
 			.on('mouseenter', function() {
+				// Bind actions on first mouseover for faster creation
+				if(event._need_actions_linked)
+				{
+					event._copy_parent_actions();
+				}
 				// Tooltip
 				if(!event._tooltipElem)
 				{
@@ -108,6 +113,8 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 			.appendTo(this.title);
 
 		this.setDOMNode(this.div[0]);
+
+		this._need_actions_linked = false;
 	},
 
 	doLoadingFinished: function() {
@@ -195,6 +202,14 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 		// Check for changing days in the grid view
 		if(!this._sameday_check(value))
 		{
+			// May need to update parent to remove out-of-view events
+			var parent = this._parent;
+			this._parent.removeChild(this);
+			if(event === null && parent && parent._out_of_view)
+			{
+				parent._out_of_view();
+			}
+			
 			// This should now cease to exist, as new events have been created
 			this.free();
 			return;
@@ -235,23 +250,7 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 			this._actionObject.id = 'calendar::' + id;
 		}
 
-		// Copy actions set in parent
-		if(!this.options.readonly && !this._parent.options.readonly)
-		{
-			var action_parent = this;
-			while(action_parent != null && !action_parent.options.actions &&
-				!action_parent.instanceOf(et2_container)
-			)
-			{
-				action_parent = action_parent.getParent();
-			}
-			try {
-				this._link_actions(action_parent.options.actions||{});
-			} catch (e) {
-				// something went wrong, but keep quiet about it
-				debugger;
-			}
-		}
+		this._need_actions_linked = true;
 
 		// Make sure category stuff is there
 		// Fake it to use the cache / call - if already there, these will return
@@ -292,6 +291,7 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 			.attr('data-owner', event.owner)
 			.attr('data-recur_type', event.recur_type)
 			.attr('data-resize', event.whole_day ? 'WD' : '' + (event.recur_type ? 'S':''))
+			.attr('data-priority', event.priority)
 			// Remove any category classes
 			.removeClass(function(index, css) {
 				return (css.match (/(^|\s)cat_\S+/g) || []).join(' ');
@@ -322,7 +322,7 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 		this.body.toggleClass('calendar_calEventBodySmall', event.whole_day_on_top || false);
 
 		// Header
-		var title = !event.is_private ? event['title'] : egw.lang('private');
+		var title = !event.is_private ? egw.htmlspecialchars(event['title']) : egw.lang('private');
 
 		this.title
 			.html('<span class="calendar_calTimespan">'+this._get_timespan(event) + '<br /></span>')
@@ -362,7 +362,7 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 			if(this.options.value.description.trim())
 			{
 				this.body
-					.append('<p>'+this.options.value.description+'</p>');
+					.append('<p>'+egw.htmlspecialchars(this.options.value.description)+'</p>');
 			}
 		}
 
@@ -390,6 +390,9 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 
 		if(this.options.value.whole_day_on_top) return;
 
+		// Skip for planner view, it's always small
+		if(this._parent && this._parent.instanceOf(et2_calendar_planner_row)) return;
+
 		// Pre-calculation reset
 		this.div.removeClass('calendar_calEventSmall');
 		this.body.css('height', 'auto');
@@ -462,7 +465,7 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 	 * @return {String}
 	 */
 	_tooltip: function() {
-		if(!this.div) return '';
+		if(!this.div || !this.options.value || !this.options.value.app_id) return '';
 
 		var border = this.div.css('borderTopColor');
 		var bg_color = this.div.css('background-color');
@@ -476,7 +479,7 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 
 		var times = !this.options.value.multiday ?
 			'<span class="calendar_calEventLabel">'+this.egw().lang('Time')+'</span>:' + timespan :
-			'<span class="calendar_calEventLabel">'+this.egw().lang('Start') + '</span>:' +start+
+			'<span class="calendar_calEventLabel">'+this.egw().lang('Start') + '</span>:' +start+ ' ' +
 			'<span class="calendar_calEventLabel">'+this.egw().lang('End') + '</span>:' + end;
 		var cat_label = '';
 		if(this.options.value.category)
@@ -493,6 +496,19 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 			}
 			cat.destroy();
 		}
+		var participants = '';
+		if(this.options.value.participant_types[''])
+		{
+			participants += this.options.value.participant_types[''].join("<br />");
+		}
+		for(var type_name in this.options.value.participant_types)
+		{
+			if(type_name)
+			{
+				participants += '</p><p><span class="calendar_calEventLabel">'+type_name+'</span>:<br />';
+				participants += this.options.value.participant_types[type_name].join("<br />");
+			}
+		}
 
 		return '<div class="calendar_calEventTooltip ' + this._status_class() +' '+ this.options.class +
 			'" style="border-color: '+border+'; background-color: '+bg_color+';">'+
@@ -502,17 +518,50 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 			'</div>'+
 			'<div class="calendar_calEventBody">'+
 				'<p style="margin: 0px;">'+
-				'<span class="calendar_calEventTitle">'+this.options.value.title+'</span><br>'+
-				this.options.value.description+'</p>'+
+				'<span class="calendar_calEventTitle">'+egw.htmlspecialchars(this.options.value.title)+'</span><br>'+
+				egw.htmlspecialchars(this.options.value.description)+'</p>'+
 				'<p style="margin: 2px 0px;">'+times+'</p>'+
-				(this.options.value.location ? '<p><span class="calendar_calEventLabel">'+this.egw().lang('Location') + '</span>:' + this.options.value.location+'</p>' : '')+
+				(this.options.value.location ? '<p><span class="calendar_calEventLabel">'+this.egw().lang('Location') + '</span>:' + 
+				egw.htmlspecialchars(this.options.value.location)+'</p>' : '')+
 				(cat_label ? '<p><span class="calendar_calEventLabel">'+this.egw().lang('Category') + '</span>:' + cat_label +'</p>' : '')+
 				'<p><span class="calendar_calEventLabel">'+this.egw().lang('Participants')+'</span>:<br />'+
-					(this.options.value.parts ? this.options.value.parts.replace("\n","<br />"):'')+'</p>'+
+					participants + '</p>'+ this._participant_summary(this.options.value.participants) +
 			'</div>'+
 		'</div>';
 	},
 
+	/**
+	 * Generate participant summary line
+	 *
+	 * @returns {String}
+	 */
+	_participant_summary: function(participants)
+	{
+		if( Object.keys(this.options.value.participants).length < 2)
+		{
+			return '';
+		}
+		
+		var participant_status = {A: 0, R: 0, T: 0, U: 0, D: 0};
+		var status_label = {A: 'accepted', R: 'rejected', T: 'tentative', U: 'unknown', D: 'delegated'};
+		var participant_summary = Object.keys(this.options.value.participants).length + ' ' + this.egw().lang('Participants')+': ';
+		var status_totals = [];
+
+		for(var id in this.options.value.participants)
+		{
+			var status = this.options.value.participants[id].substr(0,1);
+			participant_status[status]++;
+		}
+		for(var status in participant_status)
+		{
+			if(participant_status[status] > 0)
+			{
+				status_totals.push(participant_status[status] + ' ' + this.egw().lang(status_label[status]));
+			}
+		}
+		return participant_summary + status_totals.join(', ');
+	},
+
 	/**
 	 * Get actual icons from list
 	 * @returns {undefined}
@@ -632,7 +681,6 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 			var duration = event.multiday ?
 				(event.end - event.start) / 60000 :
 				(event.end_m - event.start_m);
-			if (event.end_m === 24*60-1) ++duration;
 			duration = Math.floor(duration/60) + this.egw().lang('h')+(duration%60 ? duration%60 : '');
 
 			timespan = jQuery.datepicker.formatTime(
@@ -646,7 +694,18 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 				{"ampm": (egw.preference("timeformat") === "12")}
 			).trim();
 
-			timespan += ' ' + duration;
+			timespan += ' - ' + jQuery.datepicker.formatTime(
+				egw.preference("timeformat") === "12" ? "h:mmtt" : "HH:mm",
+				{
+					hour: event.end_m / 60,
+					minute: event.end_m % 60,
+					seconds: 0,
+					timezone: 0
+				},
+				{"ampm": (egw.preference("timeformat") === "12")}
+			).trim();
+
+			timespan += ': ' + duration;
 		}
 		return timespan;
 	},
@@ -830,6 +889,32 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 		et2_calendar_event.series_split_prompt(this.options.value,this.options.value.recur_date, callback);
 	},
 
+	/**
+	 * Copy the actions set on the parent, apply them to self
+	 *
+	 * This can take a while to do, so we try to do it only when needed - on mouseover
+	 */
+	_copy_parent_actions: function()
+	{
+		// Copy actions set in parent
+		if(!this.options.readonly && !this._parent.options.readonly)
+		{
+			var action_parent = this;
+			while(action_parent != null && !action_parent.options.actions &&
+				!action_parent.instanceOf(et2_container)
+			)
+			{
+				action_parent = action_parent.getParent();
+			}
+			try {
+				this._link_actions(action_parent.options.actions||{});
+				this._need_actions_linked = false;
+			} catch (e) {
+				// something went wrong, but keep quiet about it
+			}
+		}
+	},
+	
 	/**
 	 * Link the actions to the DOM nodes / widget bits.
 	 *
@@ -840,7 +925,7 @@ var et2_calendar_event = (function(){ "use strict"; return et2_valueWidget.exten
 		if(!this._actionObject)
 		{
 			// Get the top level element - timegrid or so
-			var objectManager = this.getParent().getParent()._actionObject ||
+			var objectManager = this.getParent()._actionObject || this.getParent().getParent()._actionObject ||
 			   egw_getAppObjectManager(true).getObjectById(this._parent._parent._parent.id) || egw_getAppObjectManager(true);
 			this._actionObject = objectManager.getObjectById('calendar::'+this.options.value.row_id);
 		}
@@ -918,15 +1003,37 @@ et2_calendar_event.owner_check = function owner_check(event, parent, owner_too)
 	{
 		owner_too = app.calendar.state.status_filter === 'owner';
 	}
-	if(event.participants && parent.options.owner)
+	var options = false;
+	if(app.calendar && app.calendar.sidebox_et2 && app.calendar.sidebox_et2.getWidgetById('owner'))
 	{
-		var parent_owner = typeof parent.options.owner !== 'object' ?
+		options = app.calendar.sidebox_et2.getWidgetById('owner').taglist.getSelection();
+	}
+	else
+	{
+		options = parent.getArrayMgr("sel_options").getRoot().getEntry('owner');
+	}
+	if(event.participants && typeof parent.options.owner != 'undefined' && parent.options.owner.length > 0)
+	{
+		var parent_owner = jQuery.extend([], typeof parent.options.owner !== 'object' ?
 			[parent.options.owner] :
-			parent.options.owner;
+			parent.options.owner);
 		owner_match = false;
 		var length = parent_owner.length;
 		for(var i = 0; i < length; i++ )
 		{
+			// Handle grouped resources like mailing lists, they won't match so
+			// we need the list - pull it from sidebox owner
+			if(isNaN(parent_owner[i]) && options && options.find)
+			{
+				var resource = options.find(function(element) {return element.id == parent_owner[i];}) || {};
+				if(resource && resource.resources)
+				{
+					parent_owner.splice(i,1);
+					parent_owner = parent_owner.concat(resource.resources);
+					continue;
+				}
+			}
+			
 			if (parseInt(parent_owner[i]) < 0)
 			{
 				// Add in groups, if we can get them (this is syncronous)
@@ -999,7 +1106,16 @@ et2_calendar_event.recur_prompt = function(event_data, callback, extra_data)
 {
 	var edit_id = event_data.app_id;
 	var edit_date = event_data.start;
+
+	// seems window.opener somehow in certian conditions could be from different origin
+	// we try to catch the exception and in this case retrive the egw object from current window.
+	try {
 	var egw = this.egw ? (typeof this.egw == 'function' ? this.egw() : this.egw) : window.opener && typeof window.opener.egw != 'undefined' ? window.opener.egw('calendar'):window.egw('calendar');
+	}
+	catch(e){
+		var egw = window.egw('calendar');
+	}
+
 	var that = this;
 
 	var extra_params = extra_data && typeof extra_data == 'object' ? extra_data : {};
@@ -1063,7 +1179,15 @@ et2_calendar_event.recur_prompt = function(event_data, callback, extra_data)
  */
 et2_calendar_event.series_split_prompt = function(event_data, instance_date, callback)
 {
+	// seems window.opener somehow in certian conditions could be from different origin
+	// we try to catch the exception and in this case retrive the egw object from current window.
+	try {
 	var egw = this.egw ? (typeof this.egw == 'function' ? this.egw() : this.egw) : window.opener && typeof window.opener.egw != 'undefined' ? window.opener.egw('calendar'):window.egw('calendar');
+	}
+	catch(e){
+		var egw = window.egw('calendar');
+	}
+
 	var that = this;
 
 	if(typeof instance_date == 'string')
