@@ -23,7 +23,7 @@
  *
  * @augments et2_calendar_view
  */
-var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.extend([et2_IDetachedDOM, et2_IResizeable],
+var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.extend([et2_IDetachedDOM, et2_IResizeable, et2_IPrint],
 {
 	createNamespace: true,
 
@@ -46,6 +46,12 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			default: egw.preference('days_in_weekview','calendar') != 5,
 			description: "Display weekends.  The date range should still include them for proper scrolling, but they just won't be shown."
 		},
+		hide_empty: {
+			name: "Hide empty rows",
+			type: "boolean",
+			default: false,
+			description: "Hide rows with no events."
+		},
 		value: {
 			type: "any",
 			description: "A list of events, optionally you can set start_date, end_date and group_by as keys and events will be fetched"
@@ -64,6 +70,8 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		}
 	},
 
+	DEFERRED_ROW_TIME: 100,
+
 	/**
 	 * Constructor
 	 *
@@ -108,6 +116,8 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		this.setDOMNode(this.div[0]);
 
 		this.registeredCallbacks = [];
+		this.cache = {};
+		this._deferred_row_updates = {};
 	},
 
 	destroy: function() {
@@ -129,14 +139,13 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			this._drawGrid();
 		}
 
-		// Actions may be set on a parent, so we need to explicitly get in here
-		// and get ours
-		this._link_actions(this.options.actions || this._parent.options.actions || []);
-
 		// Automatically bind drag and resize for every event using jQuery directly
 		// - no action system -
 		var planner = this;
 
+		this.cache = {};
+		this._deferred_row_updates = {};
+		
 		/**
 		 * If user puts the mouse over an event, then we'll set up resizing so
 		 * they can adjust the length.  Should be a little better on resources
@@ -171,6 +180,21 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 						}
 					},
 
+					/**
+					 * If dragging to resize an event, abort drag to create
+					 *
+					 * @param {jQuery.Event} event
+					 * @param {Object} ui
+					 */
+					start: function(event, ui)
+					{
+						if(planner.drag_create.start)
+						{
+							// Abort drag to create, we're dragging to resize
+							planner._drag_create_end({});
+						}
+					},
+
 					/**
 					 * Triggered at the end of resizing the calEvent.
 					 *
@@ -225,16 +249,21 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 					 */
 					resize:function(event, ui)
 					{
-						planner._drag_helper(this,{
-							top:ui.position.top,
-							left: ui.position.left + ui.helper.width()
-						},ui.helper.outerHeight());
+						if(planner.options.group_by == 'month')
+						{
+							var position = {left: event.clientX, top: event.clientY};
+						}
+						else
+						{
+							var position = {top:ui.position.top, left: ui.position.left + ui.helper.width()};
+						}
+						planner._drag_helper(this,position,ui.helper.outerHeight());
 					}
 				});
 			})
 			.on('mousemove', function(event) {
-				// Not when over header
-				if(jQuery(event.target).closest('.calendar_eventRows').length == 0)
+				// Ignore headers
+				if(planner.headers.has(event.target).length !== 0)
 				{
 					planner.vertical_bar.hide();
 					return;
@@ -248,7 +277,12 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 				planner.vertical_bar.css('top','0px');
 
 				// Get time at mouse
-				if(planner.options.group_by == 'month')
+				if(jQuery(event.target).closest('.calendar_eventRows').length == 0)
+				{
+					// "Invalid" times, from space after the last planner row, or header
+					var time = planner._get_time_from_position(event.pageX - planner.grid.offset().left, 10);
+				}
+				else if(planner.options.group_by == 'month')
 				{
 					var time = planner._get_time_from_position(event.clientX, event.clientY);
 				}
@@ -263,13 +297,26 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 					planner.vertical_bar
 						.html('<span>'+date(egw.preference('timeformat','calendar') == 12 ? 'h:ia' : 'H:i',formatDate)+'</span>')
 						.show();
+
+					if(planner.drag_create.event && planner.drag_create.parent && planner.drag_create.end)
+					{
+
+						planner.drag_create.end.date = time.toJSON()
+						planner._drag_update_event();
+					}
 				}
 				else
 				{
 					// No (valid) time, just hide
 					planner.vertical_bar.hide();
 				}
-			});
+			})
+			.on('mousedown', jQuery.proxy(this._mouse_down, this))
+			.on('mouseup', jQuery.proxy(this._mouse_up, this));
+
+		// Actions may be set on a parent, so we need to explicitly get in here
+		// and get ours
+		this._link_actions(this.options.actions || this._parent.options.actions || []);
 
 		// Customize and override some draggable settings
 		this.div.on('dragcreate','.calendar_calEvent', function(event, ui) {
@@ -283,6 +330,9 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 					.css('top', '').css('left','')
 					.appendTo(ui.helper);
 				ui.helper.width(jQuery(this).width());
+
+				// Cancel drag to create, we're dragging an existing event
+				planner._drag_create_end();
 			});
 		return true;
 	},
@@ -331,10 +381,50 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			row_labels: function() {
 				var labels = [];
 				var already_added = [];
+				var options = false;
+				if(app.calendar && app.calendar.sidebox_et2 && app.calendar.sidebox_et2.getWidgetById('owner'))
+				{
+					options = app.calendar.sidebox_et2.getWidgetById('owner').taglist.getSelection();
+				}
+				else
+				{
+					options = this.getArrayMgr("sel_options").getRoot().getEntry('owner');
+				}
 				for(var i = 0; i < this.options.owner.length; i++)
 				{
 					var user = this.options.owner[i];
-					if (user < 0)	// groups
+					// Handle grouped resources like mailing lists - pull it from sidebox owner
+					// and expand to their contents
+					if(isNaN(user) && options && options.find)
+					{
+						var resource = options.find(function(element) {return element.id == user;}) || {};
+						if(resource && resource.resources)
+						{
+							for(var j = 0; j < resource.resources.length; j++)
+							{
+								var id = resource.resources[j];
+								if(already_added.indexOf(''+id) < 0)
+								{
+									labels.push({
+										id: id,
+										label: this._get_owner_name(id)||'',
+										data: {participants:id,owner:id}
+									});
+									already_added.push(''+id);
+								}
+							}
+						}
+						else if(already_added.indexOf(''+user) < 0)
+						{
+							labels.push({
+								id: user,
+								label: this._get_owner_name(user),
+								data: {participants:user,owner:user}
+							});
+							already_added.push(''+user);
+						}
+					}
+					else if (user < 0)	// groups
 					{
 						egw.accountData(user,'account_fullname',true,function(result) {
 							for(var id in result)
@@ -423,10 +513,28 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			},
 			// Draw a single row
 			draw_row: function(sort_key, label, events) {
-				if(['user','both'].indexOf(egw.preference('planner_show_empty_rows','calendar')) !== -1 || events.length)
+				var row = this._drawRow(sort_key, label,events,this.options.start_date, this.options.end_date);
+				if(this.options.hide_empty && !events.length)
 				{
-					return this._drawRow(sort_key, label,events,this.options.start_date, this.options.end_date);
+					row.set_disabled(true);
 				}
+				// Highlight current user, sort_key is account_id
+				if(sort_key === egw.user('account_id'))
+				{
+					row.set_class('current_user')
+				}
+				// Since the daywise cache is by user, we can tap in here
+				var t = new Date(this.options.start_date);
+				var end = new Date(this.options.end_date);
+				do
+				{
+					var cache_id = app.classes.calendar._daywise_cache_id(t, sort_key);
+					egw.dataRegisterUID(cache_id, row._data_callback, row);
+
+					t.setUTCDate(t.getUTCDate() + 1);
+				}
+				while(t < end);
+				return row;
 			}
 		},
 
@@ -589,7 +697,7 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 
 						// Get its children immediately
 						egw.json(
-							this.getInstanceManager().app+'.etemplate_widget_menupopup.ajax_get_options.etemplate',
+							'EGroupware\\Api\\Etemplate\\Widget\\Select::ajax_get_options',
 							['select-cat',',,,calendar,'+cat_id[i]],
 							function(data) {
 								labels = labels.concat(data);
@@ -655,10 +763,12 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 				}
 			},
 			draw_row: function(sort_key, label, events) {
-				if(['cat','both'].indexOf(egw.preference('planner_show_empty_rows','calendar')) !== -1 || events.length)
+				var row = this._drawRow(sort_key, label,events,this.options.start_date, this.options.end_date);
+				if(this.options.hide_empty && !events.length)
 				{
-					return this._drawRow(sort_key, label,events,this.options.start_date, this.options.end_date);
+					row.set_disabled(true);
 				}
+				return row;
 			}
 		}
 	},
@@ -690,16 +800,13 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			// Show AJAX loader
 			this.widget.loader.show();
 
-			this.widget.value = this.widget._fetch_data();
+			this.widget.cache = {};
+			this._deferred_row_updates = {};
+
+			this.widget._fetch_data();
 
 			this.widget._drawGrid();
 
-			// Update actions
-			if(this.widget._actionManager)
-			{
-				this.widget._link_actions(this.widget._actionManager.children);
-			}
-
 			if(this.trigger)
 			{
 				this.widget.change();
@@ -778,7 +885,7 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			.append(this.grid);
 		this.grid.empty();
 
-		var grouper = this.groupers[isNaN(this.options.group_by) ? this.options.group_by : 'category'];
+		var grouper = this.grouper;
 		if(!grouper) return;
 
 		// Headers
@@ -832,6 +939,14 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		{
 			this.gridHeader.css('margin-right', (this.rows.width() - this.rows.children().last().width()) + 'px');
 		}
+		// Add actual events
+		for(var key in this._deferred_row_updates)
+		{
+			window.clearTimeout(key);
+		}
+		window.setTimeout(jQuery.proxy(function() {
+			this._deferred_row_update();
+		}, this ),this.DEFERRED_ROW_TIME)
 		this.value = [];
 	},
 
@@ -861,9 +976,6 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			row.doLoadingFinished();
 		}
 
-		// Add actual events
-		row._update_events(events);
-
 		return row;
 	},
 
@@ -1027,8 +1139,7 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			if(!this.options.show_weekend && [0,6].indexOf(t.getDay()) !== -1 ) continue;
 			var holidays = [];
 			var tempDate = new Date(t);
-			tempDate.setMinutes(tempDate.getMinutes()-start.getTimezoneOffset());
-			var day_class = this.day_class_holiday(tempDate,holidays);
+			tempDate.setMinutes(tempDate.getMinutes()-tempDate.getTimezoneOffset());
 			var title = '';
 			var state = '';
 
@@ -1044,10 +1155,11 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			{
 				title = this.egw().lang(date('D',t)).substr(0,2)+'<br />'+date('j',t);
 			}
-			state = new Date(t.valueOf() - start.getTimezoneOffset() * 60 * 1000).toJSON();
+			state = new Date(t.valueOf() - t.getTimezoneOffset() * 60 * 1000);
+			var day_class = this.day_class_holiday(state,holidays);
 
 			content += '<div class="calendar_plannerDayScale et2_clickable et2_link '+ day_class+
-				'" data-date=\'' + state +'\''+
+				'" data-date=\'' + state.toJSON() +'\''+
 				(holidays ? ' title="'+holidays.join(',')+'"' : '')+'>'+title+"</div>\n";
 		}
 		content += "</div>";		// end of plannerScale
@@ -1194,6 +1306,51 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 
 		var aoi = new et2_action_object_impl(this,this.getDOMNode());
 
+		/**
+		 * Determine if we allow a dropped event to use the invite/change actions,
+		 * and enable or disable them appropriately
+		 * 
+		 * @param {egwAction} action
+		 * @param {et2_calendar_event} event The event widget being dragged
+		 * @param {egwActionObject} target Planner action object
+		 */
+		var _invite_enabled = function(action, event, target)
+		{
+			var event = event.iface.getWidget();
+			var planner = target.iface.getWidget() || false;
+			//debugger;
+			if(event === planner || !event || !planner ||
+				!event.options || !event.options.value.participants || !planner.options.owner
+			)
+			{
+				return false;
+			}
+			var owner_match = false;
+			var own_row = false;
+
+			for(var id in event.options.value.participants)
+			{
+				planner.iterateOver(function(row) {
+					// Check scroll section or header section
+					if(row.div.hasClass('drop-hover') || row.div.has(':hover'))
+					{
+						owner_match = owner_match || row.node.dataset[planner.options.group_by] === ''+id;
+						own_row = (row === event.getParent());
+					}
+				}, this, et2_calendar_planner_row);
+
+			}
+			var enabled = !owner_match &&
+				// Not inside its own row
+				!own_row;
+
+			widget_object.getActionLink('invite').enabled = enabled;
+			widget_object.getActionLink('change_participant').enabled = enabled;
+
+			// If invite or change participant are enabled, drag is not
+			widget_object.getActionLink('egw_link_drop').enabled = !enabled;
+		};
+
 		aoi.doTriggerEvent = function(_event, _data) {
 
 			// Determine target node
@@ -1290,7 +1447,17 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		var self = this;
 
 		var drop_action = mgr.getActionById('egw_link_drop');
+		var drop_change_participant = mgr.getActionById('change_participant');
+		var drop_invite = mgr.getActionById('invite');
 		var drag_action = mgr.getActionById('egw_link_drag');
+		var paste_action = mgr.getActionById('egw_paste');
+
+		// Disable paste action
+		if(paste_action == null)
+		{
+			paste_action = mgr.addAction('popup', 'egw_paste', egw.lang('Paste'), egw.image('editpaste'), function(){},true);
+		}
+		paste_action.set_enabled(false);
 
 		// Check if this app supports linking
 		if(!egw.link_get_registry(this.dataStorePrefix || 'calendar', 'query') ||
@@ -1350,11 +1517,83 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 					).sendRequest();
 				}
 			},true);
+
+			drop_action.acceptedTypes = ['default','link'];
+			drop_action.hideOnDisabled = true;
+
+			// Create the drop action for moving events between planner rows
+			var invite_action = function(action, source, target) {
+
+				// Extract link IDs
+				var links = [];
+				var id = '';
+				for(var i = 0; i < source.length; i++)
+				{
+					// Check for no ID (invalid) or same manager (dragging an event)
+					if(!source[i].id) continue;
+					if(source[i].manager === target.manager)
+					{
+
+						// Find the row, could have dropped on an event
+						var row = target.iface.getWidget();
+						while(target.parent && row.instanceOf && !row.instanceOf(et2_calendar_planner_row))
+						{
+							target = target.parent;
+							row = target.iface.getWidget();
+						}
+
+						// Leave the helper there until the update is done
+						var loading = action.ui.helper.clone(true).appendTo(jQuery('body'));
+
+						// and add a loading icon so user knows something is happening
+						if(jQuery('.calendar_timeDemo',loading).length == 0)
+						{
+							jQuery('.calendar_calEventHeader',loading).addClass('loading');
+						}
+						else
+						{
+							jQuery('.calendar_timeDemo',loading).after('<div class="loading"></div>');
+						}
+
+						var event_data = egw.dataGetUIDdata(source[i].id).data;
+						et2_calendar_event.recur_prompt(event_data, function(button_id) {
+							if(button_id === 'cancel' || !button_id)
+							{
+								return;
+							}
+							var add_owner = [row.node.dataset.participants];
+
+							egw().json('calendar.calendar_uiforms.ajax_invite', [
+									button_id==='series' ? event_data.id : event_data.app_id,
+									add_owner,
+									action.id === 'change_participant' ?
+										[source[i].iface.getWidget().getParent().node.dataset.participants] :
+										[]
+								],
+								function() { loading.remove();}
+							).sendRequest(true);
+						});
+						// Ok, stop.
+						return false;
+					}
+				}
+			};
+
+			drop_change_participant = mgr.addAction('drop', 'change_participant', egw.lang('Move to'), egw.image('participant'), invite_action,true);
+			drop_change_participant.acceptedTypes = ['calendar'];
+			drop_change_participant.hideOnDisabled = true;
+
+			drop_invite = mgr.addAction('drop', 'invite', egw.lang('Invite'), egw.image('participant'), invite_action,true);
+			drop_invite.acceptedTypes = ['calendar'];
+			drop_invite.hideOnDisabled = true;
 		}
 		if(actionLinks.indexOf(drop_action.id) < 0)
 		{
 			actionLinks.push(drop_action.id);
 		}
+		actionLinks.push(drop_invite.id);
+		actionLinks.push(drop_change_participant.id);
+		
 		// Accept other links, and files dragged from the filemanager
 		// This does not handle files dragged from the desktop.  They are
 		// handled by et2_nextmatch, since it needs DOM stuff
@@ -1379,7 +1618,7 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		{
 			actionLinks.push(drag_action.id);
 		}
-		drag_action.set_dragType('link');
+		drag_action.set_dragType(['link','calendar']);
 	},
 
 	/**
@@ -1393,15 +1632,24 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 	_get_action_links: function(actions)
 	{
 		var action_links = [];
-		// TODO: determine which actions are allowed without an action (empty actions)
+
+		// Only these actions are allowed without a selection (empty actions)
+		var empty_actions = ['add'];
+
 		for(var i in actions)
 		{
 			var action = actions[i];
-			if(action.type === 'drop')
+			if(empty_actions.indexOf(action.id) !== -1 ||  action.type === 'drop')
 			{
 				action_links.push(typeof action.id !== 'undefined' ? action.id : i);
 			}
 		}
+		// Disable automatic paste action, it doesn't have what is needed to work
+		action_links.push({
+			"actionObj": 'egw_paste',
+			"enabled": false,
+			"visible": false
+		});
 		return action_links;
 	},
 
@@ -1511,76 +1759,183 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		var end = new Date(this.options.end_date);
 		do
 		{
-			// Cache is by date (and owner, if seperate)
-			var date = t.getUTCFullYear() + sprintf('%02d',t.getUTCMonth()+1) + sprintf('%02d',t.getUTCDate());
-			var cache_id = app.classes.calendar._daywise_cache_id(date, this.options.owner);
-
-			if(egw.dataHasUID(cache_id))
-			{
-				var c = egw.dataGetUIDdata(cache_id);
-				if(c.data && c.data !== null)
-				{
-					// There is data, pass it along now
-					for(var j = 0; j < c.data.length; j++)
-					{
-						if(last_data.indexOf(c.data[j]) === -1 && egw.dataHasUID('calendar::'+c.data[j]))
-						{
-							value.push(egw.dataGetUIDdata('calendar::'+c.data[j]).data);
-						}
-					}
-					last_data = c.data;
-				}
-			}
-			else
-			{
-				fetch = true;
-				// Assume it's empty, if there is data it will be filled later
-				egw.dataStoreUID(cache_id, []);
-			}
-			this.registeredCallbacks.push(cache_id);
-			egw.dataRegisterUID(cache_id, function(data) {
-				if(data && data.length)
-				{
-					// If displaying by category, we need the infolog (or other app) categories too
-					var im = this.getInstanceManager();
-					for(var i = 0; i < data.length && this.options.group_by == 'category'; i++)
-					{
-						var event = egw.dataGetUIDdata('calendar::'+data[i]);
-						if(event && event.data && event.data.app)
-						{
-							// Fake it to use the cache / call
-							et2_selectbox.cat_options({
-								_type:'select-cat',
-								getInstanceManager: function() {return im;}
-							}, {application:event.data.app||'calendar'});
-
-							// Get CSS too
-							egw.includeCSS('/api/categories.php?app='+event.data.app);
-						}
-					}
-
-					this.invalidate(false);
-				}
-			}, this, this.getInstanceManager().execId,this.id);
+			value = value.concat(this._cache_register(t, this.options.owner, last_data));
 
 			t.setUTCDate(t.getUTCDate() + 1);
 		}
 		while(t < end);
-		// Need to get some more from the server
-		if(fetch && app.calendar)
-		{
-			app.calendar._fetch_data({
-				first: this.options.start_date,
-				last: this.options.end_date,
-				owner: this.options.owner,
-				filter: this.options.filter
-			}, this.getInstanceManager());
-		}
 
 		this.doInvalidate = true;
 		return value;
 	},
 
+	/**
+	 * Deal with registering for data cache
+	 *
+	 * @param Date t
+	 * @param String owner Calendar owner
+	 */
+	_cache_register: function _cache_register(t, owner, last_data)
+	{
+		// Cache is by date (and owner, if seperate)
+		var date = t.getUTCFullYear() + sprintf('%02d',t.getUTCMonth()+1) + sprintf('%02d',t.getUTCDate());
+		var cache_id = app.classes.calendar._daywise_cache_id(date, owner);
+		var value = [];
+
+		if(egw.dataHasUID(cache_id))
+		{
+			var c = egw.dataGetUIDdata(cache_id);
+			if(c.data && c.data !== null)
+			{
+				// There is data, pass it along now
+				for(var j = 0; j < c.data.length; j++)
+				{
+					if(last_data.indexOf(c.data[j]) === -1 && egw.dataHasUID('calendar::'+c.data[j]))
+					{
+						value.push(egw.dataGetUIDdata('calendar::'+c.data[j]).data);
+					}
+				}
+				last_data = c.data;
+			}
+		}
+		else
+		{
+			fetch = true;
+			// Assume it's empty, if there is data it will be filled later
+			egw.dataStoreUID(cache_id, []);
+		}
+		this.registeredCallbacks.push(cache_id);
+
+		egw.dataRegisterUID(cache_id, function(data) {
+
+			if(data && data.length)
+			{
+				var invalidate = true;
+
+				// Try to determine rows interested
+				var labels = [];
+				var events = {};
+				if(this.grouper)
+				{
+					labels = this.grouper.row_labels.call(this);
+					invalidate = false;
+				}
+				
+				var im = this.getInstanceManager();
+				for(var i = 0; i < data.length; i++)
+				{
+					var event = egw.dataGetUIDdata('calendar::'+data[i]);
+
+					if(!event) continue;
+					events = {};
+
+					// Try to determine rows interested
+					if(event.data && this.grouper)
+					{
+						this.grouper.group.call(this, labels, events, event.data);
+					}
+					if(Object.keys(events).length > 0 )
+					{
+						for(var label_id in events)
+						{
+							var id = ""+labels[label_id].id;
+							if(typeof this.cache[id] === 'undefined')
+							{
+								this.cache[id] = [];
+							}
+							if(this.cache[id].indexOf(event.data.row_id) === -1)
+							{
+								this.cache[id].push(event.data.row_id);
+							}
+							if (this._deferred_row_updates[id])
+							{
+								window.clearTimeout(this._deferred_row_updates[id]);
+							}
+							this._deferred_row_updates[id] = window.setTimeout(jQuery.proxy(this._deferred_row_update,this,id),this.DEFERRED_ROW_TIME);
+						}
+					}
+					else
+					{
+						// Could be an event no row is interested in, could be a problem.
+						// Just redraw everything
+						invalidate = true;
+						continue;
+					}
+
+					// If displaying by category, we need the infolog (or other app) categories too
+					if(event && event.data && event.data.app && this.options.group_by == 'category')
+					{
+						// Fake it to use the cache / call
+						et2_selectbox.cat_options({
+							_type:'select-cat',
+							getInstanceManager: function() {return im;}
+						}, {application:event.data.app||'calendar'});
+
+						// Get CSS too
+						egw.includeCSS('/api/categories.php?app='+event.data.app);
+					}
+				}
+
+				if(invalidate)
+				{
+					this.invalidate(false);
+				}
+			}
+		}, this, this.getInstanceManager().execId,this.id);
+		
+		return value;
+	},
+
+	/**
+	 * Because users may be participants in various events and the time it takes
+	 * to create many events, we don't want to update a row too soon - we may have
+	 * to re-draw it if we find the user / category in another event.  Pagination
+	 * makes this worse.  We wait a bit before updating the row to avoid
+	 * having to re-draw it multiple times.
+	 *
+	 * @param {type} id
+	 * @returns {undefined}
+	 */
+	_deferred_row_update: function(id) {
+		// Something's in progress, skip
+		if(!this.doInvalidate) return;
+
+		this.grid.height(0);
+		
+		var id_list = typeof id === 'undefined' ? Object.keys(this.cache) : [id];
+		for(var i = 0; i < id_list.length; i++)
+		{
+			var cache_id = id_list[i];
+			var row = this.getWidgetById('planner_row_'+cache_id);
+
+			window.clearTimeout(this._deferred_row_updates[cache_id]);
+			delete this._deferred_row_updates[cache_id];
+
+			if(row)
+			{
+				row._data_callback(this.cache[cache_id]);
+				row.set_disabled(this.options.hide_empty && this.cache[cache_id].length === 0);
+			}
+			else
+			{
+				break;
+			}
+		}
+
+		// Updating the row may push things longer, update length
+		// Add 1 to keep the scrollbar, otherwise we need to recalculate the
+		// header widths too.
+		this.grid.height(this.rows[0].scrollHeight+1);
+		
+		// Adjust header if there's a scrollbar - Firefox needs this re-calculated,
+		// otherwise the header will be missing the margin space for the scrollbar
+		// in some cases
+		if(this.rows.children().last().length)
+		{
+			this.gridHeader.css('margin-right', (this.rows.width() - this.rows.children().last().width()) + 'px');
+		}
+	},
+
 	/**
 	 * Provide specific data to be displayed.
 	 * This is a way to set start and end dates, owner and event data in once call.
@@ -1593,7 +1948,7 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 	 *	Days should be in order.
 	 *
 	 */
-	set_value: function(events)
+	set_value: function set_value(events)
 	{
 		if(typeof events !== 'object') return false;
 
@@ -1640,7 +1995,7 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 	 * @param {string|number} group_by 'user', 'month', or an integer category ID
 	 * @returns {undefined}
 	 */
-	set_group_by: function(group_by)
+	set_group_by: function set_group_by(group_by)
 	{
 		if(isNaN(group_by) && typeof this.groupers[group_by] === 'undefined')
 		{
@@ -1649,6 +2004,8 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		var old = this.options.group_by;
 		this.options.group_by = ''+group_by;
 
+		this.grouper = this.groupers[isNaN(this.options.group_by) ? this.options.group_by : 'category'];
+		
 		if(old !== this.options.group_by && this.isAttached())
 		{
 			this.invalidate(true);
@@ -1660,7 +2017,7 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 	 *
 	 * @param {boolean} weekends
 	 */
-	set_show_weekend: function(weekends)
+	set_show_weekend: function set_show_weekend(weekends)
 	{
 		weekends = weekends ? true : false;
 		if(this.options.show_weekend !== weekends)
@@ -1673,6 +2030,16 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		}
 	},
 
+	/**
+	 * Turn on or off the visibility of hidden (empty) rows
+	 *
+	 * @param {boolean} hidden
+	 */
+	set_hide_empty: function set_hide_empty(hidden)
+	{
+		this.options.hide_empty = hidden;
+	},
+
 	/**
 	 * Call change handler, if set
 	 *
@@ -1742,6 +2109,9 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 	{
 		var result = true;
 
+		// Drag to create in progress
+		if(this.drag_create.start !== null) return;
+		
 		// Is this click in the event stuff, or in the header?
 		if(!this.options.readonly && this.gridHeader.has(_ev.target).length === 0 && !jQuery(_ev.target).hasClass('calendar_plannerRowHeader'))
 		{
@@ -1766,7 +2136,12 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 			{
 				// Clicked in row, but not on an event
 				// Default handler to open a new event at the selected time
-				if(this.options.group_by == 'month')
+				if(jQuery(event.target).closest('.calendar_eventRows').length == 0)
+				{
+					// "Invalid" times, from space after the last planner row, or header
+					var date = this._get_time_from_position(_ev.pageX - this.grid.offset().left, _ev.pageY - this.grid.offset().top);
+				}
+				else if(this.options.group_by == 'month')
 				{
 					var date = this._get_time_from_position(_ev.clientX, _ev.clientY);
 				}
@@ -1824,6 +2199,9 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 
 		x = Math.round(x);
 		y = Math.round(y);
+		
+		// Round to user's preferred event interval
+		var interval = egw.preference('interval','calendar') || 30;
 
 		// Relative horizontal position, as a percentage
 		var rel_x = Math.min(x / jQuery('.calendar_eventRows',this.div).width(),1);
@@ -1831,16 +2209,65 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		// Relative time, in minutes from start
 		var rel_time = 0;
 
+		var day_header = jQuery('.calendar_plannerScaleDay',this.headers);
+
 		// Simple math, the x is offset from start date
-		if(this.options.group_by !== 'month')
+		if(this.options.group_by !== 'month' && (
+			// Either all days are visible, or only 1 day (no day header)
+			this.options.show_weekend || day_header.length === 0
+		))
 		{
 			rel_time = (new Date(this.options.end_date) - new Date(this.options.start_date))*rel_x/1000;
 			this.date_helper.set_value(this.options.start_date.toJSON());
 		}
+		// Not so simple math, need to account for missing days
+		else if(this.options.group_by !== 'month' && !this.options.show_weekend)
+		{
+			// Find which day
+			if(day_header.length === 0) return false;
+			var day = document.elementFromPoint(
+				day_header.offset().left + rel_x * this.headers.innerWidth(),
+				day_header.offset().top
+			);
+
+			// Use day, and find time in that day
+			if(day && day.dataset && day.dataset.date)
+			{
+				this.date_helper.set_value(day.dataset.date);
+				rel_time = ((x - jQuery(day).position().left) / jQuery(day).outerWidth(true)) * 24*60;
+				this.date_helper.set_minutes(Math.round(rel_time/interval) * interval);
+				return new Date(this.date_helper.getValue());
+			}
+			return false;
+		}
 		else
 		{
 			// Find the correct row so we know which month, then get the offset
-			var row = jQuery(document.elementFromPoint(x, y)).closest('.calendar_plannerRowWidget');
+			var hidden_nodes = [];
+			var row = null;
+			// Hide any drag or tooltips that may interfere
+			do
+			{
+				row = document.elementFromPoint(x, y);
+				if(this.div.has(row).length == 0)
+				{
+					hidden_nodes.push(jQuery(row).hide());
+				}
+				else
+				{
+					break;
+				}
+			} while(row && row.nodeName !== 'BODY');
+			if(!row) return false;
+			
+			// Restore hidden nodes
+			for(var i = 0; i < hidden_nodes.length; i++)
+			{
+				hidden_nodes[i].show();
+			}
+			row = jQuery(row).closest('.calendar_plannerRowWidget');
+
+
 			var row_widget = null;
 			for(var i = 0; i < this._children.length && row.length > 0; i++)
 			{
@@ -1867,12 +2294,74 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		}
 		if(rel_time < 0) return false;
 
-		var interval = egw.preference('interval','calendar') || 30;
 		this.date_helper.set_minutes(Math.round(rel_time / (60 * interval))*interval);
 
 		return new Date(this.date_helper.getValue());
 	},
 
+	/**
+	 * Mousedown handler to support drag to create
+	 *
+	 * @param {jQuery.Event} event
+	 */
+	_mouse_down: function(event)
+	{
+		// Only left mouse button
+		if(event.which !== 1) return;
+		
+		// Ignore headers
+		if(this.headers.has(event.target).length !== 0) return false;
+		
+		// Get time at mouse
+		if(this.options.group_by === 'month')
+		{
+			var time = this._get_time_from_position(event.clientX, event.clientY);
+		}
+		else
+		{
+			var time = this._get_time_from_position(event.offsetX, event.offsetY);
+		}
+		if(!time) return false;
+
+		// Find the correct row so we know the parent
+		var row = event.target.closest('.calendar_plannerRowWidget');
+		for(var i = 0; i < this._children.length && row; i++)
+		{
+			if(this._children[i].div[0] === row)
+			{
+				this.drag_create.parent = this._children[i];
+				// Clear cached events for re-layout
+				this._children[i]._cached_rows = [];
+				break;
+			}
+		}
+		if(!this.drag_create.parent) return false;
+
+		this.div.css('cursor', 'ew-resize');
+
+		return this._drag_create_start(jQuery.extend({},this.drag_create.parent.node.dataset,{date: time.toJSON()}));
+	},
+
+	/**
+	 * Mouseup handler to support drag to create
+	 *
+	 * @param {jQuery.Event} event
+	 */
+	_mouse_up: function(event)
+	{
+		// Get time at mouse
+		if(this.options.group_by === 'month')
+		{
+			var time = this._get_time_from_position(event.clientX, event.clientY);
+		}
+		else
+		{
+			var time = this._get_time_from_position(event.offsetX, event.offsetY);
+		}
+
+		return this._drag_create_end(time ? {date: time.toJSON()} : false);
+	},
+
 	/**
 	 * Code for implementing et2_IDetachedDOM
 	 *
@@ -1912,6 +2401,39 @@ var et2_calendar_planner = (function(){ "use strict"; return et2_calendar_view.e
 		this.div.css('height', this.options.height);
 		// Set height for rows
 		this.rows.height(this.div.height() - this.headers.outerHeight());
+		
+		this.grid.height(this.rows[0].scrollHeight);
+	},
+
+	/**
+	 * Set up for printing
+	 *
+	 * @return {undefined|Deferred} Return a jQuery Deferred object if not done setting up
+	 *  (waiting for data)
+	 */
+	beforePrint: function() {
+
+		if(this.disabled || !this.div.is(':visible'))
+		{
+			return;
+		}
+		this.rows.css('overflow-y', 'visible');
+
+		var rows = jQuery('.calendar_eventRows');
+		var width = rows.width();
+		var events = jQuery('.calendar_calEvent', rows)
+				.each(function() {
+					var event = jQuery(this);
+					event.width((event.width() / width) * 100 + '%')
+				});
+
+	},
+
+	/**
+	 * Reset after printing
+	 */
+	afterPrint: function() {
+		this.rows.css('overflow-y', 'auto');
 	}
 });}).call(this);
-et2_register_widget(et2_calendar_planner, ["calendar-planner"]);
\ No newline at end of file
+et2_register_widget(et2_calendar_planner, ["calendar-planner"]);
