@@ -22,7 +22,7 @@
  *
  * @augments et2_valueWidget
  */
-var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget.extend([et2_IDetachedDOM],
+var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget.extend([et2_IResizeable],
 {
 	attributes: {
 		start_date: {
@@ -66,6 +66,8 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 		this.set_start_date(this.options.start_date);
 		this.set_end_date(this.options.end_date);
 
+		this._cached_rows = [];
+		this._row_height = 20;
 	},
 
 	doLoadingFinished: function() {
@@ -73,6 +75,8 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 
 		this.set_label(this.options.label);
 		this._draw();
+		
+		this._link_actions([]);
 		return true;
 	},
 
@@ -96,6 +100,224 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 		}
 	},
 
+	/**
+	 * Link the actions to the DOM nodes / widget bits.
+	 *
+	 * @param {object} actions {ID: {attributes..}+} map of egw action information
+	 */
+	_link_actions: function(actions)
+	{
+		// Get the parent?  Might be a grid row, might not.  Either way, it is
+		// just a container with no valid actions
+		var objectManager = egw_getObjectManager(this.getInstanceManager().app,true,1);
+		objectManager = objectManager.getObjectById(this.getInstanceManager().uniqueId,2) || objectManager;
+		var parent = objectManager.getObjectById(this.id,1) || objectManager.getObjectById(this._parent.id,1) || objectManager;
+		if(!parent)
+		{
+			egw.debug('error','No parent objectManager found');
+			return;
+		}
+
+		// This binds into the egw action system.  Most user interactions (drag to move, resize)
+		// are handled internally using jQuery directly.
+		var widget_object = this._actionObject || parent.getObjectById(this.id);
+		var aoi = new et2_action_object_impl(this,this.getDOMNode());
+		var planner = this.getParent();
+
+		for(var i = 0; i < parent.children.length; i++)
+		{
+			var parent_finder = jQuery(parent.children[i].iface.doGetDOMNode()).find(this.div);
+			if(parent_finder.length > 0)
+			{
+				parent = parent.children[i];
+				break;
+			}
+		}
+		
+		// Determine if we allow a dropped event to use the invite/change actions
+		var _invite_enabled = function(action, event, target)
+		{
+			var event = event.iface.getWidget();
+			var row = target.iface.getWidget() || false;
+			if(event === row || !event || !row ||
+				!event.options || !event.options.value.participants
+			)
+			{
+				return false;
+			}
+			
+			var owner_match = false;
+			var own_row = event.getParent() === row;
+
+			for(var id in event.options.value.participants)
+			{
+				owner_match = owner_match || row.node.dataset.participants === ''+id;
+			}
+
+			var enabled = !owner_match &&
+				// Not inside its own timegrid
+				!own_row;
+
+			widget_object.getActionLink('invite').enabled = enabled;
+			widget_object.getActionLink('change_participant').enabled = enabled;
+
+			// If invite or change participant are enabled, drag is not
+			widget_object.getActionLink('egw_link_drop').enabled = !enabled;
+		};
+
+		aoi.doTriggerEvent = function(_event, _data) {
+
+			// Determine target node
+			var event = _data.event || false;
+			if(!event) return;
+			if(_data.ui.draggable.hasClass('rowNoEdit')) return;
+			/*
+			We have to handle the drop in the normal event stream instead of waiting
+			for the egwAction system so we can get the helper, and destination
+			*/
+			if(event.type === 'drop' && widget_object.getActionLink('egw_link_drop').enabled)
+			{
+				this.getWidget().getParent()._event_drop.call(
+					jQuery('.calendar_d-n-d_timeCounter',_data.ui.helper)[0],
+					this.getWidget().getParent(), event, _data.ui,
+					this.getWidget()
+				);
+			}
+			var drag_listener = function(_event, ui) {
+				if(planner.options.group_by === 'month')
+				{
+					var position = {left: _event.clientX, top: _event.clientY};
+				}
+				else
+				{
+					var position = {top:ui.position.top, left: ui.position.left - jQuery(this).parent().offset().left};
+				}
+				aoi.getWidget().getParent()._drag_helper(
+					jQuery('.calendar_d-n-d_timeCounter',ui.helper)[0],
+					position,0
+				);
+
+				var event = _data.ui.draggable.data('selected')[0];
+				if(!event || event.id && event.id.indexOf('calendar') !== 0)
+				{
+					event = false;
+				}
+				if(event)
+				{
+					_invite_enabled(
+						widget_object.getActionLink('invite').actionObj,
+						event,
+						widget_object
+					);
+				}
+			};
+			var time = jQuery('.calendar_d-n-d_timeCounter',_data.ui.helper);
+			switch(_event)
+			{
+				// Triggered once, when something is dragged into the timegrid's div
+				case EGW_AI_DRAG_OVER:
+					// Listen to the drag and update the helper with the time
+					// This part lets us drag between different timegrids
+					_data.ui.draggable.on('drag.et2_timegrid_row'+widget_object.id, drag_listener);
+					_data.ui.draggable.on('dragend.et2_timegrid_row'+widget_object.id, function() {
+						_data.ui.draggable.off('drag.et2_timegrid_row' + widget_object.id);
+					});
+					widget_object.iface.getWidget().div.addClass('drop-hover');
+
+					// Disable invite / change actions for same calendar or already participant
+					var event = _data.ui.draggable.data('selected')[0];
+					if(!event || event.id && event.id.indexOf('calendar') !== 0)
+					{
+						event = false;
+					}
+					if(event)
+					{
+						_invite_enabled(
+							widget_object.getActionLink('invite').actionObj,
+							event,
+							widget_object
+						);
+					}
+					if(time.length)
+					{
+						// The out will trigger after the over, so we count
+						time.data('count',time.data('count')+1);
+					}
+					else
+					{
+						_data.ui.helper.prepend('<div class="calendar_d-n-d_timeCounter" data-count="1"><span></span></div>');
+					}
+
+
+					break;
+
+				// Triggered once, when something is dragged out of the timegrid
+				case EGW_AI_DRAG_OUT:
+					// Stop listening
+					_data.ui.draggable.off('drag.et2_timegrid_row'+widget_object.id);
+					// Remove highlight
+					widget_object.iface.getWidget().div.removeClass('drop-hover');
+					
+					// Out triggers after the over, count to not accidentally remove
+					time.data('count',time.data('count')-1);
+					if(time.length && time.data('count') <= 0)
+					{
+						time.remove();
+					}
+					break;
+			}
+		};
+
+		if (widget_object == null) {
+			// Add a new container to the object manager which will hold the widget
+			// objects
+			widget_object = parent.insertObject(false, new egwActionObject(
+				this.id, parent, aoi,
+				this._actionManager|| parent.manager.getActionById(this.id) || parent.manager
+			));
+		}
+		else
+		{
+			widget_object.setAOI(aoi);
+		}
+		this._actionObject = widget_object;
+
+		// Delete all old objects
+		widget_object.clear();
+		widget_object.unregisterActions();
+
+		// Go over the widget & add links - this is where we decide which actions are
+		// 'allowed' for this widget at this time
+		var action_links = this._get_action_links(actions);
+
+		this.getParent()._init_links_dnd(widget_object.manager, action_links);
+
+		widget_object.updateActionLinks(action_links);
+	},
+
+	/**
+	 * Get all action-links / id's of 1.-level actions from a given action object
+	 *
+	 * Here we are only interested in drop events.
+	 *
+	 * @param actions
+	 * @returns {Array}
+	 */
+	_get_action_links: function(actions)
+	{
+		var action_links = [];
+		// TODO: determine which actions are allowed without an action (empty actions)
+		for(var i in actions)
+		{
+			var action = actions[i];
+			if(action.type == 'drop')
+			{
+				action_links.push(typeof action.id != 'undefined' ? action.id : i);
+			}
+		}
+		return action_links;
+	},
+
 	/**
 	 * Draw the individual divs for weekends and events
 	 */
@@ -213,6 +435,39 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 		return content;
 	},
 
+	/**
+	 * Callback used when the daywise data changes
+	 *
+	 * Events should update themselves when their data changes, here we are
+	 * dealing with a change in which events are displayed on this row.
+	 *
+	 * @param {String[]} event_ids
+	 * @returns {undefined}
+	 */
+	_data_callback: function(event_ids) {
+		var events = [];
+		if(event_ids == null || typeof event_ids.length == 'undefined') event_ids = [];
+		for(var i = 0; i < event_ids.length; i++)
+		{
+			var event = egw.dataGetUIDdata('calendar::'+event_ids[i]);
+			event = event && event.data || false;
+			if(event && event.date)
+			{
+				events.push(event);
+			}
+			else if (event)
+			{
+				// Got an ID that doesn't belong
+				event_ids.splice(i--,1);
+			}
+		}
+		if(!this._parent.disabled)
+		{
+			this.resize();
+			this._update_events(events);
+		}
+	},
+
 	/**
 	 * Load the event data for this day and create event widgets for each.
 	 *
@@ -223,10 +478,11 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 	_update_events: function(events)
 	{
 		// Remove all events
-		while(this._children.length)
+		while(this._children.length > 0)
 		{
-			this._children[this._children.length-1].free();
-			this.removeChild(this._children[this._children.length-1]);
+			var node = this._children[this._children.length-1];
+			this.removeChild(node);
+			node.free();
 		}
 		this._cached_rows = [];
 
@@ -260,9 +516,14 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 	position_event: function(event)
 	{
 		var rows = this._spread_events();
-		var row = jQuery('<div class="calendar_plannerEventRowWidget"></div>').appendTo(this.rows);
-		var height = rows.length * (parseInt(window.getComputedStyle(row[0]).getPropertyValue("height")) || 20);
-		row.remove();
+		var height = rows.length * this._row_height;
+		var row_width = this.rows.width();
+		if(row_width == 0)
+		{
+			// Not rendered yet or something
+			row_width = this.getParent().gridHeader.width() - this.title.width()
+		}
+		row_width -= 15;
 
 		for(var c = 0; c < rows.length; c++)
 		{
@@ -279,7 +540,7 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 				rows[c][i].div.css('top', top+'%');
 				rows[c][i].div.css('height', (100/rows.length)+'%');
 				rows[c][i].div.css('left', left.toFixed(1)+'%');
-				rows[c][i].div.outerWidth(width/100 *this.rows.width() +'px');
+				rows[c][i].div.outerWidth((width/100 * row_width) +'px');
 			}
 		}
 		if(height)
@@ -355,13 +616,13 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 					day_start -= daylight_diff;
 				}
 
-				event['start_m'] = parseInt((event.start.valueOf()/1000 - day_start) / 60);
+				event['start_m'] = event.start.getUTCHours() * 60 + event.start.getUTCMinutes();
 				if (event['start_m'] < 0)
 				{
 					event['start_m'] = 0;
 					event['multiday'] = true;
 				}
-				event['end_m'] = parseInt((event.end.valueOf()/1000 - day_start) / 60);
+				event['end_m'] = event.end.getUTCHours() * 60 + event.end.getUTCMinutes();
 				if (event['end_m'] >= 24*60)
 				{
 					event['end_m'] = 24*60-1;
@@ -487,21 +748,26 @@ var et2_calendar_planner_row = (function(){ "use strict"; return et2_valueWidget
 		return pos;
 	},
 
+	// Resizable interface
 	/**
-	 * Code for implementing et2_IDetachedDOM
+	 * Resize
 	 *
-	 * @param {array} _attrs array to add further attributes to
+	 * Parent takes care of setting proper width & height for the containing div
+	 * here we just need to adjust the events to fit the new size.
 	 */
-	getDetachedAttributes: function(_attrs) {
+	resize: function ()
+	{
+		if(this.disabled || !this.div.is(':visible') || this._parent.disabled)
+		{
+			return;
+		}
 
-	},
-
-	getDetachedNodes: function() {
-		return [this.getDOMNode()];
-	},
-
-	setDetachedAttributes: function(_nodes, _values) {
+		var row = jQuery('<div class="calendar_plannerEventRowWidget"></div>').appendTo(this.rows);
+		this._row_height = (parseInt(window.getComputedStyle(row[0]).getPropertyValue("height")) || 20);
+		row.remove();
 
+		// Resize & position all events
+		this.position_event();
 	}
 
 });}).call(this);
