@@ -108,7 +108,7 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 			.appendTo(this.scrolling);
 
 		// Used for owners
-		this.owner = et2_createWidget('select-account_ro',{},this);
+		this.owner = et2_createWidget('description',{},this);
 
 		this._labelContainer = jQuery(document.createElement("label"))
 			.addClass("et2_label et2_link")
@@ -132,7 +132,7 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 	destroy: function() {
 
 		// Stop listening to tab changes
-		if(framework.getApplicationByName('calendar').tab)
+		if(typeof framework !== 'undefined' && framework.getApplicationByName('calendar').tab)
 		{
 			jQuery(framework.getApplicationByName('calendar').tab.contentDiv).off('show.' + this.id);
 		}
@@ -164,7 +164,7 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 		this._super.apply(this, arguments);
 
 		// Listen to tab show to make sure we scroll to the day start, not top
-		if(framework.getApplicationByName('calendar').tab)
+		if(typeof framework !== 'undefined' && framework.getApplicationByName('calendar').tab)
 		{
 			jQuery(framework.getApplicationByName('calendar').tab.contentDiv)
 				.on('show.' + this.id, jQuery.proxy(
@@ -230,6 +230,21 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 					}
 				},
 
+				/**
+				 * If dragging to resize an event, abort drag to create
+				 *
+				 * @param {jQuery.Event} event
+				 * @param {Object} ui
+				 */
+				start: function(event, ui)
+				{
+					if(timegrid.drag_create.start)
+					{
+						// Abort drag to create, we're dragging to resize
+						timegrid._drag_create_end({});
+					}
+				},
+
 				/**
 				 * Triggered at the end of resizing the calEvent.
 				 *
@@ -306,6 +321,10 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 					.css('top', '').css('left','')
 					.appendTo(ui.helper);
 				ui.helper.width(jQuery(this).width());
+
+				// Cancel drag to create, we're dragging an existing event
+ 				timegrid.drag_create.start = null;
+ 				timegrid._drag_create_end();
 			})
 			.on('mousemove', function(event) {
 				timegrid._get_time_from_position(event.clientX, event.clientY);
@@ -315,7 +334,9 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 				{
 					timegrid.gridHover.hide();
 				}
-			});
+			})
+			.on('mousedown', jQuery.proxy(this._mouse_down, this))
+			.on('mouseup', jQuery.proxy(this._mouse_up, this));
 		return true;
 	},
 
@@ -913,22 +934,13 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 			this.day_widgets.splice(delete_index--,1);
 		}
 
+		this.set_header_classes();
+
 		// Create / update day widgets with dates and data
 		for(var i = 0; i < this.day_widgets.length; i++)
 		{
 			day = this.day_widgets[i];
 
-			// Classes
-			if(app.calendar && app.calendar.state &&
-				this.day_list[i] && parseInt(this.day_list[i].substr(4,2)) !== new Date(app.calendar.state.date).getUTCMonth()+1)
-			{
-				day.set_class('calendar_differentMonth');
-			}
-			else
-			{
-				day.set_class('');
-			}
-
 			// Position
 			day.set_left((day_width * i) + 'px');
 			if(this.daily_owner)
@@ -978,6 +990,30 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 		*/
 	},
 
+	/**
+	 * Set header classes
+	 *
+	 */
+	set_header_classes: function()
+	{
+		var day;
+		for(var i = 0; i < this.day_widgets.length; i++)
+		{
+			day = this.day_widgets[i];
+
+			// Classes
+			if(app.calendar && app.calendar.state &&
+				this.day_list[i] && parseInt(this.day_list[i].substr(4,2)) !== new Date(app.calendar.state.date).getUTCMonth()+1)
+			{
+				day.set_class('calendar_differentMonth');
+			}
+			else
+			{
+				day.set_class('');
+			}
+		}
+	},
+
 	/**
 	 * Update UI while scrolling within the selected time
 	 *
@@ -1069,8 +1105,14 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 			var event = event.iface.getWidget();
 			var timegrid = target.iface.getWidget() || false;
 			if(event === timegrid || !event || !timegrid ||
-				!event.options || !event.options.value.participants || !timegrid.options.owner ) return false;
+				!event.options || !event.options.value.participants || !timegrid.options.owner
+			)
+			{
+				return false;
+			}
 			var owner_match = false;
+			var own_timegrid = event.getParent().getParent() === timegrid && !timegrid.daily_owner;
+
 			for(var id in event.options.value.participants)
 			{
 				if(!timegrid.daily_owner)
@@ -1089,11 +1131,15 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 						if(col.div.has(timegrid.gridHover).length || col.header.has(timegrid.gridHover).length)
 						{
 							owner_match = owner_match || col.options.owner.indexOf(id) !== -1;
+							own_timegrid = (col === event.getParent());
 						}
 					}, this, et2_calendar_daycol);
 				}
 			}
-			var enabled = !owner_match;
+			var enabled = !owner_match && 
+				// Not inside its own timegrid
+				!own_timegrid;
+				
 			widget_object.getActionLink('invite').enabled = enabled;
 			widget_object.getActionLink('change_participant').enabled = enabled;
 
@@ -1229,6 +1275,9 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 	 * @param {type} actionLinks
 	 */
 	_init_links_dnd: function(mgr,actionLinks) {
+
+		if (this.options.readonly) return;
+		
 		var self = this;
 
 		var drop_link = mgr.getActionById('egw_link_drop');
@@ -1555,17 +1604,7 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 		if(typeof _owner == 'string' && isNaN(_owner))
 		{
 			this.set_label('');
-			switch(_owner[0])
-			{
-				case 'c':
-					this.owner.options.application = 'addressbook';
-					this.owner.set_value(_owner.substr(1));
-					break;
-				case 'r':
-					this.owner.options.application = 'resources';
-					this.owner.set_value(_owner.substr(1));
-					break;
-			}
+			this.owner.set_value(this._get_owner_name(_owner));
 
 			// Label is empty, but give extra space for the owner name
 			this.div.removeClass('calendar_TimeGridNoLabel');
@@ -1584,7 +1623,7 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 		else
 		{
 			this.owner.options.application = 'api-accounts';
-			this.owner.set_value(typeof _owner == "string" || typeof _owner == "number" ? _owner : jQuery.extend([],_owner));
+			this.owner.set_value(this._get_owner_name(_owner));
 			this.set_label('');
 			jQuery(this.getDOMNode(this.owner)).prepend(this.owner.getDOMNode());
 		}
@@ -1751,6 +1790,13 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 	click: function(_ev)
 	{
 		var result = true;
+		if(this.options.readonly ) return;
+		
+		// Drag to create in progress
+		if(this.drag_create.start !== null) return;
+
+		// Drag to create in progress
+		if(this.drag_create.start !== null) return;
 
 		// Is this click in the event stuff, or in the header?
 		if(_ev.target.dataset.id || jQuery(_ev.target).parents('.calendar_calEvent').length)
@@ -1795,6 +1841,11 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 					_ev.target.dataset
 			));
 		}
+		else if (this.options.owner.length === 1 && jQuery(this.owner.getDOMNode()).is(_ev.target))
+		{
+			// Click on the owner in header, show just that owner
+			app.calendar.update_state({owner: this.options.owner});
+		}
 		else if (this.dayHeader.has(_ev.target).length)
 		{
 			// Click on a day header - let day deal with it
@@ -1819,17 +1870,123 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 			var options = {
 				date: target.dataset.date || this.options.date,
 				hour: target.dataset.hour || this._parent.options.day_start,
-				minute: target.dataset.minute || 0
+				minute: target.dataset.minute || 0,
+				owner: this.options.owner
 			};
-			if (this.options.owner != app.calendar.state.owner)
-			{
-				options.owner = this.options.owner;
-			}
 			this.egw().open(null, 'calendar', 'add', options, '_blank');
 			return false;
 		}
 	},
 
+	/**
+	 * Mousedown handler to support drag to create
+	 *
+	 * @param {jQuery.Event} event
+	 */
+	_mouse_down: function(event)
+	{
+		if(event.which !== 1) return;
+
+		if (this.options.readonly) return;
+		
+		var start = jQuery.extend({},this.gridHover[0].dataset);
+		if(start.date)
+		{
+			// Set parent for event
+			if(this.daily_owner)
+			{
+				// Each 'day' is the same date, different user
+				// Find the correct row so we know the parent
+				var col = event.target.closest('.calendar_calDayCol');
+				for(var i = 0; i < this._children.length && col; i++)
+				{
+					if(this._children[i].node === col)
+					{
+						this.drag_create.parent = this._children[i];
+						break;
+					}
+				}
+			}
+			else
+			{
+				this.drag_create.parent = this.getWidgetById(start.date);
+			}
+
+			// Format date
+			this.date_helper.set_year(start.date.substring(0,4));
+			this.date_helper.set_month(start.date.substring(4,6));
+			this.date_helper.set_date(start.date.substring(6,8));
+			if(start.hour)
+			{
+				this.date_helper.set_hours(start.hour);
+			}
+			if(start.minute)
+			{
+				this.date_helper.set_minutes(start.minute);
+			}
+			start.date = this.date_helper.get_value();
+
+			this.gridHover.css('cursor', 'ns-resize');
+
+			// Start update
+			var timegrid = this;
+			this.div.on('mousemove.dragcreate', function()
+			{
+				if(timegrid.drag_create.event && timegrid.drag_create.parent && timegrid.drag_create.end)
+				{
+					var end = jQuery.extend({}, timegrid.gridHover[0].dataset);
+					if(end.date)
+					{
+						timegrid.date_helper.set_year(end.date.substring(0,4));
+						timegrid.date_helper.set_month(end.date.substring(4,6));
+						timegrid.date_helper.set_date(end.date.substring(6,8));
+						if(end.hour)
+						{
+							timegrid.date_helper.set_hours(end.hour);
+						}
+						if(end.minute)
+						{
+							timegrid.date_helper.set_minutes(end.minute);
+						}
+						timegrid.drag_create.end.date = timegrid.date_helper.get_value();
+					}
+					timegrid._drag_update_event();
+				}
+			});
+		}
+		return this._drag_create_start(start);
+	},
+
+	/**
+	 * Mouseup handler to support drag to create
+	 *
+	 * @param {jQuery.Event} event
+	 */
+	_mouse_up: function(event)
+	{
+		if (this.options.readonly) return;
+		var end = jQuery.extend({}, this.gridHover[0].dataset);
+		if(end.date)
+		{
+			this.date_helper.set_year(end.date.substring(0,4));
+			this.date_helper.set_month(end.date.substring(4,6));
+			this.date_helper.set_date(end.date.substring(6,8));
+			if(end.hour)
+			{
+				this.date_helper.set_hours(end.hour);
+			}
+			if(end.minute)
+			{
+				this.date_helper.set_minutes(end.minute);
+			}
+			end.date = this.date_helper.get_value();
+		}
+		this.div.off('mousemove.dragcreate');
+		this.gridHover.css('cursor', '');
+
+		return this._drag_create_end(end);
+	},
+
 	/**
 	 * Get time from position for drag and drop
 	 *
@@ -1862,6 +2019,10 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 		for(var id in this.gridHover[0].dataset) {
 			delete this.gridHover[0].dataset[id];
 		}
+		if(this.options.granularity == 0)
+		{
+			this.gridHover.css('height','');
+		}
 		while(node && node != this.node && node.tagName != 'BODY' && path.length < 10)
 		{
 			path.push(node);
@@ -1875,9 +2036,14 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 					position: 'absolute',
 					top: '',
 					bottom: '0px',
-					height: $node.css('padding-bottom')
+					// Use 100% height if we're hiding the day labels to avoid
+					// any remaining space from the hidden labels
+					height: $node.height() > parseInt($node.css('line-height')) ?
+						$node.css('padding-bottom') : '100%'
 				});
 				day = node;
+				this.gridHover
+					.attr('data-non_blocking','true');
 				break;
 			}
 			if($node.hasClass('calendar_calDayCol'))
@@ -2023,6 +2189,9 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 
 		// Try to resize width, though animations cause problems
 		var total_width = jQuery(this.getInstanceManager().DOMContainer).parent().innerWidth() - this.days.position().left;
+		// Space for todos, if there
+		total_width -= jQuery(this.getInstanceManager().DOMContainer).siblings().has(':visible').not('#calendar-toolbar').outerWidth()
+		
 		var day_width = (total_width > 0 ? total_width : jQuery(this.getInstanceManager().DOMContainer).width())/this.day_widgets.length;
 		// update day widgets
 		for(var i = 0; i < this.day_widgets.length; i++)
@@ -2107,4 +2276,4 @@ var et2_calendar_timegrid = (function(){ "use strict"; return et2_calendar_view.
 		}
 	}
 });}).call(this);
-et2_register_widget(et2_calendar_timegrid, ["calendar-timegrid"]);
\ No newline at end of file
+et2_register_widget(et2_calendar_timegrid, ["calendar-timegrid"]);
