@@ -40,7 +40,7 @@ $config = array(
 	'aliasdir' => 'egroupware',             // directory created by the alias
 	'types' => array('tar.bz2','tar.gz','zip','all.tar.bz2'),
 	// add given extra-apps or (uncompressed!) archives to above all.tar.bz2 archive
-	'all-add' => array('contrib', '/home/stylite/epl-trunk/phpfreechat_data_public.tar'),
+	'all-add' => array('contrib', '/home/stylite/epl-16.1/phpfreechat_data_public.tar'),
 	// diverse binaries we need
 	'svn' => trim(`which svn`),
 	'tar' => trim(`which tar`),
@@ -55,10 +55,10 @@ $config = array(
 	'gpg' => trim(`which gpg`),
 	'editor' => trim(`which vi`),
 	'rsync' => trim(`which rsync`).' --progress -e ssh --exclude "*-stylite-*" --exclude "*-esyncpro-*"',
-	'composer' => ($composer=trim(`which composer.phar`)) ? $composer.' install --ignore-platform-reqs' : '',
+	'composer' => ($composer=trim(`which composer.phar`)) ? $composer.' install --ignore-platform-reqs --no-dev' : '',
 	'after-checkout' => 'rm -rf */source */templates/*/source',
 	'packager' => 'build@stylite.de',
-	'obs' => '/home/stylite/obs/stylite-epl-trunk',
+	'obs' => '/home/stylite/obs/stylite-epl',
 	'obs_package_alias' => '',	// name used in obs package, if different from packagename
 	'changelog' => false,   // eg. '* 1. Zeile\n* 2. Zeile' for debian.changes
 	'changelog_packager' => 'Ralf Becker <rb@stylite.de>',
@@ -263,7 +263,7 @@ function get_modules_per_repo()
 		}
 		if ($line && $line[0] == '[' && preg_match('/^\[([^]]*)\]/', $line, $matches))
 		{
-			if (in_array($matches[1], array('DEFAULT', 'api/js/ckeditor', 'api/src/Accounts/Ads', 'phpgwapi/js/ckeditor', 'phpgwapi/inc/adldap')))
+			if (in_array($matches[1], array('DEFAULT', 'vendor/egroupware/ckeditor', 'api/src/Accounts/Ads', 'phpgwapi/js/ckeditor', 'phpgwapi/inc/adldap')))
 			{
 				$module = null;
 				continue;
@@ -595,13 +595,16 @@ function do_editchangelog()
 		throw new Exception("Changelog '$changelog' not found!");
 	}
 	file_put_contents($changelog, update_changelog(file_get_contents($changelog)));
+
+	update_api_setup($api_setup=$config['checkoutdir'].'/api/setup/setup.inc.php');
+
 	if (file_exists($config['checkoutdir'].'/.git'))
 	{
-		$cmd = $config['git']." commit -m 'Changelog for $config[version].$config[packaging]' ".$changelog;
+		$cmd = $config['git']." commit -m 'Changelog for $config[version].$config[packaging]' ".$changelog.' '.$api_setup;
 	}
 	else
 	{
-		$cmd = $svn." commit -m 'Changelog for $config[version].$config[packaging]' ".$changelog;
+		$cmd = $svn." commit -m 'Changelog for $config[version].$config[packaging]' ".$changelog.' '.$api_setup;
 	}
 	run_cmd($cmd);
 
@@ -755,7 +758,7 @@ function do_obs($only_update_changelog=false)
 		if (basename(dirname($path)) == '.osc' ||
 			!preg_match('/\/('.preg_quote($config['packagename']).
 				($config['obs_package_alias'] ? '|'.preg_quote($config['obs_package_alias']) : '').
-				')[a-z-]*-('.preg_quote($config['version']).'|14.2|trunk)/',$path))
+				')[a-z-]*-('.preg_quote($config['version']).'|trunk)/',$path))
 		{
 			continue;
 		}
@@ -875,6 +878,30 @@ function update_changelog($content)
 	return $content;
 }
 
+/**
+ * Update content of api/setup/setup.inc.php file with new maintenance version
+ *
+ * @param string $path full path to "api/setup/setup.inc.php"
+ */
+function update_api_setup($path)
+{
+	global $config;
+
+	if (!($content = file_get_contents($path)))
+	{
+		throw new Exception("Could not read file '$path' to update maintenance-version!");
+	}
+
+	$content = preg_replace('/'.preg_quote("\$setup_info['api']['versions']['maintenance_release']", '/').'[^;]+;',
+		"\$setup_info['api']['versions']['maintenance_release'] = '".$config['version'].'.'.$config['packaging']."';",
+		$content);
+
+	if (!file_put_contents($path, $content))
+	{
+		throw new Exception("Could not update file '$path' with maintenance-version!");
+	}
+}
+
 /**
  * Sign sha1sum file
  */
