@@ -1,4 +1,4 @@
-#!/usr/bin/php
+#!/usr/bin/env php
 <?php
 /**
  * EGroupware - RPM post install: automatic install or update EGroupware
@@ -15,8 +15,8 @@ if (php_sapi_name() !== 'cli')	// security precaution: forbit calling post_insta
 }
 $verbose = false;
 $config = array(
-	'php'         => '/usr/bin/php',
-	'source_dir'  => '/usr/share/egroupware',
+	'php'         => PHP_BINARY,
+	'source_dir'  => realpath(__DIR__.'/../..'),
 	'data_dir'    => '/var/lib/egroupware',
 	'header'      => '$data_dir/header.inc.php',	// symlinked to source_dir by rpm
 	'setup-cli'   => '$source_dir/setup/setup-cli.php',
@@ -165,7 +165,7 @@ function set_distro_defaults($distro=null)
 set_distro_defaults();
 
 // read config from command line
-$argv = $_SERVER['argv'];
+$argv = str_replace(array("''", '""'), '', $_SERVER['argv']);
 $prog = array_shift($argv);
 
 // check if we have EGW_POST_INSTALL set and prepend it to the command line (command line has precedence)
@@ -251,9 +251,30 @@ foreach(array('php','source_dir','data_dir','setup-cli') as $name)
 // fix important php.ini and conf.d/*.ini settings
 check_fix_php_apc_ini();
 
-$setup_cli = $config['php'].' -d memory_limit=256M '.$config['setup-cli'];
+// not limiting memory, as backups might fail with limit we set
+$setup_cli = $config['php'].' -d memory_limit=-1 '.$config['setup-cli'];
 
-if (!file_exists($config['header']) || filesize($config['header']) < 200)	// default header redirecting to setup is 147 bytes
+// if we have a header, include it
+if (file_exists($config['header']) && filesize($config['header']) >= 200)	// default header redirecting to setup is 147 bytes
+{
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'noapi' => true,
+			'currentapp' => 'login',	// stop PHP Notice: Undefined index "currentapp" in pre 16.1 header
+		)
+	);
+	include $config['header'];
+
+	// get user from header and replace password, as we dont know it
+	$old_password = patch_header($config['header'],$config['config_user'],$config['config_passwd']);
+	// register a shutdown function to put old password back in any case
+	register_shutdown_function(function() use (&$config, $old_password)
+	{
+		patch_header($config['header'], $config['config_user'], $old_password);
+	});
+}
+// new header or does not include requested domain (!= "default") --> new install
+if (!isset($GLOBALS['egw_domain']) ||  $config['domain'] !== 'default' && !isset($GLOBALS['egw_domain'][$config['domain']]))
 {
 	// --> new install
 	$extra_config = '';
@@ -318,8 +339,9 @@ if (!file_exists($config['header']) || filesize($config['header']) < 200)	// def
 		run_cmd($config['php5enmod']);
 	}
 
-	// create header
-	$setup_header = $setup_cli.' --create-header '.escapeshellarg($config['config_passwd'].','.$config['config_user']).
+	// create or edit header header
+	$setup_header = $setup_cli.(isset($GLOBALS['egw_domain']) ? ' --edit-header ' : ' --create-header ').
+		escapeshellarg($config['config_passwd'].','.$config['config_user']).
 		' --domain '.escapeshellarg($config['domain'].','.$config['db_name'].','.$config['db_user'].','.$config['db_pass'].
 			','.$config['db_type'].','.$config['db_host'].','.$config['db_port']);
 	run_cmd($setup_header);
@@ -383,23 +405,17 @@ if (!file_exists($config['header']) || filesize($config['header']) < 200)	// def
 
 	if (empty($config['db_root_pw']))
 	{
-		echo "*** Database has no root password set, please fix that immediatly: mysqladmin -u root password NEWPASSWORD\n\n";
+		echo "*** Database has no root password set, please fix that immediatly".
+			(substr($config['db_type'], 0, 5) === 'mysql' ? ": mysqladmin -u root password NEWPASSWORD\n\n" : "!\n\n");
 	}
 }
 else
 {
 	// --> existing install --> update
 
-	// get user from header and replace password, as we dont know it
-	$old_password = patch_header($config['header'],$config['config_user'],$config['config_passwd']);
-	// register a shutdown function to put old password back in any case
-	register_shutdown_function(function() use (&$config, $old_password)
-	{
-		patch_header($config['header'], $config['config_user'], $old_password);
-	});
-
-	// update egroupware
-	$setup_update = $setup_cli.' --update '.escapeshellarg('all,'.$config['config_user'].','.$config['config_passwd'].',,'.$config['install-update-app']);
+	// update egroupware, or single app(s), in later case skip backup
+	$setup_update = $setup_cli.' --update '.escapeshellarg('all,'.$config['config_user'].','.$config['config_passwd'].
+		(empty($config['install-update-app']) ? '' : ',no,'.$config['install-update-app']));
 	$ret = run_cmd($setup_update,$output,array(4,15));
 
 	switch($ret)
@@ -421,10 +437,12 @@ else
 	// fix egw_cache evtl. created by root, stoping webserver from accessing it
 	fix_perms();
 
-	// restart running Apache, to force APC to update changed sources and/or Apache configuration
-	$output = array();
-	run_cmd(build_cmd('start_webserver', 'status').' && '.build_cmd('start_webserver', 'restart'), $output, true);
-
+	if (!empty($config['start_webserver']))
+	{
+		// restart running Apache, to force APC to update changed sources and/or Apache configuration
+		$output = array();
+		run_cmd(build_cmd('start_webserver', 'status').' && '.build_cmd('start_webserver', 'restart'), $output, true);
+	}
 	exit($ret);
 }
 
@@ -532,10 +550,13 @@ function randomstring($len=16)
 		'>','|','[',']','}',	// dont add /\,'"{ as we have problems dealing with them
 	);
 
+	// use cryptographically secure random_int available in PHP 7+
+	$func = function_exists('random_int') ? 'random_int' : 'mt_rand';
+
 	$str = '';
 	for($i=0; $i < $len; $i++)
 	{
-		$str .= $usedchars[mt_rand(0,count($usedchars)-1)];
+		$str .= $usedchars[$func(0,count($usedchars)-1)];
 	}
 	return $str;
 }
@@ -575,7 +596,7 @@ function fix_perms()
 {
 	global $config;
 
-	if (file_exists('/tmp/egw_cache'))
+	if (file_exists('/tmp/egw_cache') && !empty($config['webserver_user']))
 	{
 		system('/bin/chown -R '.$config['webserver_user'].' /tmp/egw_cache');
 		system('/bin/chmod 700 /tmp/egw_cache');
@@ -654,7 +675,16 @@ function set_univention_defaults()
 			$config['mailserver'] = "$mailserver,993,$domain,email,tls";
 			if (_ucr_get('mail/dovecot') == 'yes')
 			{
-				$config['imap'] = /*'cyrus,'._ucr_secret('cyrus')*/','.',Imap\\Dovecot';
+				$matches = null;
+				if (file_exists('/etc/dovecot/master-users') &&
+					preg_match('/^([^:]+):{PLAIN}([^:]+):/i', file_get_contents('/etc/dovecot/master-users'), $matches))
+				{
+					$config['imap'] = $matches[1].','.$matches[2].',Imap\\Dovecot';
+				}
+				else
+				{
+					$config['imap'] = ',,Imap\\Dovecot';
+				}
 				// default with sieve port to 4190, as config is only available on host mailserver app is installed
 				if (!($sieve_port = _ucr_get('mail/dovecot/sieve/port'))) $sieve_port = 4190;
 			}
@@ -665,7 +695,7 @@ function set_univention_defaults()
 				if (!($sieve_port = _ucr_get('mail/cyrus/sieve/port'))) $sieve_port = 4190;
 			}
 			// set folders so mail creates them on first login, UCS does not automatic
-			$config['folder'] = 'INBOX/Sent,INBOX/Trash,INBOX/Drafts,INBOX/Templates,INBOX/Spam';
+			$config['folder'] = 'INBOX/Sent,INBOX/Trash,INBOX/Drafts,INBOX/Templates,Spam,,Ham';
 			$config['sieve'] = "$mailserver,$sieve_port,starttls";
 			// set an email address for sysop user so mail works right away
 			$config['admin_email'] = '$admin_user@'.$domain;
@@ -722,7 +752,7 @@ function _ucr_secret($name)
  */
 function check_fix_php_apc_ini()
 {
-	if (extension_loaded('apc'))
+	if (extension_loaded('apc') || extension_loaded('apcu'))
 	{
 		$shm_size = ini_get('apc.shm_size');
 		$shm_segments = ini_get('apc.shm_segments');
@@ -739,7 +769,7 @@ function check_fix_php_apc_ini()
 			phpinfo();
 			$phpinfo = ob_get_clean();
 			$matches = null;
-			if (preg_match('#(/[a-z0-5./-]+apcu?.ini)(,| |$)#mi', $phpinfo, $matches) &&
+			if (preg_match('#(/[a-z0-9./-]+apcu?.ini)(,| |$)#mi', $phpinfo, $matches) &&
 				file_exists($path = $matches[1]) && ($apc_ini = file_get_contents($path)))
 			{
 				$new_shm_size = 128 / $shm_segments;
