@@ -11,6 +11,9 @@
  * @version $Id$
  */
 
+// do NOT offer emailadmin for installation
+$setup_info['emailadmin']['only_db']   = array('update');
+
 $setup_info['emailadmin']['name']      = 'emailadmin';
 $setup_info['emailadmin']['title']     = 'EMailAdmin';
 $setup_info['emailadmin']['version']   = '14.3.001';
@@ -35,17 +38,12 @@ $setup_info['emailadmin']['tables'][]	= 'egw_ea_valid';
 $setup_info['emailadmin']['tables'][]	= 'egw_ea_notifications';
 
 /* The hooks this app includes, needed for hooks registration */
-$setup_info['emailadmin']['hooks']['edit_user'] = 'emailadmin_hooks::edit_user';
 $setup_info['emailadmin']['hooks']['deleteaccount'] = 'emailadmin_hooks::deleteaccount';
 $setup_info['emailadmin']['hooks']['addaccount'] = 'emailadmin_hooks::addaccount';
 $setup_info['emailadmin']['hooks']['editaccount'] = 'emailadmin_hooks::addaccount';
 $setup_info['emailadmin']['hooks']['deletegroup'] = 'emailadmin_hooks::deletegroup';
 $setup_info['emailadmin']['hooks']['changepassword'] = 'emailadmin_hooks::changepassword';
 
-// SMTP and IMAP support
-$setup_info['emailadmin']['hooks']['smtp_server_types'] = 'emailadmin_hooks::server_types';
-$setup_info['emailadmin']['hooks']['imap_server_types'] = 'emailadmin_hooks::server_types';
-
 /* Dependencies for this app to work */
 $setup_info['emailadmin']['depends'][] = array(
 	'appname'  => 'phpgwapi',
@@ -61,10 +59,6 @@ $setup_info['emailadmin']['check_install'] = array(
 		'func' => 'pear_check',
 		'from' => 'EMailAdmin',
 	),
-	'Net_Sieve' => array(
-		'func' => 'pear_check',
-		'from' => 'EMailAdmin',
-	),
 	'pear.horde.org/Horde_Imap_Client' => array(
 		'func' => 'pear_check',
 		'from' => 'EMailAdmin',
@@ -85,6 +79,11 @@ $setup_info['emailadmin']['check_install'] = array(
 		'from' => 'EMailAdmin',
 		'version' => '1.3.0',
 	),
+	'pear.horde.org/Horde_ManageSieve' => array(
+		'func' => 'pear_check',
+		'from' => 'EMailAdmin',
+		'version' => '1.0.1',
+	),
 	// next 4 are required for TNEF support
 	'pear.horde.org/Horde_Compress' => array(
 		'func' => 'pear_check',
@@ -106,6 +105,3 @@ $setup_info['emailadmin']['check_install'] = array(
 		'from' => 'EMailAdmin',
 	),
 );
-
-
-
