@@ -337,8 +337,13 @@ class vfs_widget
 					{
 						$thparams['thsize'] = $thsize;
 					}
+					// add modification time to url to allow long caching
+					if (is_array($value) && $value['mtime'])
+					{
+						$thparams['mtime'] = $value['mtime'];
+					}
 
-					$value = $GLOBALS['egw']->link('/etemplate/thumbnail.php', $thparams);
+					$value = $GLOBALS['egw']->link('/api/thumbnail.php', $thparams);
 				}
 				else
 				{
