@@ -72,6 +72,6 @@ $setup_info['developer_tools']['hooks']     = array();
 
 /* Dependencies for this app to work */
 $setup_info['developer_tools']['depends'][] = array(
-	'appname' => 'etemplate',
+	'appname' => 'phpgwapi',
 	'versions' => Array('14.1')
-);
+);
\ No newline at end of file
