@@ -1,4 +1,4 @@
-#!/usr/bin/php -qC
+#!/usr/bin/env php
 <?php
 /**
  * EGroupware Filemanager - Command line interface
@@ -6,7 +6,7 @@
  * @link http://www.egroupware.org
  * @package filemanager
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2007-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2007-17 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  *
@@ -94,6 +94,11 @@ while(!is_null($option = array_shift($args)))
 {
 	if ($option == '-' || $option[0] != '-')	// no option --> argument
 	{
+		// remove quotes from arguments
+		if (in_array($option[0], array('"', "'")) && $option[0] == substr($option, -1))
+		{
+			$option = substr($option, 1, -1);
+		}
 		$argv[] = $option;
 		continue;
 	}
@@ -297,15 +302,15 @@ switch($cmd)
 		{
 			$url = array_shift($argv);
 
-			load_wrapper($url);
-			echo "$cmd $url (long=".(int)$long.", numeric=".(int)$numeric.", recursive=".(int)$recursive.")\n";
+			if (strpos($url, '://')) load_wrapper($url);
+			echo "$cmd $url (long=".(int)$long.", numeric=".(int)$numeric.", recursive=".(int)$recursive.") ".implode(' ', $argv)."\n";
 
 			switch($cmd)
 			{
 				case 'rm':
 					if ($recursive)
 					{
-						if (!class_exists('egw_vfs'))
+						if (!class_exists('EGroupware\\Api\\Vfs'))
 						{
 							die("rm -r only implemented for eGW streams!");	// dont want to repeat the code here
 						}
@@ -341,8 +346,8 @@ switch($cmd)
 							{
 								$mode = $url;	// first param is mode
 								$url = array_shift($argv);
+								load_wrapper($url);	// not loaded because mode was in url
 							}
-							if (Vfs::parse_url($url,PHP_URL_SCHEME)) load_wrapper($url);	// cant use stat or Vfs::mode2int otherwise!
 
 							if (strpos($mode,'+') !== false || strpos($mode,'-') !== false)
 							{
@@ -353,7 +358,7 @@ switch($cmd)
 							{
 								$set = 0;
 							}
-							if (!class_exists('egw_vfs'))
+							if (!class_exists('EGroupware\\Api\\Vfs'))
 							{
 								die("chmod only implemented for eGW streams!");	// dont want to repeat the code here
 							}
@@ -367,7 +372,7 @@ switch($cmd)
 							{
 								$owner = $url;	// first param is owner/group
 								$url = array_shift($argv);
-								if (Vfs::parse_url($url,PHP_URL_SCHEME)) load_wrapper($url);	// we need the header loaded
+								load_wrapper($url);	// not loaded because owner/group was in url
 								if ($owner == 'root')
 								{
 									$owner = 0;
@@ -397,11 +402,11 @@ switch($cmd)
 					{
 						load_wrapper($url);
 					}
-					if ($recursive && class_exists('egw_vfs'))
+					if ($recursive && class_exists('EGroupware\\Api\\Vfs'))
 					{
 						array_unshift($argv,$url);
 						$params = array($argv,null,$cmd,$params[1]);
-						$cmd = array('egw_vfs','find');
+						$cmd = array('EGroupware\\Api\\Vfs','find');
 						$argv = array();	// we processed all url's
 					}
 					//echo "calling cmd=".print_r($cmd,true).", params=".print_r($params,true)."\n";
@@ -412,7 +417,7 @@ switch($cmd)
 				case 'ls':
 				default:
 					// recursive ls atm only for vfs://
-					if ($cmd != 'cat' && $recursive && class_exists('egw_vfs'))
+					if ($cmd != 'cat' && $recursive && class_exists('EGroupware\\Api\\Vfs'))
 					{
 						load_wrapper($url);
 						array_unshift($argv,$url);
@@ -474,9 +479,8 @@ switch($cmd)
  */
 function load_wrapper($url)
 {
-	$scheme = parse_url($url,PHP_URL_SCHEME);
-
-	if (!in_array($scheme,stream_get_wrappers()))
+	if (($scheme = parse_url($url,PHP_URL_SCHEME)) &&
+		!in_array($scheme, stream_get_wrappers()))
 	{
 		switch($scheme)
 		{
@@ -484,15 +488,15 @@ function load_wrapper($url)
 			case 'webdavs':
 				require_once('HTTP/WebDAV/Client.php');
 				break;
-			case '':	// default scheme is file and always available
-				break;
+
 			default:
-				if (!isset($GLOBALS['egw']) && !in_array($scheme,array('smb','imap')))
+				if (!isset($GLOBALS['egw']) && !in_array($scheme,array('smb','imap')) &&
+					($user = parse_url($url,PHP_URL_USER)) && ($pass = parse_url($url,PHP_URL_PASS)))
 				{
-					load_egw(parse_url($url,PHP_URL_USER), parse_url($url,PHP_URL_PASS), parse_url($url,PHP_URL_HOST));
+					load_egw($user, $pass, ($host = parse_url($url,PHP_URL_HOST)) ? $host : 'default');
 				}
 				// get eGW's __autoload() function
-				include_once(EGW_API_INC.'/common_functions.inc.php');
+				include_once(EGW_SERVER_ROOT.'/api/src/loader/common.php');
 
 				if (!Vfs::load_wrapper($scheme))
 				{
@@ -560,7 +564,7 @@ function load_egw($user,$passwd,$domain='default')
 	}
 
 	$cmd = $GLOBALS['cmd'];
-	if (!in_array($cmd,array('ls','find','mount','umount','eacl')) && $GLOBALS['egw_info']['server']['files_dir'] && !is_writable($GLOBALS['egw_info']['server']['files_dir']))
+	if (!in_array($cmd,array('ls','find','mount','umount','eacl','touch','chmod','chown','chgrp')) && $GLOBALS['egw_info']['server']['files_dir'] && !is_writable($GLOBALS['egw_info']['server']['files_dir']))
 	{
 		echo "\nError: eGroupWare's files directory {$GLOBALS['egw_info']['server']['files_dir']} is NOT writable by the user running ".basename(__FILE__)."!\n".
 			"--> Please run it as the same user the webserver uses or root, otherwise the $cmd command will fail!\n\n";
@@ -581,7 +585,7 @@ function do_eacl(array $argv)
 		usage('Wrong number of parameters!');
 	}
 	load_wrapper($url = $argv[0]);
-	if (!class_exists('egw_vfs'))
+	if (!class_exists('EGroupware\\Api\\Vfs'))
 	{
 		die('eacl only implemented for eGW streams!');
 	}
@@ -646,7 +650,7 @@ function do_stat($url,$long=false,$numeric=false,$full_path=false,$inode=false)
 	{
 		//echo $url; print_r($stat);
 
-		if (class_exists('egw_vfs'))
+		if (class_exists('EGroupware\\Api\\Vfs'))
 		{
 			$perms = Vfs::int2mode($stat['mode']);
 		}
@@ -683,7 +687,7 @@ function do_stat($url,$long=false,$numeric=false,$full_path=false,$inode=false)
 		$nlink = $stat['nlink'];
 		if (($stat['mode'] & 0xA000) == 0xA000)
 		{
-			$symlink = " -> ".(class_exists('egw_vfs') ? Vfs::readlink($url) : readlink($url));
+			$symlink = " -> ".(class_exists('EGroupware\\Api\\Vfs') ? Vfs::readlink($url) : readlink($url));
 		}
 		if ($inode)
 		{
@@ -719,7 +723,7 @@ function do_cp($argv,$recursive=false,$perms=false)
 	$anz_dirs = $anz_files = 0;
 	foreach($argv as $from)
 	{
-		if (is_dir($from) && (!file_exists($to) || is_dir($to)) && $recursive && class_exists('egw_vfs'))
+		if (is_dir($from) && (!file_exists($to) || is_dir($to)) && $recursive && class_exists('EGroupware\\Api\\Vfs'))
 		{
 			foreach(Vfs::find($from,array('url' => true)) as $f)
 			{
@@ -793,8 +797,8 @@ function _cp_perms($from,$to)
 		{
 			if ($from_stat[$perm] != $to_stat[$perm])
 			{
-				//echo "egw_vfs::$cmd($to,{$from_stat[$perm]}\n";
-				call_user_func(array('egw_vfs',$cmd),$to,$from_stat[$perm]);
+				//echo "Vfs::$cmd($to,{$from_stat[$perm]}\n";
+				call_user_func(array('EGroupware\\Api\\Vfs',$cmd),$to,$from_stat[$perm]);
 			}
 		}
 	}
