@@ -5,7 +5,7 @@
  * @link http://www.egroupware.org
  * @package filemanager
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2008-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2008-17 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
@@ -166,6 +166,27 @@ class filemanager_ui
 				'group' => $group,
 				'children' => array(),
 			),
+			'egw_paste' => array(
+				'enabled' => false,
+				'group' => $group + 0.5,
+				'hideOnDisabled' => true
+			),
+			'paste' => array(
+				'caption' => lang('Paste'),
+				'acceptedTypes' => 'file',
+				'group' => $group + 0.5,
+				'order' => 10,
+				'enabled' => 'javaScript:app.filemanager.paste_enabled',
+				'children' => array()
+			),
+			'copylink' => array(
+				'caption' => lang('Copy link address'),
+				'group' => $group + 0.5,
+				'icon' => 'copy',
+				'allowOnMultiple' => false,
+				'order' => 10,
+				'onExecute' => 'javaScript:app.filemanager.copy_link'
+			),
 			'documents' => filemanager_merge::document_action(
 				$GLOBALS['egw_info']['user']['preferences']['filemanager']['document_dir'],
 				++$group, 'Insert in document', 'document_',
@@ -227,6 +248,19 @@ class filemanager_ui
 				);
 			}
 		}
+		// This would be done automatically, but we're overriding
+		foreach($actions as $action_id => $action)
+		{
+			if($action['type'] == 'drop' && $action['caption'])
+			{
+				$action['type'] = 'popup';
+				if($action['acceptedTypes'] == 'file')
+				{
+					$action['enabled'] = 'javaScript:app.filemanager.paste_enabled';
+				}
+				$actions['paste']['children']["{$action_id}_paste"] = $action;
+			}
+		}
 		return $actions;
 	}
 
@@ -296,17 +330,16 @@ class filemanager_ui
 					'default_cols'   => '!comment,ctime',	// I  columns to use if there's no user or default pref (! as first char uses all but the named columns), default all columns
 					'csv_fields'     =>	false, // I  false=disable csv export, true or unset=enable it with auto-detected fieldnames,
 									//or array with name=>label or name=>array('label'=>label,'type'=>type) pairs (type is a eT widget-type)
-					'actions'        => static::get_actions(),
 					'row_id'         => 'path',
 					'row_modified'   => 'mtime',
 					'parent_id'      => 'dir',
-					'is_parent'      => 'mime',
-					'is_parent_value'=> Vfs::DIR_MIME_TYPE,
+					'is_parent'      => 'is_dir',
 					'favorites'      => true,
-					'placeholder_actions' => array('mkdir','file_drop_mail','file_drop_move','file_drop_copy','file_drop_symlink')
+					'placeholder_actions' => array('mkdir','paste','file_drop_mail','file_drop_move','file_drop_copy','file_drop_symlink')
 				);
 				$content['nm']['path'] = static::get_home_dir();
 			}
+			$content['nm']['actions'] = static::get_actions();
 			$content['nm']['home_dir'] = static::get_home_dir();
 			$content['nm']['view'] = $GLOBALS['egw_info']['user']['preferences']['filemanager']['nm_view'];
 
@@ -333,13 +366,13 @@ class filemanager_ui
 						$path = static::get_home_dir();
 						break;
 				}
-				if ($path[0] == '/' && Vfs::stat($path,true) && Vfs::is_dir($path) && Vfs::check_access($path,Vfs::READABLE))
+				if ($path && $path[0] == '/' && Vfs::stat($path,true) && Vfs::is_dir($path) && Vfs::check_access($path,Vfs::READABLE))
 				{
 					$content['nm']['path'] = $path;
 				}
 				else
 				{
-					$msg .= lang('The requested path %1 is not available.',Vfs::decodePath($path));
+					$msg .= lang('The requested path %1 is not available.', $path ? Vfs::decodePath($path) : "false");
 				}
 				// reset lettersearch as it confuses users (they think the dir is empty)
 				$content['nm']['searchletter'] = false;
@@ -732,7 +765,7 @@ class filemanager_ui
 			// some precaution to never allow to (recursivly) remove /, /apps or /home
 			foreach((array)$selected as $path)
 			{
-				if (preg_match('/^\/?(home|apps|)\/*$/',$path))
+				if (Vfs::isProtectedDir($path))
 				{
 					$errs++;
 					return lang("Cautiously rejecting to remove folder '%1'!",Vfs::decodePath($path));
@@ -780,7 +813,8 @@ class filemanager_ui
 		// do NOT store query, if hierarchical data / children are requested
 		if (!$query['csv_export'])
 		{
-			Api\Cache::setSession('filemanager', 'index',$query);
+			Api\Cache::setSession('filemanager', 'index',
+				array_diff_key ($query, array_flip(array('rows','actions','action_links','placeholder_actions'))));
 		}
 		if(!$query['path']) $query['path'] = static::get_home_dir();
 
@@ -869,7 +903,16 @@ class filemanager_ui
 			}
 			if (Vfs::is_dir($path))
 			{
-				$row['class'] = 'isDir';
+				if (!isset($dir_is_writable[$path]))
+				{
+					$dir_is_writable[$path] = Vfs::is_writable($path);
+				}
+				if(!$dir_is_writable[$path])
+				{
+					$row['class'] .= 'noEdit ';
+				}
+				$row['class'] .= 'isDir ';
+				$row['is_dir'] = 1;
 			}
 			$row['download_url'] = Vfs::download_url($path);
 			$row['gid'] = -abs($row['gid']);	// gid are positive, but we use negagive account_id for groups internal
@@ -946,7 +989,7 @@ class filemanager_ui
 			{
 				$content = $stat;
 				$content['name'] = $content['itempicker_merge']['name'] = Vfs::basename($path);
-				$content['dir'] = $content['itempicker_merge']['dir'] = Vfs::decodePath(Vfs::dirname($path));
+				$content['dir'] = $content['itempicker_merge']['dir'] = ($dir = Vfs::dirname($path)) ? Vfs::decodePath($dir) : '';
 				$content['path'] = $path;
 				$content['hsize'] = Vfs::hsize($stat['size']);
 				$content['mime'] = Vfs::mime_content_type($path);
@@ -1018,7 +1061,13 @@ class filemanager_ui
 					{
 						if ($name == 'name')
 						{
-							$to = Vfs::concat(Vfs::dirname($path),$content['name']);
+							if (!($dir = Vfs::dirname($path)))
+							{
+								$msg .= lang('File or directory not found!')." Vfs::dirname('$path')===false";
+								if ($button == 'save') $button = 'apply';
+								continue;
+							}
+							$to = Vfs::concat($dir, $content['name']);
 							if (file_exists(Vfs::PREFIX.$to) && $content['confirm_overwrite'] !== $to)
 							{
 								$tpl->set_validation_error('name',lang("There's already a file with that name!").'<br />'.
@@ -1070,7 +1119,7 @@ class filemanager_ui
 						else
 						{
 							static $name2cmd = array('uid' => 'chown','gid' => 'chgrp','perms' => 'chmod');
-							$cmd = array('egw_vfs',$name2cmd[$name]);
+							$cmd = array('EGroupware\\Api\\Vfs',$name2cmd[$name]);
 							$value = $name == 'perms' ? static::perms2mode($content['perms']) : $content[$name];
 							if ($content['modify_subs'])
 							{
@@ -1177,7 +1226,7 @@ class filemanager_ui
 				$readonlys['perms['.$name.']'] = true;
 			}
 		}
-		$readonlys['name'] = $path == '/' || !Vfs::is_writable(Vfs::dirname($path));
+		$readonlys['name'] = $path == '/' || !($dir = Vfs::dirname($path)) || !Vfs::is_writable($dir);
 		$readonlys['comment'] = !Vfs::is_writable($path);
 		$readonlys['tabs']['filemanager.file.preview'] = $readonlys['tabs']['filemanager.file.perms'] = $content['is_link'];
 
