@@ -248,6 +248,8 @@ app.classes.filemanager = AppJS.extend(
 		{
 		   params['preset[file]['+i+']'] = 'vfs://default'+attachments[i];
 		}
+		// always open compose in html mode, as attachment links look a lot nicer in html
+		params.mimeType = 'html';
 		egw.open('', 'mail', 'add', params);
 	},
 
@@ -353,8 +355,8 @@ app.classes.filemanager = AppJS.extend(
 			if (_data.uploaded[file].confirm && !_data.uploaded[file].confirmed)
 			{
 				var buttons = [
-					{text: this.egw.lang("Yes"), id: "overwrite", class: "ui-priority-primary", "default": true},
-					{text: this.egw.lang("Rename"), id:"rename"},
+					{text: this.egw.lang("Yes"), id: "overwrite", class: "ui-priority-primary", "default": true, image: 'check',},
+					{text: this.egw.lang("Rename"), id:"rename", image: 'edit',},
 					{text: this.egw.lang("Cancel"), id:"cancel"}
 				];
 				if (_data.uploaded[file].confirm === "is_dir")
@@ -564,7 +566,7 @@ app.classes.filemanager = AppJS.extend(
 				self._do_action('createdir', dir, true, path);	// true=synchronous request
 				self.change_dir((path == '/' ? '' : path)+'/'+ dir);
 			}
-		},this.egw.lang('New directory'),this.egw.lang('Create directroy'));
+		},this.egw.lang('New directory'),this.egw.lang('Create directory'));
 	},
 
 	/**
@@ -787,6 +789,112 @@ app.classes.filemanager = AppJS.extend(
 		}), 'fileprefs', '510x425');
 	},
 
+	/**
+	 * Callback to check if the paste action is enabled.  We also update the
+	 * clipboard historical targets here as well
+	 *
+	 * @param {egwAction} _action  drop action we're checking
+	 * @param {egwActionObject[]} _senders selected files
+	 * @param {egwActionObject} _target Drop or context menu activated on this one
+	 *
+	 * @returns boolean true if enabled, false otherwise
+	 */
+	paste_enabled: function paste_enabled(_action, _senders, _target)
+	{
+		// Need files in the clipboard for this
+		var clipboard_files = this.get_clipboard_files();
+		if(clipboard_files.length === 0)
+		{
+			return false;
+		}
+
+		// Parent action (paste) gets run through here as well, but needs no
+		// further processing
+		if(_action.id == 'paste') return true;
+
+		if(_action.canHaveChildren.indexOf('drop') == -1)
+		{
+			_action.canHaveChildren.push('drop');
+		}
+		var actions = [];
+		var dir = undefined;
+		var current_dir, target_dir = false;
+
+		// Current directory
+		current_dir = this.get_path();
+		dir = egw.dataGetUIDdata('filemanager::'+current_dir);
+		var path_widget = etemplate2.getById('filemanager-index').widgetContainer.getWidgetById('button[createdir]');
+		actions.push({
+			id:_action.id+'_current', caption: current_dir, path: current_dir,
+			enabled: dir && dir.data && dir.data.class && dir.data.class.indexOf('noEdit') === -1 ||
+					!dir && path_widget && !path_widget.options.readonly
+		});
+
+		// Target, if directory
+		target_dir = this.id2path(_target.id);
+		dir = egw.dataGetUIDdata(_target.id);
+		actions.push({
+				id: _action.id+'_target',
+				caption: target_dir,
+				path: target_dir,
+				enabled: _target && _target.iface && jQuery(_target.iface.getDOMNode()).hasClass('isDir') &&
+					(dir && dir.data && dir.data.class && dir.data.class.indexOf('noEdit') === -1 || !dir)
+		});
+
+		// Last 10 folders
+		var previous_dsts = jQuery.extend([], egw.preference('drop_history',this.appname));
+		var action_index = 0;
+		for(var i = 0; i < 10; i++)
+		{
+			var path = i < previous_dsts.length ? previous_dsts[i] : '';
+			actions.push({
+				id: _action.id+'_target_'+action_index++,
+				caption: path,
+				path: path,
+				group: 2,
+				enabled: path && !(current_dir && path === current_dir || target_dir && path === target_dir)
+			});
+		}
+
+		// Common stuff, every action needs these
+		for(var i = 0; i < actions.length; i++)
+		{
+			//actions[i].type = 'drop',
+			actions[i].acceptedTypes = _action.acceptedTypes;
+			actions[i].no_lang = true;
+			actions[i].hideOnDisabled = true;
+		}
+
+		_action.updateActions(actions);
+
+		// Create paste action
+		// This injects the clipboard data and calls the original handler
+		var paste_exec = function(action, selected) {
+			// Add in clipboard as a sender
+			var clipboard = JSON.parse(egw.getSessionItem('phpgwapi', 'egw_clipboard'));
+
+			// Set a flag so apps can tell the difference, if they need to
+			action.set_onExecute(action.parent.onExecute.fnct);
+			action.execute(clipboard.selected,selected[0]);
+
+			// Clear the clipboard, the files are not there anymore
+			if(action.id.indexOf('move') !== -1)
+			{
+				egw.setSessionItem('phpgwapi', 'egw_clipboard', JSON.stringify({
+					type:[],
+					selected:[]
+				}));
+			}
+		};
+		for(var i = 0; i < actions.length; i++)
+		{
+			_action.getActionById(actions[i].id).onExecute = jQuery.extend(true, {}, _action.onExecute);
+
+			_action.getActionById(actions[i].id).set_onExecute(paste_exec);
+		}
+		return actions.length > 0;
+	},
+
 	/**
 	 * File(s) droped
 	 *
@@ -802,10 +910,22 @@ app.classes.filemanager = AppJS.extend(
 
 		// Target will be missing ID if directory is empty
 		// so start with the current directory
-		var nm_dst = this.get_path(_action.parent.data.nextmatch.getInstanceManager().uniqueId || false);
+		var parent = _action;
+		var nm = _target.manager.data.nextmatch;
+		while(!nm && parent.parent)
+		{
+			parent = parent.parent;
+			if(parent.data.nextmatch) nm = parent.data.nextmatch;
+		}
+		var nm_dst = this.get_path(nm.getInstanceManager().uniqueId || false);
 
+		// Action specifies a destination, target does not matter
+		if(_action.data && _action.data.path)
+		{
+			dst = _action.data.path;
+		}
 		// File(s) were dropped on a row, they want them inside
-		if(_target)
+		else if(_target)
 		{
 			var dst = '';
 			var paths = this._elems2paths([_target]);
@@ -822,7 +942,16 @@ app.classes.filemanager = AppJS.extend(
 			}
 		}
 
-		this._do_action(_action.id.replace("file_drop_",''), src, false, dst || nm_dst);
+		// Remember the target for next time
+		var previous_dsts = jQuery.extend([], egw.preference('drop_history',this.appname));
+		previous_dsts.unshift(dst);
+		previous_dsts = Array.from(new Set(previous_dsts)).slice(0,9);
+		egw.set_preference(this.appname, 'drop_history', previous_dsts);
+
+		// Actual action id will be something like file_drop_{move|copy|link}[_other_id],
+		// but we need to send move, copy or link
+		var action_id = _action.id.replace("file_drop_",'').split('_',1)[0];
+		this._do_action(action_id, src, false, dst || nm_dst);
 	},
 
 	/**
@@ -972,5 +1101,89 @@ app.classes.filemanager = AppJS.extend(
 					};
 			}
 		}
+	},
+
+	/**
+	 * Open file a file dialog from EPL, warn if EPL is not available
+	 *
+	 * @param {jQuery.event} _event
+	 * @param {et2_widget} _widget
+	 */
+	fileafile: function(_event, _widget)
+	{
+		if (this.egw.user('apps').stylite)
+		{
+			this.egw.open_link('/index.php?menuaction=stylite.stylite_filemanager.upload&path='+this.get_path(), '_blank', '670x320');
+		}
+		else
+		{
+			et2_dialog.show_dialog(function(_button)
+			{
+				if (_button == et2_dialog.YES_BUTTON) window.open('http://www.egroupware.org/EPL', '_blank');
+				return true;
+			}, this.egw.lang('File a file is only available with an EPL subscription.')+"\n\n"+
+				this.egw.lang('You can use regular upload [+] button to upload files.')+"\n\n"+
+				this.egw.lang('Do you want more information about EPL subscription?'),
+			this.egw.lang('File a file'), undefined, et2_dialog.BUTTONS_YES_NO, et2_dialog.QUESTION_MESSAGE);
+		}
+	},
+
+	/**
+	 * This function copies the selected file/folder entry as webdav link into clipboard
+	 *
+	 * @param {object} _action egw actions
+	 * @param {object} _senders selected nm row
+	 * @returns {Boolean} returns false if not successful
+	 */
+	copy_link: function (_action, _senders)
+	{
+		var data = egw.dataGetUIDdata(_senders[0].id);
+		var url = data ? data.data.download_url : '/webdav.php'+this.id2path(_senders[0].id);
+		if (url[0] == '/') url = egw.link(url);
+		if (url.substr(0,4) == 'http'  && url.indexOf('://') <= 5) {
+			// it's already a full url
+		}
+		else
+		{
+			var hostUrl = new URL(window.location.href);
+			url = hostUrl.origin + url;
+		}
+
+		if (url)
+		{
+			var elem = jQuery(document.createElement('div'));
+			var range = [];
+			elem.text(url);
+			elem.appendTo('body');
+			if (document.selection)
+			{
+				range = document.body.createTextRange();
+				range.moveToElementText(elem);
+				range.select();
+			}
+			else if (window.getSelection)
+			{
+				var range = document.createRange();
+				range.selectNode(elem[0]);
+				window.getSelection().removeAllRanges();
+				window.getSelection().addRange(range);
+			}
+
+			var successful = false;
+			try {
+				successful = document.execCommand('copy');
+				if (successful)
+				{
+					egw.message('WebDav link copied into clipboard');
+					window.getSelection().removeAllRanges();
+
+					return true;
+				}
+			}
+			catch (e) {}
+			egw.message('Failed to copy the link!');
+			elem.remove();
+			return false;
+		}
 	}
 });
