@@ -6,6 +6,9 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Etemplate;
+
 /**
  * Extend custom fields and make an general advanced filter
  *
@@ -21,15 +24,15 @@
  *
  * Most text fields are ignored.
  */
-class importexport_widget_filter extends etemplate_widget_transformer
+class importexport_widget_filter extends Etemplate\Widget\Transformer
 {
 
 	protected static $prefix = '';
-
+	
 	protected static $transformation = array(
 		'type' => 'customfields'
 	 );
-
+		
 	/**
 	 * Adapt the settings to custom fields widget
 	 *
@@ -64,15 +67,15 @@ class importexport_widget_filter extends etemplate_widget_transformer
 		self::$transformation['label'] = '';
 
 		$this->setElementAttribute($form_name, 'prefix', self::$prefix);
-
+		
 		$n = 1;
 		foreach($fields as $lname => &$field)
 		{
 			$type =& $field['type'];
-
+			
 			// No filters are required
 			$field['needed'] = false;
-
+			
 			switch($type)
 			{
 				case 'date':
@@ -98,14 +101,14 @@ class importexport_widget_filter extends etemplate_widget_transformer
 					// and used as such.  All unknown values will be used for selection, not passed through to the query
 					if (isset($field['values']['@']))
 					{
-						$options['values'] = egw_customfields::get_options_from_file($field['values']['@']);
+						$options['values'] = Api\Storage\Customfields::get_options_from_file($field['values']['@']);
 						unset($field['values']['@']);
 					} else {
 						$options['values'] = array_diff_key($field['values'], array_flip(ajax_select_widget::$known_options));
 					}
 					$options = array_merge($options, array_intersect_key($field['values'], array_flip(ajax_select_widget::$known_options)));
 
-
+					
 					break;
 				case 'select':
 				default:
@@ -113,7 +116,7 @@ class importexport_widget_filter extends etemplate_widget_transformer
 					{
 						if (count($field['values']) == 1 && isset($field['values']['@']))
 						{
-							$field['values'] = egw_customfields::get_options_from_file($field['values']['@']);
+							$field['values'] = Api\Storage\Customfields::get_options_from_file($field['values']['@']);
 						}
 						foreach((array)$field['values'] as $key => $val)
 						{
@@ -157,75 +160,14 @@ class importexport_widget_filter extends etemplate_widget_transformer
 			}
 			unset($widget);
 		}
-
+		
 		parent::beforeSendToClient($cname, $expand);
 
 		$this->setElementAttribute($form_name, 'customfields', $fields);
 		$this->setElementAttribute($form_name, 'fields',array_fill_keys(array_keys($fields), true));
 		return false;
 	}
-
-	/**
-	 * Create widgets to select a relative date range
-	 *
-	 * @param $lname Field name
-	 * @param $options
-	 * @param $readonly
-	 *
-	 * @return Array of widget info
-	 */
-	protected static function do_relative_date($lname, Array &$value, $options, $readonly)
-	{
-		// Maybe this could be moved to date widget
-		$input = boetemplate::empty_cell('select',$lname, array(
-			'readonly'	=> $readonly,
-			'no_lang'	=> true,
-			'options'	=> $options,
-			'sel_options'	=> array('' => lang('all'))
-		));
-		foreach(importexport_helper_functions::$relative_dates as $label => $values)
-		{
-			$input['sel_options'][$label] = lang($label);
-		}
-
-		return $input;
-	}
-
-	/**
-	 * Create widgets to select an absolute date range
-	 *
-	 * @param $lname Field name
-	 * @param $options
-	 * @param $readonly
-	 *
-	 * @return Array of widget info
-	 */
-	protected static function do_absolute_date($lname, Array &$value, $options, $readonly)
-	{
-		$input = boetemplate::empty_cell('hbox',$lname);
-
-		$type = 'date';
-		$from = boetemplate::empty_cell($type, $lname.'[from]',array(
-			'readonly'      => $readonly,
-			'no_lang'       => True,
-			'size'          => $options
-		));
-
-		$to = boetemplate::empty_cell($type, $lname.'[to]', array(
-			'readonly'      => $readonly,
-			'no_lang'       => True,
-			'size'          => $options
-		));
-		boetemplate::add_child($input, $from);
-		boetemplate::add_child($input,boetemplate::empty_cell('label','',array(
-			'label' => lang('to'),
-			'no_lang' => true
-		)));
-		boetemplate::add_child($input, $to);
-		return $input;
-	}
-
-
+	
 	public function validate($cname, array $expand, array $content, &$validated=array())
 	{
 		$form_name = self::form_name($cname, $this->id, $expand);
@@ -243,4 +185,4 @@ class importexport_widget_filter extends etemplate_widget_transformer
 	}
 }
 // Register, or it won't be found
-etemplate_widget::registerWidget('importexport_widget_filter', array('filter'));
+Etemplate\Widget::registerWidget('importexport_widget_filter', array('filter'));
\ No newline at end of file
