@@ -423,7 +423,7 @@ class infolog_bo
 	 */
 	function link_id2from(&$info,$not_app='',$not_id='')
 	{
-		//echo "<p>boinfolog::link_id2from(subject='$info[info_subject]', link_id='$info[info_link_id]', from='$info[info_from]', not_app='$not_app', not_id='$not_id')";
+		//error_log(__METHOD__ . "(subject='{$info['info_subject']}', link_id='{$info['info_link_id']}', from='{$info['info_from']}', not_app='$not_app', not_id='$not_id')");
 
 		if ($info['info_link_id'] > 0 &&
 			(isset($info['links']) && ($link = $info['links'][$info['info_link_id']]) ||	// use supplied links info
@@ -712,26 +712,27 @@ class infolog_bo
 	* @param boolean $skip_notification = false true = do NOT send notification, false (default) = send notifications
 	* @param boolean $throw_exception = false Throw an exception (if required fields are not set)
 	* @param string $purge_cfs = null null=dont, 'ical'=only iCal X-properties (cfs name starting with "#"), 'all'=all cfs
+	* @param boolean $ignore_acl =true
 	*
 	* @return int|boolean info_id on a successfull write or false
 	*/
 	function write(&$values_in, $check_defaults=true, $touch_modified=true, $user2server=true,
-		$skip_notification=false, $throw_exception=false, $purge_cfs=null)
+		$skip_notification=false, $throw_exception=false, $purge_cfs=null, $ignore_acl=false)
 	{
 		$values = $values_in;
 		//echo "boinfolog::write()values="; _debug_array($values);
-		if (!$values['info_id'] && !$this->check_access(0,Acl::EDIT,$values['info_owner']) &&
-			!$this->check_access(0,Acl::ADD,$values['info_owner']))
+		if (!$ignore_acl && (!$values['info_id'] && !$this->check_access(0,Acl::EDIT,$values['info_owner']) &&
+			!$this->check_access(0,Acl::ADD,$values['info_owner'])))
 		{
 			return false;
 		}
 		// we need to get the old values to update the links in customfields and for the tracking
 		if ($values['info_id'])
 		{
-			$old = $this->read($values['info_id'], false, 'server');
+			$old = $this->read($values['info_id'], false, 'server', $ignore_acl);
 		}
 
-		if (($status_only = $values['info_id'] && !$this->check_access($values,Acl::EDIT)))
+		if (($status_only = !$ignore_acl && $values['info_id'] && !$this->check_access($values,Acl::EDIT)))
 		{
 			if (!isset($values['info_responsible']))
 			{
@@ -750,8 +751,8 @@ class infolog_bo
 				$status_only = $undelete = $this->check_access($values['info_id'],self::ACL_UNDELETE);
 			}
 		}
-		if ($values['info_id'] && !$this->check_access($values['info_id'],Acl::EDIT) && !$status_only ||
-		    !$values['info_id'] && $values['info_id_parent'] && !$this->check_access($values['info_id_parent'],Acl::ADD))
+		if (!$ignore_acl && ($values['info_id'] && !$this->check_access($values['info_id'],Acl::EDIT) && !$status_only ||
+		    !$values['info_id'] && $values['info_id_parent'] && !$this->check_access($values['info_id_parent'],Acl::ADD)))
 		{
 			return false;
 		}
@@ -759,7 +760,8 @@ class infolog_bo
 		// Make sure status is still valid if the type changes
 		if($old['info_type'] != $values['info_type'] && $values['info_status'])
 		{
-			if(!in_array($values['info_status'], array_keys($this->status[$values['info_type']])))
+			if (isset($this->status[$values['info_type']]) &&
+				!in_array($values['info_status'], array_keys($this->status[$values['info_type']])))
 			{
 				$values['info_status'] = $this->status['defaults'][$values['info_type']];
 			}
@@ -872,7 +874,7 @@ class infolog_bo
 		if (isset($this->group_owners[$values['info_type']]))
 		{
 			$values['info_owner'] = $this->group_owners[$values['info_type']];
-			if (!($this->grants[$this->group_owners[$values['info_type']]] & Acl::EDIT))
+			if (!$ignore_acl && !($this->grants[$this->group_owners[$values['info_type']]] & Acl::EDIT))
 			{
 				if (!$this->check_access($values['info_id'],Acl::EDIT) ||
 					!$values['info_id'] && !$this->check_access($values,Acl::ADD)
@@ -888,11 +890,6 @@ class infolog_bo
 			$values['info_owner'] = $this->so->user;
 		}
 
-		if (($info_from_set = ($values['info_link_id'] && isset($values['info_from']) && empty($values['info_from']))))
-		{
-			$values['info_from'] = $this->link_id2from($values);
-		}
-
 		$to_write = $values;
 		if ($user2server)
 		{
@@ -930,11 +927,11 @@ class infolog_bo
 		//_debug_array($values);
 		// error_log(__FILE__.'['.__LINE__.'] '.__METHOD__."()\n".array2string($values)."\n",3,'/tmp/infolog');
 
-		if (($info_id = $this->so->write($to_write, $check_modified, $purge_cfs)))
+		if (($info_id = $this->so->write($to_write, $check_modified, $purge_cfs, !isset($old))))
 		{
 			if (!isset($values['info_type']) || $status_only || empty($values['caldav_url']))
 			{
-				$values = $this->read($info_id, true, 'server');
+				$values = $this->read($info_id, true, 'server', $ignore_acl);
 			}
 
 			$values['info_id'] = $info_id;
@@ -947,7 +944,34 @@ class infolog_bo
 				$values['info_responsible'] = $values['info_responsible'] ? explode(',',$values['info_responsible']) : array();
 				$to_write['info_responsible'] = $values['info_responsible'];
 			}
+
+			// writing links for a new entry
+			if (!$old && is_array($to_write['link_to']['to_id']) && count($to_write['link_to']['to_id']))
+			{
+				//echo "<p>writing links for new entry $info_id</p>\n"; _debug_array($content['link_to']['to_id']);
+				Link::link('infolog',$info_id,$to_write['link_to']['to_id']);
+				$values['link_to']['to_id'] = $info_id;
+			}
+			$this->write_check_links($to_write);
+			if(!$values['info_link_id'] || $values['info_link_id'] != $to_write['info_link_id'])
+			{
+				// Just got a link ID, need to save it
+				$this->so->write($to_write);
+				$values['info_link_id'] = $to_write['info_link_id'];
+				$values['info_contact'] = $to_write['info_contact'];
+				$this->link_id2from($values);
+			}
+
+			if (($info_from_set = ($values['info_link_id'] && isset($values['info_from']) && empty($values['info_from']))))
+			{
+				$values['info_from'] = $to_write['info_from'] = $this->link_id2from($values);
+			}
+
 			// create (and remove) links in custom fields
+			if(!is_array($old))
+			{
+				$old = array();
+			}
 			Api\Storage\Customfields::update_links('infolog',$values,$old,'info_id');
 
 			// Check for restore of deleted entry, restore held links
@@ -1000,15 +1024,77 @@ class infolog_bo
 			$values_in = array_merge($values_in,$values);
 
 			// Update modified timestamp of parent
-			if($values['info_id_parent'])
+			if($values['info_id_parent'] && $touch_modified)
 			{
-				$parent = $this->read($values['info_id_parent'], false, 'server',true);
-				$this->write($parent,false, true, false, true);
+				$parent = $this->read($values['info_id_parent'], false, 'server', true);
+				$this->write($parent, false, true, false, true, false, null, $ignore_acl);
 			}
 		}
 		return $info_id;
 	}
 
+	/**
+	 * Check links when writing an infolog entry
+	 *
+	 * Checks for info_contact properly linked, project properly linked and
+	 * adds or removes to correct.
+	 *
+	 * @param Array $values
+	 */
+	protected function write_check_links(&$values)
+	{
+		$old_link_id = (int)$values['info_link_id'];
+		if($values['info_contact'])
+		{
+			if(is_array($values['info_contact']))
+			{
+				// eTemplate2 returns the array all ready
+				$app = $values['info_contact']['app'];
+				$id = $values['info_contact']['id'];
+			}
+			else if ($values['info_contact'])
+			{
+				list($app, $id) = explode(':', $values['info_contact'], 2);
+			}
+			// if project has been removed, but is still info_contact --> also remove it
+			if ($app == 'projectmanager' && $id && $id == $values['old_pm_id'] && !$values['pm_id'])
+			{
+				unset($values['info_link_id'], $id, $values['info_contact']['id']);
+			}
+			elseif ($app && $id)
+			{
+				if(!is_array($values['link_to']))
+				{
+					$values['link_to'] = array();
+				}
+				$values['info_link_id'] = (int)($info_link_id = Link::link(
+						'infolog',
+						$values['info_id'],
+						$app,$id
+				));
+			}
+			else
+			{
+				unset($values['info_link_id']);
+			}
+		}
+		if ($old_link_id && $old_link_id != $values['info_link_id'])
+		{
+			$link = Link::get_link($old_link_id);
+			// remove selected project, if removed link is that project
+			if($link['link_app2'] == 'projectmanager' && $link['link_id2'] == $values['old_pm_id'])
+			{
+				unset($values['pm_id'], $values['old_pm_id']);
+			}
+			Link::unlink($old_link_id);
+		}
+		// if added link is a project and no other project selected, also add as project
+		if ($app == 'projectmanager' && $id && !$values['pm_id'])
+		{
+			$values['old_pm_id'] = $values['pm_id'] = $id;
+		}
+	}
+
 	/**
 	 * Query the number of children / subs for one or more info_id's
 	 *
@@ -1031,9 +1117,10 @@ class infolog_bo
 	 * @param $query[action] / $query[action_id] if only entries linked to a specified app/entry show be used
 	 * @param &$query[start], &$query[total] nextmatch-parameters will be used and set if query returns less entries
 	 * @param $query[col_filter] array with column-name - data pairs, data == '' means no filter (!)
+	 * @param boolean $no_acl =false true: ignore all acl
 	 * @return array with id's as key of the matching log-entries
 	 */
-	function &search(&$query)
+	function &search(&$query, $no_acl=false)
 	{
 		//error_log(__METHOD__.'('.array2string($query).')');
 
@@ -1065,14 +1152,14 @@ class infolog_bo
 			}
 		}
 
-		$ret = $this->so->search($query);
+		$ret = $this->so->search($query, $no_acl);
 		$this->total = $query['total'];
 
 		if (is_array($ret))
 		{
 			foreach ($ret as $id => &$data)
 			{
-				if (!$this->check_access($data,Acl::READ))
+				if (!$no_acl && !$this->check_access($data,Acl::READ))
 				{
 					unset($ret[$id]);
 					continue;
@@ -1343,8 +1430,8 @@ class infolog_bo
 		$to_include = array();
 		$date_wanted = sprintf('%04d/%02d/%02d',$args['year'],$args['month'],$args['day']);
 		$query = array(
-			'order' => 'info_startdate',
-			'sort'  => $do_events ? 'ASC' : 'DESC',
+			'order' => $args['order'] ? $args['order'] : 'info_startdate',
+			'sort'  => $args['sort'] ? $args['sort'] : ($do_events ? 'ASC' : 'DESC'),
 			'filter'=> "user$user".($do_events ? 'date' : 'opentoday').$date_wanted,
 			'start' => 0,
 		);
@@ -1412,7 +1499,7 @@ class infolog_bo
 			$query = array(
 				'col_filter' => array('info_id' => $args['infolog']),
 				'subs' => true,
-				'cols' => 'info_id,info_type,info_status,info_percent,info_id_parent',
+				'cols' => 'main.info_id,info_type,info_status,info_percent,info_id_parent',
 			);
 			$infos = array();
 			foreach($this->search($query) as $row)
@@ -1430,9 +1517,13 @@ class infolog_bo
 					$infos[$row['info_id']]['icon'] = 'infolog/'.$icon;
 				}
 			}
-			foreach($this->anzSubs(array_keys($infos)) as $info_id => $subs)
+			$anzSubs = $this->anzSubs(array_keys($infos));
+			if($anzSubs && is_array($anzSubs))
 			{
-				if ($subs) $infos[$info_id]['class'] .= ' infolog_rowHasSubs';
+				foreach($anzSubs as $info_id => $subs)
+				{
+					if ($subs) $infos[$info_id]['class'] .= ' infolog_rowHasSubs';
+				}
 			}
 		}
 		return $infos;
@@ -1564,7 +1655,6 @@ class infolog_bo
 			$GLOBALS['egw']->preferences->__construct($user);
 			$GLOBALS['egw_info']['user']['preferences'] = $GLOBALS['egw']->preferences->read_repository();
 			$GLOBALS['egw']->acl->__construct($user);
-			$GLOBALS['egw']->acl->read_repository();
 			$this->grants = $GLOBALS['egw']->acl->get_grants('infolog',$this->group_owners ? $this->group_owners : true);
 			$this->so = new infolog_so($this->grants);	// so caches it's filters
 
