@@ -511,9 +511,10 @@ class infolog_so
 	 * @param array $values with the data of the log-entry
 	 * @param int $check_modified =0 old modification date to check before update (include in WHERE)
 	 * @param string $purge_cfs =null null=dont, 'ical'=only iCal X-properties (cfs name starting with "#"), 'all'=all cfs
+	 * @param boolean $force_insert =false force using insert, even if an id is given eg. for import
 	 * @return int|boolean info_id, false on error or 0 if the entry has been updated in the meantime
 	 */
-	function write($values, $check_modified=0, $purge_cfs=null)  // did _not_ ensure ACL
+	function write($values, $check_modified=0, $purge_cfs=null, $force_insert=false)  // did _not_ ensure ACL
 	{
 		if (isset($GLOBALS['egw_info']['user']['preferences']['syncml']['minimum_uid_length']))
 		{
@@ -535,7 +536,7 @@ class infolog_so
 		$to_write = array();
 		foreach($values as $key => $val)
 		{
-			if ($key != 'info_id' && isset($table_def['fd'][$key]))
+			if (($key != 'info_id' || $force_insert && $info_id > 0) && isset($table_def['fd'][$key]))
 			{
 				$to_write[$key] = $this->data[$key] = $val;   // update internal data
 			}
@@ -543,7 +544,7 @@ class infolog_so
 		// writing no price as SQL NULL (required by postgres)
 		if ($to_write['info_price'] === '') $to_write['info_price'] = NULL;
 
-		if (($this->data['info_id'] = $info_id))
+		if (($this->data['info_id'] = $info_id) && !$force_insert)
 		{
 			$where = array('info_id' => $info_id);
 			if ($check_modified) $where['info_datemodified'] = $check_modified;
@@ -593,6 +594,10 @@ class infolog_so
 			$this->db->delete($this->extra_table,$where,__LINE__,__FILE__);
 		}
 		$to_delete = array();
+
+		// Deal with files in new entries
+		Api\Storage\Customfields::handle_files('infolog',$info_id,$values);
+
 		foreach($values as $key => $val)
 		{
 			if ($key[0] != '#')
@@ -672,9 +677,10 @@ class infolog_so
 	 * @param string|array $query[cols]=null what to query, if set the recordset / iterator get's returned
 	 * @param string $query[append]=null get's appended to sql query, eg. for GROUP BY
 	 * @param boolean $query['custom_fields']=false query custom-fields too, default not
+	 * @param boolean $no_acl =false true: ignore all acl
 	 * @return array|iterator with id's as key of the matching log-entries or recordset/iterator if cols is set
 	 */
-	function search(&$query)
+	function search(&$query, $no_acl=false)
 	{
 		//error_log(__METHOD__.'('.array2string($query).')');
 		$action2app = array(
@@ -731,7 +737,7 @@ class infolog_so
 		{
 			$ordermethod = 'ORDER BY info_datemodified DESC';   // newest first
 		}
-		$filtermethod = $this->aclFilter($query['filter']);
+		$filtermethod = $no_acl ? '1=1' : $this->aclFilter($query['filter']);
 		if (!$query['col_filter']['info_status'])  $filtermethod .= $this->statusFilter($query['filter']);
 		$filtermethod .= $this->dateFilter($query['filter']);
 		$cfcolfilter=0;
@@ -809,6 +815,7 @@ class infolog_so
 
 			$wildcard = $op = null;
 			$so_sql = new Api\Storage\Base('infolog', $this->info_table, $this->db);
+			$so_sql->table_name = 'main';
 			$search = $so_sql->search2criteria($query['search'], $wildcard, $op, null, $columns);
 			$sql_query = 'AND ('.(is_numeric($query['search']) ? 'main.info_id='.(int)$query['search'].' OR ' : '').
 				implode($op, $search) .')';
