@@ -316,7 +316,8 @@ class infolog_ui
 			unset($query['col_filter']['parent_id']);
 			if(!$query['action'])
 			{
-				Api\Cache::setSession('infolog', $query['session_for'].'session_data', $query);
+				Api\Cache::setSession('infolog', $query['session_for'].'session_data',
+					array_diff_key ($query, array_flip(array('rows','actions','action_links','placeholder_actions'))));
 			}
 			$query['actions'] = $this->get_actions($query);
 			$query['row_id'] = 'info_id';
@@ -685,6 +686,28 @@ class infolog_ui
 		return $event;
 	}
 
+	/**
+	 * hook called be calendar to include events or todos in the cal-dayview
+	 * Since the hook has no idea about infolog or preferences, we add the user's
+	 * current sorting for infolog here so they're in the expected order
+	 *
+	 * @param int $args[year], $args[month], $args[day] date of the events
+	 * @param int $args[owner] owner of the events
+	 * @param string $args[location] calendar_include_{events|todos}
+	 * @return array of events (array with keys starttime, endtime, title, view, icon, content)
+	 */
+	public function cal_to_include($args)
+	{
+		$nm = Api\Cache::getSession('infolog', 'session_data');
+		if($nm)
+		{
+			$args['order'] = $nm['order'];
+			$args['sort'] = $nm['sort'];
+		}
+
+		return $this->bo->cal_to_include($args);
+	}
+
 	/**
 	 * Shows the infolog list
 	 *
@@ -855,6 +878,7 @@ class infolog_ui
 			{
 				unset($values['nm']['multi_action']);
 				unset($values['nm']['action_id']);
+				unset($values['nm']['rows']);
 				Api\Cache::setSession('infolog', $values['nm']['session_for'].'session_data', $values['nm']);
 				$this->tmpl->location($own_referer);
 			}
@@ -916,7 +940,7 @@ class infolog_ui
 		$values['nm']['filter_onchange'] = "app.infolog.filter_change();";
 
 		//apply infolog_filter2_change javascript method (show/hide details each rows) over onchange filter2
-		$values['nm']['filter2_onchange'] = "app.infolog.filter2_change";
+		$values['nm']['filter2_onchange'] = "return app.infolog.filter2_change(ev, widget)";
 
 		// disable favories dropdown button, if not running as infolog
 		if ($called_as && $called_as != 'infolog')
@@ -1218,10 +1242,24 @@ class infolog_ui
 			$actions['timesheet'] = array(	// interactive add for a single event
 				'icon' => 'timesheet/navbar',
 				'caption' => 'Timesheet',
-				'url' => 'menuaction=timesheet.timesheet_ui.edit&link_app[]=infolog&link_id[]=$id',
 				'group' => $group,
 				'allowOnMultiple' => false,
-				'popup' => Link::get_registry('timesheet', 'add_popup'),
+
+				'children' => array(
+					'timesheet_list' => array(
+						'caption' => lang('View linked %1 entries', lang('timesheet')),
+						'icon' => 'infolog/navbar',
+						'onExecute' => 'javaScript:app.infolog.timesheet_list',
+						'allowOnMultiple' => false,
+						'hideOnDisabled' => true,
+					),
+					'timesheet_add' => array(
+						'icon' => 'timesheet/navbar',
+						'caption' => 'Add timesheet entry',
+						'url' => 'menuaction=timesheet.timesheet_ui.edit&link_app[]=infolog&link_id[]=$id',
+						'popup' => Link::get_registry('timesheet', 'add_popup'),
+					)
+				)
 			);
 		}
 		if ($GLOBALS['egw_info']['user']['apps']['tracker'])
@@ -1722,52 +1760,19 @@ class infolog_ui
 				if (($button == 'save' || $button == 'apply') && (!$info_id || $edit_acl || $status_only || $undelete))
 				{
 					$operation = $info_id ?  'edit' : 'add';
-					if ($content['info_contact'])
-					{
-						$old_link_id = (int)$content['info_link_id'];
-						if(is_array($content['info_contact']))
-						{
-							// eTemplate2 returns the array all ready
-							$app = $content['info_contact']['app'];
-							$id = $content['info_contact']['id'];
-						}
-						// if project has been removed, but is still info_contact --> also remove it
-						if ($app == 'projectmanager' && $id && $id == $content['old_pm_id'] && !$content['pm_id'])
-						{
-							unset($content['info_link_id'], $id, $content['info_contact']['id']);
-						}
-						elseif ($app && $id)
-						{
-							if(!is_array($content['link_to']))
-							{
-								$content['link_to'] = array();
-							}
-							$content['info_link_id'] = (int)($info_link_id = Link::link('infolog',$content['link_to']['to_id'],$app,$id));
-						}
-						else
-						{
-							unset($content['info_link_id']);
-						}
-						if ($old_link_id && $old_link_id != $content['info_link_id'])
-						{
-							$link = Link::get_link($old_link_id);
-							// remove selected project, if removed link is that project
-							if($link['link_app2'] == 'projectmanager' && $link['link_id2'] == $content['old_pm_id'])
-							{
-								unset($content['pm_id'], $content['old_pm_id']);
-							}
-							Link::unlink($old_link_id);
-						}
-						// if added link is a project and no other project selected, also add as project
-						if ($app == 'projectmanager' && $id && !$content['pm_id'])
-						{
-							$content['old_pm_id'] = $content['pm_id'] = $id;
-						}
-					}
+
 					if (is_array($content['link_to']['to_id']) && count($content['link_to']['to_id']))
 					{
 						$content['info_link_id'] = 0;	// as field has to be int
 					}
+					if (is_array($content['info_contact']) && $content['info_contact']['id'])
+					{
+						$content['info_contact'] = $content['info_contact']['app'] . ':' . $content['info_contact']['id'];
+					}
+					else
+					{
+						$content['info_contact'] = false;
+					}
 					$active_tab = $content['tabs'];
 					if (!($info_id = $this->bo->write($content, true, true, true, $content['no_notifications'])))
 					{
@@ -1791,6 +1796,11 @@ class infolog_ui
 						Framework::refresh_opener($content['msg'],'infolog',$info_id,$operation);
 					}
 					$content['tabs'] = $active_tab;
+					//try to keep the project manager link if the intenstion is only to remove contact
+					if ($old['info_link']['app'] == 'projectmanager' && $old['info_link']['id'] = $content['pm_id'])
+					{
+						Link::link('infolog',$content['link_to']['to_id'],'projectmanager',$content['pm_id']);
+					}
 					if ((int) $content['pm_id'] != (int) $content['old_pm_id'])
 					{
 						//echo "<p>pm_id changed: $content[old_pm_id] -> $content[pm_id]</p>\n";
@@ -1798,7 +1808,7 @@ class infolog_ui
 						if ($content['pm_id'])
 						{
 							//echo "<p>this->link->link('infolog',{$content['link_to']['to_id']},'projectmanager',{$content['pm_id']});</p>";
-							Link::link('infolog',$content['link_to']['to_id'],'projectmanager',$content['pm_id']);
+							Link::link('infolog',$info_id,'projectmanager',$content['pm_id']);
 							// making the project the selected link, if no other link selected
 							if (!$info_link_id || $info_link_id == 'projectmanager:'.$content['old_pm_id'])
 							{
@@ -1812,13 +1822,9 @@ class infolog_ui
 						}
 						$content['old_pm_id'] = $content['pm_id'];
 					}
-					// writing links for a new entry
-					if ($info_id && is_array($content['link_to']['to_id']) && count($content['link_to']['to_id']))
-					{
-						//echo "<p>writing links for new entry $info_id</p>\n"; _debug_array($content['link_to']['to_id']);
-						Link::link('infolog',$info_id,$content['link_to']['to_id']);
-						$content['link_to']['to_id'] = $info_id;
-					}
+					$content['link_to']['to_app'] = 'infolog';
+					$content['link_to']['to_id'] = $info_id;
+
 					if ($info_link_id && strpos($info_link_id,':') !== false)	// updating info_link_id if necessary
 					{
 						list($app,$id) = explode(':',$info_link_id);
@@ -1836,6 +1842,14 @@ class infolog_ui
 							);
 							//echo "<p>updating info_link_id: ".print_r($to_write,true)."</p>\n";
 							$this->bo->write($to_write,False,true,true,true);	// last true = no notifications, as no real change
+
+							// Do not override info_contact if is already filled with contact
+							if ($content['info_contact'])
+							{
+								unset($to_write['info_contact']);
+								unset($to_write['blur_title']);
+							}
+
 							// we need eg. the new modification date, for further updates
 							$content = array_merge($content,$to_write);
 						}
@@ -2131,6 +2145,7 @@ class infolog_ui
 				{
 					$readonlys[$name] = false;
 				}
+				$readonlys['timestamp'] = $readonlys['info_des'];
 				$readonlys['button[edit]'] = $readonlys['button[save]'] = $readonlys['button[apply]'] = $readonlys['no_notifications'] = false;
 			}
 			$readonlys['action'] = $readonlys['button[cancel]'] = false;	// always allowed
@@ -2364,7 +2379,7 @@ class infolog_ui
 		}
 		if (!$create_sub)
 		{
-			$content['msg'] .= ($content['msg']?"\n":'').lang('Infolog copied - the copy can now be edited');
+			$content['msg'] .= ($content['msg']?"\n":'').lang('%1 copied - the copy can now be edited', lang(Link::get_registry('infolog','entry')));
 		}
 	}
 
