@@ -60,7 +60,7 @@ app.classes.infolog = AppJS.extend(
 				var filter2 = nm.getWidgetById('filter2');
 				this.show_details(filter2.value == 'all',nm.getDOMNode(nm));
 				// Remove the rule added by show_details() if the template is removed
-				jQuery(_et2.DOMContainer).on('clear', function() {egw.css('#infolog-index_nm .et2_box.infoDes');});
+				jQuery(_et2.DOMContainer).on('clear', jQuery.proxy(function() {egw.css(this);}, '#' + nm.getDOMNode(nm).id + ' .et2_box.infoDes'));
 
 				// Enable decrypt on hover
 				if(this.egw.user('apps').stylite)
@@ -214,7 +214,9 @@ app.classes.infolog = AppJS.extend(
 					if (filter && dates)
 					{
 						dates.set_disabled(false);
-						jQuery(this.et2.getWidgetById('startdate').getDOMNode()).find('input').focus();
+						window.setTimeout(function() {
+							jQuery(dates.getWidgetById('startdate').getDOMNode()).find('input').focus();
+						},0);
 					}
 					break;
 				default:
@@ -241,7 +243,7 @@ app.classes.infolog = AppJS.extend(
 		if (nm && filter2)
 		{
 			// Show / hide descriptions
-			this.show_details(filter2.value == 'all', nm.getDOMNode(nm));
+			this.show_details(filter2.get_value() === 'all', nm.getDOMNode(nm));
 		}
 
 		// Only change columns for a real user event, to avoid interfering with
@@ -258,7 +260,10 @@ app.classes.infolog = AppJS.extend(
 			var colData = nm.columns.slice();
 			for(var i = 0; i < nm.columns.length; i++) colData[i].visible=false;
 
-			nm.set_columns(egw.preference(nm.options.settings.columnselection_pref,'infolog').split(','));
+			if(egw.preference(nm.options.settings.columnselection_pref,'infolog'))
+			{
+				nm.set_columns(egw.preference(nm.options.settings.columnselection_pref,'infolog').split(','));
+			}
 			nm._applyUserPreferences(nm.columns, colData);
 
 			// Now apply them to columns
@@ -268,9 +273,16 @@ app.classes.infolog = AppJS.extend(
 				nm.dataview.getColumnMgr().columns[i].set_visibility(colData[i].visible);
 			}
 			nm.dataview.getColumnMgr().updated = true;
-			// Update page
+			
+			// Update page - set update_in_progress to true to avoid triggering
+			// the change handler and looping if the user has a custom field
+			// column change
+			var in_progress = nm.update_in_progress;
+			nm.update_in_progress = true;
 			nm.dataview.updateColumns();
+			nm.update_in_progress = in_progress;
 		}
+		return false;
 	},
 
 	/**
@@ -521,7 +533,7 @@ app.classes.infolog = AppJS.extend(
 	 */
 	infolog_print_preview: function()
 	{
-		this.egw.message('Printing...');
+		this.egw.message(this.egw.lang('Printing...'));
 		this.egw.window.print();
 	},
 
@@ -631,6 +643,34 @@ app.classes.infolog = AppJS.extend(
 		}
 	},
 
+	/**
+	 * View a list of timesheets for the linked infolog entry
+	 *
+	 * Only one infolog entry at a time is allowed, we just pick the first one
+	 *
+	 * @param {egwAction} _action
+	 * @param {egwActionObject[]} _selected
+	 */
+	timesheet_list: function(_action, _selected)
+	{
+		var extras = {
+			link_app: 'infolog',
+			link_id: false
+		};
+		for(var i = 0; i < _selected.length; i++)
+		{
+			// Remove UID prefix for just contact_id
+			var ids = _selected[i].id.split('::');
+			ids.shift();
+			ids = ids.join('::');
+
+			extras.link_id = ids;
+			break;
+		}
+		
+		egw.open("","timesheet","list", extras, 'timesheet');
+	},
+
 	/**
 	 * Go to parent entry
 	 *
