@@ -58,7 +58,7 @@ foreach($colors as $color => $label)
 $GLOBALS['settings'] = array(
 	'prefssection' => array(
 		'type'   => 'section',
-		'title'  => lang('Preferences for the %1 template set','Stylite'),
+		'title'  => lang('Preferences for the %1 template set','jDots'),
 		'no_lang'=> true,
 		'xmlrpc' => False,
 		'admin'  => False,
