@@ -1,31 +1,31 @@
 <?php
 /**
- * Stylite: jdots template
+ * EGroupware: jdots template
  *
- * @link http://www.stylite.de
+ * @link http://www.egroupware.org
  * @package jdots
- * @author Andreas Stöckel <as@stylite.de>
- * @author Ralf Becker <rb@stylite.de>
- * @author Nathan Gray <ng@stylite.de>
+ * @author Andreas Stöckel
+ * @author Ralf Becker <rb@egroupware.org>
+ * @author Nathan Gray <ng@egroupware.org>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
 $GLOBALS['egw_info']['template']['jdots']['name']      = 'jdots';
-$GLOBALS['egw_info']['template']['jdots']['title']     = 'Stylite';
+$GLOBALS['egw_info']['template']['jdots']['title']     = 'jDots';
 $GLOBALS['egw_info']['template']['jdots']['version']   = '16.1';
 
 $GLOBALS['egw_info']['template']['jdots']['author'] = array(
-	array('name' => 'Andreas Stoeckel', 'email' => 'as@stylite.de'),
-	array('name' => 'Ralf Becker', 'email' => 'rb@stylite.de'),
-	array('name' => 'Nathan Gray', 'email' => 'ng@stylite.de'),
+	array('name' => 'Andreas Stoeckel'),
+	array('name' => 'Ralf Becker', 'email' => 'rb@egroupware.org'),
+	array('name' => 'Nathan Gray', 'email' => 'ng@egroupware.org'),
 );
 $GLOBALS['egw_info']['template']['jdots']['license'] = 'GPL';
 $GLOBALS['egw_info']['template']['jdots']['icon'] = "jdots/images/jdots-logo.png";
 $GLOBALS['egw_info']['template']['jdots']['maintainer'] = array(
-   array('name' => 'Stylite AG', 'url' => 'http://www.stylite.de/')
+   array('name' => 'EGroupware GmbH', 'url' => 'http://www.egroupware.org/')
 );
-$GLOBALS['egw_info']['template']['jdots']['description'] = "Stylite is a new jQuery based template set for EGroupware EPL.";
+$GLOBALS['egw_info']['template']['jdots']['description'] = "jDots was the  jQuery based default template set for EGroupware EPL 11.1.";
 $GLOBALS['egw_info']['template']['jdots']['windowed'] = true;
 $GLOBALS['egw_info']['template']['jdots']['icon'] = 'jdots/images/epl.png';
 
