@@ -4,8 +4,8 @@
  *
  * @link http://www.egroupware.org
  * @package mail
- * @author Hadi Nategh [hn@stylite.de]
- * @copyright (c) 2015-16 by Stylite AG <info-AT-stylite.de>
+ * @author Hadi Nategh [hn@egroupware.org]
+ * @copyright (c) 2015-16 by EGroupware GmbH <info-AT-egroupware.org>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id:$
  */
@@ -140,9 +140,9 @@ class mail_integration {
 						}
 						//make sure we search for our attached file in our configured temp_dir
 						if (isset($attachment['file']) && parse_url($attachment['file'],PHP_URL_SCHEME) != 'vfs' &&
-							file_exists($GLOBALS['egw_info']['server']['temp_dir'].SEP.basename($attachment['file'])))
+							file_exists($GLOBALS['egw_info']['server']['temp_dir'].'/'.basename($attachment['file'])))
 						{
-							$attachment['file'] = $GLOBALS['egw_info']['server']['temp_dir'].SEP.basename($attachment['file']);
+							$attachment['file'] = $GLOBALS['egw_info']['server']['temp_dir'].'/'.basename($attachment['file']);
 						}
 						if(in_array($attachment['name'], $file_list))
 						{
@@ -250,7 +250,7 @@ class mail_integration {
 					fclose($tmpfile);
 					$size = filesize($attachment_file);
 					$mailcontent['attachments'][] = array(
-							'name' => trim($subject).'.eml',
+							'name' => Api\Vfs::encodePathComponent(trim($subject)).'.eml',
 							'mimeType' => 'message/rfc822',
 							'type' => 'message/rfc822',
 							'tmp_name' => $attachment_file,
