@@ -4,8 +4,8 @@
  *
  * @link http://www.egroupware.org
  * @package mail
- * @author Hadi Nategh [hn@stylite.de]
- * @copyright (c) 2013-16 by Hadi Nategh <hn-AT-stylite.de>
+ * @author Hadi Nategh [hn@egroupware.org]
+ * @copyright (c) 2013-16 by Hadi Nategh <hn-AT-egroupware.org>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
@@ -67,7 +67,7 @@ class mail_sieve
 	function __construct()
 	{
 		$this->displayCharset = Api\Translation::charset();
-		$this->mail_admin = isset($GLOBALS['egw_info']['user']['apps']['emailadmin']);
+		$this->mail_admin = isset($GLOBALS['egw_info']['user']['apps']['admin']);
 		$this->mailConfig = Api\Config::read('mail');
 
 		$acc_id = isset($_GET['acc_id']) ? (int)$_GET['acc_id'] : Api\Cache::getSession(__CLASS__, 'acc_id');
@@ -418,7 +418,7 @@ class mail_sieve
 	 *
 	 * @param string $accountID
 	 *
-	 * @return array return multi-dimentional array of vacation and aliases
+	 * @return array return multi-dimensional array of vacation and aliases
 	 */
 	function getVacation($accountID = null)
 	{
@@ -445,15 +445,26 @@ class mail_sieve
 		}
 		if (is_null($accountID)) $accountID = $GLOBALS['egw_info']['user']['account_id'];
 
+		$account_email =  Api\Accounts::id2name($accountID, 'account_email');
 		$accAllIdentities = $this->account->smtpServer()->getAccountEmailAddress(Api\Accounts::id2name($accountID));
-		$allAliases = array($this->account->ident_email);
-		foreach ($accAllIdentities as &$arrVal)
+		$allAliases = $this->account->ident_email !=''?
+				// Fix ident_email with no domain part set
+				array(Mail::fixInvalidAliasAddress($account_email, $this->account->ident_email))
+				: array();
+		foreach ($accAllIdentities as &$val)
 		{
-			if ($arrVal['type'] !='default')
+			if ($val['type'] !='default')
 			{
-				$allAliases[] =  $arrVal['address'];
+				// if the alias has no domain part set try to add
+				// default domain extracted from ident_email address
+				$allAliases[] =  Mail::fixInvalidAliasAddress($account_email, $val['address']);
 			}
 		}
+		// try to fix already stored aliases
+		foreach ($vacation['addresses'] as &$address)
+		{
+			$address = Mail::fixInvalidAliasAddress($account_email, $address);
+		}
 		asort($allAliases);
 		return array(
 			'vacation' =>$vacation,
@@ -711,7 +722,7 @@ class mail_sieve
 	}
 
 	/**
-	 * Strip personal part from rfc822 addresses: "Ralf Becker <rb@stylite.de>" --> rb@stylite.de
+	 * Strip personal part from rfc822 addresses: "Ralf Becker <rb@egroupware.org>" --> rb@egroupware.org
 	 *
 	 * Sieve only allows email-addresses, without angle brakets and personal parts.
 	 *
@@ -1149,7 +1160,7 @@ class mail_sieve
 		$sessionData['sieve_rules']		= $this->rules;
 		$sessionData['sieve_rulesByID'] = $this->rulesByID;
 		$sessionData['sieve_scriptToEdit']	= $this->scriptToEdit;
-		$GLOBALS['egw']->session->appsession('sieve_session_data','',$sessionData);
+		Api\Cache::setSession(__CLASS__, 'sieve_session_data', $sessionData);
 	}
 
 	/**
@@ -1193,7 +1204,7 @@ class mail_sieve
 	 */
 	function restoreSessionData()
 	{
-		$sessionData = $GLOBALS['egw']->session->appsession('sieve_session_data');
+		$sessionData = Api\Cache::getSession(__CLASS__, 'sieve_session_data');
 		$this->rules		= $sessionData['sieve_rules'];
 		$this->rulesByID = $sessionData['sieve_rulesByID'];
 		$this->scriptToEdit	= $sessionData['sieve_scriptToEdit'];
