@@ -4,10 +4,10 @@
  *
  * @link http://www.egroupware.org
  * @package mail
- * @author Stylite AG [info@stylite.de]
- * @author Ralf Becker <rb@stylite.de>
+ * @author EGroupware GmbH [info@egroupware.org]
+ * @author Ralf Becker <rb@egroupware.org>
  * @author Philip Herbert <philip@knauber.de>
- * @copyright (c) 2014-16 by Stylite AG <info-AT-stylite.de>
+ * @copyright (c) 2014-16 by EGroupware GmbH <info-AT-egroupware.org>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
@@ -67,6 +67,9 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 
 	static $profileID;
 
+	// to control how deep one may dive into the past
+	const PAST_LIMIT = 178;
+
 	/**
 	 * debugLevel - enables more debug
 	 *
@@ -172,17 +175,42 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 			'default' => 'sendifnocalnotif',
 			'admin'  => False,
 		);
+		$settings['mail-maximumSyncRange'] = array(
+			'type'   => 'integer',
+			'label'  => lang('How many days to sync in the past when client does not specify a date-range (default %1)', self::PAST_LIMIT),
+			'name'   => 'mail-maximumSyncRange',
+			'help'   => 'if the client sets no sync range, you may override the setting (preventing client crash that may be caused by too many mails/too much data). If you want to sync way-back into the past: set a large number',
+			'xmlrpc' => True,
+			'admin'  => False,
+		);
+
 /*
+		$sigOptions = array(
+				'send'=>'yes, always add EGroupware signatures to outgoing mails',
+				'nosend'=>'no, never add EGroupware signatures to outgoing mails',
+			);
+		if (!isset($hook_data['setup']) && in_array($hook_data['type'], array('user', 'group'))&&$hook_data['account_id'])
+		{
+			$pID=self::$profileID;
+			if ($GLOBALS['egw_info']['user']['preferences']['activesync']['mail-ActiveSyncProfileID']=='G')
+			{
+				$pID=Mail\Account::get_default_acc_id();
+			}
+			$acc = Mail\Account::read($pID);
+			error_log(__METHOD__.__LINE__.':'.$pID.'->'.array2string($acc));
+			$Identities = Mail\Account::identities($pID);
+			foreach($Identities as &$identity)
+			{
+				$Identity = self::identity_name($identity);
+			}
+			error_log(__METHOD__.__LINE__.array2string($Identities));
+		}
 		$settings['mail-useSignature'] = array(
 			'type'   => 'select',
 			'label'  => 'control if and which available signature is added to outgoing mails',
 			'name'   => 'mail-useSignature',
 			'help'   => 'control the use of signatures',
-			'values' => array(
-				'sendifnocalnotif'=>'only send if there is no notification in calendar',
-				'send'=>'yes, always add EGroupware signatures to outgoing mails',
-				'nosend'=>'no, never add EGroupware signatures to outgoing mails',
-			),
+			'values' => $sigOptions,
 			'xmlrpc' => True,
 			'default' => 'nosend',
 			'admin'  => False,
@@ -378,20 +406,51 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 		$activeMailProfile = Mail::getStandardIdentityForProfile($activeMailProfiles,self::$profileID);
 
 		ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."(".__LINE__.")".' ProfileID:'.self::$profileID.' ActiveMailProfile:'.array2string($activeMailProfile));
+		// collect identity / signature for later usage, and to determine if we may have to manipulate TransferEncoding and Charset
+		try
+		{
+			$acc = Mail\Account::read($this->mail->icServer->ImapServerId);
+			//error_log(__METHOD__.__LINE__.array2string($acc));
+			$_signature = Mail\Account::read_identity($acc['ident_id'],true);
+		}
+		catch (Exception $e)
+		{
+			$_signature=array();
+		}
+		$signature = $_signature['ident_signature'];
+		if ((isset($preferencesArray['disableRulerForSignatureSeparation']) &&
+			$preferencesArray['disableRulerForSignatureSeparation']) ||
+			empty($signature) || trim(Api\Mail\Html::convertHTMLToText($signature)) =='')
+		{
+			$disableRuler = true;
+		}
+		$beforePlain = $beforeHtml = "";
+		$beforeHtml = ($disableRuler ?'&nbsp;<br>':'&nbsp;<br><hr style="border:dotted 1px silver; width:90%; border:dotted 1px silver;">');
+		$beforePlain = ($disableRuler ?"\r\n\r\n":"\r\n\r\n-- \r\n");
+		$sigText = Mail::merge($signature,array($GLOBALS['egw']->accounts->id2name($GLOBALS['egw_info']['user']['account_id'],'person_id')));
+		if ($this->debugLevel>0) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' Signature to use:'.$sigText);
+		$sigTextHtml = $beforeHtml.$sigText;
+		$sigTextPlain = $beforePlain.Api\Mail\Html::convertHTMLToText($sigText);
 
+		$force8bit=false;
+		if (Api\Translation::detect_encoding($sigTextPlain)!='ascii') $force8bit=true;
+		// beware. the section below might cause trouble regarding bcc and attachments, so maybe this is to be handeled differently
+		if ($force8bit)
+		{
+			$converterObj =  new Api\Mailer('initbasic');
+			$smartdata->mime = $converterObj->convertMessageTextParts($smartdata->mime,false,'utf-8');
+		}
 		// initialize the new Api\Mailer object for sending
 		$mailObject = new Api\Mailer(self::$profileID);
-		$this->mail->parseRawMessageIntoMailObject($mailObject,$smartdata->mime);
+
+		$this->mail->parseRawMessageIntoMailObject($mailObject,$smartdata->mime,$force8bit);
 		// Horde SMTP Class uses utf-8 by default. as we set charset always to utf-8
 		$mailObject->Sender  = $activeMailProfile['ident_email'];
-		$mailObject->From 	= $activeMailProfile['ident_email'];
-		$mailObject->FromName = Mail::generateIdentityString($activeMailProfile,false);
+		$mailObject->setFrom($activeMailProfile['ident_email'],Mail::generateIdentityString($activeMailProfile,false));
 		$mailObject->addHeader('X-Mailer', 'mail-Activesync');
 
-
 		// prepare addressee list; moved the adding of addresses to the mailobject down
 		// to
-
 		foreach(Mail::parseAddressList($mailObject->getHeader("To")) as $addressObject) {
 			if (!$addressObject->valid) continue;
 			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."(".__LINE__.") Header Sentmail To: ".array2string($addressObject) );
@@ -406,7 +465,7 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 			$ccMailAddr[] = imap_rfc822_write_address($addressObject->mailbox, $addressObject->host, $addressObject->personal);
 		}
 		// BCC
-		foreach(Mail::parseAddressList($mailObject->getHeader("Bcc")) as $addressObject) {
+		foreach($mailObject->getAddresses('bcc') as $addressObject) {
 			if (!$addressObject->valid) continue;
 			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."(".__LINE__.") Header Sentmail BCC: ".array2string($addressObject) );
 			//$mailObject->AddBCC($addressObject->mailbox. ($addressObject->host ? '@'.$addressObject->host : ''),$addressObject->personal);
@@ -533,32 +592,7 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 		$body = str_replace("\r",((preg_match("^text/html^i", $ContentType))?'<br>':""),$body); // what is this for?
 		if ($this->debugLevel>2) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' retrieved Body (modified):'.$body);
 */
-		// add signature!! -----------------------------------------------------------------
-		ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' ActiveMailProfile:'.array2string($activeMailProfile));
-		try
-		{
-			$acc = Mail\Account::read($this->mail->icServer->ImapServerId);
-			//error_log(__METHOD__.__LINE__.array2string($acc));
-			$_signature = Mail\Account::read_identity($acc['ident_id'],true);
-		}
-		catch (Exception $e)
-		{
-			$_signature=array();
-		}
-		$signature = $_signature['ident_signature'];
-		if ((isset($preferencesArray['disableRulerForSignatureSeparation']) &&
-			$preferencesArray['disableRulerForSignatureSeparation']) ||
-			empty($signature) || trim(Api\Mail\Html::convertHTMLToText($signature)) =='')
-		{
-			$disableRuler = true;
-		}
-		$beforePlain = $beforeHtml = "";
-		$beforeHtml = ($disableRuler ?'&nbsp;<br>':'&nbsp;<br><hr style="border:dotted 1px silver; width:90%; border:dotted 1px silver;">');
-		$beforePlain = ($disableRuler ?"\r\n\r\n":"\r\n\r\n-- \r\n");
-		$sigText = Mail::merge($signature,array($GLOBALS['egw']->accounts->id2name($GLOBALS['egw_info']['user']['account_id'],'person_id')));
-		if ($this->debugLevel>0) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' Signature to use:'.$sigText);
-		$sigTextHtml = $beforeHtml.$sigText;
-		$sigTextPlain = $beforePlain.Api\Mail\Html::convertHTMLToText($sigText);
+		// actually use prepared signature --------------------collected earlier--------------------------
 		$isreply = $isforward = false;
 		// reply ---------------------------------------------------------------------------
 		if ($smartdata_task == 'reply' && isset($smartdata->source->itemid) &&
@@ -670,8 +704,7 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 				}
 				// get all the attachments and add them too.
 				// start handle Attachments
-				//												$_uid, $_partID=null, Horde_Mime_Part $_structure=null, $fetchEmbeddedImages=true, $fetchTextCalendar=false, $resolveTNEF=true, $_folderName=''
-				$attachments = $this->mail->getMessageAttachments($uid, null,          null,								true,						false,				 true			, $folder);
+				$attachments = $this->mail->getMessageAttachments($uid,null,null,true,false,true,$folder);
 				$attachmentNames = false;
 				if (is_array($attachments) && count($attachments)>0)
 				{
@@ -690,18 +723,21 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 		// add signature, in case its not already added in forward or reply
 		if (!$isreply && !$isforward)
 		{
-				$Body = $Body.$sigTextPlain;
-				$AltBody = $AltBody.$sigTextHtml;
+			//error_log(__METHOD__.__LINE__.'adding Signature');
+			$Body = $Body.$sigTextPlain;
+			$AltBody = $AltBody.$sigTextHtml;
 		}
 		// now set the body
 		if ($AltBody && ($html_body = $mailObject->findBody('html')))
 		{
 			if ($this->debugLevel>1) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' -> '.$AltBody);
+			//error_log(__METHOD__.__LINE__.' html:'.$AltBody);
 			$html_body->setContents($AltBody,array('encoding'=>Horde_Mime_Part::DEFAULT_ENCODING));
 		}
 		if ($Body && ($text_body = $mailObject->findBody('plain')))
 		{
 			if ($this->debugLevel>1) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' -> '.$Body);
+			//error_log(__METHOD__.__LINE__.' text:'.$Body);
 			$text_body->setContents($Body,array('encoding'=>Horde_Mime_Part::DEFAULT_ENCODING));
 		}
 		//advanced debugging
@@ -769,8 +805,9 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 						$mailAddr[] = array($emailAddress, $addressObject->personal);
 					}
 				}
-				$BCCmail='';
-				if (count($mailAddr)>0) $BCCmail = $mailObject->AddrAppend("Bcc",$mailAddr);
+				//$BCCmail='';
+				if (count($mailAddr)>0) $mailObject->forceBccHeader();
+				//$BCCmail = $mailObject->AddrAppend("Bcc",$mailAddr);
 				foreach($folderArray as $folderName) {
 					if($this->mail->isSentFolder($folderName)) {
 						$flags = '\\Seen';
@@ -848,20 +885,15 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 		$account = $_folderName = $xid = null;
 		$this->splitID($folderid,$account,$_folderName,$xid);
 		$this->mail->reopen($_folderName);
-		$stat = $this->StatMessage($folderid, $id);
-		if ($this->debugLevel>3) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.array2string($stat));
+		$messages = $this->fetchMessages($folderid, NULL, $id, true);	// true: return all headers
+		$headers = $messages[$id];
+		if ($this->debugLevel>3) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.array2string($headers));
 		// StatMessage should reopen the folder in question, so we dont need folderids in the following statements.
-		if ($stat)
+		if ($headers)
 		{
-			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__." Message $id with stat ".array2string($stat));
+			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__." Message $id with stat ".array2string($headers));
 			// initialize the object
 			$output = new SyncMail();
-			$headers = $this->mail->getMessageHeader($id,'',true,true,$_folderName);
-			if (empty($headers))
-			{
-				error_log(__METHOD__.__LINE__.' Retrieval of Headers Failed! for .'.$this->account.'/'.$GLOBALS['egw_info']['user']['account_lid'].' ServerID:'.self::$profileID.'FolderID:'.$folderid.'/'.$_folderName.' ID:'.$id.' TruncSize:'.$truncsize.' Bodypreference: '.array2string($bodypreference).' Stat was:'.array2string($stat));
-				return $output;//empty object
-			}
 			//$rawHeaders = $this->mail->getMessageRawHeader($id);
 			// simple style
 			// start AS12 Stuff (bodypreference === false) case = old behaviour
@@ -979,6 +1011,7 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 							'<body>';
 						if ($output->nativebodytype==2)
 						{
+							if ($css) Api\Mail\Html::replaceTagsCompletley($body,'style');
 							// as we fetch html, and body is HTML, we may not need to handle this
 							$htmlbody .= $body;
 						}
@@ -1032,40 +1065,38 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 				}
 			}
 			// end AS12 Stuff
-			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' gather Header info:'.$headers['SUBJECT'].' from:'.$headers['DATE']);
-			$output->read = $stat["flags"];
+			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' gather Header info:'.$headers['subject'].' from:'.$headers['date']);
+			$output->read = $headers["flags"];
 
 			$output->flag = new SyncMailFlags();
-			if ($stat['flagged'] == 1)
+			if ($headers['flagged'] == 1)
 			{
 				$output->flag->flagstatus = 2;
 				//$output->flag->flagtype = "Flag for Follow up";
 			} else {
 				$output->flag->flagstatus = 0;
 			}
-			if ($stat['answered'])
+			if ($headers['answered'])
 			{
 				$output->lastverexecuted = AS_REPLYTOSENDER;
 			}
-			elseif ($stat['forwarded'])
+			elseif ($headers['forwarded'])
 			{
 				$output->lastverexecuted = AS_FORWARD;
 			}
-			$output->subject = $stat['subject'];
-			$output->importance = $stat['priority'] > 3 ? 0 :
-				($stat['priority'] < 3 ? 2 : 1) ;
-			$output->datereceived = $this->mail->_strtotime($headers['DATE'],'ts',true);
-//error_log(__METHOD__.__LINE__.' To:'.$headers['TO']);
-			$output->to = $headers['TO'];
-			if ($headers['TO']) $output->displayto = ($headers['TO'] ? $headers['TO']:null); //$stat['FETCHED_HEADER']['to_name']
-//error_log(__METHOD__.__LINE__.' From:'.$headers['FROM']);
-			$output->from = $headers['FROM'];
-			if (isset($headers['CC']) && $headers['CC']) $output->cc = ($headers['CC'] ? $headers['CC']:null);
-			if (isset($headers['REPLY_TO']) && $headers['REPLY_TO']) $output->reply_to = ($headers['REPLY_TO']?$headers['REPLY_TO']:null);
+			$output->subject = $headers['subject'];
+			$output->importance = $headers['priority'] > 3 ? 0 :
+				($headers['priority'] < 3 ? 2 : 1) ;
+			$output->datereceived = $this->mail->_strtotime($headers['date'],'ts',true);
+			$output->to = $headers['to_address'];
+			if ($headers['to']) $output->displayto = $headers['to_address']; //$headers['FETCHED_HEADER']['to_name']
+			$output->from = $headers['sender_address'];
+			if (isset($headers['cc_addresses']) && $headers['cc_addresses']) $output->cc = $headers['cc_addresses'];
+			if (isset($headers['reply_to_address']) && $headers['reply_to_address']) $output->reply_to = $headers['reply_to_address'];
 
 			$output->messageclass = "IPM.Note";
-			if (stripos($stat['mimetype'],'multipart')!== false &&
-				stripos($stat['mimetype'],'signed')!== false)
+			if (stripos($headers['mimetype'],'multipart')!== false &&
+				stripos($headers['mimetype'],'signed')!== false)
 			{
 				$output->messageclass = "IPM.Note.SMIME.MultipartSigned";
 			}
@@ -1364,10 +1395,21 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 		}
 		else
 		{
-			$cutoffdate = Api\DateTime::to('now','ts')-(3600*24*28*3);
-			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.' Client set no truncationdate. Using 12 weeks.'.date("d-M-Y", $cutoffdate));
+			$maximumSyncRangeInDays = self::PAST_LIMIT; // corresponds to our default value
+			if (isset($GLOBALS['egw_info']['user']['preferences']['activesync']['mail-maximumSyncRange']))
+			{
+				$maximumSyncRangeInDays = $GLOBALS['egw_info']['user']['preferences']['activesync']['mail-maximumSyncRange'];
+			}
+			$cutoffdate = (is_numeric($maximumSyncRangeInDays) ? Api\DateTime::to('now','ts')-(3600*24*$maximumSyncRangeInDays):null);
+			if (is_numeric($maximumSyncRangeInDays)) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.' Client set no truncationdate. Using '.$maximumSyncRangeInDays.' days.'.date("d-M-Y", $cutoffdate));
+		}
+		try {
+			return $this->fetchMessages($folderid, $cutoffdate);
+		} catch (Exception $e)
+		{
+			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' failed for '.$e->getMessage().($e->details?$e->details:''));
+			return array();
 		}
-		return $this->fetchMessages($folderid, $cutoffdate);
 	}
 
 	/**
@@ -1380,9 +1422,10 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 	 * @param int $folderid
 	 * @param int $cutoffdate timestamp with cutoffdate
 	 * @param string $_id =null uid of single message to fetch
+	 * @param boolean $return_all_headers =false true: additinal contain all headers eg. "subject"
 	 * @return array uid => array StatMessage($folderid, $_id)
 	 */
-	private function fetchMessages($folderid, $cutoffdate=NULL, $_id=NULL)
+	private function fetchMessages($folderid, $cutoffdate=NULL, $_id=NULL, $return_all_headers=false)
 	{
 		static $headers = array();
 
@@ -1440,6 +1483,7 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 			if (!empty($vars['deleted'])) continue; // cut of deleted messages
 			if ($cutoffdate && $vars['date'] < $cutoffdate) continue; // message is out of range for cutoffdate, ignore it
 			if ($this->debugLevel>0) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.__LINE__.' ID to report:'.$vars['uid'].' Subject:'.$vars['subject']);
+			$mess = $return_all_headers ? $vars : array();
 			$mess["mod"] = self::doFlagsMod($vars).$vars['date'];
 			$mess["id"] = $vars['uid'];
 			// 'seen' aka 'read' is the only flag we want to know about
@@ -1622,7 +1666,7 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 		array_pop($parent);
 		$parent = implode($delimiter,$parent);
 
-		$id = $parent ? $this->createID($account, $parent) : '0';
+		$id = $parent && $this->folders[$parent] ? $this->createID($account, $parent) : '0';
 		if ($this->debugLevel>1) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."('$folder') --> parent=$parent --> $id");
 		return $id;
 	}
@@ -1745,14 +1789,20 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 		if ($type != 'mail') return false;
 
 		if (!isset($this->mail)) $this->mail = Mail::getInstance(false,self::$profileID,true,false,true);
+		if (!$this->mail->folderIsSelectable($folder))
+		{
+			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.": could not select folder $folder returning fake state");
+			$syncstate = "M:".'0'."-R:".'0'."-U:".'0'."-NUID:".'0'."-UIDV:".'0';
+			return array();
+		}
 
-        $this->mail->reopen($folder);
+		$this->mail->reopen($folder);
 
 		if (!($status = $this->mail->getFolderStatus($folder,$ignoreStatusCache=true)))
 		{
-            ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.": could not stat folder $folder ");
-            return false;
-        }
+			ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.": could not stat folder $folder ");
+			return false;
+		}
 		$syncstate = "M:". $status['messages'] ."-R:". $status['recent'] ."-U:". $status['unseen']."-NUID:".$status['uidnext']."-UIDV:".$status['uidvalidity'];
 
 		ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."($folderid, ...) $folder ($account) returning ".array2string($syncstate));
@@ -1870,27 +1920,74 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 	 * @param string $displayname => new folder name (to be created, or to be renamed to)
 	 * @param string $type folder type, ignored in IMAP
 	 *
+	 * @throws StatusException              could throw specific SYNC_FSSTATUS_* exceptions
 	 * @return array|boolean stat array or false on error
 	 */
 	public function ChangeFolder($id, $oldid, $displayname, $type)
 	{
-		ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."('$id', '$oldid', '$displayname', $type) NOT supported!");
-		return false;
+		ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."('$id', '$oldid', '$displayname', $type)");
+		$account = $parent_id = null;
+		$this->splitID($id, $account, $parentFolder, $app);
+
+		$parent_id = $this->folder2hash($account, $parentFolder);
+		$old_hash = $oldFolder = null;
+
+		if (empty($oldid))
+		{
+			$action = 'create';
+		}
+		else
+		{
+			$action = 'rename';
+			$this->splitID($oldid, $account, $oldFolder, $app);
+			$old_hash = $this->folder2hash($account, $oldFolder);
+		}
+		ZLog::Write(LOGLEVEL_DEBUG,__METHOD__.":{$action}Folder('$id'=>($parentFolder ($parent_id)), '$oldid'".($oldid?"=>($oldFolder ($old_hash))":'').", '$displayname', $type)");
+		$this->_connect($this->account);
+		try
+		{
+			if ($action=='rename')
+			{
+				$newFolderName = $this->mail->renameFolder($oldFolder, $parentFolder, $displayname);
+			}
+			elseif ($action=='create')
+			{
+				$error=null;
+				$newFolderName = $this->mail->createFolder($parentFolder, $displayname, $error);
+			}
+		}
+		catch (\Exception $e)
+		{
+			//throw new Exception(__METHOD__." $action failed for $oldFolder ($action: $displayname) with error:".$e->getMessage());
+			return false;
+		}
+		$newHash = $this->rename_folder_hash($account, $old_hash, $newFolderName);
+		$newID = $this->createID($account, $newHash);
+		$this->folders = $this->mail->getFolderObjects(true,false,$_alwaysGetDefaultFolders=true,false);
+		ZLog::Write(LOGLEVEL_DEBUG,":{$action}Folder('$id'=>($parentFolder), '$oldid'".($oldid?"=>($oldFolder)":'').", '$displayname' => $newFolderName (ID:$newID))");
+		return $this->StatFolder($newID);
 	}
 
 	/**
 	 * Deletes (really delete) a Folder
 	 *
-	 * @param string $parentid of the folder to delete
 	 * @param string $id of the folder to delete
+	 * @param string $parentid (=false) of the folder to delete, may be false/not set
 	 *
-	 * @return
-	 * @TODO check what is to be returned
+	 * @throws StatusException              could throw specific SYNC_FSSTATUS_* exceptions
+	 * @return boolean true or false on error
 	 */
-	public function DeleteFolder($parentid, $id)
+	public function DeleteFolder($id, $parentid=false)
 	{
-		ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."('$parentid', '$id') NOT supported!");
-		return false;
+		$account = $parent_id = $app = null;
+		$this->splitID($id, $account, $folder, $app);
+		$old_hash = $this->folder2hash($account, $folder);
+		if ($parentid) $this->splitID($parentid, $account, $parentfolder, $app);
+		ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."( '$id (-> $folder)','$parentid ".($parentid?'(->'.$parentfolder.')':'')."') called!");
+		$ret = $this->mail->deleteFolder($folder);
+		if ($ret) $newHash = $this->rename_folder_hash($account, $old_hash, "##Dele#edFolder#$folder##");
+		$this->folders = $this->mail->getFolderObjects(true,false,$_alwaysGetDefaultFolders=true,false);
+		return $ret;
 	}
 
 	/**
@@ -1940,22 +2037,22 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 	}
 
 	/**
-	 * Split an ID string into $app, $folder and $id
+	 * Split an ID string into $app, $account $folder and $appid
 	 *
 	 * @param string $str
 	 * @param int &$account mail account id
 	 * @param string &$folder
-	 * @param int &$id=null
+	 * @param int &$appid=null (for mail=mail is to be expected)
 	 * @throws Api\Exception\WrongParameter
 	 */
-	private function splitID($str,&$account,&$folder,&$id=null)
+	private function splitID($str,&$account,&$folder,&$appid=null)
 	{
-		$this->backend->splitID($str, $account, $folder, $id);
+		$this->backend->splitID($str, $account, $folder, $appid);
 
 		// convert numeric folder-id back to folder name
 		$folder = $this->hash2folder($account,$f=$folder);
 
-		if ($this->debugLevel>1) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."('$str','$account','$folder',$id)");
+		if ($this->debugLevel>1) ZLog::Write(LOGLEVEL_DEBUG,__METHOD__."('$str','$account','$folder',$appid)");
 	}
 
 	/**
@@ -2002,6 +2099,25 @@ class mail_zpush implements activesync_plugin_write, activesync_plugin_sendmail,
 		return isset($this->folderHashes[$account]) ? $this->folderHashes[$account][$index] : null;
 	}
 
+	/**
+	 * Rename or create a folder in hash table
+	 *
+	 * @param int $account
+	 * @param int $index or null to create
+	 * @param string $new_name
+	 * @return int $index or new hash if $index is not found
+	 */
+	private function rename_folder_hash($account, $index, $new_name)
+	{
+		if ((string)$index === '' || !$this->hash2folder($account, $index))
+		{
+			return $this->folder2hash($account, $new_name);
+		}
+		$this->folderHashes[$account][$index] = $new_name;
+		$this->storeFolderHashes();
+		return $index;
+	}
+
 	private $folderHashes;
 
 	/**
