@@ -11,7 +11,7 @@
  * @version $Id$
  */
 
-$path_to_egroupware = realpath(dirname(__FILE__).'/../..');	//  need to be adapted if this script is moved somewhere else
+$path_to_egroupware = realpath(__DIR__.'/../..');	//  need to be adapted if this script is moved somewhere else
 $php = isset($_ENV['_']) ? $_ENV['_'] : $_SERVER['_'];
 
 foreach(file($path_to_egroupware. '/header.inc.php') as $line)
@@ -19,6 +19,6 @@ foreach(file($path_to_egroupware. '/header.inc.php') as $line)
 	if(preg_match("/GLOBALS\['egw_domain']\['(.*)']/", $line, $matches))
 	{
 		// -d memory_limit=-1 --> no memory limit
-		system($php. ' -q -d memory_limit=-1 '.$path_to_egroupware.'/phpgwapi/cron/asyncservices.php '. $matches[1]);
+		system($php. ' -q -d memory_limit=-1 '.$path_to_egroupware.'/api/asyncservices.php '. $matches[1]);
 	}
 }
