@@ -67,7 +67,6 @@ function phpgwapi_upgrade14_1_900()
 
 	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.2';
 }
-
 function phpgwapi_upgrade14_2()
 {
 	// check if egw_accounts.account_description already exists, as it might have been created by above upgrade
@@ -83,6 +82,11 @@ function phpgwapi_upgrade14_2()
 	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.2.001';
 }
 
+function phpgwapi_upgrade15_0_001()
+{
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.2.001';
+}
+
 function phpgwapi_upgrade14_2_001()
 {
 	$GLOBALS['run-from-upgrade14_2_001'] = true;	// flag no need to run 14.2.025 update
@@ -415,6 +419,13 @@ function phpgwapi_upgrade14_2_014()
 		'comment' => 'app.class.method class::method to execute'
 	));*/
 	/* done by RefreshTable() anyway
+	$GLOBALS['egw_setup']->oProc->AlterColumn('egw_async','async_data',array(
+		'type' => 'ascii',
+		'precision' => '8192',
+		'nullable' => False,
+		'comment' => 'serialized array with data to pass to method'
+	));*/
+	/* done by RefreshTable() anyway
 	$GLOBALS['egw_setup']->oProc->AddColumn('egw_async','async_auto_id',array(
 		'type' => 'auto',
 		'nullable' => False
@@ -425,7 +436,7 @@ function phpgwapi_upgrade14_2_014()
 			'async_next' => array('type' => 'int','meta' => 'timestamp','precision' => '4','nullable' => False,'comment' => 'timestamp of next run'),
 			'async_times' => array('type' => 'ascii','precision' => '255','nullable' => False,'comment' => 'serialized array with values for keys hour,min,day,month,year'),
 			'async_method' => array('type' => 'ascii','precision' => '80','nullable' => False,'comment' => 'app.class.method class::method to execute'),
-			'async_data' => array('type' => 'varchar','precision' => '8192','nullable' => False,'comment' => 'serialized array with data to pass to method'),
+			'async_data' => array('type' => 'ascii','precision' => '8192','nullable' => False,'comment' => 'serialized array with data to pass to method'),
 			'async_account_id' => array('type' => 'int','meta' => 'user','precision' => '4','nullable' => False,'default' => '0','comment' => 'creator of job'),
 			'async_auto_id' => array('type' => 'auto','nullable' => False)
 		),
@@ -899,6 +910,8 @@ function phpgwapi_upgrade14_3_004()
  */
 function phpgwapi_upgrade14_3_005()
 {
+	$GLOBALS['run-from-upgrade14_3_005'] = true;
+
 	$GLOBALS['egw_setup']->oProc->AlterColumn('egw_async','async_data',array(
 		'type' => 'varchar',
 		'precision' => '8192',
@@ -926,3 +939,138 @@ function phpgwapi_upgrade14_3_006()
 	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.007';
 }
 
+/**
+ * Updates on the way to 16.1
+ */
+
+/**
+ * Drop egw_api_content_history table used by no longer supported SyncML
+ *
+ * @return string
+ */
+function phpgwapi_upgrade14_3_007()
+{
+	$GLOBALS['egw_setup']->oProc->DropTable('egw_api_content_history');
+
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.900';
+}
+
+/**
+ * Run 14.3.002 upgrade for everyone who was already on 14.3.900
+ */
+function phpgwapi_upgrade14_3_900()
+{
+	if (empty($GLOBALS['run-from-upgrade14_3_002']))
+	{
+		phpgwapi_upgrade14_3_002();
+	}
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.901';
+}
+
+/**
+ * Run 14.3.003 upgrade for everyone who was already on 14.3.900
+ */
+function phpgwapi_upgrade14_3_901()
+{
+	if (empty($GLOBALS['run-from-upgrade14_3_003']))
+	{
+		phpgwapi_upgrade14_3_003();
+	}
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.902';
+}
+
+/**
+ * Change egw_addressbook.contact_pubkey to 16k as an ascii-armored 4096 bit PGP key is ~12k
+ *
+ * @return type
+ */
+function phpgwapi_upgrade14_3_902()
+{
+	// only shorten pubkey to varchar(16384), if it does NOT contain longer input and it can be stored as varchar
+	$max_pubkey_length = $GLOBALS['egw']->db->query('SELECT MAX(LENGTH(contact_pubkey)) FROM egw_addressbook')->fetchColumn();
+	// returns NULL, if there are no rows!
+	if ((int)$max_pubkey_length <= 16384 && $GLOBALS['egw_setup']->oProc->max_varchar_length >= 16384)
+	{
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_addressbook','contact_pubkey',array(
+			'type' => 'ascii',
+			'precision' => '16384',
+			'comment' => 'public key'
+		));
+	}
+
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.903';
+}
+
+/**
+ * Run 14.3.004 upgrade for everyone who was already on 14.3.900
+ */
+function phpgwapi_upgrade14_3_903()
+{
+	if (empty($GLOBALS['run-from-upgrade14_3_004']))
+	{
+		phpgwapi_upgrade14_3_004();
+	}
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.904';
+}
+
+/**
+ * Run 14.3.005 upgrade for everyone who was already on 14.3.9xx
+ */
+function phpgwapi_upgrade14_3_904()
+{
+	if (empty($GLOBALS['run-from-upgrade14_3_005']))
+	{
+		phpgwapi_upgrade14_3_005();
+	}
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.905';
+}
+
+/**
+ * Run 14.3.006 upgrade for everyone who was already on 14.3.9xx
+ */
+function phpgwapi_upgrade14_3_905()
+{
+	if (empty($GLOBALS['run-from-upgrade14_3_006']))
+	{
+		phpgwapi_upgrade14_3_006();
+	}
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.906';
+}
+
+/**
+ * Move content of (usually empty or for LDAP 2 rows) egw_nextid table to egw_config table and drop it
+ */
+function phpgwapi_upgrade14_3_906()
+{
+	foreach($GLOBALS['egw_setup']->db->query('SELECT appname,id FROM egw_nextid', __LINE__, __FILE__) as $row)
+	{
+		common::next_id($row['appname'], $row['id']);	// store it
+	}
+	$GLOBALS['egw_setup']->oProc->DropTable('egw_nextid');
+
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.907';
+}
+
+/**
+ * Drop no longer used egw_hooks table
+ */
+function phpgwapi_upgrade14_3_907()
+{
+	$GLOBALS['egw_setup']->oProc->DropTable('egw_hooks');
+
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.908';
+}
+
+
+/**
+ * Drop never used index tables
+ */
+function phpgwapi_upgrade14_3_908()
+{
+	$GLOBALS['egw_setup']->oProc->DropTable('egw_index_keywords');
+	$GLOBALS['egw_setup']->oProc->DropTable('egw_index');
+	$GLOBALS['egw_setup']->oProc->DropTable('egw_cat2entry');
+
+	return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '14.3.909';
+}
+
