@@ -46,6 +46,7 @@
 		open: function()
 		{
 			this._super.apply(this,arguments);
+			jQuery('.egw_fw_ui_sidemenu_listitem', this.contentDiv).click(function(){framework.toggleMenu('on');});
 			framework.toggleMenu('on');
 		}
 	});
@@ -200,7 +201,42 @@
 
 				// An iframe scrolling fix for iOS Safari
 				if (framework.getUserAgent() === 'iOS') {
-					window.setTimeout(function(){jQuery(self.$iFrame).height(popupWindow.document.body.scrollHeight);}, 500);
+					window.setTimeout(function(){
+						jQuery(self.$iFrame).height(popupWindow.document.body.scrollHeight);
+						// scrolling node
+						var node = jQuery(popupWindow.document.body);
+						// start point Y, X
+						var startY, startX = 0;
+
+						// kill delays on transitions
+						// and set the start value for transition
+						node.css ({
+							transition: 'all 0s',
+							transform:'translateX(0px) translateY(0px)',
+						});
+
+						node.on({
+							touchmove: function (e){
+								var $w = jQuery(window);
+								// current touch y position
+								var currentY = e.originalEvent.touches ? e.originalEvent.touches[0].screenY : e.originalEvent.screenY;
+								// current touch x position
+								var currentX = e.originalEvent.touches ? e.originalEvent.touches[0].screenX : e.originalEvent.screenX;
+								// check if we are the top
+								var isAtTop = (startY <= currentY && $w.scrollTop() <= 0);
+								// check if we are at the bottom
+								var isAtBottom = (startY >= currentY && node[0].scrollHeight - $w.scrollTop() === node.height());
+								// check if it's left or right touch move
+								var isLeftOrRight = (Math.abs(startX - currentX) > Math.abs(startY - currentY));
+
+								if (isAtTop || isAtBottom || isLeftOrRight) e.originalEvent.preventDefault();
+							},
+							touchstart: function (e){
+								startY = e.originalEvent.touches ? e.originalEvent.touches[0].screenY : e.originalEvent.screenY;
+								startX = e.originalEvent.touches ? e.originalEvent.touches[0].screenX : e.originalEvent.screenX;
+							}
+						});
+					}, 500);
 				}
 			});
 
@@ -342,7 +378,7 @@
 			// then prompt user base on the mode, and if the user
 			// discards the message once then do not show it again
 			var fullScreen = this.isNotFullScreen();
-			if (fullScreen && this.getUserAgent() !='iOS') egw.message(fullScreen,'info', true);
+			if (fullScreen && this.getUserAgent() !='iOS') egw.message(fullScreen,'info', 'etemplate:fw_mobile_fullscreen');
 		},
 
 		/**
@@ -955,12 +991,40 @@
 		 *
 		 * @param {object} _widget nextmatch widget
 		 * @param {object} _action action object
-		 * @param {object} _sender selected row action object
+		 * @param {object} _senders selected row(s) action object
 		 */
-		nm_onselect_ctrl: function(_widget, _action, _sender)
+		nm_onselect_ctrl: function(_widget, _action, _senders)
 		{
+			var senders = _senders? _senders:null;
+
 			// Update action_header status (3dots)
 			_widget.header.action_header.toggle(typeof _widget.getSelection().ids != 'undefined' && _widget.getSelection().ids.length > 0);
+
+			// Update selection counter in nm header
+			if (_widget._type == 'nextmatch' && _widget.getSelection().ids.length > 0)
+			{
+				if (senders && senders[0].actionLinks)
+				{
+					var delete_action = null;
+					for (var i=0; i< senders[0].actionLinks.length;i++)
+					{
+						if (senders[0].actionLinks[i].actionId == 'delete') delete_action = senders[0].actionLinks[i];
+					}
+					if (delete_action && delete_action.enabled)
+					{
+						_widget.header.delete_action
+						.show()
+						.off()
+						.click(function(){
+							if (delete_action) delete_action.actionObj.execute(senders);
+						});
+					}
+				}
+			}
+			else
+			{
+				_widget.header.delete_action.hide();
+			}
 		}
 	});
 
@@ -996,7 +1060,7 @@
 			history.pushState({type:'main'}, 'main', '#main');
 			jQuery(window).on('popstate', function(e){
 				// Check if user wants to logout and ask a confirmation
-				if (e.originalEvent.state == null || typeof e.originalEvent.state == 'undefined') {
+				if (window.location.hash == '#main') {
 					et2_dialog.show_dialog(function(button){
 						if (button === 3){
 							history.forward();
@@ -1006,7 +1070,7 @@
 					}, 'Are you sure you want to logout?', 'Logout');
 				}
 				// Execute action based on
-				switch (e.originalEvent.state.type)
+				switch (e.originalEvent.state && e.originalEvent.state.type)
 				{
 					case 'popup':
 						window.framework.popups[e.originalEvent.state.index].close(e.originalEvent.state.index);
