@@ -184,6 +184,12 @@ class preferences_settings
 	 */
 	function process_array(array &$repository, array $values, array $types, $appname, $type, $only_verify=false)
 	{
+		//fetch application specific settings from a hook
+		$settings = Api\Hooks::single(array(
+			'account_id'=>$GLOBALS['egw']->preferences->get_account_id(),
+			'location'=>'settings',
+			'type' => $type), $appname);
+
 		//_debug_array($repository);
 		$prefs = &$repository[$appname];
 
@@ -235,13 +241,15 @@ class preferences_settings
 					}
 					break;
 				case 'Array':	// notify
+					// Make sure the application translation is loaded
+					Api\Translation::add_app($appname);
 					$value = $GLOBALS['egw']->preferences->lang_notify($value, $types[$var], True);
 					break;
 			}
 
 			if (isset($value) && $value !== '' && $value !== '**NULL**' && $value !== array())
 			{
-				if (is_array($value)) $value = implode(',',$value);	// multiselect
+				if (is_array($value) && !$settings[$var]['no_sel_options']) $value = implode(',',$value);	// multiselect
 
 				$prefs[$var] = $value;
 
@@ -388,9 +396,15 @@ class preferences_settings
 						if ((string)$attrs[$n] !== '') $tpl->setElementAttribute($tab.'['.$setting['name'].']', $name, $attrs[$n]);
 					}
 					break;
+				case 'taglist':
+					if ($setting['no_sel_options'])
+					{
+						$tpl->setElementAttribute ($tab.'['.$setting['name'].']', 'autocomplete_url', '');
+					}
+					break;
 			}
 			// move values/options to sel_options array
-			if (isset($setting['values']) && is_array($setting['values']))
+			if (isset($setting['values']) && is_array($setting['values']) && !$setting['no_sel_options'])
 			{
 				if ($old_type != 'multiselect' && $old_type != 'notify')
 				{
@@ -435,7 +449,6 @@ class preferences_settings
 				'type' => $setting['type'],
 				'label' => preg_replace('|<br[ /]*>|i', "\n", $setting['label']),
 				'help' => lang($setting['help']),	// is html
-				//'size' => $setting['size'],	// old eT
 				'default' => !empty($default) ? lang('Default').': '.$default : null,
 				'onchange' => $setting['onchange'],
 			);
