@@ -10,6 +10,9 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+
 /**
  * constants for the different types of data
  *
@@ -158,7 +161,7 @@ class datasource
 	 */
 	function get($data_id)
 	{
-		if (($title = egw_link::title($this->type,$data_id)))
+		if (($title = Link::title($this->type,$data_id)))
 		{
 			return array(
 				'pe_title'  => $title,
@@ -188,7 +191,8 @@ class datasource
 		if ($ds)
 		{
 			// setting a not set planned start from a contrains
-			if ((!$ds['pe_planned_start'] || $ds['ignore_planned_start']) && !is_null($pe_data) && $pe_data['pe_constraints']['start'])
+			if ((!$ds['pe_planned_start'] && isset($ds['pe_planned_start']) || $ds['ignore_planned_start']) &&
+				!is_null($pe_data) && $pe_data['pe_constraints']['start'])
 			{
 				//echo "start-constr."; _debug_array($pe_data['pe_constraints']['start']);
 				$start = 0;
@@ -213,12 +217,12 @@ class datasource
 				}
 			}
 			// setting the planned start from the real-start
-			if (!$ds['pe_planned_start'] && !$ds['ignore_planned_start'] && $ds['pe_real_start'])
+			if (!$ds['pe_planned_start'] && isset($ds['pe_planned_start']) && !$ds['ignore_planned_start'] && $ds['pe_real_start'])
 			{
 				$ds['pe_planned_start'] = $ds['pe_real_start'];
 			}
 			// setting the planned start from the projects start
-			if ((!$ds['pe_planned_start'] || $ds['ignore_planned_start']) && $pe_data['pm_id'])
+			if ((!$ds['pe_planned_start'] && isset($ds['pe_planned_start']) || $ds['ignore_planned_start']) && $pe_data['pm_id'])
 			{
 				if (!is_object($this->bo_pe))
 				{
