@@ -670,18 +670,21 @@ class projectmanager_bo extends projectmanager_so
 	 * @param int|array $entry int pm_id or array with project entry
 	 * @return string/boolean string with title, null if project not found or false if no perms to view it
 	 */
-	function link_title( $entry )
+	public static function link_title( $entry )
 	{
 		if (!is_array($entry))
 		{
-			$pm_id = $entry;
-			$entry = $this->read( $entry );
+			$bo = new projectmanager_bo();
 
-			// Even though ADD_TIMESHEET means no read, we let them
-			// see the title
-			if(!$entry && $this->check_acl(EGW_ACL_ADD_TIMESHEET, $pm_id))
+			// reading entry incl. read ACL check, possibly returning false
+			$entry = $bo->read($pm_id=$entry);
+
+			// even though ADD_TIMESHEET means no read, we let them see the title
+			if(!$entry && $bo->check_acl(EGW_ACL_ADD_TIMESHEET, $pm_id))
 			{
-				$entry = $this->data;
+				// this is achieved by calling parent::read() which does NOT implement ACL
+				$so = new projectmanager_so();
+				$entry = $so->read($pm_id);
 			}
 		}
 		if (!$entry)
@@ -696,7 +699,7 @@ class projectmanager_bo extends projectmanager_so
 	 *
 	 * Is called as hook to participate in the linking
 	 *
-	 * @param int|array $entry int pm_id or array with project entry
+	 * @param array $ids int pm_id or array with project entry
 	 * @return array or titles, see link_title
 	 */
 	function link_titles( array $ids )
@@ -738,7 +741,10 @@ class projectmanager_bo extends projectmanager_so
 			$need_count = true;
 		}
 		$result = array();
-		foreach((array) $this->search($pattern,false,'pm_number','','%',false,'OR',$limit,array('pm_status'=>'active'), true, $need_count) as $prj )
+		$order = $this->prefs['link_sort_order'];
+		// Protect against bad preference value
+		$order = $this->field2label[reset(explode(' ',$order))] ? $order : 'pm_created DESC';
+		foreach((array) $this->search($pattern,false,$order,'','%',false,'OR',$limit,array('pm_status'=>'active'), true, $need_count) as $prj )
 		{
 			if ($prj['pm_id']) $result[$prj['pm_id']] = $this->link_title($prj);
 		}
@@ -780,7 +786,7 @@ class projectmanager_bo extends projectmanager_so
 		static $ancestors_cache = array();	// some caching
 
 		if (!$pm_id && !($pm_id = $this->pm_id)) return false;
-		
+
 		if (!isset($ancestors_cache[$pm_id]))
 		{
 			$ancestors_cache[$pm_id] = array();
@@ -868,9 +874,13 @@ class projectmanager_bo extends projectmanager_so
 		// if parents given, also return number of (grand-)children
 		if (isset($_parents)) $extra_cols[] = 'children';
 
+		$order = $this->prefs['link_sort_order'];
+		// Protect against bad preference value
+		$order = $this->field2label[reset(explode(' ',$order))] ? $order : 'pm_status,pm_number';
+
 		// get the children
 		while (($children = $this->search($filter,$this->table_name.'.pm_id AS pm_id,pm_number,pm_title,link_id1 AS pm_parent,pm_status',
-			'pm_status,pm_number',$extra_cols,'',false,$filter_op,false,array('subs_or_mains' => $parents))))
+			$order,$extra_cols,'',false,$filter_op,false,array('subs_or_mains' => $parents))))
 		{
 			//error_log(__METHOD__."(".array2string($filter).", '$filter_op, ".array2string($_parents).") parents=".array2string($parents)." --> children=".array2string($children));
 			// sort the children behind the parents
@@ -1146,6 +1156,22 @@ class projectmanager_bo extends projectmanager_so
 			// copying the constrains
 			$this->constraints->copy((int)$source,$elements,$milestones,$boelements->pm_id);
 		}
+
+		// Copy files
+		$dir = '/apps/projectmanager/'.$source;
+		$files = Api\Vfs::scandir($dir);
+		foreach($files as $key => &$file)
+		{
+			if($file == '.' || $file == '..' || Api\Vfs::is_link($dir.'/'.$file))
+			{
+				unset($files[$key]);
+				continue;
+			}
+			$file = $dir . '/' . $file;
+		}
+		$copied = array();
+		Api\Vfs::copy_files($files, "/apps/projectmanager/{$this->data['pm_id']}");
+
 		return $boelements->pm_id;
 	}
 }
