@@ -198,7 +198,21 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 				break;
 
 			case 'unlink':
-				$this->delete(array('pm_id' => $data['id'],'pe_id' => $data['link_id']));
+				// Link class caches the object it notifies, so new object to avoid problems
+				// (eg. delete happens on 2 different projects, or unlink a deleted project)
+				$e_bo = new projectmanager_elements_bo();
+				if($e_bo->project->history)
+				{
+					// Might be keeping this...
+					$link = Link::get_link($data['link_id']);
+					if($link['deleted'])
+					{
+						// Need to just delete, without changing links
+						$e_bo->delete(array('pm_id' => $data['id'], 'pe_id' => $data['link_id']), false, false);
+						return;
+					}
+				}
+				$e_bo->delete(array('pm_id' => $data['id'],'pe_id' => $data['link_id']));
 				break;
 
 		}
@@ -549,9 +563,10 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 	 *
 	 * @param array/int $keys if given array with pm_id and/or pe_id or just an integer pe_id
 	 * @param boolean $delete_sources=false true=delete datasources of the elements too (if supported by the datasource), false dont do it
+	 * @param boolean $unlink = false Internal use only, passing false will skip the unlinking steps
 	 * @return int affected rows, should be 1 if ok, 0 if an error
 	 */
-	function delete($keys=null,$delete_sources=false)
+	function delete($keys=null,$delete_sources=false, $unlink = true)
 	{
 		if ((int) $this->debug >= 1 || $this->debug == 'delete') $this->debug_message("projectmanager_elements_bo::delete(".print_r($keys,true).",$delete_sources) this->data[pm_id] = ".$this->data['pm_id']);
 
@@ -577,14 +592,17 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 
 		if ($pe_id)
 		{
-			// delete one link
-			Link::unlink($pe_id);
+			if($unlink)
+			{
+				// delete one link
+				Link::unlink($pe_id,'','',0,'','',(boolean)$this->project->history);
+			}
 			// update the project
 			$this->project->update($pm_id);
 
 			$this->constraints->delete(array('pe_id' => $pe_id));
 		}
-		elseif ($pm_id)
+		elseif ($pm_id && $unlink)
 		{
 			// delete all links to project $pm_id
 			Link::unlink(0,'projectmanager',$pm_id);
@@ -693,6 +711,10 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		$elements =& $this->search('',false,'pe_planned_start,pe_title','','',false,'AND',false,array('pm_id'=>$source));
 		if (!$elements) return array();
 
+		// Calculate the difference in times between original project and new project
+		// we can apply that difference to elements too.
+		$offsets = $this->get_time_offsets($source, $this->pm_id);
+
 		$copied = $apps_copied = $callbacks = $params = array();
 		foreach($elements as $element)
 		{
@@ -702,7 +724,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 			{
 				if ((int) $this->debug >= 3 || $this->debug == 'copytree') $this->debug_message("copying $element[pe_app]:$element[pe_app_id] $element[pe_title]");
 				$callback = $param = null;
-				list($app_id,$link_id,$callback,$param) = $ds->copy($element,$this->pm_id,$this->project->data);
+				list($app_id,$link_id,$callback,$param) = $ds->copy($element,$this->pm_id,$this->project->data, $offsets);
 				if (!is_null($callback))
 				{
 					$callbacks[] = $callback;
@@ -761,6 +783,58 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		return $copied;
 	}
 
+	/**
+	 * Determine the time offsets between two projects
+	 *
+	 * We'll use the time offsets when copying templates to update the elements
+	 *
+	 * @param int $source Source project ID
+	 * @param int $target Target project ID
+	 *
+	 * @return DateInterval[] Array of DateIntervals, indexed by field name
+	 */
+	protected function get_time_offsets($source, $target)
+	{
+		$offsets = array('planned_start'=>0,'planned_end'=>0,'real_start'=>0,'real_end'=>0);
+		$offset_count = 0;
+
+		if($this->project->data && $target == $this->project->data['pm_id'])
+		{
+			$target_project = $this->project->data;
+			$source_project = $this->project->read($source);
+			$this->project->data = $target_project;
+		}
+		else
+		{
+			$source_project = $this->project->read($source);
+			$target_project = $this->project->read($target);
+		}
+
+		foreach($offsets as $date_field => &$offset)
+		{
+			if($source_project["pm_$date_field"] && $target_project["pm_$date_field"])
+			{
+				$source_date = new Api\DateTime($source_project["pm_$date_field"]);
+				$target_date = new Api\DateTime($target_project["pm_$date_field"]);
+
+				$offset = $source_date->diff($target_date);
+				$offset_count++;
+				//error_log("$source => $target $date_field " . $source_date . ' => ' . $target_date . ' = ' . (method_exists($offset,'format') ? $offset->format('%R%a days') : $offset));
+			}
+		}
+
+		// Now set any that are missing using the "next-best" information - real
+		// if planned is missing, end if start is missing
+		if($offset_count && $offset_count != count($offsets))
+		{
+			$offsets['planned_start'] = $offsets['planned_start'] ?: $offsets['real_start'] ?: $offsets['planned_end'] ?: $offsets['real_end'];
+			$offsets['planned_end'] = $offsets['planned_end'] ?: $offsets['real_end'] ?: $offsets['planned_start'] ?: $offsets['real_start'];
+			$offsets['real_start'] = $offsets['real_start'] ?: $offsets['planned_start'] ?: $offsets['real_end'] ?: $offsets['planned_end'];
+			$offsets['real_end'] = $offsets['real_end'] ?: $offsets['planned_end'] ?: $offsets['real_start'] ?: $offsets['planned_start'];
+		}
+		return $offsets;
+	}
+
 	/**
 	 * Runs a certain method on the datasources of given elements
 	 *
