@@ -126,8 +126,6 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 			}
 			if (!$content['view'])
 			{
-				if ($content['pe_completion'] !== '') $content['pe_completion'] .= '%';
-
 				foreach($datasource->name2id as $name => $id)
 				{
 					if ($id == PM_TITLE || $id == PM_DETAILS) continue;	// title and details can NOT be edited
@@ -195,7 +193,7 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 
 				foreach(array('pe_status','pe_remark','pe_constraints','pe_share','pe_eroles') as $name)
 				{
-					if ($name == 'pe_constraints')
+					if ($name == 'pe_constraints' && is_array($content['pe_constraints']))
 					{
 						foreach($content['pe_constraints'] as $type => $data)
 						{
@@ -366,7 +364,10 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 		{
 			$planned_quantity_blur = $ds['pe_planned_quantity'];
 		}
-
+		if($this->data['pe_completion'])
+		{
+			$this->data['pe_completion'] = (int)$this->data['pe_completion'];
+		}
 		$content = $this->data + array(
 			'ds'  => $ds,
 			'msg' => $msg,
@@ -397,9 +398,12 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 			$content['pe_share'] = $content['share_percentage'];
 		}
 		// Set classes on constraints
-		foreach($content['pe_constraints'] as &$constraint)
+		if(is_array($content['pe_constraints']))
 		{
-			$constraint['class'] = $constraint['pe_id_start'] == $this->data['pe_id'] ? 'source' : 'target';
+			foreach($content['pe_constraints'] as &$constraint)
+			{
+				$constraint['class'] = $constraint['pe_id_start'] == $this->data['pe_id'] ? 'source' : 'target';
+			}
 		}
 
 		//_debug_array($content);
@@ -481,7 +485,8 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 		unset($query_in['col_filter']['parent_id']);
 		if(!$query_in['csv_export'])
 		{
-			Api\Cache::setSession('projectmanager', 'projectelements_list', $query_in);
+			Api\Cache::setSession('projectmanager', 'projectelements_list',
+				array_diff_key ($query_in, array_flip(array('rows','actions','action_links','placeholder_actions'))));
 		}
 
 		//echo "<p>project_elements_ui::get_rows(".print_r($query,true).")</p>\n";
@@ -1156,7 +1161,7 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 				$success = $failed = 0;
 				foreach($checked as $id)
 				{
-					$element = $this->read($id);
+					$element = $this->read(array('pe_id' => $id));
 					if(!$this->save(array('pe_status' => $ignore ? 'ignore' : 'new')))
 					{
 						$success++;
@@ -1204,8 +1209,9 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 					$query = $old_query = Api\Cache::getSession('projectmanager', 'projectelements_list');
 					$query['num_rows'] = -1;        // all
 					$this->get_rows($query,$selection,$readonlys);
-					foreach($selection as $element)
+					foreach($selection as $key => $element)
 					{
+						if (!is_int($key)) continue;	// ignore string keys from get_rows
 						if($element['pe_id'] && is_numeric($element['pe_id'])) $checked[] = $element['pe_id'];
 					}
 
@@ -1318,8 +1324,8 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 
 		if($ids['contacts']) {
 			$document_merge->contact_ids = $ids['contacts'];
-			unset($ids['contacts']);
 		}
+		unset($ids['contacts']);
 
 		if(isset($this->prefs['document_download_name']))
 		{
@@ -1338,8 +1344,8 @@ class projectmanager_elements_ui extends projectmanager_elements_bo
 				return lang('No rights to export more then %1 entries!',(int)$document_merge->export_limit);
 			}
 			$document_merge->elements = $ids['elements'];
-			unset($ids['elements']);
 		}
+		unset($ids['elements']);
 
 		return $document_merge->download($document, $ids, isset($name) ? $name : null, $this->prefs['document_dir']);
 	}
