@@ -170,7 +170,7 @@ class projectmanager_hooks
 						)),
 					),
 					array(
-						'text' => 'Gantt chart',
+						'text' => 'Ganttchart',
 						'link' =>  Egw::link('/index.php',array(
 							'menuaction' => 'projectmanager.projectmanager_ui.index',
 							'ajax' => 'true',
@@ -225,12 +225,19 @@ class projectmanager_hooks
 		if ($GLOBALS['egw_info']['user']['apps']['admin'])
 		{
 			$file = Array(
-				'Site configuration' => Egw::link('/index.php','menuaction=projectmanager.projectmanager_admin.config'),
-				'Custom fields' => Egw::link('/index.php','menuaction=admin.customfields.index&appname=projectmanager&use_private=1'),
+				'Site configuration' => Egw::link('/index.php',array(
+					'menuaction' => 'projectmanager.projectmanager_admin.config',
+					// As long as CKEditor needs CSP exceptions, this needs to
+					// load in an iframe
+					'ajax' => 'false',
+				)),
+				'Custom fields' => Egw::link('/index.php','menuaction=admin.admin_customfields.index&appname=projectmanager&use_private=1&ajax=true'),
 				'Global Categories'  => Egw::link('/index.php',array(
 					'menuaction' => 'admin.admin_categories.index',
 					'appname'    => $appname,
-					'global_cats'=> True)),
+					'global_cats'=> True,
+					'ajax' => 'true',
+				)),
 			);
 			if ($location == 'admin')
 			{
@@ -364,23 +371,36 @@ class projectmanager_hooks
 			'admin'  => False,
 			'default'=> true,
 		);
+		$settings['link_sort_order'] = array(
+			'type'     => 'select',
+			'label'    => 'Project sort order',
+			'name'     => 'link_sort_order',
+			'values'   => array(
+				'pm_number DESC' => lang('Project ID') . '▼',
+				'pm_number ASC' => lang('Project ID') . '▲',
+				'pm_title ASC'  => lang('Project title'),
+				'pm_created DESC' => lang('creation date and time')
+			),
+			'help'     => 'Select project sort order for project tree and link search',
+			'default'  => 'pm_created DESC'
+		);
 		$settings['show_links'] = array(
-				'type'   => 'check',
-				'label'  => 'Show links in the Project Elements list',
-				'name'   => 'show_links',
-				'help'   => 'Should Project Elements show the links to other applications and/or the file-attachments in the Project Elements list (only when showing details).',
-				'xmlrpc' => True,
-				'admin'  => False,
-				'default'=> false,
+			'type'   => 'check',
+			'label'  => 'Show links in the Project Elements list',
+			'name'   => 'show_links',
+			'help'   => 'Should Project Elements show the links to other applications and/or the file-attachments in the Project Elements list (only when showing details).',
+			'xmlrpc' => True,
+			'admin'  => False,
+			'default'=> false,
 		);
 		$settings['show_infolog_type_icon'] = array(
-				'type'   => 'check',
-				'label'  => 'Show infolog type icon in the Project Elements list',
-				'name'   => 'show_infolog_type_icon',
-				'help'   => 'Should Project Elements list show the dedicated icons of the infolog types. Icons for infolog custom types can be added at the VFS-Path where additional images, icons or logos can be found (see Site Configuration). If 32x32 pixels icons are uploaded with a file name ending with \'_element\', that bigger icon will be loaded in the element list.',
-				'xmlrpc' => True,
-				'admin'  => False,
-				'forced'=> False,
+			'type'   => 'check',
+			'label'  => 'Show infolog type icon in the Project Elements list',
+			'name'   => 'show_infolog_type_icon',
+			'help'   => 'Should Project Elements list show the dedicated icons of the infolog types. Icons for infolog custom types can be added at the VFS-Path where additional images, icons or logos can be found (see Site Configuration). If 32x32 pixels icons are uploaded with a file name ending with \'_element\', that bigger icon will be loaded in the element list.',
+			'xmlrpc' => True,
+			'admin'  => False,
+			'forced'=> False,
 		);
 		$pm_list_options = array(
 			'~edit~'    => lang('Edit project'),
