@@ -214,6 +214,28 @@ class projectmanager_merge extends Api\Storage\Merge
 			$this->projectmanager_elements_bo = new projectmanager_elements_bo($id);
 		}
 		$this->projectmanager_bo = new projectmanager_bo($id);
+
+		// add erole(s)
+		$this->eroles = array();
+		if($this->projectmanager_bo->config['enable_eroles'])
+		{
+			foreach($this->projectmanager_elements_bo->search(array('pm_id' => $id),false) as $element)
+			{
+				if(!empty($element['pe_eroles']))
+				{
+					// one element could have multiple eroles
+					foreach(explode(',',$element['pe_eroles']) as $erole_id)
+					{
+						$this->eroles[] = array(
+							'pe_id'		=> $element['pe_id'],
+							'app' 		=> $element['pe_app'],
+							'app_id' 	=> $element['pe_app_id'],
+							'erole_id'	=> $erole_id,
+						);
+					}
+				}
+			}
+		}
 	}
 
 	/**
@@ -246,6 +268,23 @@ class projectmanager_merge extends Api\Storage\Merge
 
 		$replacements += $this->projectmanager_replacements($this->pm_id, '', $content);
 
+		$replacements += $this->get_erole_replacements($content);
+		
+		return empty($replacements) ? false : $replacements;
+	}
+
+	/**
+	 * Get erole replacements for the project
+	 *
+	 * Handles normal erole placeholders, not in an erole table
+	 *
+	 * @param string $content Repeating content, used to remove any missing placeholders
+	 *
+	 * @return Array
+	 */
+	protected function get_erole_replacements(&$content)
+	{
+		$replacements = array();
 		// further replacements are made by eroles (if given)
 		if(!empty($this->eroles) && is_array($this->eroles))
 		{
@@ -263,9 +302,22 @@ class projectmanager_merge extends Api\Storage\Merge
 				}
 			}
 		}
-		return empty($replacements) ? false : $replacements;
+		
+		// Strip unassigned erole tags
+		$matches = array();
+		preg_match_all('@\$\$erole/([A-Za-z0-9_]+)(/?(?:[^\$])*)?\$\$@s',$content,$matches);
+		foreach($matches[0] as $missing_erole)
+		{
+			if(!$replacements[$missing_erole])
+			{
+				$replacements[$missing_erole] = '';
+			}
+		}
+		
+		return $replacements;
 	}
 
+
 	/**
 	 * Get element replacements
 	 *
@@ -398,9 +450,6 @@ class projectmanager_merge extends Api\Storage\Merge
 			$value = $project[$name];
 			switch($name)
 			{
-				case 'pm_created': case 'pm_modified':
-				case 'pm_planned_start': case 'pm_planned_end':
-				case 'pm_real_start': case 'pm_real_end':
 				case 'pe_planned_start_total': case 'pe_planned_end_total':
 				case 'pe_real_start_total': case 'pe_real_end_total':
 					if($value) $value = Api\DateTime::to($value);
@@ -700,7 +749,7 @@ class projectmanager_merge extends Api\Storage\Merge
 			'labelplacement' => lang('Tag to mark positions for address labels'),
 			'IF fieldname' => lang('Example {{IF n_prefix~Mr~Hello Mr.~Hello Ms.}} - search the field "n_prefix", for "Mr", if found, write Hello Mr., else write Hello Ms.'),
 			'NELF' => lang('Example {{NELF role}} - if field role is not empty, you will get a new line with the value of field role'),
-			'NENVLF' => lang('Example {{NELFNV role}} - if field role is not empty, set a LF without any value of the field'),
+			'NENVLF' => lang('Example {{NENVLF role}} - if field role is not empty, set a LF without any value of the field'),
 			'LETTERPREFIX' => lang('Example {{LETTERPREFIX}} - Gives a letter prefix without double spaces, if the title is emty for  example'),
 			'LETTERPREFIXCUSTOM' => lang('Example {{LETTERPREFIXCUSTOM n_prefix title n_family}} - Example: Mr Dr. James Miller'),
 			) as $name => $label)
