@@ -542,7 +542,8 @@ class projectmanager_ui extends projectmanager_bo
 		$query = $query_in;
 		// Don't keep pm_id filter in seesion
 		unset($query_in['col_filter']['pm_id']);
-		Api\Cache::setSession('projectmanager', 'project_list', $query_in);
+		Api\Cache::setSession('projectmanager', 'project_list',
+			array_diff_key ($query_in, array_flip(array('rows','actions','action_links','placeholder_actions'))));
 
 		//echo "<p>projectmanager_ui::get_rows(".print_r($query,true).")</p>\n";
 		// save the state of the index in the user prefs
@@ -552,7 +553,7 @@ class projectmanager_ui extends projectmanager_bo
 			'cat_id'     => $query['cat_id'],
 			'order'      => $query['order'],
 			'sort'       => $query['sort'],
-			));
+		));
 		if ($state != $this->prefs['pm_index_state'])
 		{
 			$GLOBALS['egw']->preferences->add('projectmanager','pm_index_state',$state);
@@ -950,7 +951,7 @@ class projectmanager_ui extends projectmanager_bo
 			unset($actions['filemanager']);
 		}
 		// show pricelist only if we use pricelists
-		if ($this->config['accounting_types'] && !in_array('pricelist',$this->config['accounting_types']))
+		if ($this->config['accounting_types'] && !in_array('pricelist',(array)$this->config['accounting_types']))
 		{
 			unset($actions['pricelist']);
 		}
