@@ -29,7 +29,7 @@ app.classes.projectmanager = AppJS.extend(
 		// Name = key, etemplate is filled in when loaded, sidemenu is untranslated text from hooks
 		list: {name: 'list', etemplate: null, sidemenu: 'Projectlist'},
 		elements: {name: 'elements', etemplate: null, sidemenu: 'Elementlist'},
-		gantt: {name: 'gantt', etemplate: null, sidemenu: 'Gantt chart'},
+		gantt: {name: 'gantt', etemplate: null, sidemenu: 'Ganttchart'},
 		prices: {name: 'prices', etemplate: null, sidemenu: 'Pricelist'}
 	},
 
@@ -522,7 +522,9 @@ app.classes.projectmanager = AppJS.extend(
 				var nm = this.views.elements.etemplate ? this.views.elements.etemplate.widgetContainer.getWidgetById('nm') : null;
 				if(nm)
 				{
-					nm.refresh(_id,_type);
+					// Element list has totals that probably need refreshed, so do a
+					// full refresh, not just intelligent by type refresh.
+					nm.refresh(_id);
 				}
 				return false;
 			case 'gantt':
@@ -797,6 +799,51 @@ app.classes.projectmanager = AppJS.extend(
 		}
 	},
 
+	/**
+	 * Action callback to edit a price on the price list
+	 *
+	 * @param {egwAction} action
+	 * @param {egwActionObject[]} selected
+	 */
+	edit_price: function(action, selected)
+	{
+		var extra = {
+			menuaction: 'projectmanager.projectmanager_pricelist_ui.edit',
+			pm_id: this.getState().col_filter.pm_id
+		};
+		if(selected[0] && selected[0].id)
+		{
+			var data = this.egw.dataGetUIDdata(selected[0].id);
+			if(data && data.data)
+			{
+				extra.pl_id = data.data.pl_id;
+			}
+		}
+		egw.openPopup(egw.link('/index.php', extra),600,450,'','filemanager');
+	},
+	
+	/**
+	 * Add a new price to a pricelist
+	 * 
+	 * Used by the add button on the pricelist index
+	 * 
+	 * @param {et2_widget} widget
+	 */
+	add_price: function add_price(widget)
+	{
+		var extras = {
+			menuaction: 'projectmanager.projectmanager_pricelist_ui.edit',
+			pm_id: 0
+		}
+		var pm_filter = widget.getRoot().getWidgetById('pm_id');
+		if(pm_filter)
+		{
+			extras.pm_id = pm_filter.get_value();
+		}
+		window.open(this.egw.link('/index.php',extras),'_blank','dependent=yes,width=600,height=450,scrollbars=yes,status=yes');
+		return false;
+	},
+
 	/**
 	 * Action callback to show the filemanager for a selected project
 	 *
