@@ -156,7 +156,7 @@
 			return true;
 		}
 
-		function admin()
+		public static function admin()
 		{
 			// are we using LDAP for accounts
 			if (!empty($GLOBALS['egw_info']['server']['ldap_host']) &&
@@ -164,7 +164,7 @@
 			{
 				$appname = 'sambaadmin';
 				$file = array(
-					'Site Configuration'	=> egw::link('/index.php','menuaction=admin.uiconfig.index&appname='.$appname),
+					'Site Configuration'	=> egw::link('/index.php','menuaction=admin.admin_config.index&appname='.$appname.'&ajax=true'),
 					//'check ldap setup (experimental!!!)'	=> egw::link('/index.php','menuaction=sambaadmin.uisambaadmin.checkLDAPSetup'),
 				);
 				display_section($appname,$appname,$file);
