@@ -259,7 +259,8 @@ class setup
 		$auth_type = strtolower($_auth_type);
 		$GLOBALS['egw_info']['setup']['HeaderLoginMSG'] = $GLOBALS['egw_info']['setup']['ConfigLoginMSG'] = '';
 
-		if(!$this->checkip($_SERVER['REMOTE_ADDR']))
+		if(!$this->checkip(isset($_SERVER['HTTP_X_FORWARDED_FOR']) ?
+			$_SERVER['HTTP_X_FORWARDED_FOR'] : $_SERVER['REMOTE_ADDR']))
 		{
 			//error_log(__METHOD__."('$auth_type') invalid IP");
 			return false;
@@ -501,7 +502,7 @@ class setup
 					'app_icon_app'  => $setup_info[$appname]['icon_app'],
 				),False,__LINE__,__FILE__);
 
-			$this->clear_session_cache();
+			Api\Egw\Applications::invalidate();
 		}
 	}
 
@@ -581,6 +582,8 @@ class setup
 					'app_icon'      => $setup_info[$appname]['icon'],
 					'app_icon_app'  => $setup_info[$appname]['icon_app'],
 				),array('app_name'=>$appname),__LINE__,__FILE__);
+
+			Api\Egw\Applications::invalidate();
 		}
 	}
 
@@ -607,6 +610,8 @@ class setup
 			$this->db->update($this->applications_table,array(
 					'app_version'	=> $setup_info[$appname]['currentver'],
 				),array('app_name'=>$appname),__LINE__,__FILE__);
+
+			Api\Egw\Applications::invalidate();
 		}
 		return $setup_info;
 	}
@@ -635,10 +640,10 @@ class setup
 		//echo 'DELETING application: ' . $appname;
 		$this->db->delete($this->applications_table,array('app_name'=>$appname),__LINE__,__FILE__);
 
+		Api\Egw\Applications::invalidate();
+
 		// Remove links to the app
 		Link::unlink(0, $appname);
-
-		$this->clear_session_cache();
 	}
 
 	/**
@@ -991,7 +996,7 @@ class setup
 				'account_primary_group' => $primary_group_id,
 				'account_expires'   => -1,
 				'account_email'     => $email,
-				'account_members'   => ''
+				'account_members'   => array()
 			);
 			if (!($accountid = $this->accounts->save($account)))
 			{
@@ -1074,28 +1079,33 @@ class setup
 	 */
 	function accounts_exist()
 	{
-		if (!$this->setup_account_object()) return false;
+		try {
+			if (!$this->setup_account_object()) return false;
 
-		$this->accounts->search(array(
-			'type'   => 'accounts',
-			'start'  => 0,
-			'offset' => 2	// we only need to check 2 accounts, if we just check for not anonymous
-		));
+			$this->accounts->search(array(
+				'type'   => 'accounts',
+				'start'  => 0,
+				'offset' => 2	// we only need to check 2 accounts, if we just check for not anonymous
+			));
 
-		if ($this->accounts->total != 1)
-		{
-			return $this->accounts->total > 1;
+			if ($this->accounts->total != 1)
+			{
+				return $this->accounts->total > 1;
+			}
+
+			// one account, need to check it's not the anonymous one
+			$this->accounts->search(array(
+				'type'   => 'accounts',
+				'start'  => 0,
+				'offset' => 0,
+				'query_type' => 'lid',
+				'query'  => 'anonymous',
+			));
+		}
+		catch (Api\Db\Exception $e) {
+			_egw_log_exception($e);
+			return false;
 		}
-
-		// one account, need to check it's not the anonymous one
-		$this->accounts->search(array(
-			'type'   => 'accounts',
-			'start'  => 0,
-			'offset' => 0,
-			'query_type' => 'lid',
-			'query'  => 'anonymous',
-		));
-
 		return !$this->accounts->total;
 	}
 
