@@ -5,11 +5,14 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package setup
- * @copyright (c) 2007-14 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2007-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Egw;
+
 /**
  * setup command: abstract baseclass for all setup commands, extending admin_cmd
  */
@@ -25,7 +28,7 @@ abstract class setup_cmd extends admin_cmd
 	/**
 	 * Should be called by every command usually requiring header admin rights
 	 *
-	 * @throws egw_exception_no_permission(lang('Wrong credentials to access the header.inc.php file!'),2);
+	 * @throws Api\Exception\NoPermission(lang('Wrong credentials to access the header.inc.php file!'),2);
 	 */
 	protected function _check_header_access()
 	{
@@ -41,7 +44,7 @@ abstract class setup_cmd extends admin_cmd
 		if ($this->header_secret != $secret)
 		{
 			//echo "_check_header_access: header_secret='$this->header_secret' != '$secret'=_calc_header_secret({$GLOBALS['egw_info']['server']['header_admin_user']},{$GLOBALS['egw_info']['server']['header_admin_password']})\n";
-			throw new egw_exception_no_permission(lang('Wrong credentials to access the header.inc.php file!'),5);
+			throw new Api\Exception\NoPermission(lang('Wrong credentials to access the header.inc.php file!'),5);
 		}
 
 	}
@@ -85,7 +88,7 @@ abstract class setup_cmd extends admin_cmd
 	/**
 	 * Saving the object to the database, reimplemented to not do it in setup context
 	 *
-	 * @param boolean $set_modifier=true set the current user as modifier or 0 (= run by the system)
+	 * @param boolean $set_modifier =true set the current user as modifier or 0 (= run by the system)
 	 * @return boolean true on success, false otherwise
 	 */
 	function save($set_modifier=true)
@@ -120,7 +123,7 @@ abstract class setup_cmd extends admin_cmd
 		self::$egw_setup->ConfigDomain = $domain;
 
 		if (isset($GLOBALS['egw_info']['server']['header_admin_user']) && !isset($GLOBALS['egw_domain']) &&
-			is_object($GLOBALS['egw']) && $GLOBALS['egw'] instanceof egw)
+			is_object($GLOBALS['egw']) && $GLOBALS['egw'] instanceof Egw)
 		{
 			// we run inside eGW, not setup --> read egw_domain array from the header via the showheader cmd
 			$cmd = new setup_cmd_showheader(null);	// null = only header, no db stuff, no hashes
@@ -137,10 +140,10 @@ abstract class setup_cmd extends admin_cmd
 		if (is_object($GLOBALS['egw']->db) && $domain)
 		{
 			$GLOBALS['egw']->db->disconnect();
-			$GLOBALS['egw']->db = new egw_db($GLOBALS['egw_domain'][$domain]);
+			$GLOBALS['egw']->db = new Api\Db($GLOBALS['egw_domain'][$domain]);
 
 			// change caching to managed instance
-			egw_cache::unset_instance_key();
+			Api\Cache::unset_instance_key();
 		}
 	}
 
@@ -153,15 +156,15 @@ abstract class setup_cmd extends admin_cmd
 		if (is_object($GLOBALS['egw']->db))
 		{
 			$GLOBALS['egw']->db->disconnect();
-			$GLOBALS['egw']->db = new egw_db($GLOBALS['egw_info']['server']);
+			$GLOBALS['egw']->db = new Api\Db($GLOBALS['egw_info']['server']);
 
 			// change caching back to own instance
-			egw_cache::unset_instance_key();
+			Api\Cache::unset_instance_key();
 
 			if (!is_null(self::$egw_accounts_backup))
 			{
 				$GLOBALS['egw']->accounts = self::$egw_accounts_backup;
-				accounts::cache_invalidate();
+				Api\Accounts::cache_invalidate();
 				unset(self::$egw_accounts_backup);
 			}
 		}
@@ -172,9 +175,9 @@ abstract class setup_cmd extends admin_cmd
 	 *
 	 * @param string $user
 	 * @param string $pw
-	 * @param string $domain=null if given we also check agains config user/pw
-	 * @throws egw_exception_no_permission(lang('Access denied: wrong username or password for manage-header !!!'),21);
-	 * @throws egw_exception_no_permission(lang("Access denied: wrong username or password to configure the domain '%1(%2)' !!!",$domain,$GLOBALS['egw_domain'][$domain]['db_type']),40);
+	 * @param string $domain =null if given we also check agains config user/pw
+	 * @throws Api\Exception\NoPermission(lang('Access denied: wrong username or password for manage-header !!!'),21);
+	 * @throws Api\Exception\NoPermission(lang("Access denied: wrong username or password to configure the domain '%1(%2)' !!!",$domain,$GLOBALS['egw_domain'][$domain]['db_type']),40);
 	 */
 	static function check_setup_auth($user,$pw,$domain=null)
 	{
@@ -191,11 +194,11 @@ abstract class setup_cmd extends admin_cmd
 			{
 				if (is_null($domain))
 				{
-					throw new egw_exception_no_permission(lang('Access denied: wrong username or password for manage-header !!!'),21);
+					throw new Api\Exception\NoPermission(lang('Access denied: wrong username or password for manage-header !!!'),21);
 				}
 				else
 				{
-					throw new egw_exception_no_permission(lang("Access denied: wrong username or password to configure the domain '%1(%2)' !!!",$domain,$GLOBALS['egw_domain'][$domain]['db_type']),40);
+					throw new Api\Exception\NoPermission(lang("Access denied: wrong username or password to configure the domain '%1(%2)' !!!",$domain,$GLOBALS['egw_domain'][$domain]['db_type']),40);
 				}
 			}
 		}
@@ -219,9 +222,9 @@ abstract class setup_cmd extends admin_cmd
 	 *
 	 * Sets self::$apps_to_update and self::$apps_to_install for the last/only domain only!
 	 *
-	 * @param string $domain='' domain to check, default '' = all
-	 * @param int/array $stop=0 stop checks before given exit-code(s), default 0 = all checks
-	 * @param boolean $verbose=false echo messages as they happen, instead returning them
+	 * @param string $domain ='' domain to check, default '' = all
+	 * @param int/array $stop =0 stop checks before given exit-code(s), default 0 = all checks
+	 * @param boolean $verbose =false echo messages as they happen, instead returning them
 	 * @return array with translated messages
 	 */
 	static function check_installed($domain='',$stop=0,$verbose=false)
@@ -237,35 +240,35 @@ abstract class setup_cmd extends admin_cmd
 
 		$versions =& $GLOBALS['egw_info']['server']['versions'];
 
-		if (!$versions['phpgwapi'])
+		if (!$versions['api'])
 		{
-			if (!include(EGW_INCLUDE_ROOT.'/phpgwapi/setup/setup.inc.php'))
+			if (!include(EGW_INCLUDE_ROOT.'/api/setup/setup.inc.php'))
 			{
-				throw new egw_exception_wrong_userinput(lang("eGroupWare sources in '%1' are not complete, file '%2' missing !!!",realpath('..'),'phpgwapi/setup/setup.inc.php'),99);	// should not happen ;-)
+				throw new Api\Exception\WrongUserinput(lang("EGroupware sources in '%1' are not complete, file '%2' missing !!!",realpath('..'),'api/setup/setup.inc.php'),99);	// should not happen ;-)
 			}
-			$versions['phpgwapi'] = $setup_info['phpgwapi']['version'];
+			$versions['api'] = $setup_info['api']['version'];
 			unset($setup_info);
 		}
 		if ($header_checks)
 		{
-			$messages[] = self::_echo_message($verbose,lang('eGroupWare API version %1 found.',$versions['phpgwapi']));
+			$messages[] = self::_echo_message($verbose,lang('EGroupware API version %1 found.',$versions['api']));
 		}
 		$header_stage = self::$egw_setup->detection->check_header();
 		if ($stop && in_array($header_stage,$stop)) return true;
 
 		switch ($header_stage)
 		{
-			case 1: throw new egw_exception_wrong_userinput(lang('eGroupWare configuration file (header.inc.php) does NOT exist.')."\n".lang('Use --create-header to create the configuration file (--usage gives more options).'),1);
+			case 1: throw new Api\Exception\WrongUserinput(lang('EGroupware configuration file (header.inc.php) does NOT exist.')."\n".lang('Use --create-header to create the configuration file (--usage gives more options).'),1);
 
-//			case 2: throw new egw_exception_wrong_userinput(lang('eGroupWare configuration file (header.inc.php) version %1 exists%2',$versions['header'],'.')."\n".lang('No header admin password set! Use --edit-header <password>[,<user>] to set one (--usage gives more options).'),2);
+//			case 2: throw new Api\Exception\WrongUserinput(lang('EGroupware configuration file (header.inc.php) version %1 exists%2',$versions['header'],'.')."\n".lang('No header admin password set! Use --edit-header <password>[,<user>] to set one (--usage gives more options).'),2);
 
-			case 3: throw new egw_exception_wrong_userinput(lang('eGroupWare configuration file (header.inc.php) version %1 exists%2',$versions['header'],'.')."\n".lang('No eGroupWare domains / database instances exist! Use --edit-header --domain to add one (--usage gives more options).'),3);
+			case 3: throw new Api\Exception\WrongUserinput(lang('EGroupware configuration file (header.inc.php) version %1 exists%2',$versions['header'],'.')."\n".lang('No EGroupware domains / database instances exist! Use --edit-header --domain to add one (--usage gives more options).'),3);
 
-			case 4: throw new egw_exception_wrong_userinput(lang('eGroupWare configuration file (header.inc.php) version %1 exists%2',$versions['header'],'.')."\n".lang('It needs upgrading to version %1! Use --update-header <password>[,<user>] to do so (--usage gives more options).',$versions['current_header']),4);
+			case 4: throw new Api\Exception\WrongUserinput(lang('EGroupware configuration file (header.inc.php) version %1 exists%2',$versions['header'],'.')."\n".lang('It needs upgrading to version %1! Use --update-header <password>[,<user>] to do so (--usage gives more options).',$versions['current_header']),4);
 		}
 		if ($header_checks)
 		{
-			$messages[] = self::_echo_message($verbose,lang('eGroupWare configuration file (header.inc.php) version %1 exists%2',
+			$messages[] = self::_echo_message($verbose,lang('EGroupware configuration file (header.inc.php) version %1 exists%2',
 				$versions['header'],' '.lang('and is up to date')));
 		}
 		unset($header_checks);	// no further output of the header checks
@@ -273,7 +276,7 @@ abstract class setup_cmd extends admin_cmd
 		$domains = $GLOBALS['egw_domain'];
 		if ($domain)	// domain to check given
 		{
-			if (!isset($GLOBALS['egw_domain'][$domain])) throw new egw_exception_wrong_userinput(lang("Domain '%1' does NOT exist !!!",$domain), 92);
+			if (!isset($GLOBALS['egw_domain'][$domain])) throw new Api\Exception\WrongUserinput(lang("Domain '%1' does NOT exist !!!",$domain), 92);
 
 			$domains = array($domain => $GLOBALS['egw_domain'][$domain]);
 		}
@@ -283,7 +286,7 @@ abstract class setup_cmd extends admin_cmd
 			if (count($GLOBALS['egw_domain']) > 1)
 			{
 				self::_echo_message($verbose);
-				$messages[] = self::_echo_message($verbose,lang('eGroupWare domain/instance %1(%2):',$domain,$data['db_type']));
+				$messages[] = self::_echo_message($verbose,lang('EGroupware domain/instance %1(%2):',$domain,$data['db_type']));
 			}
 			$setup_info = self::$egw_setup->detection->get_versions();
 			// check if there's already a db-connection and close if, otherwise the db-connection of the previous domain will be used
@@ -307,11 +310,11 @@ abstract class setup_cmd extends admin_cmd
 			}
 			switch($db_stage)
 			{
-				case 1: throw new egw_exception_wrong_userinput(lang('Your Database is not working!')." $db: ".self::$egw_setup->db->Error,11);
+				case 1: throw new Api\Exception\WrongUserinput(lang('Your Database is not working!')." $db: ".self::$egw_setup->db->Error,11);
 
-				case 3: throw new egw_exception_wrong_userinput(lang('Your database is working, but you dont have any applications installed')." ($db). ".lang("Use --install to install eGroupWare."),13);
+				case 3: throw new Api\Exception\WrongUserinput(lang('Your database is working, but you dont have any applications installed')." ($db). ".lang("Use --install to install EGroupware."),13);
 
-				case 4: throw new egw_exception_wrong_userinput(lang('eGroupWare API needs a database (schema) update from version %1 to %2!',$setup_info['phpgwapi']['currentver'],$versions['phpgwapi']).' '.lang('Use --update to do so.'),14);
+				case 4: throw new Api\Exception\WrongUserinput(lang('EGroupware API needs a database (schema) update from version %1 to %2!',$setup_info['phpgwapi']['currentver'],$versions['phpgwapi']).' '.lang('Use --update to do so.'),14);
 
 				case 10:	// also check apps of updates
 					self::$apps_to_upgrade = self::$apps_to_install = array();
@@ -336,16 +339,16 @@ abstract class setup_cmd extends admin_cmd
 						$db_stage = 4;
 						if ($stop && in_array(10+$db_stage,$stop)) return $messages;
 
-						throw new egw_exception_wrong_userinput(lang('The following applications need to be upgraded:').' '.implode(', ',self::$apps_to_upgrade).'! '.lang('Use --update to do so.'),14);
+						throw new Api\Exception\WrongUserinput(lang('The following applications need to be upgraded:').' '.implode(', ',self::$apps_to_upgrade).'! '.lang('Use --update to do so.'),14);
 					}
 					break;
 			}
-			$messages[] = self::_echo_message($verbose,lang("database is version %1 and up to date.",$setup_info['phpgwapi']['currentver']));
+			$messages[] = self::_echo_message($verbose,lang("database is version %1 and up to date.",$setup_info['api']['currentver']));
 
 			self::$egw_setup->detection->check_config();
 			if ($GLOBALS['egw_info']['setup']['config_errors'] && $stop && !in_array(15,$stop))
 			{
-				throw new egw_exception_wrong_userinput(lang('You need to configure eGroupWare:')."\n- ".@implode("\n- ",$GLOBALS['egw_info']['setup']['config_errors']),15);
+				throw new Api\Exception\WrongUserinput(lang('You need to configure EGroupware:')."\n- ".@implode("\n- ",$GLOBALS['egw_info']['setup']['config_errors']),15);
 			}
 		}
 		return $messages;
