@@ -546,8 +546,7 @@ class setup_cmd_ldap extends setup_cmd
 				if (!isset($ldap_class))
 				{
 					$ldap_class = false;
-					$ldap = new ldap();
-					$ldap->ldapConnect();
+					$ldap = Api\Ldap::factory(false);
 					foreach(array(	// todo: have these enumerated by emailadmin ...
 						'qmailUser' => 'EGroupware\\Api\\Mail\\Smtp\\Oldqmailuser',
 						'dbMailUser' => 'EGroupware\\Api\\Mail\\Smtp\\Dbmailuser',
@@ -785,8 +784,8 @@ class setup_cmd_ldap extends setup_cmd
 			array(
 				'account_repository' => $GLOBALS['egw_info']['server']['account_repository'],
 			) + $this->as_array()) ||
-			!is_a(self::$egw_setup->accounts,'accounts') ||
-			!is_a(self::$egw_setup->accounts->backend,'accounts_'.$type))
+			!is_a(self::$egw_setup->accounts, 'EGroupware\\Api\\Accounts') ||
+			!is_a(self::$egw_setup->accounts->backend, 'EGroupware\\Api\\Accounts\\'.ucfirst($type)))
 		{
 			throw new Exception(lang("Can NOT instancate accounts object for %1", strtoupper($type)));
 		}
