@@ -1,6 +1,6 @@
 <?php
 /**
- * eGroupWare Setup
+ * EGroupware Setup
  *
  * @link http://www.egroupware.org
  * @package setup
@@ -11,6 +11,8 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * Some static helper functions to generate html stuff in setup
  */
@@ -29,8 +31,8 @@ class setup_html
 		$GLOBALS['header_template']->set_block('header','domain','domain');
 		$var = Array();
 
-		$deletedomain = get_var('deletedomain',Array('POST'));
-		$domains = get_var('domains',Array('POST'));
+		$deletedomain = $_POST['deletedomain'];
+		$domains = $_POST['domains'];
 
 		foreach($domains as $k => $v)
 		{
@@ -39,7 +41,7 @@ class setup_html
 				continue;
 			}
 			$variableName = str_replace('.','_',$k);
-			$dom = get_var('setting_'.$variableName,Array('POST'));
+			$dom = $_POST['setting_'.$variableName];
 			$GLOBALS['header_template']->set_var('DB_DOMAIN',$v);
 			foreach($dom as $x => $y)
 			{
@@ -70,7 +72,7 @@ class setup_html
 
 		$GLOBALS['header_template']->set_var('domain','');
 
-		$setting = get_var('setting',Array('POST'));
+		$setting = $_POST['setting'];
 		while($setting && list($k,$v) = @each($setting))
 		{
 			if(strtoupper($k) == 'HEADER_ADMIN_PASSWORD')
@@ -99,14 +101,14 @@ class setup_html
 		/* hack to get tpl dir */
 		if (is_dir(EGW_SERVER_ROOT))
 		{
-			$srv_root = EGW_SERVER_ROOT . SEP . "$app_name" . SEP;
+			$srv_root = EGW_SERVER_ROOT . '/' . $app_name . '/';
 		}
 		else
 		{
 			$srv_root = '';
 		}
 
-		$tpl_typical = 'templates' . SEP . 'default';
+		$tpl_typical = 'templates/default';
 		$tpl_root = "$srv_root" ."$tpl_typical";
 		return $tpl_root;
 	}
@@ -152,11 +154,19 @@ class setup_html
 		if(basename($_SERVER['SCRIPT_FILENAME']) != 'index.php')
 		{
 			$index_btn = '<a href="index.php" class="link">' . lang('Setup Main Menu') . '</a>';
-			$index_img = '<img src="../phpgwapi/templates/default/images/bullet.png" />';
+			$index_img = '<img src="../api/templates/default/images/bullet.png" />';
 		}
 
 		$GLOBALS['setup_tpl']->set_var('lang_version',lang('version'));
-		$GLOBALS['setup_tpl']->set_var('pgw_ver',@$GLOBALS['egw_info']['server']['versions']['phpgwapi']);
+		if (!isset($GLOBALS['setup_info']) || !isset($GLOBALS['setup_info']['api']))
+		{
+			include(EGW_SERVER_ROOT.'/api/setup/setup.inc.php');
+		}
+		else
+		{
+			$setup_info = $GLOBALS['setup_info'];
+		}
+		$GLOBALS['setup_tpl']->set_var('pgw_ver', $setup_info['api']['version']);
 		$GLOBALS['setup_tpl']->set_var(array(
 			'logoutbutton'  => $btn_logout,
 			'indexbutton'   => $index_btn,
@@ -238,7 +248,7 @@ class setup_html
 			*/
 			if (count($GLOBALS['egw_domain']) > 1)
 			{
-				foreach($GLOBALS['egw_domain'] as $domain => $data)
+				foreach(array_keys($GLOBALS['egw_domain']) as $domain)
 				{
 					$domains .= "<option value=\"$domain\" ".($domain == @$GLOBALS['egw_info']['setup']['LastDomain'] ? ' selected="selected"' : '').">$domain</option>\n";
 				}
@@ -287,7 +297,7 @@ class setup_html
 			$ConfigLang = setup::get_lang();
 			if (empty($ConfigLang)) $ConfigLang = substr($_SERVER['HTTP_ACCEPT_LANGUAGE'],0,2);
 		}
-		return html::select('ConfigLang', $ConfigLang, translation::get_available_langs(false), true,
+		return Api\Html::select('ConfigLang', $ConfigLang, Api\Translation::get_available_langs(false), true,
 			$onChange ? ' onchange="this.form.submit();"' : '');
 	}
 
@@ -295,6 +305,7 @@ class setup_html
 	{
 		$d = dir(EGW_SERVER_ROOT . '/phpgwapi/templates');
 
+		$list = array();
 		while($entry = $d->read())
 		{
 			if ($entry != 'CVS' && $entry != '.' && $entry != '..')
