@@ -1,6 +1,6 @@
 <?php
 /**
- * Setup
+ * EGroupware Setup
  *
  * @link http://www.egroupware.org
  * @package setup
@@ -13,7 +13,7 @@
  * @version $Id$
  */
 
-error_reporting(error_reporting() & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
+error_reporting(error_reporting() & ~E_NOTICE & ~E_STRICT);
 
 // for an old header, we need to setup the reference before including it
 $GLOBALS['phpgw_info'] =& $GLOBALS['egw_info'];
@@ -50,7 +50,7 @@ if(!defined('EGW_SERVER_ROOT') && !defined('EGW_INCLUDE_ROOT'))
 	define('EGW_API_INC',EGW_SERVER_ROOT.'/phpgwapi/inc');
 }
 
-require_once(EGW_INCLUDE_ROOT . '/phpgwapi/inc/common_functions.inc.php');
+require_once(EGW_INCLUDE_ROOT . '/api/src/loader/common.php');
 
 /**
  * function to handle multilanguage support
@@ -66,15 +66,15 @@ function lang($key,$vars=null)
 	return $GLOBALS['egw_setup']->translation->translate("$key", $vars);
 }
 
-if(file_exists(EGW_SERVER_ROOT.'/phpgwapi/setup/setup.inc.php'))
+if(file_exists(EGW_SERVER_ROOT.'/api/setup/setup.inc.php'))
 {
-	include(EGW_SERVER_ROOT.'/phpgwapi/setup/setup.inc.php'); /* To set the current core version */
+	include(EGW_SERVER_ROOT.'/api/setup/setup.inc.php'); /* To set the current core version */
 	/* This will change to just use setup_info */
-	$GLOBALS['egw_info']['server']['versions']['current_header'] = $setup_info['phpgwapi']['versions']['current_header'];
+	$GLOBALS['egw_info']['server']['versions']['current_header'] = $setup_info['api']['versions']['current_header'];
 }
 else
 {
-	$GLOBALS['egw_info']['server']['versions']['phpgwapi'] = 'Undetected';
+	$GLOBALS['egw_info']['server']['versions']['api'] = 'Undetected';
 }
 
 $GLOBALS['egw_info']['server']['app_images'] = 'templates/default/images';
