@@ -280,15 +280,18 @@ class timesheet_bo extends Api\Storage
 	/**
 	 * get list of specified grants as uid => Username pairs
 	 *
-	 * @param int $required =EGW_ACL_READ
+	 * @param int $required =Acl::READ
+	 * @param boolean $hide_deactive =null default only Acl::EDIT hides deactivates users
 	 * @return array with uid => Username pairs
 	 */
-	function grant_list($required=EGW_ACL_READ)
+	function grant_list($required=Acl::READ, $hide_deactive=null)
 	{
+		if (!isset($hide_deactive)) $hide_deactive = $required == Acl::EDIT;
+
 		$result = array();
 		foreach($this->grants as $uid => $grant)
 		{
-			if ($grant & $required)
+			if ($grant & $required && (!$hide_deactive || Api\Accounts::getInstance()->is_active($uid)))
 			{
 				$result[$uid] = Api\Accounts::username($uid);
 			}
@@ -393,6 +396,7 @@ class timesheet_bo extends Api\Storage
 	 * search the timesheet
 	 *
 	 * reimplemented to limit result to users we have grants from
+	 * Use $filter['ts_owner'] === false for no ACL check.
 	 *
 	 * @param array|string $criteria array of key and data cols, OR a SQL query (content for WHERE), fully quoted (!)
 	 * @param boolean|string $only_keys =true True returns only keys, False returns all cols. comma seperated list of keys to return
@@ -428,6 +432,11 @@ class timesheet_bo extends Api\Storage
 		{
 			$filter['ts_owner'] = array_keys($this->grants);
 		}
+		// $filter['ts_owner'] === false --> no ACL checks
+		elseif ($filter['ts_owner'] === false)
+		{
+			$filter['ts_owner'] = '';
+		}
 		else
 		{
 			if (!is_array($filter['ts_owner'])) $filter['ts_owner'] = array($filter['ts_owner']);
@@ -592,6 +601,17 @@ class timesheet_bo extends Api\Storage
 		{
 			return false;
 		}
+		// Update ts_project to match project
+		if ($this->pm_integration == 'full' && (
+				!$old && $this->data['pm_id'] != $this->data['old_pm_id'] || $old && $old['pm_id'] != $new['pm_id']
+		))
+		{
+			$this->data['ts_project'] = $this->data['pm_id'] ? Link::title('projectmanager', $this->data['pm_id']) : '';
+			if($this->data['ts_title'] == Link::title('projectmanager', $old['pm_id']))
+			{
+				$this->data['ts_title'] = $this->data['ts_project'];
+			}
+		}
 
 		// Check for restore of deleted contact, restore held links
 		if($old && $old['ts_status'] == self::DELETED_STATUS && $new['ts_status'] != self::DELETED_STATUS)
