@@ -5,7 +5,7 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package timesheet
- * @copyright (c) 2005-8 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2005-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
@@ -82,11 +82,13 @@ class timesheet_datasource extends datasource
 	 *
 	 * @param array $element source project element representing an InfoLog entry, $element['pe_app_id'] = info_id
 	 * @param int $target target project id
-	 * @param array $target_data=null data of target-project, atm not used by the infolog datasource
-	 * @return array/boolean array(info_id,link_id) on success, false otherwise
+	 * @param array $extra =null data of target-project, atm not used by the infolog datasource
+	 * @return array|boolean array(info_id,link_id) on success, false otherwise
 	 */
 	function copy($element,$target,$extra=null)
 	{
+		unset($element,$target,$extra);	// not used, but required by function signature
+
 		return false;
 	}
 
