@@ -85,19 +85,33 @@ class timesheet_ui extends timesheet_bo
 					'ts_owner' => $GLOBALS['egw_info']['user']['account_id'],
 					'cat_id'   => (int) $_REQUEST['cat_id'],
 					'ts_status'=> $GLOBALS['egw_info']['user']['preferences']['timesheet']['predefined_status'],
+					'ts_project' => $_REQUEST['ts_project'],
+					'ts_title_blur' => $_REQUEST['ts_project'],
 				);
+				if(!is_numeric($_REQUEST['ts_project']))
+				{
+					$this->data['pm_id'] = $this->find_pm_id($_REQUEST['ts_project']);
+				}
 			}
 			$matches = null;
 			$referer = preg_match('/menuaction=([^&]+)/',$_SERVER['HTTP_REFERER'],$matches) ? $matches[1] :
 				(strpos($_SERVER['HTTP_REFERER'],'/infolog/index.php') !== false ? 'infolog.infolog_ui.index' : TIMESHEET_APP.'.timesheet_ui.index');
 
+			if($_GET['action'] == 'copy')
+			{
+				$this->create_copy();
+				$msg = lang('%1 copied - the copy can now be edited', lang(Link::get_registry(TIMESHEET_APP,'entry')));
+			}
 			if (!$this->check_statusForEditRights($this->data))
 			{
 				$view = true;  //only admin can edit with this status
 				$only_admin_edit = true;
 				$msg = lang('only Admin can edit this status');
 			}
-			$this->data['ts_project_blur'] = $this->data['pm_id'] ? Link::title('projectmanager', $this->data['pm_id']) : '';
+			if(!$this->data['ts_project_blur'])
+			{
+				$this->data['ts_project_blur'] = $this->data['pm_id'] ? Link::title('projectmanager', $this->data['pm_id']) : '';
+			}
 		}
 		else
 		{
@@ -190,7 +204,9 @@ class timesheet_ui extends timesheet_bo
 					// set ts_title to ts_project if short viewtype (title is not editable)
 					if($this->ts_viewtype == 'short')
 					{
-						$this->data['ts_title'] = $this->data['ts_project'];
+						$this->data['ts_title'] = $this->data['ts_project'] = $this->data['pm_id'] ?
+								Link::title('projectmanager', $this->data['pm_id']) :
+								$this->data['ts_project'];
 					}
 					if (!$this->data['ts_title'])
 					{
@@ -269,12 +285,16 @@ class timesheet_ui extends timesheet_bo
 						}
 						// create a new entry
 						$this->data['ts_start'] += 60 * $this->data['ts_duration'];
-						foreach(array('ts_id','ts_title','ts_description','ts_duration','ts_quantity','ts_modified','ts_modifier') as $name)
+						foreach(array('ts_id','ts_title','ts_description','ts_duration','ts_quantity','ts_modified','ts_modifier','link_to') as $name)
 						{
 							unset($this->data[$name]);
 						}
 						// save the selected project, to delete the project-link, if the user changes the project
 						$this->data['old_pm_id'] = $this->data['pm_id'];
+						if($this->pm_integration == 'none')
+						{
+							unset($this->data['pm_id']);
+						}
 						break;
 					}
 					// fall-through for save
@@ -307,7 +327,8 @@ class timesheet_ui extends timesheet_bo
 			'view' => $view,
 			'tabs'  => $content['tabs'],
 			'link_to' => array(
-				'to_id' => $this->data['ts_id'] ? $this->data['ts_id'] : $content['link_to']['to_id'],
+				'to_id' => $this->data['ts_id'] ? $this->data['ts_id'] :
+					($this->data['link_to']['to_id'] ? $this->data['link_to']['to_id'] : $content['link_to']['to_id']),
 				'to_app' => TIMESHEET_APP,
 			),
 			'ts_quantity_blur' => $this->data['ts_duration'] ? round($this->data['ts_duration'] / 60.0,3) : '',
@@ -368,7 +389,7 @@ class timesheet_ui extends timesheet_bo
 		{
 			$preserv['old_pm_id'] = array_shift($links);
 		}
-		if (!isset($this->data['pm_id']) && $preserv['old_pm_id'])
+		if ((!isset($this->data['pm_id']) || $this->data['pm_id'] === false) && $preserv['old_pm_id'])
 		{
 			$content['pm_id'] = $preserv['old_pm_id'];
 		}
@@ -437,6 +458,10 @@ class timesheet_ui extends timesheet_bo
 		{
 			$content['ts_viewtype'] = $readonlys['tabs']['notes'] = true;
 			$content['ts_description_short'] = $content['ts_description'];
+			if(!$content['pm_id'] && $this->pm_integration != 'full' && $content['ts_project'])
+			{
+				$etpl->setElementAttribute('pm_id','blur',$content['ts_project']);
+			}
 		}
 		if (!$this->customfields) $readonlys['tabs']['customfields'] = true;	// suppress tab if there are not customfields
 		if (!$this->data['ts_id']) $readonlys['tabs']['history']    = true;   //suppress history for the first loading without ID
@@ -471,11 +496,12 @@ class timesheet_ui extends timesheet_bo
 	function get_rows(&$query_in,&$rows,&$readonlys,$id_only=false)
 	{
 		$this->show_sums = false;
+		$end_date = false;
 
 		// Date filter
-		$end_date = $query_in['enddate'] ? $query_in['enddate'] : false;
-		if($end_date || $query_in['filter'] === 'custom')
+		if($query_in['filter'] === 'custom')
 		{
+			$end_date = $query_in['enddate'] ? $query_in['enddate'] : false;
 			$query_in['startdate'] = $query_in['startdate'] ? $query_in['startdate'] : 1;
 		}
 		$date_filter = $this->date_filter($query_in['filter'],$query_in['startdate'],$end_date);
@@ -505,14 +531,14 @@ class timesheet_ui extends timesheet_bo
 				case 'Saturday': $week_end_day = 'Friday'; break;
 			}
 			$filter_start_day = date('l',$query_in['startdate']+12*60*60);
-			$filter_end_day   = $query_in['enddate'] ? date('l',$query_in['enddate']+12*60*60) : false;
+			$filter_end_day   = $end_date ? date('l',$end_date+12*60*60) : false;
 			//echo "<p align=right>prefs: $week_start_day - $week_end_day, filter: $filter_start_day - $filter_end_day</p>\n";
 			if ($filter_start_day == $week_start_day && (!$filter_end_day || $filter_end_day == $week_end_day))
 			{
 				$this->show_sums[] = 'week';
 			}
 			// show day-sums, if range <= 5 weeks
-			if (!$query_in['enddate'] || $query_in['enddate'] - $query_in['startdate'] < 36*24*60*60)
+			if (!$end_date || $end_date - $query_in['startdate'] < 36*24*60*60)
 			{
 				$this->show_sums[] = 'day';
 			}
@@ -553,7 +579,15 @@ class timesheet_ui extends timesheet_bo
 		// handle linked filter (show only entries linked to a certain other entry)
 		if ($query['col_filter']['linked'])
 		{
-			list($app,$id) = explode(':',$query['col_filter']['linked']);
+			if(!is_array($query['col_filter']['linked']))
+			{
+				list($app,$id) = explode(':',$query['col_filter']['linked']);
+			}
+			else
+			{
+				$app = $query['col_filter']['linked']['app'];
+				$id = $query['col_filter']['linked']['id'];
+			}
 			if (!($links = Link::get_links($app,$id,'timesheet')))
 			{
 				$rows = array();	// no infologs linked to project --> no rows to return
@@ -901,12 +935,18 @@ class timesheet_ui extends timesheet_bo
 				'placeholder_actions' => array('add')
 			);
 		}
-		$content['nm']['actions'] = $this->get_actions($content['nm']);
 
 		if($_GET['search'])
 		{
 			$content['nm']['search'] = $_GET['search'];
 		}
+		if($_GET['link_app'] && Link::get_registry($_GET['link_app'], 'query') && $_GET['link_id'])
+		{
+			$content['nm']['col_filter']['linked'] = array(
+				'app' => $_GET['link_app'],
+				'id' => $_GET['link_id']
+			);
+		}
 		$read_grants = $this->grant_list(Acl::READ);
 		$content['nm']['no_owner_col'] = count($read_grants) == 1;
 		if ($GLOBALS['egw_info']['user']['preferences']['timesheet']['nextmatch-timesheet.index.rows']) $content['nm']['selectcols'] = $GLOBALS['egw_info']['user']['preferences']['timesheet']['nextmatch-timesheet.index.rows'];
@@ -976,9 +1016,21 @@ class timesheet_ui extends timesheet_bo
 */
 			'add' => array(
 				'caption' => 'Add',
-				'url' => 'menuaction=timesheet.timesheet_ui.edit',
-				'popup' => Link::get_registry('timesheet', 'add_popup'),
 				'group' => $group,
+				'children' => array(
+					'new' => array(
+						'caption' => 'New',
+						'onExecute' => 'javaScript:app.timesheet.add_action_handler',
+						'icon' => 'new',
+					),
+					'copy' => array(
+						'caption' => 'Copy',
+						'url' => 'menuaction=timesheet.timesheet_ui.edit&action=copy&ts_id=$id',
+						'popup' => Link::get_registry('infolog', 'add_popup'),
+						'allowOnMultiple' => false,
+						'icon' => 'copy',
+					),
+				)
 			),
 			'cat' => Etemplate\Widget\Nextmatch::category_action(
 				'timesheet',++$group,'Change category','cat_'
@@ -1239,4 +1291,61 @@ class timesheet_ui extends timesheet_bo
 		$etpl = new Etemplate('timesheet.editstatus');
 		$etpl->exec('timesheet.timesheet_ui.editstatus',$content,$sel_options,array(),$preserv);
 	}
+
+	/**
+	 * Try to find a PM ID from project title
+	 *
+	 * @param string $project
+	 */
+	protected function find_pm_id($project)
+	{
+		list($pm_number, $pm_title) = explode(': ', $project, 2);
+		if(!$pm_number || !$pm_title)
+		{
+			return false;
+		}
+
+		$pm = new projectmanager_bo();
+		$pm_ids = $pm->search(array('pm_number' => $pm_number, 'pm_title' => $pm_title));
+		if($pm_ids && count($pm_ids) >= 1)
+		{
+			return $pm_ids[0]['pm_id'];
+		}
+		return false;
+	}
+
+	/**
+	 * Create a copy from an entry currently read into $this->data including all
+	 * customfields, attachments and links
+	 */
+	private function create_copy()
+	{
+		$original_id = $this->data['ts_id'];
+		unset($this->data['ts_id']);
+
+		$this->data['ts_title'] = lang('Copy of:') . ' ' .$this->data['ts_title'];
+		unset($this->data['ts_modified']);
+		unset($this->data['ts_modifier']);
+		$this->data['ts_owner'] = !(int)$this->data['ts_owner'] || !$this->check_acl(Acl::ADD,NULL,$this->data['ts_owner']) ? $this->user : $this->data['ts_owner'];
+
+		// Copy links
+		if(!is_array($this->data['link_to'])) $this->data['link_to'] = array();
+		$this->data['link_to']['to_app'] = 'timesheet';
+		$this->data['link_to']['to_id'] = 0;
+
+		foreach(Link::get_links($this->data['link_to']['to_app'], $original_id) as $link)
+		{
+			if ($link['app'] != Link::VFS_APPNAME)
+			{
+				Link::link('timesheet', $this->data['link_to']['to_id'], $link['app'], $link['id'], $link['remark']);
+			}
+			elseif ($link['app'] == Link::VFS_APPNAME)
+			{
+				Link::link('timesheet', $this->data['link_to']['to_id'], Link::VFS_APPNAME, array(
+					'tmp_name' => Link::vfs_path($link['app2'], $link['id2']).'/'.$link['id'],
+					'name' => $link['id'],
+				), $link['remark']);
+			}
+		}
+	}
 }
