@@ -75,6 +75,7 @@ class tracker_bo extends tracker_so
 	 * @var array
 	 */
 	protected $priorities;
+
 	/**
 	 * Stati used by all trackers
 	 *
@@ -308,7 +309,7 @@ class tracker_bo extends tracker_so
 	 * @var array
 	 */
 	var $config_names = array(
-		'technicians','admins','users','notification','projects','priorities','restrictions',	// tracker specific
+		'technicians','admins','users','notification','projects','priorities','default_priority','restrictions',	// tracker specific
 		'field_acl','allow_assign_groups','allow_voting','overdue_days','pending_close_days','htmledit','create_new_as_private','allow_assign_users','allow_infolog','allow_restricted_comments','mailhandling',	// tracker unspecific
 		'allow_bounties','currency','enabled_queue_acl_access','exclude_app_on_timesheetcreation','show_dates'
 	);
@@ -407,6 +408,10 @@ class tracker_bo extends tracker_so
 		// set default resolution
 		$this->get_tracker_labels('resolution', $this->data['tr_tracker'], $this->data['tr_resolution']);
 
+		// set default priority
+		$this->get_tracker_priorities($this->data['tr_tracker'],$this->data['cat_id'], true, $default_priority);
+		$this->data['tr_priority'] = $default_priority;
+
 		$this->data_merge($keys);
 
 		return $this->data;
@@ -571,6 +576,12 @@ class tracker_bo extends tracker_so
 				}
 			}
 
+			// Auto-assign if category changed & noone assigned
+			if ($this->data['cat_id'] && $this->data['cat_id'] != $old['cat_id'] && !$this->data['tr_assigned'])
+			{
+				$this->autoassign();
+			}
+
 			// Changes mark the ticket unseen for everbody but the current
 			// user if the ticket wasn't closed at the same time
 			if (!in_array($this->data['tr_status'],$this->get_tracker_stati(null, true)))
@@ -1268,9 +1279,10 @@ class tracker_bo extends tracker_so
 	 * @param int $tracker = null tracker to use or null to use tracker unspecific priorities
 	 * @param int $cat_id = null category to use or null to use categorie unspecific priorities
 	 * @param boolean $remove_empty = true should empty labels be displayed, default no
+	 * @param int &$default = null on return default, if it is set
 	 * @return array
 	 */
-	function get_tracker_priorities($tracker=null,$cat_id=null,$remove_empty=true)
+	function get_tracker_priorities($tracker=null,$cat_id=null,$remove_empty=true, &$default = null)
 	{
 		if (isset($this->priorities[$tracker.'-'.$cat_id]))
 		{
@@ -1292,6 +1304,9 @@ class tracker_bo extends tracker_so
 		{
 			$prios = self::$stock_priorities;
 		}
+		$default = $prios['default'] ? $prios['default'] : 5;
+		unset($prios['default']);
+		
 		if ($remove_empty)
 		{
 			foreach($prios as $key => $val)
@@ -1535,7 +1550,7 @@ class tracker_bo extends tracker_so
 
 		if (!is_object($this->historylog))
 		{
-			$this->historylog =& CreateObject('phpgwapi.historylog','tracker');
+			$this->historylog = new Api\Storage\History('tracker');
 		}
 		$ids = $this->query_list($this->table_name.'.tr_id','',array('tr_tracker' => $tracker));
 		if ($ids) $this->historylog->delete($ids);
@@ -1822,7 +1837,7 @@ class tracker_bo extends tracker_so
 	{
 		if (!is_object($this->historylog))
 		{
-			$this->historylog =& CreateObject('phpgwapi.historylog','tracker');
+			$this->historylog = new Api\Storage\History('tracker');
 		}
 		if (is_null($new) && $old)
 		{
@@ -1908,7 +1923,12 @@ class tracker_bo extends tracker_so
 			return 0;
 		}
 		// Use strncmp() here, since a Fwd might add a sqr bracket.
-		if (strncmp(trim($trackerData[0]['tr_summary']), trim($tr_data[3][0]), strlen(trim($trackerData[0]['tr_summary']))))
+		if (strncmp(trim($trackerData[0]['tr_summary']), trim($tr_data[3][0]), strlen(trim($trackerData[0]['tr_summary']))) &&
+				// Some mail apps might truncate long subjects, 72 seems to be the smallest
+				// Those are OK if what remains matches
+				strlen($tr_data[3][0]) <= 70 &&
+				strpos(trim($tr_data[3][0]), trim($trackerData[0]['tr_summary'])) !== 0
+		)
 		{
 			//_debug_array($trackerData);
 			return 0; // Summary doesn't match. Should this be ok?
