@@ -11,6 +11,8 @@
  * @version $Id
  */
 
+use EGroupware\Api;
+
 /**
  * export tickets to CSV
  */
@@ -18,7 +20,7 @@ class tracker_export_csv implements importexport_iface_export_plugin {
 
 	public function __construct()
 	{
-		translation::add_app('tracker');
+		Api\Translation::add_app('tracker');
 		$this->ui = new tracker_ui();
 		$this->get_selects();
 	}
@@ -32,28 +34,30 @@ class tracker_export_csv implements importexport_iface_export_plugin {
 
 
 		$selection = array();
-		$query_key = 'tracker'.($options['tracker'] ? '-'.$options['tracker'] : '');
-		$query = $old_query = egw_session::appsession('index',$query_key);
+		$query_key = 'index'.($options['tracker'] ? '-'.$options['tracker'] : '');
+		$query = $old_query = Api\Cache::getSession('tracker',$query_key);
 		switch($options['selection'])
 		{
 			case 'search':
 				// ui selection with checkbox 'use_all'
 				$query['num_rows'] = -1;	// all
 				$query['csv_export'] = true;	// so get_rows method _can_ produce different content or not store state in the session
+				$readonlys = null;
 				$this->ui->get_rows($query,$selection,$readonlys);
 
 				// Reset nm params
-				egw_session::appsession('index',$query_key, $old_query);
+				Api\Cache::setSession('tracker',$query_key, $old_query);
 				break;
 			case 'filter':
 			case 'all':
 				$query = array(
 					'num_rows' => -1,		// all
+					'order' => 'tr_id',
 					'csv_export' => true,	// so get_rows method _can_ produce different content or not store state in the session
 				);
 				if($options['selection'] == 'filter')
 				{
-					$fields = importexport_helper_functions::get_filter_fields($_definition->application, $this);
+					importexport_helper_functions::get_filter_fields($_definition->application, $this);
 					$query['col_filter'] = $_definition->filter;
 
 					// Backend expects a string
@@ -77,7 +81,7 @@ class tracker_export_csv implements importexport_iface_export_plugin {
 				$this->ui->get_rows($query,$selection,$readonlys);
 
 				// Reset nm params
-				egw_session::appsession('index',$query_key, $old_query);
+				Api\Cache::setSession('tracker',$query_key, $old_query);
 			break;
 			default:
 				$selection = explode(',',$options['selection']);
@@ -179,6 +183,7 @@ class tracker_export_csv implements importexport_iface_export_plugin {
 	 * @param tracker_egw_record $record Record to be converted
 	 */
 	protected static function convert(tracker_egw_record &$record, array $options = array()) {
+		unset($options);	// not used, but required by function signature
 		$record->tr_description = htmlspecialchars_decode(strip_tags($record->tr_description));
 
 		if(is_array($record->replies)) {
@@ -187,7 +192,7 @@ class tracker_export_csv implements importexport_iface_export_plugin {
 				// User date format
 				$date = date($GLOBALS['egw_info']['user']['preferences']['common']['dateformat'] . ', '.
 					($GLOBALS['egw_info']['user']['preferences']['common']['timeformat'] == '24' ? 'H' : 'h').':i:s',$reply['reply_created']);
-				$name = common::grab_owner_name($reply['reply_creator']);
+				$name = Api\Accounts::username($reply['reply_creator']);
 				$message = str_replace("\r\n", "\n", htmlspecialchars_decode(strip_tags($reply['reply_message'])));
 
 				$replies[$id] = "$date \t$name \t$message";
@@ -199,10 +204,10 @@ class tracker_export_csv implements importexport_iface_export_plugin {
 			if( count($record->bounties) > 0) {
 				$bounties = array();
 				$total = 0;
-				foreach($record->bounties as $key => $bounty) {
+				foreach($record->bounties as $bounty) {
 					$date = date($GLOBALS['egw_info']['user']['preferences']['common']['dateformat'] . ', '.
 						($GLOBALS['egw_info']['user']['preferences']['common']['timeformat'] == '24' ? 'H' : 'h').':i:s',$bounty['bounty_created']);
-					$name = common::grab_owner_name($bounty['bounty_creator']);
+					$name = Api\Accounts::username($bounty['bounty_creator']);
 					$total += $bounty['bounty_amount'];
 					$bounties[] = "$date\t$name\t".$bounty['bounty_amount'];
 				}
@@ -227,7 +232,7 @@ class tracker_export_csv implements importexport_iface_export_plugin {
 			'tr_priority'	=> $this->ui->get_tracker_priorities(),
 			'tr_private'	=> array('' => lang('no'),0 => lang('no'),'1'=>lang('yes')),
 		);
-		foreach($this->selects['tr_tracker'] as $id => $name) {
+		foreach(array_keys($this->selects['tr_tracker']) as $id) {
 			$this->selects['tr_version'] += $this->ui->get_tracker_labels('version', $id);
 			$this->selects['tr_status'] += $this->ui->get_tracker_stati($id);
 			$this->selects['tr_resolution'] += $this->ui->get_tracker_labels('resolution',$id);
@@ -239,7 +244,7 @@ class tracker_export_csv implements importexport_iface_export_plugin {
 	 * Adjust automatically generated filter fields
 	 */
 	public function get_filter_fields(Array &$filters)
-	{
+    {
 		// When filtering, use only categories flagged as category
 		$filters['cat_id']['type'] = 'select';
 		$filters['cat_id']['values'] = $this->ui->get_tracker_labels('cat',null);
