@@ -144,8 +144,10 @@ class tracker_import_csv implements importexport_iface_import_plugin  {
 		}
 
 		// set Owner
-		$_definition->plugin_options['record_owner'] = isset( $_definition->plugin_options['record_owner'] ) ?
+		$plugin_options = $_definition->plugin_options;
+		$plugin_options['record_owner'] = isset( $_definition->plugin_options['record_owner'] ) ?
 			$_definition->plugin_options['record_owner'] : $this->user;
+		$_definition->plugin_options = $plugin_options;
 
 		// Process cat_id as a normal select
 		$types = tracker_egw_record::$types;
