@@ -5,15 +5,17 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package tracker
- * @copyright (c) 2006-12 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2006-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * Tracker - tracking object for the tracker
  */
-class tracker_tracking extends bo_tracking
+class tracker_tracking extends Api\Storage\Tracking
 {
 	/**
 	 * Application we are tracking (required!)
@@ -79,11 +81,11 @@ class tracker_tracking extends bo_tracking
 	 * Overridden from parent to hide restricted comments
 	 *
 	 * @param array $data current entry
-	 * @param array $old=null old/last state of the entry or null for a new entry
-	 * @param int $user=null user who made the changes, default to current user
-	 * @param boolean $deleted=null can be set to true to let the tracking know the item got deleted or undeleted
-	 * @param array $changed_fields=null changed fields from ealier call to $this->changed_fields($data,$old), to not compute it again
-	 * @param boolean $skip_notification=false do NOT send any notification
+	 * @param array $old =null old/last state of the entry or null for a new entry
+	 * @param int $user =null user who made the changes, default to current user
+	 * @param boolean $deleted =null can be set to true to let the tracking know the item got deleted or undeleted
+	 * @param array $changed_fields =null changed fields from ealier call to $this->changed_fields($data,$old), to not compute it again
+	 * @param boolean $skip_notification =false do NOT send any notification
 	 * @return int|boolean false on error, integer number of changes logged or true for new entries ($old == null)
 	 */
 	public function track(array $data,array $old=null,$user=null,$deleted=null,array $changed_fields=null,$skip_notification=false)
@@ -93,7 +95,7 @@ class tracker_tracking extends bo_tracking
 		$changes = true;
 
 		// Hide restricted comments from reply count
-		foreach((array)$data['replies'] as $key => $reply)
+		foreach((array)$data['replies'] as $reply)
 		{
 			if($reply['reply_visible'] != 0)
 			{
@@ -127,7 +129,7 @@ class tracker_tracking extends bo_tracking
 	 * @param array $autoreply values for:
 	 *			'reply_text' => Texline to add to the mail message
 	 *			'reply_to' => UserID or email address
-	 * @param array $old=null old/last state of the entry or null for a new entry
+	 * @param array $old =null old/last state of the entry or null for a new entry
 	 */
 	function autoreply($data,$autoreply,$old=null)
 	{
@@ -165,13 +167,12 @@ class tracker_tracking extends bo_tracking
 	 *
 	 * @internal use only track($data,$old,$user)
 	 * @param array $data current entry
-	 * @param array $old=null old/last state of the entry or null for a new entry
-	 * @param boolean $deleted=null can be set to true to let the tracking know the item got deleted or undelted
+	 * @param array $old =null old/last state of the entry or null for a new entry
+	 * @param boolean $deleted =null can be set to true to let the tracking know the item got deleted or undelted
 	 * @return boolean true on success, false on error (error messages are in $this->errors)
 	 */
 	public function do_notifications($data,$old,$deleted, $changes)
 	{
-		$success = True;
 		$skip = $this->get_config('skip_notify',$data,$old);
 		$email_notified = $skip ? $skip : array();
 
@@ -189,7 +190,7 @@ class tracker_tracking extends bo_tracking
 		$data['tr_private'] = true;
 
 		// Send notification - $email_notified will be skipped
-		$success = $success && parent::do_notifications($data, $old, $deleted, $email_notified);
+		$success = parent::do_notifications($data, $old, $deleted, $email_notified);
 
 		//error_log(__METHOD__.__LINE__." email notified with restricted comments:".array2string($email_notified));
 
@@ -217,26 +218,28 @@ class tracker_tracking extends bo_tracking
 			$this->creator_field = $creator_field;
 		}
 		$data['tr_private'] = $private;
-		$already_notified = $email_notified;
-		$success = $success && parent::do_notifications($data, $old, $deleted, $email_notified);
+		//$already_notified = $email_notified;
+		$ret = $success && parent::do_notifications($data, $old, $deleted, $email_notified);
 		//error_log(__METHOD__.__LINE__." email notified, restricted comments removed:".array2string(array_diff($email_notified,$already_notified)));
 
-		return $success;
+		return $ret;
 	}
 
 	/**
 	 * Get a notification-config value
 	 *
-	 * @param string $what
+	 * @param string $name
 	 * 	- 'copy' array of email addresses notifications should be copied too, can depend on $data
 	 *  - 'lang' string lang code for copy mail
 	 *  - 'sender' string send email address
 	 * @param array $data current entry
-	 * @param array $old=null old/last state of the entry or null for a new entry
+	 * @param array $old =null old/last state of the entry or null for a new entry
 	 * @return mixed
 	 */
 	function get_config($name,$data,$old=null)
 	{
+		unset($old);	// not used
+
 		$tracker = $data['tr_tracker'];
 
 		$config = $this->tracker->notification[$tracker][$name] ? $this->tracker->notification[$tracker][$name] : $this->tracker->notification[0][$name];
@@ -260,7 +263,7 @@ class tracker_tracking extends bo_tracking
 	}
 
 	/**
-	 * Get the subject for a given entry, reimplementation for get_subject in bo_tracking
+	 * Get the subject for a given entry, reimplementation for get_subject in Api\Storage\Tracking
 	 *
 	 * Default implementation uses the link-title
 	 *
@@ -270,6 +273,8 @@ class tracker_tracking extends bo_tracking
 	 */
 	function get_subject($data,$old)
 	{
+		unset($old);	// not used
+
 		return $data['prefix'] . $this->tracker->trackers[$data['tr_tracker']].' #'.$data['tr_id'].': '.$data['tr_summary'];
 	}
 
@@ -289,10 +294,10 @@ class tracker_tracking extends bo_tracking
 	{
 		$notification = $this->tracker->notification[$data['tr_tracker']];
 		$merge = new tracker_merge();
-		
+
 		// Set comments according to data, avoids re-reading from DB
 		if (isset($data['replies'])) $merge->set_comments($data['tr_id'], $data['replies']);
-		
+
 		if(trim(strip_tags($notification['message'])) == '' || !$notification['use_custom'])
 		{
 			$notification['message'] = $this->tracker->notification[0]['message'];
@@ -310,6 +315,7 @@ class tracker_tracking extends bo_tracking
 		}
 		else
 		{
+			$error = null;
 			$notification['signature'] = $merge->merge_string($notification['signature'], array($data['tr_id']), $error, 'text/html');
 		}
 
@@ -330,14 +336,18 @@ class tracker_tracking extends bo_tracking
 			error_log($error);
 			return parent::get_body($html_email,$data,$old,$integrate_link,$receiver)."\n".$notification['signature'];
 		}
-		return $html_email ? $message : translation::convertHTMLToText(html::purify($message), false, true, true);
+		return $html_email ? $message : Api\Mail\Html::convertHTMLToText(Api\Html::purify($message), false, true, true);
 	}
 
 	/**
 	 * Override parent to return nothing, it's taken care of in get_body()
+	 *
 	 * @see get_body()
 	 */
-	protected function get_signature($data,$old,$receiver) {
+	protected function get_signature($data,$old,$receiver)
+	{
+		unset($data,$old,$receiver);	// not used
+
 		return false;
 	}
 
@@ -361,12 +371,12 @@ class tracker_tracking extends bo_tracking
 		if (!$data['tr_modified'] || !$old)
 		{
 			$r[] = lang('New ticket submitted by %1 at %2',
-				common::grab_owner_name($data['tr_creator']),
+				Api\Accounts::username($data['tr_creator']),
 				$this->datetime($data['tr_created_servertime']));
 			return $r;
 		}
 		$r[] = lang('Ticket modified by %1 at %2',
-			$data['tr_modifier'] ? common::grab_owner_name($data['tr_modifier']) : lang('Tracker'),
+			$data['tr_modifier'] ? Api\Accounts::username($data['tr_modifier']) : lang('Tracker'),
 			$this->datetime($data['tr_modified_servertime']));
 		return $r;
 	}
@@ -381,7 +391,7 @@ class tracker_tracking extends bo_tracking
 	 */
 	function get_details($data)
 	{
-		static $cats,$versions,$statis,$priorities,$resolutions;
+		static $cats=null,$versions=null,$statis=null,$priorities=null,$resolutions=null;
 		if (!$cats)
 		{
 			$cats = $this->tracker->get_tracker_labels('cat',$data['tr_tracker']);
@@ -394,7 +404,7 @@ class tracker_tracking extends bo_tracking
 		{
 			foreach($data['tr_assigned'] as $uid)
 			{
-				$assigned[] = common::grab_owner_name($uid);
+				$assigned[] = Api\Accounts::username($uid);
 			}
 			$assigned = implode(', ',$assigned);
 		}
@@ -417,7 +427,7 @@ class tracker_tracking extends bo_tracking
 			'tr_resolution'  => lang($resolutions[$data['tr_resolution']]),
 			'tr_completion'  => (int)$data['tr_completion'].'%',
 			'tr_priority'    => lang($priorities[$data['tr_priority']]),
-			'tr_creator'     => common::grab_owner_name($data['tr_creator']),
+			'tr_creator'     => Api\Accounts::username($data['tr_creator']),
 			'tr_created'     => $this->datetime($data['tr_created']),
 			'tr_assigned'	 => !$data['tr_assigned'] ? lang('Not assigned') : $assigned,
 			'tr_cc'			 => $data['tr_cc'],
@@ -427,7 +437,7 @@ class tracker_tracking extends bo_tracking
 		);
 
 		// Don't show start date / due date if disabled or not set
-		$config = config::read('tracker');
+		$config = Api\Config::read('tracker');
 		if(!$config['show_dates'])
 		{
 			unset($detail_fields['tr_startdate']);
@@ -456,7 +466,7 @@ class tracker_tracking extends bo_tracking
 			foreach($data['replies'] as $n => $reply)
 			{
 				$details[$n ? 2*$n : 'replies'] = array(	// first reply need to be checked against old to marked modified for new
-					'value' => lang('Comment by %1 at %2:',$reply['reply_creator'] ? common::grab_owner_name($reply['reply_creator']) : lang('Tracker'),
+					'value' => lang('Comment by %1 at %2:',$reply['reply_creator'] ? Api\Accounts::username($reply['reply_creator']) : lang('Tracker'),
 						$this->datetime($reply['reply_servertime'])),
 					'type'  => 'reply',
 				);
@@ -484,7 +494,7 @@ class tracker_tracking extends bo_tracking
 	 * - tr_completion is postfixed with a percent
 	 *
 	 * @param array $data
-	 * @param array $old=null
+	 * @param array $old =null
 	 * @return array of keys with different values in $data and $old
 	 */
 	public function changed_fields(array $data,array $old=null)
