@@ -193,7 +193,18 @@ class tracker_ui extends tracker_bo
 				{
 					$this->data['tr_tracker'] = $regardInInit['tr_tracker'] = (int)$_GET['tracker'];
 				}
-				$this->data['tr_priority'] = $regardInInit['tr_priority'] = 5;
+				// State can have more than one tracker selected, edit has only 1
+				if(is_array($this->data['tr_tracker']))
+				{
+					$this->data['tr_tracker'] = $regardInInit['tr_tracker']  = (int)  array_pop($this->data['tr_tracker']);
+				}
+			}
+
+
+			// Copy
+			if($_GET['tr_id'] && $_GET['makecp'])
+			{
+				$this->copy($this->data);
 			}
 			// initialize and try to merge what we already have
 			if ($needInit)
@@ -662,9 +673,9 @@ class tracker_ui extends tracker_bo
 		$account_select_pref = $GLOBALS['egw_info']['user']['preferences']['common']['account_selection'];
 		$sel_options = array(
 			'tr_tracker'  => &$this->trackers,
-			'cat_id'      => $this->get_tracker_labels('cat',$tracker),
+			'cat_id'      => $this->get_tracker_labels('cat',is_array($tracker) && count($tracker) == 1?$tracker[0]:$tracker),
 			'tr_version'  => $this->get_tracker_labels('version',$tracker),
-			'tr_priority' => $this->get_tracker_priorities($tracker,$content['cat_id']),
+			'tr_priority' => $this->get_tracker_priorities($tracker,$content['cat_id'], true, $default_priority),
 			'tr_status'   => &$statis,
 			'tr_resolution' => $this->get_tracker_labels('resolution',$tracker),
 			'tr_assigned' => $account_select_pref == 'none' ? array() : $this->get_staff($tracker,$this->allow_assign_groups,$this->allow_assign_users?'usersANDtechnicians':'technicians'),
@@ -674,6 +685,12 @@ class tracker_ui extends tracker_bo
 			'canned_response' => $this->get_tracker_labels('response'),
 		);
 
+		// Keep updating priority to default until it's saved
+		if(!$tr_id)
+		{
+			$content['tr_priority'] = (int)$default_priority;
+		}
+
 		foreach($this->field2history as $field => $status)
 		{
 			$sel_options['status'][$status] = $this->field2label[$field];
@@ -775,7 +792,8 @@ class tracker_ui extends tracker_bo
 		$query = $query_in;
 		if (!$query['csv_export'])	// do not store query for csv-export in session
 		{
-			Api\Cache::setSession('tracker',$query['session_for'] ? $query['session_for'] : 'index'.($query_in['only_tracker'] ? '-'.$query_in['only_tracker'] : ''),$query);
+			Api\Cache::setSession('tracker',$query['session_for'] ? $query['session_for'] : 'index'.($query_in['only_tracker'] ? '-'.$query_in['only_tracker'] : ''),
+				array_diff_key ($query, array_flip(array('rows','actions','action_links','placeholder_actions'))));
 		}
 		// save the state of the index page (filters) in the user prefs
 		// need to save state, before resolving diverse col-filters, eg. to all group-members or sub-cats
@@ -1057,11 +1075,13 @@ class tracker_ui extends tracker_bo
 		$set = array();
 		if ((int)$data['id'] && ($ticket = $this->read($data['id'])))
 		{
+			// Timesheet and files are always excluded
+			$excluded_apps = array('timesheet',Link::VFS_APPNAME) + $this->exclude_app_on_timesheetcreation;
+
 			//error_log(__METHOD__.__LINE__.$this->exclude_app_on_timesheetcreation);
 			foreach(Link::get_links('tracker',$ticket['tr_id'],'','link_lastmod DESC',true) as $link)
 			{
-				//if ($link['app'] != 'timesheet' && $link['app'] != Link::VFS_APPNAME)
-				if (stripos($this->exclude_app_on_timesheetcreation.','.'timesheet'.','.Link::VFS_APPNAME,$link['app'])===false)
+				if (!in_array($link['app'], $excluded_apps))
 				{
 					$set['link_app'][] = $link['app'];
 					$set['link_id'][]  = $link['id'];
@@ -1297,7 +1317,7 @@ class tracker_ui extends tracker_bo
 			{
 				$date_filters[$name] = lang($name);
 			}
-			$date_filters['custom'] = 'custom';
+			$date_filters['custom'] = lang('custom');
 			$content['nm'] = array(
 				'get_rows'       =>	'tracker.tracker_ui.get_rows',
 				'cat_is_select'  => 'no_lang',
@@ -1380,7 +1400,7 @@ class tracker_ui extends tracker_bo
 		{
 			$content['nm']['favorites'] = true; // Enable favorites
 		}
-		$content['duration_format'] = $this->duration_format;
+		$content['duration_format'] = ','.$this->duration_format;
 
 		$content['is_admin'] = $this->is_admin($tracker);
 		//_debug_array($content);
@@ -1453,6 +1473,10 @@ width:100%;
 		{
 			$percent[$i] = $i.'%';
 		}
+		// Find the ID for 'Fixed' resolution, used below
+		$resolution_fixed = key(array_filter($this->get_tracker_labels('resolution'), function($a) {
+			return $a == 'Fixed';
+		}));
 		$actions = array(
 			'open' => array(
 				'caption' => 'Open',
@@ -1474,8 +1498,21 @@ width:100%;
 			'add' => array(
 				'caption' => 'Add',
 				'group' => $group,
-				'url' => 'menuaction=tracker.tracker_ui.edit',
-				'popup' => Link::get_registry('tracker', 'add_popup'),
+				'children' => array(
+					'new' => array(
+						'caption' => 'New',
+						'url' => 'menuaction=tracker.tracker_ui.edit',
+						'popup' => Link::get_registry('tracker', 'add_popup'),
+						'icon' => 'new',
+					),
+					'copy' => array(
+						'caption' => 'Copy',
+						'url' => 'menuaction=tracker.tracker_ui.edit&makecp=1&tr_id=$id',
+						'popup' => Link::get_registry('tracker', 'add_popup'),
+						'allowOnMultiple' => false,
+						'icon' => 'copy',
+					),
+				),
 				'hideOnMobile' => true
 			),
 			'no_notifications' => array(
@@ -1572,6 +1609,12 @@ width:100%;
 				'group' => $group,
 				'disableClass' => 'rowNoClose',
 			),
+			'close_100_'.$resolution_fixed => array(
+				'caption' => lang('Close') . ' - 100% ' . lang('fixed'),
+				'icon' => 'check',
+				'group' => $group,
+				'disableClass' => 'rowNoClose',
+			),
 
 			'admin' => array(
 				'caption' => 'Multiple changes',
@@ -1736,11 +1779,24 @@ width:100%;
 			{
 				case 'close':
 					$action_msg = lang('closed');
+					if(is_string($settings)) // ex: closed-100-fixed
+					{
+						$settings = explode('_', $settings);
+					}
 					foreach($checked as $tr_id)
 					{
 						if (!$this->read($tr_id)) continue;
 						$this->data['tr_status'] = tracker_bo::STATUS_CLOSED;
 						if($no_notification) $this->data['no_notifications'] = true;
+
+						if($settings[0])
+						{
+							$this->data['tr_completion'] = $settings[0];
+						}
+						if($settings[1])
+						{
+							$this->data['tr_resolution'] = $settings[1];
+						}
 						if (!$this->save())
 						{
 							$success++;
@@ -1932,4 +1988,67 @@ width:100%;
 
 		$this->index(null);
 	}
+
+	/**
+	 * Copy a given ticket (not storing it!)
+	 *
+	 * Taken care only configured fields get copied and certain fields never to copy (uid etc.).
+	 *
+	 * @param array& $content
+	 */
+	function copy(array &$content)
+	{
+		$id = $content['tr_id'];
+
+		$exclude_fields = array('tr_id', 'tr_closed', 'tr_seen',
+			'tr_created', 'tr_modified', 'tr_modifier'
+		);
+		foreach ($exclude_fields as $field)
+		{
+			unset($content[$field]);
+		}
+		// startdate in the past --> set startdate
+		if ($content['tr_startdate'] && $content['tr_startdate'] < Api\DateTime::to('now'))
+		{
+			$content['tr_startdate'] = Api\DateTime::to('now');
+		}
+		// duedate in the past --> unset it
+		if (isset($content['tr_duedate']) && $content['tr_duedate'] < Api\DateTime::to('now'))
+		{
+			unset($content['tr_duedate']);
+		}
+
+		if(!is_array($content['link_to'])) $content['link_to'] = array();
+		$content['link_to']['to_app'] = 'tracker';
+		$content['link_to']['to_id'] = 0;
+		// Get links to be copied, if not excluded
+		if (!in_array('link_to',$exclude_fields) || !in_array('attachments',$exclude_fields))
+		{
+			foreach(Link::get_links($content['link_to']['to_app'], $id) as $link)
+			{
+				if ($link['app'] != Link::VFS_APPNAME && !in_array('link_to', $exclude_fields))
+				{
+					Link::link('tracker', $content['link_to']['to_id'], $link['app'], $link['id'], $link['remark']);
+				}
+				elseif ($link['app'] == Link::VFS_APPNAME && !in_array('attachments', $exclude_fields))
+				{
+					Link::link('tracker', $content['link_to']['to_id'], Link::VFS_APPNAME, array(
+						'tmp_name' => Link::vfs_path($link['app2'], $link['id2']).'/'.$link['id'],
+						'name' => $link['id'],
+					), $link['remark']);
+				}
+			}
+		}
+		$content['links'] = $content['link_to'];
+
+		$content['tr_owner'] = !(int)$content['owner'] || !$this->bo->check_perms(Acl::ADD,0,$content['owner']) ? $this->user : $this->owner;
+
+		if (!empty($content['tr_summary']))
+		{
+			$content['tr_summary'] = lang('Copy of:').' '.$content['tr_summary'];
+		}
+
+		$content['msg'] .= ($content['msg']?"\n":'').lang('%1 copied - the copy can now be edited', lang(Link::get_registry('tracker','entry')));
+	}
+
 }
