@@ -1,15 +1,18 @@
 <?php
 /**
- * eGroupware Wiki - User interface
+ * EGroupware Wiki - User interface
  *
  * @link http://www.egroupware.org
  * @package wiki
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (C) 2004-10 by RalfBecker-AT-outdoor-training.de
+ * @copyright (C) 2004-17 by RalfBecker-AT-outdoor-training.de
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+
 class wiki_ui extends wiki_bo
 {
 	var $public_functions = array(
@@ -22,7 +25,7 @@ class wiki_ui extends wiki_bo
 	/**
 	 * Constructor
 	 *
-	 * @param int $wiki_id=null wiki_id to pass on to parent if specified, otherwise $_GET['wiki_id'] is used
+	 * @param int $wiki_id =null wiki_id to pass on to parent if specified, otherwise $_GET['wiki_id'] is used
 	 */
 	function __construct($wiki_id=null)
 	{
@@ -30,8 +33,6 @@ class wiki_ui extends wiki_bo
 
 		$this->anonymous = $this->config['allow_anonymous'] && $this->config['anonymous_username'] == $GLOBALS['egw_info']['user']['account_lid'];
 
-		$this->tpl = new etemplate();
-
 		// should pages with wiki-syntax be converted to html automaticaly
 		switch($this->AutoconvertPages)
 		{
@@ -42,7 +43,7 @@ class wiki_ui extends wiki_bo
 				break;
 			case 'auto':
 			default:
-				$this->auto_convert = html::htmlarea_availible();
+				$this->auto_convert = Api\Html::htmlarea_availible();
 		}
 		if (get_magic_quotes_gpc())
 		{
@@ -51,6 +52,9 @@ class wiki_ui extends wiki_bo
 				$_GET[$name] = stripslashes($val);
 			}
 		}
+
+		// load app.js to automatic add target _blank to external links
+		Framework::includeJS('/wiki/js/app.js');
 	}
 
 	function uiwiki()
@@ -65,6 +69,7 @@ class wiki_ui extends wiki_bo
 
 		if (!is_array($content))
 		{
+			$content = array();
 			$content['name'] = $content ? $content : html_entity_decode($_GET['page']);
 			$content['lang'] = $_GET['lang'];
 			$content['version'] = $_GET['version'];
@@ -73,7 +78,7 @@ class wiki_ui extends wiki_bo
 		list($action) = @each($content['action']);
 		if (empty($content['name']))
 		{
-			$this->tpl->location('/wiki/');
+			Api\Egw::redirect_link('/wiki/');
 		}
 		$pg = $this->page($content['name'],$content['lang']);
 		if ($content['version'] && $action != 'load')
@@ -87,7 +92,7 @@ class wiki_ui extends wiki_bo
 		}
 		elseif (!$pg->acl_check(True))	// no read-rights
 		{
-			$this->tpl->location('/wiki/');
+			Api\Egw::redirect_link('/wiki/');
 		}
 		if ($start || $action == 'load')
 		{
@@ -108,6 +113,7 @@ class wiki_ui extends wiki_bo
 		}
 		if ($content['is_html'])
 		{
+			$content['rtfEditorFeatures'] = $GLOBALS['egw_info']['user']['preferences']['common']['rte_features'];
 			// some tavi stuff need to be at the line-end
 			$content['text'] = preg_replace(array('/(.+)(<br \\/>)/i',"/(<br \\/>\n?)+$/i"),array("\\1\n\\2",''),$content['text']);
 
@@ -126,7 +132,7 @@ class wiki_ui extends wiki_bo
 			{
 				case 'delete':
 					//error_log(__METHOD__.array2string($content));
-					if (trim($content['text'])=='' || (trim($content['text'])=='##EXPUNGE##' && trim($content['summary'])=='##EXPUNGE##'))
+					if (($content['is_html']&&trim(Api\Mail\Html::convertHTMLToText($content['text']))=='')||trim($content['text'])=='' || (trim($content['text'])=='##EXPUNGE##' && trim($content['summary'])=='##EXPUNGE##'))
 					{
 						$content['text']='##EXPUNGE##';
 						$content['comment'] = '##EXPUNGE##';
@@ -191,30 +197,30 @@ class wiki_ui extends wiki_bo
 					if(count(array_intersect($pg->memberships, $pref)) == 0 && count(array_intersect(array_keys($acl_values), $pref)) == 0)
 					{
 						$pref[] = $GLOBALS['egw_info']['user']['account_primary_group'];
-					};
+					}
 					$content[$attr] = $pref;
 				}
 			}
 		}
-		$this->tpl->read('wiki.edit');
+		$tpl = new Api\Etemplate('wiki.edit');
 
-		if ($content['is_html'] || $this->AutoconvertPages == 'never' || !html::htmlarea_availible())
+		if ($content['is_html'] || $this->AutoconvertPages == 'never' || !Api\Html::htmlarea_availible())
 		{
-			$this->tpl->disable_cells('action[convert]');
+			$tpl->disableElement('action[convert]');
 			$content['upload_dir'] = $GLOBALS['egw_info']['user']['preferences']['wiki']['upload_dir'];
 		}
 		if ($content['is_html'] || $this->AutoconvertPages != 'never')
 		{
 			// tell framework CK Editor needs eval and inline javascript AND we cant switch via Ajax once page is loaded :(
-			egw_framework::csp_script_src_attrs(array('unsafe-eval', 'unsafe-inline'));
+			Api\Header\ContentSecurityPolicy::add('script-src', array('unsafe-eval', 'unsafe-inline'));
 		}
 		$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps']['wiki']['title'] . ' - ' .
 			lang('edit') . ' ' . $content['name'] .
 			($content['lang'] && $content['lang'] != $GLOBALS['egw_info']['user']['preferences']['common']['lang'] ?
 				':' . $content['lang'] : '').
 			($content['name'] != $content['title'] ? ' - ' . $content['title'] : '');
-		$this->tpl->exec('wiki.wiki_ui.edit',$content,array(
-			'lang'     => array('' => lang('not set')) + $GLOBALS['egw']->translation->get_installed_langs(),
+		$tpl->exec('wiki.wiki_ui.edit',$content,array(
+			'lang'     => array('' => lang('not set')) + Api\Translation::get_installed_langs(),
 			'readable' => $acl_values,
 			'writable' => $acl_values,
 		),null,array(
@@ -240,13 +246,13 @@ class wiki_ui extends wiki_bo
 
 		if ($page->read() === false)
 		{
-			$html = '<p><b>'.lang("Page '%1' not found !!!",'<i>'.html::htmlspecialchars($_GET['page'].
+			$html = '<p><b>'.lang("Page '%1' not found !!!",'<i>'.Api\Html::htmlspecialchars($_GET['page'].
 				($_GET['lang']?':'.$_GET['lang']:'')).'</i>')."</b></p>\n";
 			$page = false;
 		}
 		if ($page && !$page->acl_check(True))	// no read-rights
 		{
-			$this->tpl->location('/wiki/');
+			Api\Egw::redirect_link('/wiki/');
 		}
 		$html = $this->header($page).$html;
 		if ($page) $html .= $this->get($page,'',$this->wiki_id);
@@ -261,14 +267,14 @@ class wiki_ui extends wiki_bo
 	/**
 	 * Show the page-header for the manual
 	 *
-	 * @param object/boolean $page sowikipage object or false
+	 * @param object|boolean $page sowikipage object or false
  	 * @param string $title title of the search
 	 */
 	function header($page=false,$title='')
 	{
 		// anonymous sessions have no navbar !!!
 		$GLOBALS['egw_info']['flags']['nonavbar'] = $this->config['allow_anonymous'] != 'Navbar' && $this->anonymous;
-		$GLOBALS['egw']->common->egw_header();
+		echo $GLOBALS['egw']->framework->header();
 
 		if ($page)
 		{
@@ -279,11 +285,25 @@ class wiki_ui extends wiki_bo
 		}
 		$html = '<h1 style="margin:0px;" class="title">'.$title."</h1>\n";
 
-		$html .= '<form action="'.$GLOBALS['egw']->link('/index.php',array('menuaction'=>'wiki.wiki_ui.search')).'" method="POST" class="noPrint">'.
+		if (Api\Header\UserAgent::mobile())
+		{
+			$editable = $page?($page->acl_check()?true:false):false;
+			$html .= '<form action="'.$GLOBALS['egw']->link('/index.php',array('menuaction'=>'wiki.wiki_ui.search')).'" method="POST" class="noPrint searchBox">'.
+				'<input name="search" placeholder="search here..." value="'.Api\Html::htmlspecialchars($_REQUEST['search']).'" /> '.
+				'<input type="submit" name="go" value=""/>'.
+				'<a class="wikiHome" href="'.$this->viewURL($this->config['wikihome']).'"></a>'.
+				'<a class="recentChanges" href="'.$this->viewUrl('RecentChanges').'"></a>'.
+				'<a class="editButton'.(!$editable?" disabled":"").'" href="'.htmlspecialchars($this->editURL($page->name,$page->lang,$page->version)).'"></a>'.
+				'</form> '."\n";
+		}
+		else
+		{
+			$html .= '<form action="'.$GLOBALS['egw']->link('/index.php',array('menuaction'=>'wiki.wiki_ui.search')).'" method="POST" class="noPrint">'.
 			'<a href="'.$this->viewURL($this->config['wikihome']).'">'.$this->link_title($this->config['wikihome']).'</a> | '.
 			'<a href="'.$this->viewUrl('RecentChanges').'">'.lang('Recent Changes').'</a> | '.
-			'<input name="search" value="'.html::htmlspecialchars($_REQUEST['search']).'" /> '.
-			'<input type="submit" name="go" value="'.html::htmlspecialchars(lang('Search')).'" /></form>'."\n";
+				'<input name="search" value="'.Api\Html::htmlspecialchars($_REQUEST['search']).'" /> '.
+				'<input type="submit" name="go" value="'.Api\Html::htmlspecialchars(lang('Search')).'" /></form>'."\n";
+		}
 		$html .= "<hr />\n";
 
 		return $html;
@@ -292,7 +312,7 @@ class wiki_ui extends wiki_bo
 	/**
 	 * Show the page-footer for the manual
 	 *
-	 * @param object/boolean $page sowikipage object or false
+	 * @param object|boolean $page sowikipage object or false
  	 */
 	function footer($page=false)
 	{
@@ -300,13 +320,15 @@ class wiki_ui extends wiki_bo
 
 		if ($page)
 		{
-			$parts[] = $page->acl_check() ? '<a href="'.htmlspecialchars($this->editURL($page->name,$page->lang,$page->version)).'" class="noPrint">'.
-				($page->supercede == $page->time ? lang('Edit this document') : lang('Edit this <em>ARCHIVE VERSION</em> of this document')).'</a>' :
-				lang('This page can not be edited.');
+			if (!Api\Header\UserAgent::mobile())
+			{
+				$parts[] = $page->acl_check() ? '<a class="editButton" href="'.htmlspecialchars($this->editURL($page->name,$page->lang,$page->version)).'" class="noPrint">'.
+					($page->supercede == $page->time ? lang('Edit this document') : lang('Edit this <em>ARCHIVE VERSION</em> of this document')).'</a>' :
+					lang('This page can not be edited.');
 
-			$parts[] = '<a href="'.htmlspecialchars($this->historyURL($page->name,false,$page->lang)).'" class="noPrint">'.lang('View document history').'</a>';
-
-			$parts[] = lang('Document last modified').': '.html_time($page->time);
+				$parts[] = '<a class="viewButton" href="'.htmlspecialchars($this->historyURL($page->name,false,$page->lang)).'" class="noPrint">'.lang('View document history').'</a>';
+			}
+			$parts[] = '<span class="lastModified">'.lang('Document last modified').': '.html_time($page->time).'</span>';
 		}
 		return $parts ? "<hr />\n".implode('<span class="noPrint"> | </span>',$parts) : '';
 	}
@@ -320,7 +342,7 @@ class wiki_ui extends wiki_bo
 
 		if (strlen(trim($_REQUEST['search']))==0) $_REQUEST['search'] = '*';
 
-		$html = $this->header(false,lang('Search for').': '.(trim($_REQUEST['search'])=='*'?lang('everything'):html::htmlspecialchars($_REQUEST['search'])));
+		$html = $this->header(false,lang('Search for').': '.(trim($_REQUEST['search'])=='*'?lang('everything'):Api\Html::htmlspecialchars($_REQUEST['search'])));
 
 		$nothing_found = true;
 		foreach($this->find(str_replace(array('*','?'),array('%','_'),$_REQUEST['search'])) as $page)
@@ -330,9 +352,9 @@ class wiki_ui extends wiki_bo
 				$nothing_found = false;
 				$html .= "<ul>\n";
 			}
-			$item = '<li><a href="'.htmlspecialchars($this->viewURL($page['name'],$page['lang'])).'"><b>'.html::htmlspecialchars($page['title']).'</b></a>'.
-				($page['lang'] != $this->lang ? ' <i>'.html::htmlspecialchars($GLOBALS['egw']->translation->lang2language($page['lang'])).'</i>' : '').'<br />'.
-				html::htmlspecialchars($this->summary($page))."</li>\n";
+			$item = '<li><a href="'.htmlspecialchars($this->viewURL($page['name'],$page['lang'])).'"><b>'.Api\Html::htmlspecialchars($page['title']).'</b></a>'.
+				($page['lang'] != $this->lang ? ' <i>'.Api\Html::htmlspecialchars(Api\Translation::lang2language($page['lang'])).'</i>' : '').'<br />'.
+				Api\Html::htmlspecialchars($this->summary($page))."</li>\n";
 
 			if ($page['lang'] != $this->lang)
 			{
