@@ -12,14 +12,14 @@
 
 $setup_info['wiki']['name']      = 'wiki';
 $setup_info['wiki']['title']     = 'Wiki';
-$setup_info['wiki']['version']   = '14.1';
+$setup_info['wiki']['version']   = '16.1';
 $setup_info['wiki']['app_order'] = 11;
 $setup_info['wiki']['enable']    = 1;
 
 $setup_info['wiki']['author']    = 'Tavi Team';
 $setup_info['wiki']['license']   = 'GPL';
 $setup_info['wiki']['description'] =
-	'Wiki is a modified and enhanced version of <a href="http://tavi.sf.net" target="_new">WikkiTikkiTavi</a> for use with eGroupware.';
+	'Wiki is a modified and enhanced version of <a href="http://tavi.sf.net" target="_new">WikkiTikkiTavi</a> for use with EGroupware.';
 $setup_info['wiki']['maintainer'] = 'Ralf Becker';
 $setup_info['wiki']['maintainer_email'] = 'RalfBecker@outdoor-training.de';
 
@@ -48,11 +48,6 @@ $setup_info['wiki']['check_install'] = array(
 /* Dependencies for this app to work */
 $setup_info['wiki']['depends'][] = array
 (
-	'appname'  => 'phpgwapi',
-	'versions' => Array('1.9','14.1')
-);
-$setup_info['wiki']['depends'][] = array
-(
-	'appname'  => 'etemplate',
-	'versions' => Array('1.9','14.1')
+	'appname'  => 'api',
+	'versions' => Array('16.1')
 );
